/*-------------------------------------------------------------------------
 |                                                                         
 |                    SAS SETUP FILE FOR ICPSR 06852
 |             NATIONAL HOUSEHOLD SURVEY ON DRUG ABUSE, 1993
 |
 |
 | SAS setup sections are provided for the ASCII version of this data
 | collection.  These sections are listed below:
 |
 | PROC FORMAT:  creates user-defined formats for the variables. Formats
 | replace original value codes with value code descriptions. Only
 | variables with user-defined formats are included in this section.
 |
 | DATA:  begins a SAS data step and names an output SAS data set.
 |
 | INFILE:  identifies the input file to be read with the input statement.
 | Users must replace the "data-filename" with a filename specifying the
 | directory on the user's computer system in which the downloaded and
 | unzipped data file is physically located (e.g.,
 | "c:\temp\06852-0001-data.txt").
 |
 | INPUT:  assigns the name, type, decimal specification (if any), and
 | specifies the beginning and ending column locations for each variable
 | in the data file.
 |
 | LABEL:  assigns descriptive labels to all variables. Variable labels
 | and variable names may be identical for some variables.
 |
 | MISSING VALUE RECODES:  sets user-defined numeric missing values to
 | missing as interpreted by the SAS system. Only variables with
 | user-defined missing values are included in this section.
 |
 | If any variables have more than one missing value, they are assigned
 | to the standard missing value of a single period (.) in the statement
 | below. To maintain the original meaning of missing codes, users may want
 | to take advantage of the SAS missing values (the letters A-Z or an
 | underscore preceded by a period).
 |
 | An example of a standard missing value recode:
 |
 |   IF (RELATION = 98 OR RELATION = 99) THEN RELATION = .; 
 |
 | The same example using special missing value recodes:
 |
 |    IF RELATION = 98 THEN RELATION = .A;
 |    IF RELATION = 99 THEN RELATION = .B;
 |
 | FORMAT:  associates the formats created by the PROC FORMAT step with
 | the variables named in the INPUT statement.
 |
 | NOTE:  Users should modify this setup file to suit their specific needs.
 | Sections for PROC FORMAT, FORMAT, and MISSING VALUE RECODES have been
 | commented out (i.e., '/*'). To include these sections in the final SAS
 | setup, users should remove the SAS comment indicators from the desired
 | section(s).
 |
 |------------------------------------------------------------------------*/

* SAS PROC FORMAT;

/*
PROC FORMAT;
  VALUE cigtry    985='(985) BAD DATA Logically assigned'
                  991='(991) NEVER USED CIGARETTES' 994='(994) DON''T KNOW' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE cig5pk    1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED'
                  81='(81) NEVER USED CIGARETTES Logically assigned'
                  91='(91) NEVER USED CIGARETTES' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cigage    981='(981) NEVER USED CIGARETTES Logically assigned'
                  985='(985) BAD DATA Logically assigned'
                  989='(989) LEGITIMATE SKIP Logically assigned'
                  991='(991) NEVER USED CIGARETTES' 993='(993) NEVER SMOKED DAILY'
                  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE cigyrs    985='(985) BAD DATA Logically assigned'
                  991='(991) NEVER USED CIGARETTES' 994='(994) DON''T KNOW' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE packs     1='(1) One to five cigarettes a day'
                  2='(2) About 1/2 pack a day (6-15 cigarettes)'
                  3='(3) About a pack a day (16-25 cigarettes)'
                  4='(4) About 1 1/2 packs a day (26-35 cigarettes)'
                  5='(5) About 2 packs or more a day (over 35 cigarettes)'
                  91='(91) NEVER USED CIGARETTES' 94='(94) DON''T KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE cigrec    1='(1) Within the past month(30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago'
                  7='(7) Use in past 30 days LOGICALLY IMPUTED'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER USED CIGARETTES' 94='(94) DON''T KNOW'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE avcig     1='(1) Less than one cigarette a day'
                  2='(2) One to five cigarettes a day'
                  3='(3) About 1/2 pack a day (6-15 cigarettes)'
                  4='(4) About a pack a day (16-25 cigarettes)'
                  5='(5) About 1 1/2 packs a day (26-35 cigarettes)'
                  6='(6) About 2 packs or more a day (over 35 cigarettes)'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  91='(91) NEVER USED CIGARETTES' 94='(94) DON''T KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE cigtime   9981='(9981) NEVER USED CIGARETTES Logically assigned'
                  9985='(9985) BAD DATA Logically assigned'
                  9989='(9989) LEGITIMATE SKIP Logically assigned'
                  9991='(9991) NEVER USED CIGARETTES' 9994='(9994) DON''T KNOW'
                  9997='(9997) REFUSED' 9998='(9998) BLANK (NO ANSWER)'
                  9999='(9999) LEGITIMATE SKIP' ;
  VALUE snufrec   1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER USED SMOKELESS TOBACCO' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE othtob    1='(1) Daily in the past 12 Months'
                  2='(2) Almost daily (3-6 days a week)' 3='(3) 1 or 2 days a week'
                  4='(4) Several times a month (25-51 days a year)'
                  5='(5) 1 or 2 times a month (12-24 days a year)'
                  6='(6) Every other month or so (6-11 days a year)'
                  7='(7) 3-5 days this past year' 8='(8) 1 or 2 days this past year'
                  83='(83) DID NOT USE SMOKELESS TOBACCO PST YR Logic.assgn.'
                  91='(91) NEVER USED SMOKELESS TOBACCO' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE alctry    981='(981) NEVER USED ALCOHOL Logically assigned'
                  985='(985) BAD DATA Logically assigned' 991='(991) NEVER USED ALCOHOL'
                  994='(994) DON''T KNOW' 998='(998) BLANK (NO ANSWER)' ;
  VALUE alcrec    1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago'
                  7='(7) Use in past 30 days LOGICALLY IMPUTED'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  81='(81) NEVER USED ALCOHOL Logically assigned'
                  91='(91) NEVER USED ALCOHOL' ;
  VALUE alcage    981='(981) NEVER USED ALCOHOL Logically assigned'
                  985='(985) BAD DATA Logically assigned' 991='(991) NEVER USED ALCOHOL'
                  993='(993) NEVER USED ALCOHOL MONTHLY OR MORE OFTEN'
                  994='(994) DON''T KNOW' 998='(998) BLANK (NO ANSWER)' ;
  VALUE alcdays   81='(81) NEVER USED ALCOHOL Logically assigned'
                  83='(83) DID NOT USE ALCOHOL IN THE PAST 30 DAYS Logic Asn'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ALCOHOL'
                  93='(93) DID NOT USE ALCOHOL IN THE PAST 30 DAYS'
                  94='(94) DON''T KNOW' 95='(95) BAD DATA' 98='(98) BLANK (NO ANSWER)' ;
  VALUE nodr30a   81='(81) NEVER USED ALCOHOL Logically assigned'
                  83='(83) DID NOT USE ALCOHOL IN THE PAST 30 DAYS Logic Asn'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ALCOHOL'
                  93='(93) DID NOT USE ALCOHOL IN THE PAST 30 DAYS'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE dr5day    81='(81) NEVER USED ALCOHOL Logically assigned'
                  83='(83) DID NOT USE ALCOHOL IN THE PAST 30 DAYS Logic Asn'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ALCOHOL'
                  93='(93) DID NOT USE ALCOHOL IN THE PAST 30 DAYS'
                  94='(94) DON''T KNOW' 95='(95) BAD DATA' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE modr30a   81='(81) NEVER USED ALCOHOL Logically assigned'
                  83='(83) DID NOT USE ALCOHOL IN THE PAST 30 DAYS Logic Asn'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ALCOHOL'
                  93='(93) DID NOT USE ALCOHOL IN THE PAST 30 DAYS'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE modr30dy  81='(81) NEVER USED ALCOHOL Logically assigned'
                  83='(83) DID NOT USE ALCOHOL IN THE PAST 30 DAYS Logic Asn'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ALCOHOL'
                  93='(93) DID NOT USE ALCOHOL IN THE PAST 30 DAYS'
                  94='(94) DON''T KNOW' 95='(95) BAD DATA' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE alcpat    1='(1) Daily in the past 12 months'
                  2='(2) Almost daily or 3 to 6 days a week'
                  3='(3) About 1 or 2 days a week'
                  4='(4) Several times a month (about 25 to 51 days a year)'
                  5='(5) 1 to 2 times a month (12 to 24 days a year)'
                  6='(6) Every other month or so (6 to 11 days a year)'
                  7='(7) 3 to 5 days in the past 12 months'
                  8='(8) 1 or 2 days in the past 12 months'
                  81='(81) NEVER USED ALCOHOL Logically assigned'
                  83='(83) DID NOT USE ALCOHOL PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ALCOHOL'
                  93='(93) DID NOT USE ALCOHOL IN THE PAST 12 MONTHS'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE drunkyr   1='(1) Daily in the past 12 months'
                  2='(2) Almost daily or 3 to 6 days a week'
                  3='(3) About 1 or 2 days a week'
                  4='(4) Several times a month (about 25 to 51 days a year)'
                  5='(5) 1 to 2 times a month (12 to 24 days a year)'
                  6='(6) Every other month or so (6 to 11 days a year)'
                  7='(7) 3 to 5 days in the past 12 months'
                  8='(8) 1 or 2 days in the past 12 months'
                  9='(9) Never got very high or drunk in past 12 months'
                  81='(81) NEVER USED ALCOHOL Logically assigned'
                  83='(83) DID NOT USE ALCOHOL PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ALCOHOL'
                  93='(93) DID NOT USE ALCOHOL IN THE PAST 12 MONTHS'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE alcbeer   1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED ALCOHOL Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ALCOHOL'
                  94='(94) DON''T KNOW' ;
  VALUE alcwine   1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED ALCOHOL Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ALCOHOL' ;
  VALUE alcliqr   1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED ALCOHOL Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ALCOHOL' ;
  VALUE alcvary   1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED ALCOHOL Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ALCOHOL' ;
  VALUE nosedat   1='(1) Response circled' 2='(2) Response not circled'
                  4='(4) Response not circled LOGICALLY IMPUTED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE butisol   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE buticaps  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE amytal    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE mebaral   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE placidyl  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE doriden   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE noludar   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE nembutal  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE seconal   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE tuinal    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE dalmane   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE restoril  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE halcion   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE amobarb   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE phenobar  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE methaq    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE chhyd     1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE pentob    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE secob     1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE sednewa   108='(108) Nembutal' 120='(120) Downers; OTHER Sedative, NOT SPECIFIED'
                  122='(122) Sleep Aid' 127='(127) Nytol' 129='(129) Reds' 135='(135) Mini Thins'
                  137='(137) 7-14' 158='(158) Calmociteno (in Brazil)' 159='(159) Octanox'
                  160='(160) sic' 161='(161) Rufonol' 162='(162) sic' 201='(201) Valium'
                  206='(206) Tranxene' 209='(209) Xanax' 224='(224) Triavil' 311='(311) Preludin'
                  326='(326) White cross' 327='(327) Black beauties, Black Beauty'
                  339='(339) Amphetamines (speed generically)' 369='(369) Artane'
                  401='(401) Darvon' 409='(409) Tylenol with Codeine, Tylenol 3, Tylenol'
                  415='(415) Codeine' 420='(420) OTHER Analgesic, NOT SPECIFIED'
                  422='(422) Motrin' 423='(423) Percocet' 427='(427) Darvocet'
                  430='(430) Aspirin, Ecotrin, Empirin'
                  434='(434) Co-Gesic, Hydrocodone, Tussionex, Vicodin'
                  435='(435) Tylenol, Tylenol Extrastrength' 456='(456) see also 434'
                  704='(704) Dope' 811='(811) Muscle relaxers'
                  864='(864) Dramamine ,Motion sickness pill'
                  981='(981) NEVER USED SEDATIVES Logically assigned'
                  991='(991) NEVER USED SEDATIVES' 998='(998) BLANK (NO ANSWER)' ;
  VALUE sednewb   116='(116) Methaqualone, Quaalude, Sopor' 209='(209) Xanax' 244='(244) sic'
                  247='(247) Adapin, Doxepin, Sinequan' 326='(326) White cross'
                  362='(362) Benadryl' 415='(415) Codeine' 428='(428) sic'
                  991='(991) NEVER USED SEDATIVES' 998='(998) BLANK (NO ANSWER)' ;
  VALUE sednewc   809='(809) Pills' 991='(991) NEVER USED SEDATIVES'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE sednewd   991='(991) NEVER USED SEDATIVES' 998='(998) BLANK (NO ANSWER)' ;
  VALUE sednewe   991='(991) NEVER USED SEDATIVES' 998='(998) BLANK (NO ANSWER)' ;
  VALUE sednosp   1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Sedative use LOGICALLY IMPUTED'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE seddknam  1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED SEDATIVES Logically assigned'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE sedage    981='(981) NEVER USED SEDATIVES Logically assigned'
                  985='(985) BAD DATA Logically assigned'
                  991='(991) NEVER USED SEDATIVES' 994='(994) DON''T KNOW'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE sedtot    1='(1) 1 or 2 times' 2='(2) 3 to 5 times' 3='(3) 6 to 10 times'
                  4='(4) 11 to 49 times' 5='(5) 50 to 99 times' 6='(6) 100 to 199 times'
                  7='(7) 200 or more times'
                  81='(81) NEVER USED SEDATIVES Logically assigned'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE sedrec    1='(1) Within the past month(30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE sedyrfrq  1='(1) Daily in the past 12 months'
                  2='(2) Almost daily or 3 to 6 days a week'
                  3='(3) About 1 or 2 days a week'
                  4='(4) Several times a month (25 to 51 days a year)'
                  5='(5) 1 to 2 times a month (12 to 24 days a year)'
                  6='(6) Every other month or so (6 to 11 days a year)'
                  7='(7) 3 to 5 days in the past 12 months'
                  8='(8) 1 or 2 days in the past 12 months'
                  81='(81) NEVER USED SEDATIVES Logically assigned'
                  83='(83) DID NOT USE SEDATIVE PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED SEDATIVES'
                  93='(93) DID NOT USE ANY SEDATIVE IN THE PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE trnread   1='(1) Wants interviewer to continue reading'
                  2='(2) Wants to do it himself/herself' 98='(98) BLANK (NO ANSWER)' ;
  VALUE notranq   1='(1) Response circled' 2='(2) Response not circled'
                  4='(4) Response not circled LOGICALLY IMPUTED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE valium    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE librium   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE limbtrol  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE menrium   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE serax     1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE tranxene  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ativan    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE centrax   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE xanax     1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE paxipam   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE buspar    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE miltown   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE equanil   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE deprol    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE vistar    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE atarax    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE durrax    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE diazepam  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE skly      1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE meprob    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE trnewa    110='(110) Tuinal' 116='(116) Methaqualone, Quaalude, Sopor'
                  131='(131) Haldol, Haloperidol' 201='(201) Valium' 207='(207) Ativan'
                  209='(209) Xanax' 218='(218) Diazepam'
                  221='(221) OTHER Tranquilizer, NOT SPECIFIED' 227='(227) Thorazine'
                  228='(228) see also 239' 234='(234) Cyclobenzaprine, Flexeril'
                  239='(239) see also 228' 268='(268) Rahipinal'
                  269='(269) Pasidrin (in Mexico)' 270='(270) Torzien' 336='(336) Diet pills'
                  344='(344) Bennies' 415='(415) Codeine' 422='(422) Motrin' 427='(427) Darvocet'
                  430='(430) Aspirin, Ecotrin, Empirin' 437='(437) Parafon Forte'
                  438='(438) Anaprox, Naprosyn' 991='(991) NEVER USED TRANQUILIZERS'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE trnewb    128='(128) Nervine' 226='(226) Stelazine, Trifluoperazine HCl'
                  991='(991) NEVER USED TRANQUILIZERS' 998='(998) BLANK (NO ANSWER)' ;
  VALUE trnewc    230='(230) Compazine' 991='(991) NEVER USED TRANQUILIZERS'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE trnewd    991='(991) NEVER USED TRANQUILIZERS' 998='(998) BLANK (NO ANSWER)' ;
  VALUE trnewe    991='(991) NEVER USED TRANQUILIZERS' 998='(998) BLANK (NO ANSWER)' ;
  VALUE trnosp    1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Tranquilizer use LOGICALLY IMPUTED'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE trdknam   1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED TRANQUILIZERS Logically assigned'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE tranage   981='(981) NEVER USED TRANQUILIZERS Logically assigned'
                  985='(985) BAD DATA Logically assigned'
                  991='(991) NEVER USED TRANQUILIZERS' 998='(998) BLANK (NO ANSWER)' ;
  VALUE trantot   1='(1) 1 or 2 times' 2='(2) 3 to 5 times' 3='(3) 6 to 10 times'
                  4='(4) 11 to 49 times' 5='(5) 50 to 99 times' 6='(6) 100 to 199 times'
                  7='(7) 200 or more times' 91='(91) NEVER USED TRANQUILIZERS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE tranrec   1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE trnyrfrq  1='(1) Daily in the past 12 months'
                  2='(2) Almost daily or 3 to 6 days a week'
                  3='(3) About 1 or 2 days a week'
                  4='(4) Several times a month (about 25 to 51 days a year)'
                  5='(5) 1 to 2 times a month (12 to 24 days a year)'
                  6='(6) Every other month or so (6 to 11 days a year)'
                  7='(7) 3 to 5 days in the past 12 months'
                  8='(8) 1 or 2 days in the past 12 months'
                  81='(81) NEVER USED TRANQUILIZERS Logically assigned'
                  83='(83) DID NOT USE TRANQUILIZER PAST 12 MOS. Logic.assgnd'
                  85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED TRANQUILIZERS'
                  93='(93) DID NOT USE ANY TRANQUILIZER IN THE PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE stmread   1='(1) Wants interviewer to continue reading'
                  2='(2) Wants to do it himself/herself' 96='(96) MULTIPLE RESPONSE'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE nostims   1='(1) Response circled' 2='(2) Response not circled'
                  4='(4) Response not circled LOGICALLY IMPUTED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE dexed     1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE dexamyl   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE eskat     1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE benz      1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE biphet    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE desoxyn   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE tenuate   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE tepanil   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE didrex    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE plegine   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE preludin  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ionamin   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE fastin    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE pondimin  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE voranil   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE sanorex   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE mazanor   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ritalin   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE cylert    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE detamp    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE methi     1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE methamp   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE obla      1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE stimnewa  124='(124) Yellow jackets' 135='(135) Mini Thins' 145='(145) Red devil(s)'
                  301='(301) Dexedrine' 305='(305) Biphetamine' 313='(313) Fastin, Phentermine'
                  316='(316) Sanorex' 324='(324) Uppers; OTHER Stimulant, NOT SPECIFIED'
                  325='(325) USED STIMULANT, DON''T KNOW NAME' 326='(326) White cross'
                  327='(327) Black beauties, Black Beauty' 328='(328) Pink hearts'
                  329='(329) Robin''s eggs, speckled eggs' 331='(331) Whites, Blancas'
                  332='(332) see also 346' 333='(333) 357 Magnum, Magnum 44'
                  334='(334) Crossroads, cross tops' 335='(335) Dexatrim'
                  336='(336) Diet pills' 339='(339) Amphetamines (speed generically)'
                  344='(344) Bennies' 347='(347) Phenylpropanolamine' 348='(348) Crystal'
                  352='(352) Lemons' 353='(353) No-Doz' 354='(354) Vivarin' 355='(355) Crystal meth'
                  357='(357) Heart-shaped black pills' 384='(384) Little crosses'
                  385='(385) Little pink one' 386='(386) Ma Huang' 388='(388) Pink lemon'
                  389='(389) sic' 390='(390) Max Alert' 391='(391) sic'
                  409='(409) Tylenol with Codeine, Tylenol 3, Tylenol'
                  430='(430) Aspirin, Ecotrin, Empirin'
                  435='(435) Tylenol, Tylenol Extrastrength'
                  530='(530) Asthma inhaler, asthma med., bronchial dilators'
                  606='(606) sic' 621='(621) Red dragon' 635='(635) Ginseng seeds' 702='(702) Heroin'
                  803='(803) sic' 805='(805) Cocaine, coke, coca' 806='(806) Crack, rock'
                  814='(814) Caffeine' 815='(815) Coffee' 991='(991) NEVER USED STIMULANTS'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE stimnewb  124='(124) Yellow jackets' 254='(254) sic' 326='(326) White cross'
                  327='(327) Black beauties, Black Beauty' 328='(328) Pink hearts'
                  332='(332) see also 346' 334='(334) Crossroads, cross tops'
                  339='(339) Amphetamines (speed generically)' 344='(344) Bennies'
                  353='(353) No-Doz' 354='(354) Vivarin' 355='(355) Crystal meth' 363='(363) Bam(s)'
                  620='(620) Blue dragon' 805='(805) Cocaine, coke' 806='(806) Crack, rock'
                  814='(814) Caffeine' 991='(991) NEVER USED STIMULANTS'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE stimnewc  374='(374) Christmas tree(s)' 991='(991) NEVER USED STIMULANTS'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE stimnewd  387='(387) Pink football' 991='(991) NEVER USED STIMULANTS'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE stimnewe  991='(991) NEVER USED STIMULANTS' 998='(998) BLANK (NO ANSWER)' ;
  VALUE stimnosp  1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Stimulant use LOGICALLY IMPUTED'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE stmdknam  1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED STIMULANTS Logically assigned'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE stimage   981='(981) NEVER USED STIMULANTS Logically assigned'
                  985='(985) BAD DATA Logically assigned'
                  991='(991) NEVER USED STIMULANTS' 998='(998) BLANK (NO ANSWER)' ;
  VALUE stimtot   1='(1) 1 or 2 times' 2='(2) 3 to 5 times' 3='(3) 6 to 10 times'
                  4='(4) 11 to 49 times' 5='(5) 50 to 99 times' 6='(6) 100 to 199 times'
                  7='(7) 200 or more times' 91='(91) NEVER USED STIMULANTS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE stimrec   1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE stmyrfrq  1='(1) Daily in the past 12 months'
                  2='(2) Almost daily or 3 to 6 days a week'
                  3='(3) About 1 or 2 days a week'
                  4='(4) Several times a month (about 25 to 51 days a year)'
                  5='(5) 1 to 2 times a month (12 to 24 days a year)'
                  6='(6) Every other month or so (6 to 11 days a year)'
                  7='(7) 3 to 5 days in the past 12 months'
                  8='(8) 1 or 2 days in the past 12 months'
                  81='(81) NEVER USED STIMULANTS Logically assigned'
                  83='(83) DID NOT USE STIMULANT PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED STIMULANTS'
                  93='(93) DID NOT USE STIMULANT IN THE PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE stneedle  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED'
                  81='(81) NEVER USED STIMULANTS Logically assigned'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE stndlrec  1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago but less than 10 years ago'
                  6='(6) 10 or more years ago'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  81='(81) NEVER USED STIMULANTS Logically assigned'
                  83='(83) NEVER USED AMPHETAMINES W/A NEEDLE Logic.assigned'
                  91='(91) NEVER USED STIMULANTS'
                  93='(93) NEVER USED AMPHETAMINES WITH A NEEDLE'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE anlread   1='(1) Wants interviewer to read questions'
                  2='(2) Wants to do it himself/herself' 96='(96) MULTIPLE RESPONSE'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE analnone  1='(1) Response circled' 2='(2) Response not circled'
                  4='(4) Response not circled LOGICALLY IMPUTED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE darvon    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE dolene    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE sk65a     1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE wygesic   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE levodro   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE percodan  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE demerol   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE dilaud    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE tylcod    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE phencod   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE talwin    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE talwinnx  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE talacen   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE propoxy   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE codeine   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE anilerid  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE morphine  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE methdon   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE stadol    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE analnewa  234='(234) Cyclobenzaprine, Flexeril'
                  322='(322) Methamphetamine (speed or ice or crank)'
                  406='(406) Oxycodone, Percodan, Roxicet' 407='(407) Demerol'
                  420='(420) OTHER Analgesic, NOT SPECIFIED' 422='(422) Motrin'
                  423='(423) Percocet' 425='(425) Advil'
                  426='(426) Butalbital, Fiorinal, Phrenilin Forte' 427='(427) Darvocet'
                  430='(430) Aspirin, Ecotrin, Empirin' 431='(431) Tylox'
                  434='(434) Co-Gesic, Hydrocodone, Tussionex, Vicodin'
                  435='(435) Tylenol, Tylenol Extrastrength'
                  438='(438) Anaprox, Naprosyn' 442='(442) Ibuprofen' 443='(443) Dolobid'
                  455='(455) Fiorinal with Codeine' 470='(470) Cafergot'
                  471='(471) Butazolidin' 472='(472) Indocin, Indomethacin'
                  473='(473) Pyridium' 474='(474) sic' 475='(475) sic' 476='(476) Isocom, Midrin'
                  477='(477) Neo-Melubrina (Spanish)' 479='(479) Pentrexyl'
                  480='(480) Robitussin AC with Codeine' 702='(702) Heroin' 703='(703) Opium'
                  811='(811) Muscle relaxers' 820='(820) Penicillin' 829='(829) Robitussin DM'
                  991='(991) NEVER USED ANALGESICS' 992='(992) ILLEGIBLE'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE analnewb  415='(415) Codeine' 424='(424) Fioricet'
                  430='(430) Aspirin, Ecotrin, Empirin'
                  434='(434) Co-Gesic, Hydrocodone, Tussionex, Vicodin'
                  443='(443) Dolobid' 450='(450) Acetaminophen' 828='(828) Tetracycline'
                  991='(991) NEVER USED ANALGESICS' 998='(998) BLANK (NO ANSWER)' ;
  VALUE analnewc  478='(478) Nogirtronia' 991='(991) NEVER USED ANALGESICS'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE analnewd  234='(234) Cyclobenzaprine, Flexeril' 991='(991) NEVER USED ANALGESICS'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE analnewe  991='(991) NEVER USED ANALGESICS' 998='(998) BLANK (NO ANSWER)' ;
  VALUE anlnosp   1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Analgesic use LOGICALLY IMPUTED'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE anldknam  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE analage   981='(981) NEVER USED ANALGESICS Logically assigned'
                  985='(985) BAD DATA Logically assigned'
                  991='(991) NEVER USED ANALGESICS' 994='(994) DON''T KNOW'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE analtot   1='(1) 1 or 2 times' 2='(2) 3 to 5 times' 3='(3) 6 to 10 times'
                  4='(4) 11 to 49 times' 5='(5) 50 to 99 times' 6='(6) 100 to 199 times'
                  7='(7) 200 or more times' 91='(91) NEVER USED ANALGESICS'
                  94='(94) DON''T KNOW' 98='(98) BLANK (NO ANSWER)' ;
  VALUE analrec   1='(1) Within past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE anlyrfrq  1='(1) Daily in the past 12 months'
                  2='(2) Almost daily or 3 to 6 days a week'
                  3='(3) About 1 or 2 days a week'
                  4='(4) Several times a month (about 25 to 51 days a year)'
                  5='(5) 1 to 2 times a month (12 to 24 days a year)'
                  6='(6) Every other month or so (6 to 11 days a year)'
                  7='(7) 3 to 5 days in the past 12 months'
                  8='(8) 1 or 2 days in the past 12 months'
                  81='(81) NEVER USED ANALGESICS Logically assigned'
                  83='(83) DID NOT USE ANALGESICS PAST 12 MO. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANALGESICS'
                  93='(93) DID NOT USE ANALGESICS IN THE PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE mjopp     981='(981) NEVER HAD CHANCE TO TRY MARIJUANA Logic.assigned'
                  985='(985) BAD DATA Logically assigned'
                  991='(991) NEVER HAD CHANCE TO TRY MARIJUANA' 994='(994) DON''T KNOW'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' ;
  VALUE mjage     981='(981) NEVER USED MARIJUANA Logically assigned'
                  985='(985) BAD DATA Logically assigned'
                  991='(991) NEVER USED MARIJUANA' 994='(994) DON''T KNOW'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE mjtot     1='(1) 1 or 2 times' 2='(2) 3 to 5 times' 3='(3) 6 to 10 times'
                  4='(4) 11 to 49 times' 5='(5) 50 to 99 times' 6='(6) 100 to 199 times'
                  7='(7) 200 or more times'
                  81='(81) NEVER USED MARIJUANA Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED MARIJUANA'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE mjrec     1='(1) Within the past week (7 days)'
                  2='(2) More than 1 week ago but less than 1 month ago'
                  3='(3) 1 or more months ago but less than 6 months ago'
                  4='(4) 6 or more months ago but less than 1 year ago'
                  5='(5) 1 or more years ago but less than 3 years ago'
                  6='(6) 3 or more years ago'
                  7='(7) Use in past 30 days LOGICALLY IMPUTED'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  81='(81) NEVER USED MARIJUANA Logically assigned'
                  91='(91) NEVER USED MARIJUANA' ;
  VALUE mjday30a  81='(81) NEVER USED MARIJUANA Logically assigned'
                  83='(83) DID NOT USE MARIJUANA PAST 30 DAYS Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED MARIJUANA'
                  93='(93) DID NOT USE MARIJUANA IN PAST 30 DAYS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE mjav30a   81='(81) NEVER USED MARIJUANA Logically assigned'
                  83='(83) DID NOT USE MARIJUANA PAST 30 DAYS Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED MARIJUANA'
                  93='(93) DID NOT USE MARIJUANA IN PAST 30 DAYS' 94='(94) DON''T KNOW'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE mjav30b   81='(81) NEVER USED MARIJUANA Logically assigned'
                  83='(83) DID NOT USE MARIJUANA PAST 30 DAYS Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED MARIJUANA'
                  93='(93) DID NOT USE MARIJUANA IN PAST 30 DAYS' 94='(94) DON''T KNOW'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE mjamt30a  1='(1) 1 to 10 joints in the past 30 days'
                  2='(2) 11 to 20 joints in the past 30 days'
                  3='(3) About 1 ounce in the past 30 days'
                  4='(4) About 2 ounces in the past 30 days'
                  5='(5) 3 to 4 ounces in the past 30 days'
                  6='(6) 5 to 6 ounces in the past 30 days'
                  8='(8) 8 ounces in the past 30 days'
                  30='(30) 30 ounces in the past 30 days'
                  55='(55) Nickel bag in the past 30 days'
                  77='(77) More than 6 oz. exact amt not spec. in pst 30 days'
                  81='(81) NEVER USED MARIJUANA Logically assigned'
                  83='(83) DID NOT USE MARIJUANA PAST 30 DAYS Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED MARIJUANA'
                  93='(93) DID NOT USE MARIJUANA IN PAST 30 DAYS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE mjfriend  1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED MARIJUANA Logically assigned'
                  83='(83) DID NOT USE MARIJUANA PST 30 DAYS Logic. assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED MARIJUANA'
                  93='(93) DID NOT USE MARIJUANA IN PAST 30 DAYS' 97='(97) REFUSED' ;
  VALUE mjdealer  1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED MARIJUANA Logically assigned'
                  83='(83) DID NOT USE MARIJUANA PST 30 DAYS Logic. assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED MARIJUANA'
                  93='(93) DID NOT USE MARIJUANA IN PAST 30 DAYS' 97='(97) REFUSED' ;
  VALUE mjothshr  1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED MARIJUANA Logically assigned'
                  83='(83) DID NOT USE MARIJUANA PST 30 DAYS Logic. assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED MARIJUANA'
                  93='(93) DID NOT USE MARIJUANA IN PAST 30 DAYS' 97='(97) REFUSED' ;
  VALUE mjgiven   1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED MARIJUANA Logically assigned'
                  83='(83) DID NOT USE MARIJUANA PST 30 DAYS Logic. assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED MARIJUANA'
                  93='(93) DID NOT USE MARIJUANA IN PAST 30 DAYS' 97='(97) REFUSED' ;
  VALUE mjtrgood  1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED MARIJUANA Logically assigned'
                  83='(83) DID NOT USE MARIJUANA PST 30 DAYS Logic. assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED MARIJUANA'
                  93='(93) DID NOT USE MARIJUANA IN PAST 30 DAYS' 97='(97) REFUSED' ;
  VALUE mjtrserv  1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED MARIJUANA Logically assigned'
                  83='(83) DID NOT USE MARIJUANA PST 30 DAYS Logic. assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED MARIJUANA'
                  93='(93) DID NOT USE MARIJUANA IN PAST 30 DAYS' 97='(97) REFUSED' ;
  VALUE mjstole   1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED MARIJUANA Logically assigned'
                  83='(83) DID NOT USE MARIJUANA PST 30 DAYS Logic. assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED MARIJUANA'
                  93='(93) DID NOT USE MARIJUANA IN PAST 30 DAYS' 97='(97) REFUSED' ;
  VALUE mjtrick   1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED MARIJUANA Logically assigned'
                  83='(83) DID NOT USE MARIJUANA PST 30 DAYS Logic. assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED MARIJUANA'
                  93='(93) DID NOT USE MARIJUANA IN PAST 30 DAYS' 97='(97) REFUSED' ;
  VALUE mjgrew    1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED MARIJUANA Logically assigned'
                  83='(83) DID NOT USE MARIJUANA PST 30 DAYS Logic. assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED MARIJUANA'
                  93='(93) DID NOT USE MARIJUANA IN PAST 30 DAYS' 97='(97) REFUSED' ;
  VALUE mjobtnon  2='(2) Response not circled'
                  81='(81) NEVER USED MARIJUANA Logically assigned'
                  83='(83) DID NOT USE MARIJUANA PST 30 DAYS Logic. assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED MARIJUANA'
                  93='(93) DID NOT USE MARIJUANA IN PAST 30 DAYS' 97='(97) REFUSED' ;
  VALUE mjbuck    .0='(.0) Did not spend any money on marijuana pst 30 days'
                  9981.0='(9981.0) NEVER USED MARIJUANA Logically assigned'
                  9983.0='(9983.0) DID NOT USE MARIJUANA PST 30 DAYS Logic. assigned'
                  9985.0='(9985.0) BAD DATA Logically assigned'
                  9991.0='(9991.0) NEVER USED MARIJUANA'
                  9993.0='(9993.0) DID NOT USE MARIJUANA IN THE PAST 30 DAYS'
                  9994.0='(9994.0) DON''T KNOW' 9997.0='(9997.0) REFUSED'
                  9998.0='(9998.0) BLANK (NO ANSWER)' ;
  VALUE mjyrfreq  1='(1) Several times a day in the past 12 months'
                  2='(2) Daily in the past 12 months'
                  3='(3) Almost daily or 3 to 6 days a week'
                  4='(4) 1 or 2 days a week'
                  5='(5) Several times a month (about 25 to 51 days a year)'
                  6='(6) 1 to 2 times a month (12 to 24 days a year)'
                  7='(7) Every other month or so (6 to 11 days a year)'
                  8='(8) 3 to 5 days in the past 12 months'
                  9='(9) 1 or 2 days in the past 12 months'
                  81='(81) NEVER USED MARIJUANA Logically assigned'
                  83='(83) DID NOT USE MARIJUANA PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED MARIJUANA'
                  93='(93) DID NOT USE MARIJUANA IN PAST 12 MONTHS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE mjjoint   1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED MARIJUANA Logically assigned'
                  83='(83) DID NOT USE MARIJUANA PAST 12 MOS. Logic.assigned'
                  91='(91) NEVER USED MARIJUANA'
                  93='(93) DID NOT USE MARIJUANA IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' ;
  VALUE mjpipe    1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED MARIJUANA Logically assigned'
                  83='(83) DID NOT USE MARIJUANA PAST 12 MOS. Logic.assigned'
                  91='(91) NEVER USED MARIJUANA'
                  93='(93) DID NOT USE MARIJUANA IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' ;
  VALUE mjbake    1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED MARIJUANA Logically assigned'
                  83='(83) DID NOT USE MARIJUANA PAST 12 MOS. Logic.assigned'
                  91='(91) NEVER USED MARIJUANA'
                  93='(93) DID NOT USE MARIJUANA IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' ;
  VALUE mjchew    1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED MARIJUANA Logically assigned'
                  83='(83) DID NOT USE MARIJUANA PAST 12 MOS. Logic.assigned'
                  91='(91) NEVER USED MARIJUANA'
                  93='(93) DID NOT USE MARIJUANA IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' ;
  VALUE mjway     1='(1) Response circled, method not specified'
                  2='(2) Response not circled'
                  4='(4) PST 30 DAY OR PST 12 MTH MJ USER W/NO Q.M-11 ANS.'
                  6='(6) Can with holes/in a bowl' 7='(7) One hitter/pinch hit'
                  8='(8) Boiled with tea'
                  9='(9) Smoky small room(burn in small room like bathroom)'
                  12='(12) Chewing/eating/suck on stems/gumming'
                  13='(13) Through an apple made like a pipe' 14='(14) sic'
                  15='(15) Steam roller' 16='(16) Laced'
                  17='(17) Blunts/smoked with or in a cigar/in cigar paper'
                  19='(19) With cocaine' 24='(24) Drank it'
                  25='(25) Hash under glass/can/glass bottle'
                  28='(28) In tobacco paper/rolling paper' 31='(31) Joint'
                  32='(32) Pipe/water pipe'
                  81='(81) NEVER USED MARIJUANA Logically assigned'
                  83='(83) DID NOT USE MARIJUANA PAST 12 MOS. Logic.assigned'
                  91='(91) NEVER USED MARIJUANA'
                  93='(93) DID NOT USE MARIJUANA IN THE PAST 12 MONTHS' ;
  VALUE mjlfdaly  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED (from UDAYMJ)'
                  81='(81) NEVER USED MARIJUANA Logically assigned'
                  91='(91) NEVER USED MARIJUANA' 94='(94) DON''T KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE inhread   1='(1) Wants interviewer to read questions'
                  2='(2) Wants to do it himself/herself' 96='(96) MULTIPLE RESPONSE'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE gas       1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED (from GAS30A)'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE lgas      1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED (from LGAS30A)'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE sppaint   1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED (frm SPPAN30A)'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE aeros     1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED (frm AEROS30A)'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE glue      1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED (frm GLUE30A)'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE solvent   1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED (frm SOLVN30A)'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE amylnit   1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED (frm AMLNT30A)'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ether     1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE nitoxid   1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED (frm NOX30A)'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE cleflu    1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED (frm CLFL30A)'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE inhnewa   327='(327) Black beauties, Black Beauty' 348='(348) Crystal'
                  417='(417) Morphine' 501='(501) Gasoline or lighter fluids'
                  503='(503) Other aerosol sprays'
                  504='(504) Shoeshine liq, glue,toluene,Super Glue,rubber cem'
                  505='(505) Lacquer thinner or other paint solvents'
                  506='(506) Amyl nitrite, poppers, locker rm odorizer,rush'
                  507='(507) Halothane, ether, or other anesthetics; chloroform'
                  508='(508) Nitrous oxide, whippets, dentist gas'
                  509='(509) Corr flds, degreasers, cleaning flds, Liquid Paper'
                  511='(511) Markers, felt-tip pens, ink pens' 513='(513) sic' 514='(514) sic'
                  515='(515) Vicks' 516='(516) Freon' 518='(518) Acetone, nail polish remover'
                  519='(519) Helium' 524='(524) see also 509' 525='(525) see also 521,544'
                  526='(526) Nail polish' 528='(528) Whipped-cream can'
                  530='(530) Asthma inhaler, asthma med., bronchial dilators'
                  539='(539) ScotchGard' 540='(540) PAM' 542='(542) Spirits of ammonia'
                  545='(545) Car tailpipe exhaust fumes, CO2' 553='(553) Pixie sticks'
                  555='(555) Chillers' 558='(558) Kool Aid' 559='(559) LOLOY' 560='(560) Soap'
                  561='(561) Amputee gas cleanser' 562='(562) Ban apple gas'
                  563='(563) Acetylene' 565='(565) Trichloroethane'
                  566='(566) Smoked tea from Lipton tea bag' 567='(567) Pertussin spray'
                  568='(568) Tally' 569='(569) Peganento' 570='(570) PVC (in Mexico)'
                  702='(702) Heroin' 706='(706) Smack' 803='(803) sic'
                  805='(805) Cocaine, coke, coca'
                  816='(816) Smokeless tobacco, snuff, chewing tobacco' 852='(852) sic'
                  900='(900) Non-Drug reason given for Drug Problem'
                  981='(981) NEVER USED INHALANTS Logically assigned'
                  991='(991) NEVER USED INHALANTS' 998='(998) BLANK (NO ANSWER)' ;
  VALUE inhnewb   322='(322) Methamphetamine (speed or ice or crank)'
                  504='(504) Shoeshine liq, glue,toluene,Super Glue,rubber cem'
                  508='(508) Nitrous oxide, whippets, dentist gas'
                  509='(509) Corr flds, degreasers, cleaning flds, Liquid Paper'
                  511='(511) Markers, felt-tip pens, ink pens'
                  518='(518) Acetone, nail polish remover' 519='(519) Helium'
                  524='(524) see also 509' 548='(548) Cologne, rubbing alcohol'
                  556='(556) Energine' 564='(564) Electric contact cleaner'
                  818='(818) Nicotine'
                  981='(981) NEVER USED INHALANTS Logically assigned'
                  991='(991) NEVER USED INHALANTS' 998='(998) BLANK (NO ANSWER)' ;
  VALUE inhnewc   504='(504) Shoeshine liq, glue,toluene,Super Glue,rubber cem'
                  519='(519) Helium' 981='(981) NEVER USED INHALANTS Logically assigned'
                  991='(991) NEVER USED INHALANTS' 998='(998) BLANK (NO ANSWER)' ;
  VALUE inhnewd   981='(981) NEVER USED INHALANTS Logically assigned'
                  991='(991) NEVER USED INHALANTS' 998='(998) BLANK (NO ANSWER)' ;
  VALUE inhnewe   981='(981) NEVER USED INHALANTS Logically assigned'
                  991='(991) NEVER USED INHALANTS' 998='(998) BLANK (NO ANSWER)' ;
  VALUE inhnosp   1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Inhalant use LOGICALLY IMPUTED'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE inhdknam  1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE inhage    981='(981) NEVER USED INHALANTS Logically assigned'
                  985='(985) BAD DATA Logically assigned'
                  991='(991) NEVER USED INHALANTS' 994='(994) DON''T KNOW'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE inhtot    1='(1) 1 or 2 times' 2='(2) 3 to 5 times' 3='(3) 6 to 10 times'
                  4='(4) 11 to 49 times' 5='(5) 50 to 99 times' 6='(6) 100 to 199 times'
                  7='(7) 200 or more times'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED INHALANTS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE inhrec    1='(1) Within the past week (7 days)'
                  2='(2) More than 1 week ago but less than 1 month ago'
                  3='(3) 1 or more months ago but less than 6 months ago'
                  4='(4) 6 or more months ago but less than 1 year ago'
                  5='(5) 1 or more years ago but less than 3 years ago'
                  6='(6) 3 or more years ago'
                  7='(7) Use in past 30 days LOGICALLY IMPUTED'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE gas30a    1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  83='(83) DID NOT USE INHALANT PAST 30 DAYS Logic.assigned'
                  91='(91) NEVER USED INHALANTS'
                  93='(93) DID NOT USE INHALANT IN PAST 30 DAYS' 94='(94) DON''T KNOW'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE lgas30a   1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  83='(83) DID NOT USE INHALANT PAST 30 DAYS Logic.assigned'
                  91='(91) NEVER USED INHALANTS'
                  93='(93) DID NOT USE INHALANT IN PAST 30 DAYS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE sppan30a  1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  83='(83) DID NOT USE INHALANT PAST 30 DAYS Logic. assigned'
                  91='(91) NEVER USED INHALANTS'
                  93='(93) DID NOT USE INHALANT IN PAST 30 DAYS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE aeros30a  1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  83='(83) DID NOT USE INHALANT PAST 30 DAYS Logic.assigned'
                  91='(91) NEVER USED INHALANTS'
                  93='(93) DID NOT USE INHALANT IN PAST 30 DAYS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE glue30a   1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  83='(83) DID NOT USED INHALANT PAST 30 DAYS Logic.assigned'
                  91='(91) NEVER USED INHALANTS'
                  93='(93) DID NOT USE INHALANT IN PAST 30 DAYS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE solvn30a  1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  83='(83) DID NOT USE INHALANT PAST 30 DAYS Logic.assigned'
                  91='(91) NEVER USED INHALANTS'
                  93='(93) DID NOT USE INHALANT IN PAST 30 DAYS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE amlnt30a  1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  83='(83) DID NOT USE INHALANT PAST 30 DAYS Logic.assigned'
                  91='(91) NEVER USED INHALANTS'
                  93='(93) DID NOT USE INHALANT IN PAST 30 DAYS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE ether30a  1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  83='(83) DID NOT USED INHALANT PAST 30 DAYS Logic.assigned'
                  91='(91) NEVER USED INHALANTS'
                  93='(93) DID NOT USE INHALANT IN PAST 30 DAYS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE nox30a    1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  83='(83) DID NOT USE INHALANT PAST 30 DAYS Logic.assigned'
                  91='(91) NEVER USED INHALANTS'
                  93='(93) DID NOT USE INHALANT IN PAST 30 DAYS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE clfl30a   1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  83='(83) DID NOT USE INHALANT PAST 30 DAYS Logic.assigned'
                  91='(91) NEVER USED INHALANTS'
                  93='(93) DID NOT USE INHALANT IN PAST 30 DAYS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE innew30a  348='(348) Crystal'
                  504='(504) Shoeshine liq, glue,toluene,Super Glue,rubber cem'
                  505='(505) Lacquer thinner or other paint solvents'
                  509='(509) Corr flds, degreasers, cleaning flds, Liquid Paper'
                  511='(511) Markers, felt-tip pens, ink pens' 519='(519) Helium'
                  524='(524) see also 509' 526='(526) Nail polish'
                  528='(528) Whipped-cream can' 539='(539) ScotchGard'
                  900='(900) Non-Drug reason given for Drug Problem'
                  981='(981) NEVER USED INHALANTS Logically assigned'
                  983='(983) DID NOT USE INHALANTS PAST 30 DAYS Logic.assigned'
                  991='(991) NEVER USED INHALANTS'
                  993='(993) DID NOT USE INHALANTS IN PAST 30 DAYS'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE innew30b  519='(519) Helium' 981='(981) NEVER USED INHALANTS Logically assigned'
                  983='(983) DID NOT USE INHALANTS PAST 30 DAYS Logic.assigned'
                  991='(991) NEVER USED INHALANTS'
                  993='(993) DID NOT USE INHALANTS PAST 30 DAYS'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE innew30c  981='(981) NEVER USED INHALANTS Logically assigned'
                  983='(983) DID NOT USE INHALANTS PAST 30 DAYS Logic.assigned'
                  991='(991) NEVER USED INHALANTS'
                  993='(993) DID NOT USE INHALANTS IN PAST 30 DAYS'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE innew30d  981='(981) NEVER USED INHALANTS Logically assigned'
                  983='(983) DID NOT USE INHALANTS PAST 30 DAYS Logic.assigned'
                  991='(991) NEVER USED INHALANTS'
                  993='(993) DID NOT USE INHALANTS PAST 30 DAYS'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE innew30e  981='(981) NEVER USED INHALANTS Logically assigned'
                  983='(983) DID NOT USE INHALANTS PAST 30 DAYS Logic.assigned'
                  991='(991) NEVER USED INHALANTS'
                  993='(993) DID NOT USE INHALANTS IN PAST 30 DAYS'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE in30nosp  1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Inhalant use LOGICALLY IMPUTED'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  83='(83) DID NOT USE INHALANT PAST 30 DAYS Logic.assigned'
                  91='(91) NEVER USED INHALANTS'
                  93='(93) DID NOT USE INHALANT IN PAST 30 DAYS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE inh30no   1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED'
                  4='(4) Response not circled LOGICALLY IMPUTED'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE inhdy30a  81='(81) NEVER USED INHALANTS Logically assigned'
                  83='(83) DID NOT USE INHALANTS PAST 30 DAYS Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED INHALANTS'
                  93='(93) DID NOT USE INHALANT IN PAST 30 DAYS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE inhyrfrq  1='(1) Daily in the past 12 months'
                  2='(2) Almost daily or 3 to 6 days a week'
                  3='(3) About 1 or 2 days a week'
                  4='(4) Several times a month (about 25 to 51 days a year)'
                  5='(5) 1 to 2 times a month (12 to 24 days a year)'
                  6='(6) Every other month or so (6 to 11 days a year)'
                  7='(7) 3 to 5 days in the past 12 months'
                  8='(8) 1 or 2 days in the past 12 months'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  83='(83) DID NOT USE INHALANT PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED INHALANTS'
                  93='(93) DID NOT USE INHALANT IN THE PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE inhpo     1='(1) Yes' 2='(2) No' 81='(81) NEVER USED INHALANTS Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED INHALANTS'
                  94='(94) DON''T KNOW' 98='(98) BLANK (NO ANSWER)' ;
  VALUE inhqnc1f  1='(1) QUESTION 1 NOT CLEAR' 98='(98) BLANK (NO ANSWER)' ;
  VALUE inhqnc2f  2='(2) QUESTION 2 NOT CLEAR' 98='(98) BLANK (NO ANSWER)' ;
  VALUE inhqnc3f  3='(3) QUESTION 3 NOT CLEAR' 98='(98) BLANK (NO ANSWER)' ;
  VALUE inhqnc4f  4='(4) QUESTION 4 NOT CLEAR' 98='(98) BLANK (NO ANSWER)' ;
  VALUE inhqnc5f  5='(5) QUESTION 5 NOT CLEAR' 98='(98) BLANK (NO ANSWER)' ;
  VALUE inhqnc6f  6='(6) QUESTION 6 NOT CLEAR' 98='(98) BLANK (NO ANSWER)' ;
  VALUE inhqnc7f  7='(7) QUESTION 7 NOT CLEAR' 98='(98) BLANK (NO ANSWER)' ;
  VALUE inhqnc8f  8='(8) QUESTION 8 NOT CLEAR' 98='(98) BLANK (NO ANSWER)' ;
  VALUE inhqnc0f  10='(10) ALL QUESTIONS WERE CLEAR' 98='(98) BLANK (NO ANSWER)' ;
  VALUE inhansy   1='(1) Yes' 2='(2) No' 96='(96) MULTIPLE RESPONSE'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cocopp    981='(981) NEVER HAD A CHANCE TO TRY COCAINE Logic. assigned'
                  985='(985) BAD DATA Logically assigned'
                  991='(991) NEVER HAD A CHANCE TO TRY COCAINE IN ANY FORM'
                  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' ;
  VALUE cocage    981='(981) NEVER USED COCAINE Logically assigned'
                  985='(985) BAD DATA Logically assigned' 991='(991) NEVER USED COCAINE'
                  994='(994) DON''T KNOW' 998='(998) BLANK (NO ANSWER)' ;
  VALUE coctot    1='(1) 1 or 2 times' 2='(2) 3 to 5 times' 3='(3) 6 to 10 times'
                  4='(4) 11 to 49 times' 5='(5) 50 to 99 times' 6='(6) 100 to 199 times'
                  7='(7) 200 or more times'
                  81='(81) NEVER USED COCAINE Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED COCAINE'
                  94='(94) DON''T KNOW' 98='(98) BLANK (NO ANSWER)' ;
  VALUE cocrec    1='(1) Within the past week (7 days)'
                  2='(2) More than 1 week ago but less than 1 month ago'
                  3='(3) 1 or more months ago but less than 6 months ago'
                  4='(4) 6 or more months ago but less than 1 year ago'
                  5='(5) 1 or more years ago but less than 3 years ago'
                  6='(6) 3 or more years ago'
                  7='(7) Use in past 30 days LOGICALLY IMPUTED'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  81='(81) NEVER USED COCAINE Logically assigned'
                  91='(91) NEVER USED COCAINE' ;
  VALUE cocus30a  81='(81) NEVER USED COCAINE Logically assigned'
                  83='(83) DID NOT USE COCAINE IN PAST 30 DAYS Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN PAST 30 DAYS' ;
  VALUE cocam30a  1='(1) Used some but less than 1/4 gram in past 30 days'
                  2='(2) About 1/4 gram in the past 30 days'
                  3='(3) About 1/2 gram in the past 30 days'
                  4='(4) About 1 gram in the past 30 days'
                  5='(5) About 2 grams in the past 30 days'
                  6='(6) About 3 grams in the past 30 days'
                  7='(7) About 4 grams in the past 30 days'
                  8='(8) About 5 grams in the past 30 days'
                  10='(10) About 7 grams in the past 30 days'
                  12='(12) About 9 grams in the past 30 days'
                  15='(15) About 12 grams in the past 30 days'
                  19='(19) About 16 grams in the past 30 days'
                  77='(77) More than 3 grams exact amt not spec. pst 30 days'
                  81='(81) NEVER USED COCAINE Logically assigned'
                  83='(83) DID NOT USE COCAINE IN PAST 30 DAYS Logic.assignd'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN PAST 30 DAYS' 94='(94) DON''T KNOW'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE ccfriend  1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED (frm CKFRIEND)'
                  81='(81) NEVER USED COCAINE Logically assigned'
                  83='(83) DID NOT USE COCAINE PST 30 DAYS Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN PAST 30 DAYS' 97='(97) REFUSED' ;
  VALUE ccdealer  1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED (frm CKDEALER)'
                  81='(81) NEVER USED COCAINE Logically Assigned'
                  83='(83) DID NOT USE COCAINE PST 30 DAYS Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN PAST 30 DAYS' 97='(97) REFUSED' ;
  VALUE ccothshr  1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED (frm CKOTHSHR)'
                  81='(81) NEVER USED COCAINE Logically assigned'
                  83='(83) DID NOT USE COCAINE PST 30 DAYS Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN PAST 30 DAYS' 97='(97) REFUSED' ;
  VALUE ccgiven   1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED (frm CKGIVEN)'
                  81='(81) NEVER USED COCAINE Logically Assigned'
                  83='(83) DID NOT USE COCAINE PST 30 DAYS Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN PAST 30 DAYS' 97='(97) REFUSED' ;
  VALUE cctrgood  1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED (frm CKTRGOOD)'
                  81='(81) NEVER USED COCAINE Logically assigned'
                  83='(83) DID NOT USE COCAINE PST 30 DAYS Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN PST 30 DAYS Logic assgn.'
                  97='(97) REFUSED' ;
  VALUE cctrserv  1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED (frm CKTRSERV)'
                  81='(81) NEVER USED COCAINE Logically assigned'
                  83='(83) DID NOT USE COCAINE PST 30 DAYS Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN PST 30 DAYS Logic assgn.'
                  97='(97) REFUSED' ;
  VALUE ccstole   1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED (from CKSTOLE)'
                  81='(81) NEVER USED COCAINE Logically assigned'
                  83='(83) DID NOT USE COCAINE PST 30 DAYS Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN PAST 30 DAYS' 97='(97) REFUSED' ;
  VALUE cctrick   1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED (frm CKTRICK)'
                  81='(81) NEVER USED COCAINE Logically assigned'
                  83='(83) DID NOT USE COCAINE PST 30 DAYS Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN PST 30 DAYS' 97='(97) REFUSED' ;
  VALUE ccobtnon  2='(2) Response not circled'
                  81='(81) NEVER USED COCAINE Logically assigned'
                  83='(83) DID NOT USE COCAINE PST 30 DAYS Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN PAST 30 DAYS' 97='(97) REFUSED' ;
  VALUE cocbuck   0='(0) Did not spend any money on cocaine pst 30 days'
                  9981='(9981) NEVER USED COCAINE Logically assigned'
                  9983='(9983) DID NOT USE COCAINE PAST 30 DAYS Logic.assigned'
                  9985='(9985) BAD DATA Logically assigned'
                  9991='(9991) NEVER USED COCAINE'
                  9993='(9993) DID NOT USE COCAINE IN PAST 30 DAYS'
                  9994='(9994) DON''T KNOW' 9997='(9997) REFUSED' 9998='(9998) BLANK (NO ANSWER)' ;
  VALUE cocyrfrq  1='(1) Daily in the past 12 months'
                  2='(2) Almost daily or 3 to 6 days a week'
                  3='(3) About 1 or 2 days a week'
                  4='(4) Several times a month (about 25 to 51 days a year)'
                  5='(5) 1 to 2 times a month (12 to 24 days a year)'
                  6='(6) Every other month or so (6 to 11 days a year)'
                  7='(7) 3 to 5 days in the past 12 months'
                  8='(8) 1 or 2 days in the past 12 months'
                  81='(81) NEVER USED COCAINE Logically assigned'
                  83='(83) DID NOT USE COCAINE IN PAST 12 MONTHS Logic.assgnd'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN PAST 12 MONTHS' 94='(94) DON''T KNOW'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cocsniff  1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED COCAINE Logically assigned'
                  83='(83) DID NOT USE COCAINE PAST 12 MOS Logically assigned'
                  91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN PAST 12 MONTHS' ;
  VALUE cocswal   1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED COCAINE Logically assigned'
                  83='(83) DID NOT USE COCAINE PAST 12 MOS Logically assigned'
                  91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN PAST 12 MONTHS' ;
  VALUE cociv     1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED (frm CONDLREC)'
                  81='(81) NEVER USED COCAINE Logically assigned'
                  83='(83) DID NOT USE COCAINE PAST 12 MOS Logically assigned'
                  91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN PAST 12 MONTHS' ;
  VALUE freebase  1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED (frm CRAKREC)'
                  81='(81) NEVER USED COCAINE Logically assigned'
                  83='(83) DID NOT USE COCAINE PAST 12 MOS Logically assigned'
                  91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN PAST 12 MONTHS' ;
  VALUE cocway    1='(1) Response circled, method not specified'
                  2='(2) Response not circled'
                  4='(4) PST 3O DAYS OR PST 12 MTH COC USR W/NO Q.CN-10 ANS'
                  7='(7) On my gums/mouth' 8='(8) Freeze, put on tongue'
                  9='(9) Smoked in a cigarette/Snowcap' 10='(10) Laced with marijuana'
                  11='(11) Smoked using aluminum foil' 12='(12) Pop-can bong'
                  13='(13) Lined with PCP' 14='(14) Mixed in food' 15='(15) Sexually'
                  81='(81) NEVER USED COCAINE Logically assigned'
                  83='(83) DID NOT USE COCAINE PAST 12 MOS Logically assigned'
                  91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN PAST 12 MONTHS' ;
  VALUE condlrec  1='(1) Within past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago but less than 10 years ago'
                  6='(6) 10 or more years ago'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  81='(81) NEVER USED COCAINE Logically assigned'
                  83='(83) USED COCAINE BUT NEVER W/A NEEDLE Logic. assigned'
                  91='(91) NEVER USED COCAINE'
                  93='(93) USED COCAINE BUT NEVER W/A NEEDLE'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cclfdaly  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED (from UDAYCOC)'
                  81='(81) NEVER USED COCAINE Logically assigned'
                  91='(91) NEVER USED COCAINE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE crakrec   1='(1) Within the past week (7 days)'
                  2='(2) More than 1 week ago but less than 1 month ago'
                  3='(3) 1 or more months ago but less than 6 months ago'
                  4='(4) 6 or more months ago but less than 1 year ago'
                  5='(5) 1 or more years ago but less than 3 years ago'
                  6='(6) 3 or more years ago'
                  7='(7) Use in past 30 days LOGICALLY IMPUTED'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  81='(81) NEVER USED CRACK Logically assigned'
                  91='(91) NEVER USED CRACK' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE crkam30a  981='(981) NEVER USED CRACK Logically assigned'
                  983='(983) DID NOT USE CRACK IN PAST 30 DAYS Logic.assignd'
                  985='(985) BAD DATA Logically assigned' 991='(991) NEVER USED CRACK'
                  993='(993) DID NOT USE CRACK IN PAST 30 DAYS' 994='(994) DON''T KNOW'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE ckfriend  1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED CRACK Logically assigned'
                  83='(83) DID NOT USE CRACK PST 30 DAYS Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED CRACK'
                  93='(93) DID NOT USE CRACK IN PAST 30 DAYS' 97='(97) REFUSED' ;
  VALUE ckdealer  1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED CRACK Logically assigned'
                  83='(83) DID NOT USE CRACK PST 30 DAYS Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED CRACK'
                  93='(93) DID NOT USE CRACK IN PAST 30 DAYS' 97='(97) REFUSED' ;
  VALUE ckothshr  1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED CRACK Logically assigned'
                  83='(83) DID NOT USE CRACK PST 30 DAYS Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED CRACK'
                  93='(93) DID NOT USE CRACK IN PAST 30 DAYS' 97='(97) REFUSED' ;
  VALUE ckgiven   1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED CRACK Logically assigned'
                  83='(83) DID NOT USE CRACK PST 30 DAYS Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED CRACK'
                  93='(93) DID NOT USE CRACK IN PST 30 DAYS' 97='(97) REFUSED' ;
  VALUE cktrgood  1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED CRACK Logically assigned'
                  83='(83) DID NOT USE CRACK PST 30 DAYS Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED CRACK'
                  93='(93) DID NOT USE CRACK IN PAST 30 DAYS' 97='(97) REFUSED' ;
  VALUE cktrserv  1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED CRACK Logically assigned'
                  83='(83) DID NOT USE CRACK PST 30 DAYS Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED CRACK'
                  93='(93) DID NOT USE CRACK IN PAST 30 DAYS' 97='(97) REFUSED' ;
  VALUE ckstole   1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED CRACK Logically assigned'
                  83='(83) DID NOT USE CRACK PST 30 DAYS Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED CRACK'
                  93='(93) DID NOT USE CRACK IN PAST 30 DAYS' 97='(97) REFUSED' ;
  VALUE cktrick   1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED CRACK Logically assigned'
                  83='(83) DID NOT USE CRACK PST 30 DAYS Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED CRACK'
                  93='(93) DID NOT USE CRACK IN PAST 30 DAYS' 97='(97) REFUSED' ;
  VALUE ckobtnon  2='(2) Response not circled'
                  81='(81) NEVER USED CRACK Logically assigned'
                  83='(83) DID NOT USE CRACK PST 30 DAYS Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED CRACK'
                  93='(93) DID NOT USE CRACK IN PAST 30 DAYS' ;
  VALUE crakbuck  0='(0) Did not spend any money on crack pst 30 days'
                  9981='(9981) NEVER USED CRACK Logically assigned'
                  9983='(9983) DID NOT USE CRACK PAST 30 DAYS Logic.assigned'
                  9985='(9985) BAD DATA Logically assigned' 9991='(9991) NEVER USED CRACK'
                  9993='(9993) DID NOT USE CRACK IN PAST 30 DAYS' 9994='(9994) DON''T KNOW'
                  9997='(9997) REFUSED' 9998='(9998) BLANK (NO ANSWER)' ;
  VALUE cklfdaly  1='(1) Yes' 2='(2) No' 81='(81) NEVER USED CRACK Logically assigned'
                  91='(91) NEVER USED CRACK' 98='(98) BLANK (NO ANSWER)' ;
  VALUE halread   1='(1) Wants interviewer to continue reading'
                  2='(2) Wants to do it himself/herself' 98='(98) BLANK (NO ANSWER)' ;
  VALUE lsd       1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED HALLUCINOGENS Logically assigned'
                  85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED HALLUCINOGENS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE peyote    1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED HALLUCINOGENS Logically assigned'
                  85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED HALLUCINOGENS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE mesc      1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED HALLUCINOGENS Logically assigned'
                  85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED HALLUCINOGENS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE psilcy    1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED HALLUCINOGENS Logically assigned'
                  85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED HALLUCINOGENS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE pcp       1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED (frm PCPREC)'
                  81='(81) NEVER USED HALLUCINOGENS Logically assigned'
                  85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED HALLUCINOGENS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE ecstasy   1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED HALLUCINOGENS Logically assigned'
                  85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED HALLUCINOGENS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE halnewa   116='(116) Methaqualone, Quaalude, Sopor' 125='(125) sic'
                  142='(142) Belladona' 248='(248) sic' 267='(267) Marezine'
                  322='(322) Methamphetamine (speed or ice or crank)'
                  339='(339) Amphetamines (speed generically)'
                  501='(501) Gasoline or lighter fluids'
                  509='(509) Corr flds, degreasers, cleaning flds, Liquid Paper'
                  601='(601) see also 618' 602='(602) Peyote'
                  604='(604) Psilocybin (mushrooms)' 606='(606) sic'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 609='(609) sic' 614='(614) MDA'
                  616='(616) DMT' 617='(617) Morning glory seeds' 618='(618) see also 601'
                  622='(622) Microdot(s), purple microdot' 625='(625) Window pane'
                  628='(628) Hawaiian rosebud seed tea' 636='(636) STP' 646='(646) sic'
                  649='(649) sic' 653='(653) Cricketshit' 654='(654) Eve' 657='(657) Orange barrel'
                  658='(658) Special' 659='(659) Boat (Marijuana & PCP)'
                  660='(660) Toad, Toad licking' 661='(661) sic' 662='(662) Kanepolin'
                  702='(702) Heroin' 703='(703) Opium' 802='(802) THC, cannabinol' 803='(803) sic'
                  981='(981) NEVER USED HALLUCINOGENS Logically assigned'
                  991='(991) NEVER USED HALLUCINOGENS' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE halnewb   328='(328) Pink hearts' 348='(348) Crystal' 601='(601) see also 618'
                  616='(616) DMT' 624='(624) Orange sunshine, sunshine, yellow sunshine'
                  636='(636) STP' 646='(646) sic' 655='(655) Flying elephant' 658='(658) Special'
                  864='(864) Dramamine ,Motion sickness pill'
                  981='(981) NEVER USED HALLUCINOGENS Logically assigned'
                  991='(991) NEVER USED HALLUCINOGENS' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE halnewc   625='(625) Window pane' 652='(652) ALD-52, ALD-S2 (version of LSD)'
                  656='(656) Mars'
                  981='(981) NEVER USED HALLUCINOGENS Logically assigned'
                  991='(991) NEVER USED HALLUCINOGENS' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE halnewd   981='(981) NEVER USED HALLUCINOGENS Logically assigned'
                  991='(991) NEVER USED HALLUCINOGENS' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE halnewe   981='(981) NEVER USED HALLUCINOGENS Logically assigned'
                  991='(991) NEVER USED HALLUCINOGENS' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE halnosp   1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED'
                  81='(81) NEVER USED HALLUCINOGENS Logically assigned'
                  85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED HALLUCINOGENS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE haldknam  1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED HALLUCINOGENS Logically assigned'
                  85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED HALLUCINOGENS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE hallopp   981='(981) NEVER HAD A CHANCE TO TRY HALLUCINOGENS Logic.asgn'
                  985='(985) BAD DATA Logically assigned'
                  991='(991) NEVER HAD A CHANCE TO TRY HALLUCINOGENS'
                  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' ;
  VALUE hallage   981='(981) NEVER USED HALLUCINOGENS Logically assigned'
                  985='(985) BAD DATA Logically assigned'
                  991='(991) NEVER USED HALLUCINOGENS' 994='(994) DON''T KNOW'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' ;
  VALUE halltot   1='(1) 1 or 2 times' 2='(2) 3 to 5 times' 3='(3) 6 to 10 times'
                  4='(4) 11 to 49 times' 5='(5) 50 to 99 times' 6='(6) 100 to 199 times'
                  7='(7) 200 or more times'
                  81='(81) NEVER USED HALLUCINOGENS Logically assigned'
                  85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED HALLUCINOGENS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE hallrec   1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago'
                  7='(7) Use in past 30 days LOGICALLY IMPUTED'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  81='(81) NEVER USED HALLUCINOGENS Logically assigned'
                  85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED HALLUCINOGENS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE hal30use  81='(81) NEVER USED HALLUCINOGENS Logically assigned'
                  83='(83) DID NOT USE HALLUCINOGENS PST 30 DAYS Logic.assgnd'
                  85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED HALLUCINOGENS'
                  93='(93) DID NOT USE HALLUCINOGENS IN THE PAST 30 DAYS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE halyrfrq  1='(1) Daily in the past 12 months'
                  2='(2) Almost daily or 3 to 6 days a week'
                  3='(3) About 1 or 2 days a week'
                  4='(4) Several times a month (about 25 to 51 days a year)'
                  5='(5) 1 to 2 times a month (12 to 24 days a year)'
                  6='(6) Every other month or so (6 to 11 days a year)'
                  7='(7) 3 to 5 days in the past 12 months'
                  8='(8) 1 or 2 days in the past 12 months'
                  81='(81) NEVER USED HALLUCINOGENS Logically assigned'
                  83='(83) DID NOT USE HALLUCINOGENS PST 12 MOS. Logic.assgnd'
                  85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED HALLUCINOGENS'
                  93='(93) DID NOT USE HALLUCINOGENS IN THE PST 12 MONTHS'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE pcprec    1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  81='(81) NEVER USED PCP Logically assigned' 91='(91) NEVER USED PCP'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE herread   1='(1) Wants interviewer to continue reading'
                  2='(2) Wants to do it himself/herself' 96='(96) MULTIPLE RESPONSE'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE heropp    981='(981) NEVER HAD A CHANCE TO TRY HEROIN Logic.assigned'
                  985='(985) BAD DATA Logically assigned'
                  991='(991) NEVER HAD A CHANCE TO TRY HEROIN' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE herage    981='(981) NEVER USED HEROIN Logically assigned'
                  985='(985) BAD DATA Logically assigned' 991='(991) NEVER USED HEROIN'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' ;
  VALUE hertot    1='(1) 1 or 2 times' 2='(2) 3 to 5 times' 3='(3) 6 to 10 times'
                  4='(4) 11 to 49 times' 5='(5) 50 to 99 times' 6='(6) 100 to 199 times'
                  7='(7) 200 or more times'
                  81='(81) NEVER USED HEROIN Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED HEROIN'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE herrec    1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago'
                  7='(7) Use in past 30 days LOGICALLY IMPUTED'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  81='(81) NEVER USED HEROIN Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED HEROIN'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE her30use  81='(81) NEVER USED HEROIN Logically assigned'
                  83='(83) DID NOT USE HEROIN PAST 30 DAYS Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED HEROIN'
                  93='(93) DID NOT USE HEROIN IN THE PAST 30 DAYS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE herneedl  1='(1) Yes, have used heroin with a needle'
                  2='(2) No, have used heroin, but not with a needle'
                  3='(3) Yes, used heroin w/a needle LOGICALLY IMPUTED'
                  4='(4) No, used heroin, but w/o a needle LOGIC. IMPUTED'
                  81='(81) NEVER USED HEROIN Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED HEROIN'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE hrndlrec  1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago but less than 10 years ago'
                  6='(6) 10 or more years ago'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  81='(81) NEVER USED HEROIN Logically assigned'
                  83='(83) NEVER USED HEROIN WITH A NEEDLE Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED HEROIN'
                  93='(93) NEVER USED HEROIN WITH A NEEDLE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE hersmoke  1='(1) Yes, have smoked heroin'
                  2='(2) No, have used heroin, but have never smoked it'
                  3='(3) Yes, have smoked heroin LOGICALLY IMPUTED'
                  4='(4) No, used heroin, but never smoked it LOGIC.IMPUTED'
                  81='(81) NEVER USED HEROIN Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED HEROIN'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE hrsmkrec  1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago but less than 10 years ago'
                  6='(6) 10 or more years ago'
                  81='(81) NEVER USED HEROIN Logically assigned'
                  83='(83) USED HEROIN IN LIFE/NEVER SMOKED Logic. assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED HEROIN'
                  93='(93) USED HEROIN IN LIFE BUT NEVER SMOKED IT' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE hersniff  1='(1) Yes, have sniffed (snorted) heroin'
                  2='(2) No, have used heroin, but have never sniffed it'
                  3='(3) Yes, have sniffed (snorted) heroin LOGIC.IMPUTED'
                  4='(4) No, used heroin, but never sniffed LOGIC. IMPUTED'
                  81='(81) NEVER USED HEROIN Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED HEROIN'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE hrsnfrec  1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago but less than 10 years ago'
                  6='(6) 10 or more years ago'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  81='(81) NEVER USED HEROIN Logically assigned'
                  83='(83) USED HEROIN IN LIFE/NEVER SNIFFED Logic. assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED HEROIN'
                  93='(93) USED HEROIN IN LIFE BUT NEVER SNIFFED IT' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE drgread   1='(1) Wants interviewer to continue reading'
                  2='(2) Wants to do it himself/herself' 96='(96) MULTIPLE RESPONSE'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cdcig     1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not try to cut down on any drug in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE cdalc     1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not try to cut down on any drug in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE cdsed     1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not try to cut down on any drug in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE cdtran    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not try to cut down on any drug in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE cdstm     1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not try to cut down on any drug in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE cdanal    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not try to cut down on any drug in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE cdmj      1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not try to cut down on any drug in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE cdinh     1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not try to cut down on any drug in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE cdcoc     1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not try to cut down on any drug in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE cdhall    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not try to cut down on any drug in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE cdher     1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not try to cut down on any drug in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE cdothop   1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not try to cut down on any drug in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE cdnone    1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ucdcig    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not try to cut down on any drug in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUG PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned (CDCIG > 1)'
                  91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUG IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ucdalc    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not try to cut down on any drug in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUG PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned (CDALC > 1)'
                  91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUG IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ucdsed    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not try to cut down on any drug in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUG PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUG IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ucdtran   1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not try to cut down on any drug in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUG PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUG IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ucdstm    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not try to cut down on any drug in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUG PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUG IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ucdanal   1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not try to cut down on any drug in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUG PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUG IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ucdmj     1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not try to cut down on any drug in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUG PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned (CDMJ > 1)'
                  91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUG IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ucdinh    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not try to cut down on any drug in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUG PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUG IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ucdcoc    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not try to cut down on any drug in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUG PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUG IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ucdhall   1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not try to cut down on any drug in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUG PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUG IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ucdher    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not try to cut down on any drug in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUG PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUG IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ucdothop  1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not try to cut down on any drug in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUG PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUG IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ucdnone   1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUG PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUG IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE effcig    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not need more of any drug used for same effect'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE effalc    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not need more of any drug used for same effect'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE effsed    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not need more of any drug used for same effect'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE efftran   1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not need more of any drug used for same effect'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE effstm    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not need more of any drug used for same effect'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE effanal   1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not need more of any drug used for same effect'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE effmj     1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not need more of any drug used for same effect'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE effinh    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not need more of any drug used for same effect'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE effcoc    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not need more of any drug used for same effect'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE effhall   1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not need more of any drug used for same effect'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE effher    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not need more of any drug used for same effect'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE effothop  1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not need more of any drug used for same effect'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE effnone   1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE udaycig   1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not use any drug daily in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE udayalc   1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not use any drug daily in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE udaysed   1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not use any drug daily in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE udaytran  1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not use any drug daily in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE udaystm   1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not use any drug daily in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE udayanal  1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not use any drug daily in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE udaymj    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not use any drug daily in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE udayinh   1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not use any drug daily in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE udaycoc   1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not use any drug daily in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE udayhall  1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not use any drug daily in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE udayher   1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not use any drug daily in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE udayoth   1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not use any drug daily in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE udaynone  1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE depcig    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not feel like had to have any drug used pastyr'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE depalc    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not feel like had to have any drug used pastyr'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE depsed    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not feel like had to have any drug used pastyr'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE deptran   1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not feel like had to have any drug used pastyr'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE depstm    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not feel like had to have any drug used pastyr'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE depanal   1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not feel like had to have any drug used pastyr'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE depmj     1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not feel like had to have any drug used pastyr'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE depinh    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not feel like had to have any drug used pastyr'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE depcoc    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not feel like had to have any drug used pastyr'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE dephall   1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not feel like had to have any drug used pastyr'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE depher    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not feel like had to have any drug used pastyr'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE depothop  1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not feel like had to have any drug used pastyr'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE depnone   1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE wscig     1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not have withdrawal symptoms in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE wsalc     1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not have withdrawal symptoms in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE wssed     1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not have withdrawal symptoms in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE wstran    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not have withdrawal symptoms in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE wsstm     1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not have withdrawal symptoms in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE wsanal    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not have withdrawal symptoms in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE wsmj      1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not have withdrawal symptoms in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE wsinh     1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not have withdrawal symptoms in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE wscoc     1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not have withdrawal symptoms in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE wshall    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not have withdrawal symptoms in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE wsher     1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not have withdrawal symptoms in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE wsothop   1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not have withdrawal symptoms in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE wsnone    1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUGS'
                  93='(93) DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ndlread   1='(1) Wants interviewer to continue reading'
                  2='(2) Wants to do it himself/herself' 96='(96) MULTIPLE RESPONSE'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE gnndllif  1='(1) Yes, have used a needle to take a drug'
                  2='(2) No, have never used a needle to take a drug'
                  3='(3) Yes, have used a ndle to take a drug LOGIC.IMPUTED'
                  4='(4) No, have never used a ndle to take drug, LOGIC. IM'
                  81='(81) NEVER USED A NEEDLE TO TAKE A DRUG Logic.assigned'
                  91='(91) NEVER USED A NEEDLE TO TAKE A DRUG' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE gnndlrec  1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago but less than 10 years ago'
                  6='(6) 10 or more years ago'
                  7='(7) Use in past 30 days LOGICALLY IMPUTED'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  81='(81) NEVER USED ANY DRUG FOR NONMDCL RSN Logic.assigned'
                  83='(83) NEVER USED A NDL TO TAKE ANY DRUG Logic. assigned'
                  91='(91) NEVER USED ANY DRUG FOR NONMEDICAL REASONS'
                  93='(93) NEVER USED A NEEDLE TO TAKE ANY DRUG' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE gnndlsed  1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED ANY DRUGS LISTED ABOVE Logic.assigned'
                  83='(83) NEVER USED A NEEDLE TO TAKE DRUG Logic.assigned'
                  91='(91) NEVER USED ANY OF THE DRUGS LISTED ABOVE'
                  93='(93) NEVER USED A NEEDLE TO TAKE ANY DRUG' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE gnndltra  1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED ANY DRUGS LISTED ABOVE Logic.assigned'
                  83='(83) NEVER USED A NEEDLE TO TAKE DRUG Logic.assigned'
                  91='(91) NEVER USED ANY OF THE DRUGS LISTED ABOVE'
                  93='(93) NEVER USED A NEEDLE TO TAKE ANY DRUG' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE gnndlstm  1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED (frm STNDLREC)'
                  81='(81) NEVER USED ANY DRUGS LISTED ABOVE Logic.assigned'
                  83='(83) NEVER USED A NEEDLE TO TAKE DRUG Logic.assigned'
                  91='(91) NEVER USED ANY OF THE DRUGS LISTED ABOVE'
                  93='(93) NEVER USED A NEEDLE TO TAKE ANY DRUG' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE gnndlanl  1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED ANY DRUGS LISTED ABOVE Logic.assigned'
                  83='(83) NEVER USED A NEEDLE TO TAKE DRUG Logic.assigned'
                  91='(91) NEVER USED ANY OF THE DRUGS LISTED ABOVE'
                  93='(93) NEVER USED A NEEDLE TO TAKE ANY DRUG' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE gnndlinh  1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED ANY DRUGS LISTED ABOVE Logic.assigned'
                  83='(83) NEVER USED A NEEDLE TO TAKE DRUG Logic.assigned'
                  91='(91) NEVER USED ANY OF THE DRUGS LISTED ABOVE'
                  93='(93) NEVER USED A NEEDLE TO TAKE ANY DRUG' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE gnndlcoc  1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED (frm CONDLREC)'
                  81='(81) NEVER USED ANY DRUGS LISTED ABOVE Logic.assigned'
                  83='(83) NEVER USED A NEEDLE TO TAKE DRUG Logic.assigned'
                  91='(91) NEVER USED ANY OF THE DRUGS LISTED ABOVE'
                  93='(93) NEVER USED A NEEDLE TO TAKE ANY DRUG' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE gnndlhal  1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED ANY DRUGS LISTED ABOVE Logic.assigned'
                  83='(83) NEVER USED A NEEDLE TO TAKE DRUG Logic.assigned'
                  91='(91) NEVER USED ANY OF THE DRUGS LISTED ABOVE'
                  93='(93) NEVER USED A NEEDLE TO TAKE ANY DRUG' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE gnndlher  1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED (frm HRNDLREC)'
                  81='(81) NEVER USED ANY DRUGS LISTED ABOVE Logic.assigned'
                  83='(83) NEVER USED A NEEDLE TO TAKE DRUG Logic.assigned'
                  91='(91) NEVER USED ANY OF THE DRUGS LISTED ABOVE'
                  93='(93) NEVER USED A NEEDLE TO TAKE ANY DRUG' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE gnndlopt  1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED ANY DRUGS LISTED ABOVE Logic.assigned'
                  83='(83) NEVER USED A NEEDLE TO TAKE DRUG Logic.assigned'
                  91='(91) NEVER USED ANY OF THE DRUGS LISTED ABOVE'
                  93='(93) NEVER USED A NEEDLE TO TAKE ANY DRUG' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE gnndlstr  1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED ANY DRUGS LSTD ABOVE Logically assigned'
                  83='(83) NEVER USED A NEEDLE TO TAKE DRUG Logic.assigned'
                  91='(91) NEVER USED ANY OF THE DRUGS LISTED ABOVE'
                  93='(93) NEVER USED A NEEDLE TO TAKE ANY DRUG' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE gnndlnon  2='(2) Response not circled'
                  81='(81) NEVER USED ANY DRUGS LISTED ABOVE Logic.assigned'
                  83='(83) NEVER USED A NEEDLE TO TAKE DRUG Logic.assigned'
                  85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED ANY OF THE DRUGS LISTED ABOVE'
                  93='(93) NEVER USED A NEEDLE TO TAKE ANY DRUG' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE gnndlshf  1='(1) Yes, have used a needle after someone else used it'
                  2='(2) No, have not used a needle after someone used it'
                  81='(81) NEVER USED ANY DRUG Logically assigned'
                  83='(83) NEVER USED A NEEDLE TO TAKE DRUG Logic.assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUG'
                  93='(93) NEVER USED A NEEDLE TO TAKE ANY DRUG' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE gnndls0f  1='(1) Yes, someone used a needle after I used it'
                  2='(2) No, no one has used a needle after I used it'
                  81='(81) NEVER USED ANY DRUG Logically assigned'
                  83='(83) NEVER USED A NEEDLE TO TAKE DRUG Logic. assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANY DRUG'
                  93='(93) NEVER USED A NEEDLE TO TAKE ANY DRUG' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE sptread   1='(1) Wants interviewer to continue reading'
                  2='(2) Wants to do it himself/herself' 98='(98) BLANK (NO ANSWER)' ;
  VALUE drugtest  1='(1) Yes' 2='(2) No' 3='(3) Did not have a job during past 12 months'
                  85='(85) BAD DATA Logically assigned' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE testpos   1='(1) Yes' 2='(2) No' 3='(3) Did not receive test in past 12 months'
                  4='(4) Did not have a job during past 12 months'
                  85='(85) BAD DATA Logically assigned' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE icelife   1='(1) Yes' 3='(3) Yes LOGICALLY IMPUTED'
                  81='(81) NEVER USED ICE Logically assigned' 91='(91) NEVER USED ICE'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE icerec    1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago but less than 10 years ago'
                  6='(6) 10 or more years ago'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  81='(81) NEVER USED ICE Logically assigned' 91='(91) NEVER USED ICE'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE steropp   981='(981) NEVER HAD CHANCE TO TRY ANABOLIC STEROIDS Log.asn'
                  985='(985) BAD DATA Logically assigned'
                  991='(991) NEVER HAD A CHANCE TO TRY ANABOLIC STEROIDS'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' ;
  VALUE sterage   981='(981) NEVER USED ANABOLIC STEROIDS Logically assigned'
                  985='(985) BAD DATA Logically assigned'
                  991='(991) NEVER USED ANABOLIC STEROIDS' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE stertot   1='(1) 1 or 2 times' 2='(2) 3 to 5 times' 3='(3) 6 to 10 times'
                  4='(4) 11 to 49 times' 5='(5) 50 to 99 times' 6='(6) 100 to 199 times'
                  7='(7) 200 or more times'
                  81='(81) NEVER USED ANABOLIC STEROIDS Logically assigned'
                  85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED ANABOLIC STEROIDS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE sterrec   1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  81='(81) NEVER USED ANABOLIC STEROIDS Logically assigned'
                  91='(91) NEVER USED ANABOLIC STEROIDS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE spnewa    0='(0) None (code used only for question SP-9)'
                  116='(116) Methaqualone, Quaalude, Sopor'
                  120='(120) Downers; OTHER Sedative, NOT SPECIFIED'
                  142='(142) Belladona' 222='(222) USED TRANQUILIZER, DON''T KNOW NAME'
                  240='(240) Lithium carbonate'
                  322='(322) Methamphetamine (speed or ice or crank)'
                  326='(326) White cross' 327='(327) Black beauties, Black Beauty'
                  339='(339) Amphetamines (speed generically)' 348='(348) Crystal'
                  355='(355) Crystal meth' 375='(375) sic'
                  409='(409) Tylenol with Codeine, Tylenol 3, Tylenol'
                  415='(415) Codeine'
                  434='(434) Co-Gesic, Hydrocodone, Tussionex, Vicodin'
                  438='(438) Anaprox, Naprosyn' 516='(516) Freon' 601='(601) see also 618'
                  604='(604) Psilocybin (mushrooms)' 606='(606) sic' 611='(611) Greens'
                  636='(636) STP' 654='(654) Eve' 658='(658) Special' 660='(660) Toad, Toad licking'
                  703='(703) Opium' 705='(705) Speed Ball (heroin + cocaine)' 803='(803) sic'
                  804='(804) Hashish' 805='(805) Cocaine, coke, coca' 806='(806) Crack, rock'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  813='(813) Cigarettes, smoking (subst spec), tobacco not spec'
                  824='(824) Steroids' 828='(828) Tetracycline' 832='(832) Primo'
                  844='(844) Blood pressure medication' 857='(857) sic' 859='(859) sic'
                  866='(866) Boomers' 867='(867) Boron' 868='(868) sic' 872='(872) sic'
                  873='(873) Contraceptives, Ferutal, Ortho Novum' 880='(880) Frios'
                  881='(881) YLOALE' 900='(900) Non-Drug reason given for Drug Problem'
                  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' ;
  VALUE spnewb    239='(239) see also 228'
                  322='(322) Methamphetamine (speed or ice or crank)'
                  332='(332) see also 346' 339='(339) Amphetamines (speed generically)'
                  348='(348) Crystal' 355='(355) Crystal meth' 456='(456) see also 434'
                  601='(601) see also 618' 605='(605) PCP (angel dust, phencyclidine)'
                  616='(616) DMT' 803='(803) sic' 805='(805) Cocaine, coke, coca'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  813='(813) Cigarettes, smoking (subst spec), tobacco not spec'
                  816='(816) Smokeless tobacco, snuff, chewing tobacco'
                  824='(824) Steroids' 852='(852) sic' 871='(871) sic' 876='(876) Glass'
                  878='(878) Friying' 900='(900) Non-Drug reason given for Drug Problem'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' ;
  VALUE spnewc    355='(355) Crystal meth' 406='(406) Oxycodone, Percodan, Roxicet'
                  601='(601) see also 618' 605='(605) PCP (angel dust, phencyclidine)'
                  652='(652) ALD-52, ALD-S2 (version of LSD)' 803='(803) sic'
                  804='(804) Hashish'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' ;
  VALUE spnewd    806='(806) Crack, rock' 879='(879) Dimethyltriptamide MMPT'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' ;
  VALUE spnewe    701='(701) OTHER Opiates, NOT SPECIFIED' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE booked    1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE nobookyr  0='(0) Was not arrested and booked in past 12 months'
                  85='(85) BAD DATA Logically assigned' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE bklarcny  1='(1) Response circled' 2='(2) Response not circled'
                  85='(85) BAD DATA Logically assigned' 94='(94) DON''T KNOW'
                  97='(97) REFUSED'
                  98='(98) BOOKED IN PAST YEAR BUT SP-12 NOT ANSWERED' ;
  VALUE bkburgl   1='(1) Response circled' 2='(2) Response not circled'
                  85='(85) BAD DATA Logically assigned' 94='(94) DON''T KNOW'
                  97='(97) REFUSED'
                  98='(98) BOOKED IN PAST YEAR BUT SP-12 NOT ANSWERED' ;
  VALUE bkagaslt  1='(1) Response circled' 2='(2) Response not circled'
                  85='(85) BAD DATA Logically assigned' 94='(94) DON''T KNOW'
                  97='(97) REFUSED'
                  98='(98) BOOKED IN PAST YEAR BUT SP-12 NOT ANSWERED' ;
  VALUE bksmaslt  1='(1) Response circled' 2='(2) Response not circled'
                  85='(85) BAD DATA Logically assigned' 94='(94) DON''T KNOW'
                  97='(97) REFUSED'
                  98='(98) BOOKED IN PAST YEAR BUT SP-12 NOT ANSWERED' ;
  VALUE bkmvthft  1='(1) Response circled' 2='(2) Response not circled'
                  85='(85) BAD DATA Logically assigned' 94='(94) DON''T KNOW'
                  97='(97) REFUSED'
                  98='(98) BOOKED IN PAST YEAR BUT SP-12 NOT ANSWERED' ;
  VALUE bkrob     1='(1) Response circled' 2='(2) Response not circled'
                  85='(85) BAD DATA Logically assigned' 94='(94) DON''T KNOW'
                  97='(97) REFUSED'
                  98='(98) BOOKED IN PAST YEAR BUT SP-12 NOT ANSWERED' ;
  VALUE bkrape    1='(1) Response circled' 2='(2) Response not circled'
                  85='(85) BAD DATA Logically assigned' 94='(94) DON''T KNOW'
                  97='(97) REFUSED'
                  98='(98) BOOKED IN PAST YEAR BUT SP-12 NOT ANSWERED' ;
  VALUE bkmurder  2='(2) Response not circled' 85='(85) BAD DATA Logically assigned'
                  94='(94) DON''T KNOW' 97='(97) REFUSED'
                  98='(98) BOOKED IN PAST YEAR BUT SP-12 NOT ANSWERED' ;
  VALUE bkarson   1='(1) Response circled' 2='(2) Response not circled'
                  85='(85) BAD DATA Logically assigned' 94='(94) DON''T KNOW'
                  97='(97) REFUSED'
                  98='(98) BOOKED IN PAST YEAR BUT SP-12 NOT ANSWERED' ;
  VALUE bkdrvinf  1='(1) Response circled' 2='(2) Response not circled'
                  85='(85) BAD DATA Logically assigned' 94='(94) DON''T KNOW'
                  97='(97) REFUSED'
                  98='(98) BOOKED IN PAST YEAR BUT SP-12 NOT ANSWERED' ;
  VALUE bkdrunk   1='(1) Response circled' 2='(2) Response not circled'
                  85='(85) BAD DATA Logically assigned' 94='(94) DON''T KNOW'
                  97='(97) REFUSED'
                  98='(98) BOOKED IN PAST YEAR BUT SP-12 NOT ANSWERED' ;
  VALUE bkdrug    1='(1) Response circled' 2='(2) Response not circled'
                  85='(85) BAD DATA Logically assigned' 94='(94) DON''T KNOW'
                  97='(97) REFUSED'
                  98='(98) BOOKED IN PAST YEAR BUT SP-12 NOT ANSWERED' ;
  VALUE bkpros    1='(1) Response circled' 2='(2) Response not circled'
                  85='(85) BAD DATA Logically assigned' 94='(94) DON''T KNOW'
                  97='(97) REFUSED'
                  98='(98) BOOKED IN PAST YEAR BUT SP-12 NOT ANSWERED' ;
  VALUE bkvandal  1='(1) Response circled' 2='(2) Response not circled'
                  85='(85) BAD DATA Logically assigned' 94='(94) DON''T KNOW'
                  97='(97) REFUSED'
                  98='(98) BOOKED IN PAST YEAR BUT SP-12 NOT ANSWERED' ;
  VALUE bkothoff  1='(1) Larceny or theft' 2='(2) Burglary or breaking and entering'
                  3='(3) Aggravated assault'
                  4='(4) Other assault, such as simple assault or battery'
                  6='(6) Robbery'
                  8='(8) Murder, homicide, or nonnegligent manslaughter'
                  10='(10) Driving under the influence'
                  11='(11) Drunkenness or other liquor law violation'
                  12='(12) Possession or sale of drugs'
                  14='(14) Oth proprty offns:- fraud, poss stln goods, vndlsm'
                  15='(15) Other offenses (NOT SPECIFIED)' 16='(16) Weapons offenses'
                  17='(17) Other offenses against persons'
                  18='(18) Violation of court order, parole, probation'
                  19='(19) Public order offenses' 20='(20) Juvenile status offenses'
                  22='(22) Traffic violations' 85='(85) BAD DATA Logically assigned'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE notbked   1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED'
                  85='(85) BAD DATA Logically assigned' 94='(94) DON''T KNOW'
                  97='(97) REFUSED'
                  98='(98) BOOKED IN PAST YEAR BUT SP-12 NOT ANSWERED' ;
  VALUE probaton  1='(1) Yes' 2='(2) No' 94='(94) DON''T KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE parole    1='(1) Yes' 2='(2) No' 94='(94) DON''T KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE strsteal  1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE othsteal  1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE damage    1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE carsteal  1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE forcemon  1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE breakin   1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE phyfight  1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE hurtbad   1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE gunmoney  1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE drunkdrv  1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE solddrug  1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE othdoing  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED'
                  85='(85) BAD DATA Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE othdospf  1='(1) Shoplifting' 2='(2) Other larceny or theft'
                  3='(3) Property damage/destruction (incl. vandalism)'
                  4='(4) Motor vehicle theft' 5='(5) Robbery'
                  6='(6) Breaking and entering'
                  7='(7) Hitting someone or physically fighting'
                  8='(8) Hurting someone enough to need medical attn'
                  9='(9) Other assault, battery'
                  10='(10) Driving under the influence of alcohol or drugs'
                  11='(11) Selling illegal drugs'
                  12='(12) Drug offense (except sales) involving marijuana'
                  13='(13) Other drug-related offenses'
                  14='(14) Drunkenness or other liquor law violation'
                  17='(17) Other offenses against persons' 18='(18) Arson'
                  19='(19) Nondestructive prop offenses, fraud, stln goods'
                  20='(20) Prostitution of commercialized sex'
                  21='(21) Weapons offenses'
                  22='(22) Violation of court order, parole, probation'
                  23='(23) Public order offenses' 24='(24) Juvenile status offenses'
                  26='(26) Traffic violations' 27='(27) Other offenses, NOT SPECIFIED'
                  85='(85) BAD DATA Logically assigned' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE othdos0f  1='(1) Shoplifting' 2='(2) Other larceny or theft'
                  3='(3) Property damage/destruction (incl. vandalism)'
                  4='(4) Motor vehicle theft'
                  7='(7) Hitting someone or physically fighting'
                  8='(8) Hurting someone enough to need medical attn'
                  9='(9) Other assault, battery'
                  10='(10) Driving under the influence of alcohol or drugs'
                  11='(11) Selling illegal drugs'
                  12='(12) Drug offense (except sales) involving marijuana'
                  13='(13) Other drug-related offenses'
                  14='(14) Drunkenness or other liquor law violation' 18='(18) Arson'
                  19='(19) Nondestructive prop offenses, fraud, stln goods'
                  21='(21) Weapons offenses' 23='(23) Public order offenses'
                  24='(24) Juvenile status offenses' 26='(26) Traffic violations'
                  27='(27) Other offenses, NOT SPECIFIED'
                  85='(85) BAD DATA Logically assigned' 98='(98) BLANK (NO ANSWER)' ;
  VALUE dexread   1='(1) Wants interviewer to continue reading'
                  2='(2) Wants to do it himself/herself' 96='(96) MULTIPLE RESPONSE'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE noboozyr  1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED'
                  85='(85) BAD DATA Logically assigned' ;
  VALUE alcaggr   1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE alcargum  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE alcabsnt  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE alchigh   1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE alcjob    1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE alcmatcd  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE alcrelcd  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE alcfrdcd  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE alctoss   1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE alcholic  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE alcdrunk  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE alcintox  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE alcrem    1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE alcquick  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE alcmorn   1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE alcshook  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE alcalone  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE alcbrkpm  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE alcmj     1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) RESPONSE NOT CIRCLED' 99='(99) LEGITIMATE SKIP' ;
  VALUE alccoc    1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) RESPONSE NOT CIRCLED' 99='(99) LEGITIMATE SKIP' ;
  VALUE alcopt    1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) RESPONSE NOT CIRCLED' 99='(99) LEGITIMATE SKIP' ;
  VALUE alchal    1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) RESPONSE NOT CIRCLED' 99='(99) LEGITIMATE SKIP' ;
  VALUE alcinh    1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) RESPONSE NOT CIRCLED' 99='(99) LEGITIMATE SKIP' ;
  VALUE alcanal   1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) RESPONSE NOT CIRCLED' 99='(99) LEGITIMATE SKIP' ;
  VALUE alctran   1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) RESPONSE NOT CIRCLED' 99='(99) LEGITIMATE SKIP' ;
  VALUE alcstm    1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) RESPONSE NOT CIRCLED' 99='(99) LEGITIMATE SKIP' ;
  VALUE alcsed    1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) RESPONSE NOT CIRCLED' 99='(99) LEGITIMATE SKIP' ;
  VALUE as13none  1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED'
                  85='(85) BAD DATA Logically assigned' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' ;
  VALUE drdeprss  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE depdrg1a  116='(116) Methaqualone, Quaalude, Sopor' 201='(201) Valium'
                  209='(209) Xanax' 221='(221) OTHER Tranquilizer, NOT SPECIFIED'
                  241='(241) Prozac' 312='(312) Ionamin' 313='(313) Fastin, Phentermine'
                  322='(322) Methamphetamine (speed or ice or crank)'
                  324='(324) Uppers; OTHER Stimulant, NOT SPECIFIED'
                  339='(339) Amphetamines (speed generically)' 348='(348) Crystal'
                  355='(355) Crystal meth' 375='(375) sic'
                  426='(426) Butalbital, Fiorinal, Phrenilin Forte'
                  501='(501) Gasoline or lighter fluids' 502='(502) Spray paints'
                  510='(510) OTHER Inhalant, NOT SPECIFIED' 557='(557) Hagwash'
                  601='(601) see also 618' 605='(605) PCP (angel dust, phencyclidine)'
                  606='(606) sic' 702='(702) Heroin' 704='(704) Dope'
                  801='(801) OTHER Drugs, NOT SPECIFIED' 803='(803) sic' 804='(804) Hashish'
                  805='(805) Cocaine, coke, coca' 806='(806) Crack, rock'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  808='(808) All of the ones I''ve tried' 809='(809) Pills' 810='(810) Hemp'
                  812='(812) Cigars'
                  813='(813) Cigarettes, smoking (subst spec), tobacco not spec'
                  814='(814) Caffeine'
                  816='(816) Smokeless tobacco, snuff, chewing tobacco' 869='(869) sic'
                  874='(874) Premarin' 900='(900) Non-Drug reason given for Drug Problem'
                  989='(989) LEGITIMATE SKIP Logically assigned' 994='(994) DON''T KNOW'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE depdrg2a  120='(120) Downers; OTHER Sedative, NOT SPECIFIED'
                  221='(221) OTHER Tranquilizer, NOT SPECIFIED'
                  322='(322) Methamphetamine (speed or ice or crank)'
                  324='(324) Uppers; OTHER Stimulant, NOT SPECIFIED'
                  339='(339) Amphetamines (speed generically)' 348='(348) Crystal'
                  601='(601) see also 618' 605='(605) PCP (angel dust, phencyclidine)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 702='(702) Heroin'
                  803='(803) sic' 805='(805) Cocaine, coke' 806='(806) Crack, rock'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  813='(813) Cigarettes, smoking (subst spec), tobacco not spec'
                  840='(840) Cough medicine (contents not specified)'
                  900='(900) Non-Drug reason given for Drug Problem'
                  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE depdrg3a  339='(339) Amphetamines (speed generically)'
                  510='(510) OTHER Inhalant, NOT SPECIFIED' 601='(601) see also 618'
                  604='(604) Psilocybin (mushrooms)' 803='(803) sic' 804='(804) Hashish'
                  805='(805) Cocaine, coke' 806='(806) Crack, rock'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  813='(813) Cigarettes, smoking (subst spec), tobacco not spec'
                  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE depdrg4a  415='(415) Codeine' 601='(601) see also 618'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 805='(805) Cocaine, coke'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  809='(809) Pills' 994='(994) DON''T KNOW' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE depdrg5a  607='(607) OTHER Hallucinogen, NOT SPECIFIED'
                  900='(900) Non-Drug reason given for Drug Problem'
                  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE drargum   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE argdrg1a  209='(209) Xanax' 221='(221) OTHER Tranquilizer, NOT SPECIFIED'
                  241='(241) Prozac' 312='(312) Ionamin'
                  322='(322) Methamphetamine (speed or ice or crank)'
                  324='(324) Uppers; OTHER Stimulant, NOT SPECIFIED'
                  339='(339) Amphetamines (speed generically)' 348='(348) Crystal'
                  355='(355) Crystal meth' 415='(415) Codeine' 440='(440) Soma' 557='(557) Hagwash'
                  601='(601) see also 618' 605='(605) PCP (angel dust, phencyclidine)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 702='(702) Heroin'
                  704='(704) Dope' 801='(801) OTHER Drugs, NOT SPECIFIED' 803='(803) sic'
                  804='(804) Hashish' 805='(805) Cocaine, coke, coca' 806='(806) Crack, rock'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  808='(808) All of the ones I''ve tried' 810='(810) Hemp' 812='(812) Cigars'
                  813='(813) Cigarettes, smoking (subst spec), tobacco not spec'
                  816='(816) Smokeless tobacco, snuff, chewing tobacco'
                  818='(818) Nicotine' 824='(824) Steroids'
                  900='(900) Non-Drug reason given for Drug Problem'
                  989='(989) LEGITIMATE SKIP Logically assigned' 994='(994) DON''T KNOW'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE argdrg2a  221='(221) OTHER Tranquilizer, NOT SPECIFIED'
                  324='(324) Uppers; OTHER Stimulant, NOT SPECIFIED'
                  332='(332) see also 346' 339='(339) Amphetamines (speed generically)'
                  348='(348) Crystal' 408='(408) Dilaudid' 601='(601) see also 618'
                  605='(605) PCP (angel dust, phencyclidine)' 702='(702) Heroin'
                  803='(803) sic' 805='(805) Cocaine, coke' 806='(806) Crack, rock'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  813='(813) Cigarettes, smoking (subst spec), tobacco not spec'
                  840='(840) Cough medicine (contents not specified)'
                  900='(900) Non-Drug reason given for Drug Problem'
                  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE argdrg3a  601='(601) see also 618' 605='(605) PCP (angel dust, phencyclidine)'
                  803='(803) sic' 805='(805) Cocaine, coke'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  813='(813) Cigarettes, smoking (subst spec), tobacco not spec'
                  900='(900) Non-Drug reason given for Drug Problem'
                  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE argdrg4a  508='(508) Nitrous oxide, whippets, dentist gas'
                  805='(805) Cocaine, coke'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE argdrg5a  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE dralone   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE alndrg1a  201='(201) Valium' 209='(209) Xanax'
                  221='(221) OTHER Tranquilizer, NOT SPECIFIED' 241='(241) Prozac'
                  312='(312) Ionamin' 322='(322) Methamphetamine (speed or ice or crank)'
                  324='(324) Uppers; OTHER Stimulant, NOT SPECIFIED'
                  339='(339) Amphetamines (speed generically)' 348='(348) Crystal'
                  355='(355) Crystal meth' 401='(401) Darvon'
                  406='(406) Oxycodone, Percodan, Roxicet' 408='(408) Dilaudid'
                  601='(601) see also 618' 604='(604) Psilocybin (mushrooms)'
                  605='(605) PCP (angel dust, phencyclidine)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 702='(702) Heroin'
                  704='(704) Dope' 707='(707) Black Tar' 801='(801) OTHER Drugs, NOT SPECIFIED'
                  803='(803) sic' 805='(805) Cocaine, coke, coca' 806='(806) Crack, rock'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  808='(808) All of the ones I''ve tried' 809='(809) Pills' 812='(812) Cigars'
                  813='(813) Cigarettes, smoking (subst spec), tobacco not spec'
                  900='(900) Non-Drug reason given for Drug Problem'
                  989='(989) LEGITIMATE SKIP Logically assigned' 994='(994) DON''T KNOW'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE alndrg2a  209='(209) Xanax' 324='(324) Uppers; OTHER Stimulant, NOT SPECIFIED'
                  434='(434) Co-Gesic, Hydrocodone, Tussionex, Vicodin'
                  601='(601) see also 618' 605='(605) PCP (angel dust, phencyclidine)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 702='(702) Heroin'
                  803='(803) sic' 805='(805) Cocaine, coke' 806='(806) Crack, rock'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  813='(813) Cigarettes, smoking (subst spec), tobacco not spec'
                  840='(840) Cough medicine (contents not specified)'
                  848='(848) Liquid vitamin'
                  900='(900) Non-Drug reason given for Drug Problem'
                  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE alndrg3a  803='(803) sic' 805='(805) Cocaine, coke'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  813='(813) Cigarettes, smoking (subst spec), tobacco not spec'
                  900='(900) Non-Drug reason given for Drug Problem'
                  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE alndrg4a  510='(510) OTHER Inhalant, NOT SPECIFIED'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  809='(809) Pills' 994='(994) DON''T KNOW' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE alndrg5a  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 994='(994) DON''T KNOW'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE dranx     1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE anxdrg1a  209='(209) Xanax' 221='(221) OTHER Tranquilizer, NOT SPECIFIED'
                  241='(241) Prozac' 247='(247) Adapin, Doxepin, Sinequan' 271='(271) Zoloft'
                  301='(301) Dexedrine' 309='(309) Didrex' 312='(312) Ionamin'
                  313='(313) Fastin, Phentermine'
                  322='(322) Methamphetamine (speed or ice or crank)'
                  324='(324) Uppers; OTHER Stimulant, NOT SPECIFIED'
                  332='(332) see also 346' 336='(336) Diet pills'
                  339='(339) Amphetamines (speed generically)' 348='(348) Crystal'
                  354='(354) Vivarin' 355='(355) Crystal meth' 375='(375) sic' 408='(408) Dilaudid'
                  415='(415) Codeine' 420='(420) OTHER Analgesic, NOT SPECIFIED'
                  435='(435) Tylenol, Tylenol Extrastrength'
                  510='(510) OTHER Inhalant, NOT SPECIFIED' 557='(557) Hagwash'
                  601='(601) see also 618' 605='(605) PCP (angel dust, phencyclidine)'
                  606='(606) sic' 607='(607) OTHER Hallucinogen, NOT SPECIFIED'
                  702='(702) Heroin' 704='(704) Dope' 801='(801) OTHER Drugs, NOT SPECIFIED'
                  803='(803) sic' 804='(804) Hashish' 805='(805) Cocaine, coke, coca'
                  806='(806) Crack, rock'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  808='(808) All of the ones I''ve tried' 812='(812) Cigars'
                  813='(813) Cigarettes, smoking (subst spec), tobacco not spec'
                  814='(814) Caffeine' 815='(815) Coffee'
                  816='(816) Smokeless tobacco, snuff, chewing tobacco'
                  818='(818) Nicotine' 873='(873) Contraceptives, Ferutal, Ortho Novum'
                  900='(900) Non-Drug reason given for Drug Problem'
                  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE anxdrg2a  120='(120) Downers; OTHER Sedative, NOT SPECIFIED'
                  322='(322) Methamphetamine (speed or ice or crank)'
                  324='(324) Uppers; OTHER Stimulant, NOT SPECIFIED'
                  339='(339) Amphetamines (speed generically)' 355='(355) Crystal meth'
                  601='(601) see also 618' 604='(604) Psilocybin (mushrooms)'
                  605='(605) PCP (angel dust, phencyclidine)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 702='(702) Heroin'
                  803='(803) sic' 805='(805) Cocaine, coke' 806='(806) Crack, rock'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  813='(813) Cigarettes, smoking (subst spec), tobacco not spec'
                  840='(840) Cough medicine (contents not specified)'
                  900='(900) Non-Drug reason given for Drug Problem'
                  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE anxdrg3a  326='(326) White cross' 702='(702) Heroin' 803='(803) sic'
                  805='(805) Cocaine, coke'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  813='(813) Cigarettes, smoking (subst spec), tobacco not spec'
                  900='(900) Non-Drug reason given for Drug Problem'
                  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE anxdrg4a  510='(510) OTHER Inhalant, NOT SPECIFIED'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  809='(809) Pills' 994='(994) DON''T KNOW' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE anxdrg5a  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 994='(994) DON''T KNOW'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE drhealth  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE hltdrg1a  209='(209) Xanax' 312='(312) Ionamin'
                  322='(322) Methamphetamine (speed or ice or crank)'
                  339='(339) Amphetamines (speed generically)' 348='(348) Crystal'
                  355='(355) Crystal meth' 362='(362) Benadryl' 408='(408) Dilaudid'
                  501='(501) Gasoline or lighter fluids' 557='(557) Hagwash'
                  601='(601) see also 618' 605='(605) PCP (angel dust, phencyclidine)'
                  639='(639) Cloves, Nutmeg' 702='(702) Heroin' 704='(704) Dope'
                  801='(801) OTHER Drugs, NOT SPECIFIED' 803='(803) sic'
                  805='(805) Cocaine, coke, coca' 806='(806) Crack, rock'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  809='(809) Pills' 812='(812) Cigars'
                  813='(813) Cigarettes, smoking (subst spec), tobacco not spec'
                  814='(814) Caffeine'
                  816='(816) Smokeless tobacco, snuff, chewing tobacco'
                  818='(818) Nicotine' 870='(870) sic'
                  900='(900) Non-Drug reason given for Drug Problem'
                  989='(989) LEGITIMATE SKIP Logically assigned' 992='(992) ILLEGIBLE'
                  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE hltdrg2a  332='(332) see also 346' 339='(339) Amphetamines (speed generically)'
                  426='(426) Butalbital, Fiorinal, Phrenilin Forte'
                  506='(506) Amyl nitrite, poppers, locker rm odorizer,rush'
                  530='(530) Asthma inhaler, asthma med., bronchial dilators'
                  601='(601) see also 618' 605='(605) PCP (angel dust, phencyclidine)'
                  702='(702) Heroin' 803='(803) sic' 805='(805) Cocaine, coke, coca'
                  806='(806) Crack, rock'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  812='(812) Cigars'
                  813='(813) Cigarettes, smoking (subst spec), tobacco not spec'
                  814='(814) Caffeine' 815='(815) Coffee'
                  816='(816) Smokeless tobacco, snuff, chewing tobacco'
                  865='(865) Diuretics, Water pills'
                  900='(900) Non-Drug reason given for Drug Problem'
                  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE hltdrg3a  339='(339) Amphetamines (speed generically)' 348='(348) Crystal'
                  702='(702) Heroin' 803='(803) sic'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  813='(813) Cigarettes, smoking (subst spec), tobacco not spec'
                  900='(900) Non-Drug reason given for Drug Problem'
                  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE hltdrg4a  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE hltdrg5a  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE drnthink  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE ntkdrg1a  116='(116) Methaqualone, Quaalude, Sopor'
                  120='(120) Downers; OTHER Sedative, NOT SPECIFIED' 209='(209) Xanax'
                  221='(221) OTHER Tranquilizer, NOT SPECIFIED' 241='(241) Prozac'
                  247='(247) Adapin, Doxepin, Sinequan' 271='(271) Zoloft' 312='(312) Ionamin'
                  322='(322) Methamphetamine (speed or ice or crank)'
                  324='(324) Uppers; OTHER Stimulant, NOT SPECIFIED'
                  336='(336) Diet pills' 339='(339) Amphetamines (speed generically)'
                  348='(348) Crystal' 354='(354) Vivarin' 355='(355) Crystal meth' 401='(401) Darvon'
                  407='(407) Demerol' 408='(408) Dilaudid'
                  409='(409) Tylenol with Codeine, Tylenol 3, Tylenol'
                  418='(418) Methadone' 501='(501) Gasoline or lighter fluids'
                  502='(502) Spray paints'
                  504='(504) Shoeshine liq, glue,toluene,Super Glue,rubber cem'
                  510='(510) OTHER Inhalant, NOT SPECIFIED'
                  511='(511) Markers, felt-tip pens, ink pens' 601='(601) see also 618'
                  605='(605) PCP (angel dust, phencyclidine)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 609='(609) sic'
                  702='(702) Heroin' 704='(704) Dope' 705='(705) Speed Ball (heroin + cocaine)'
                  801='(801) OTHER Drugs, NOT SPECIFIED' 803='(803) sic' 804='(804) Hashish'
                  805='(805) Cocaine, coke, coca' 806='(806) Crack, rock'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  810='(810) Hemp' 812='(812) Cigars'
                  813='(813) Cigarettes, smoking (subst spec), tobacco not spec'
                  815='(815) Coffee' 823='(823) sic'
                  840='(840) Cough medicine (contents not specified)'
                  873='(873) Contraceptives, Ferutal, Ortho Novum'
                  900='(900) Non-Drug reason given for Drug Problem'
                  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE ntkdrg2a  322='(322) Methamphetamine (speed or ice or crank)'
                  339='(339) Amphetamines (speed generically)' 348='(348) Crystal'
                  407='(407) Demerol' 420='(420) OTHER Analgesic, NOT SPECIFIED'
                  426='(426) Butalbital, Fiorinal, Phrenilin Forte'
                  506='(506) Amyl nitrite, poppers, locker rm odorizer,rush'
                  508='(508) Nitrous oxide, whippets, dentist gas'
                  510='(510) OTHER Inhalant, NOT SPECIFIED' 601='(601) see also 618'
                  605='(605) PCP (angel dust, phencyclidine)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 702='(702) Heroin'
                  803='(803) sic' 805='(805) Cocaine, coke' 806='(806) Crack, rock'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  809='(809) Pills'
                  813='(813) Cigarettes, smoking (subst spec), tobacco not spec'
                  816='(816) Smokeless tobacco, snuff, chewing tobacco'
                  900='(900) Non-Drug reason given for Drug Problem'
                  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE ntkdrg3a  324='(324) Uppers; OTHER Stimulant, NOT SPECIFIED'
                  339='(339) Amphetamines (speed generically)' 601='(601) see also 618'
                  602='(602) Peyote' 607='(607) OTHER Hallucinogen, NOT SPECIFIED'
                  702='(702) Heroin' 803='(803) sic' 804='(804) Hashish' 805='(805) Cocaine, coke'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  813='(813) Cigarettes, smoking (subst spec), tobacco not spec'
                  900='(900) Non-Drug reason given for Drug Problem'
                  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE ntkdrg4a  415='(415) Codeine' 510='(510) OTHER Inhalant, NOT SPECIFIED' 803='(803) sic'
                  805='(805) Cocaine, coke'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE ntkdrg5a  201='(201) Valium' 607='(607) OTHER Hallucinogen, NOT SPECIFIED'
                  803='(803) sic' 994='(994) DON''T KNOW' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE drupset   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE upsdrg1a  209='(209) Xanax' 221='(221) OTHER Tranquilizer, NOT SPECIFIED'
                  241='(241) Prozac' 312='(312) Ionamin'
                  322='(322) Methamphetamine (speed or ice or crank)'
                  324='(324) Uppers; OTHER Stimulant, NOT SPECIFIED'
                  332='(332) see also 346' 339='(339) Amphetamines (speed generically)'
                  348='(348) Crystal' 355='(355) Crystal meth'
                  406='(406) Oxycodone, Percodan, Roxicet'
                  409='(409) Tylenol with Codeine, Tylenol 3, Tylenol'
                  434='(434) Co-Gesic, Hydrocodone, Tussionex, Vicodin'
                  510='(510) OTHER Inhalant, NOT SPECIFIED' 601='(601) see also 618'
                  604='(604) Psilocybin (mushrooms)'
                  605='(605) PCP (angel dust, phencyclidine)' 702='(702) Heroin'
                  704='(704) Dope' 801='(801) OTHER Drugs, NOT SPECIFIED' 803='(803) sic'
                  805='(805) Cocaine, coke, coca' 806='(806) Crack, rock'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  808='(808) All of the ones I''ve tried' 810='(810) Hemp' 812='(812) Cigars'
                  813='(813) Cigarettes, smoking (subst spec), tobacco not spec'
                  814='(814) Caffeine' 815='(815) Coffee'
                  816='(816) Smokeless tobacco, snuff, chewing tobacco'
                  818='(818) Nicotine' 824='(824) Steroids'
                  840='(840) Cough medicine (contents not specified)'
                  900='(900) Non-Drug reason given for Drug Problem'
                  989='(989) LEGITIMATE SKIP Logically assigned' 994='(994) DON''T KNOW'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE upsdrg2a  324='(324) Uppers; OTHER Stimulant, NOT SPECIFIED'
                  339='(339) Amphetamines (speed generically)' 408='(408) Dilaudid'
                  434='(434) Co-Gesic, Hydrocodone, Tussionex, Vicodin'
                  508='(508) Nitrous oxide, whippets, dentist gas'
                  601='(601) see also 618' 605='(605) PCP (angel dust, phencyclidine)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 702='(702) Heroin'
                  803='(803) sic' 805='(805) Cocaine, coke' 806='(806) Crack, rock'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  809='(809) Pills' 811='(811) Muscle relaxers'
                  813='(813) Cigarettes, smoking (subst spec), tobacco not spec'
                  814='(814) Caffeine' 815='(815) Coffee'
                  900='(900) Non-Drug reason given for Drug Problem'
                  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE upsdrg3a  437='(437) Parafon Forte' 601='(601) see also 618'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 702='(702) Heroin'
                  803='(803) sic' 805='(805) Cocaine, coke'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  809='(809) Pills'
                  813='(813) Cigarettes, smoking (subst spec), tobacco not spec'
                  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE upsdrg4a  510='(510) OTHER Inhalant, NOT SPECIFIED' 803='(803) sic'
                  805='(805) Cocaine, coke'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  813='(813) Cigarettes, smoking (subst spec), tobacco not spec'
                  900='(900) Non-Drug reason given for Drug Problem'
                  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE upsdrg5a  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 994='(994) DON''T KNOW'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE drlswork  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE lswdrg1a  201='(201) Valium' 312='(312) Ionamin'
                  322='(322) Methamphetamine (speed or ice or crank)'
                  324='(324) Uppers; OTHER Stimulant, NOT SPECIFIED'
                  336='(336) Diet pills' 339='(339) Amphetamines (speed generically)'
                  348='(348) Crystal' 355='(355) Crystal meth'
                  406='(406) Oxycodone, Percodan, Roxicet'
                  501='(501) Gasoline or lighter fluids'
                  530='(530) Asthma inhaler, asthma med., bronchial dilators'
                  601='(601) see also 618' 605='(605) PCP (angel dust, phencyclidine)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 702='(702) Heroin'
                  704='(704) Dope' 801='(801) OTHER Drugs, NOT SPECIFIED' 803='(803) sic'
                  804='(804) Hashish' 805='(805) Cocaine, coke, coca' 806='(806) Crack, rock'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  810='(810) Hemp' 812='(812) Cigars'
                  813='(813) Cigarettes, smoking (subst spec), tobacco not spec'
                  815='(815) Coffee' 900='(900) Non-Drug reason given for Drug Problem'
                  989='(989) LEGITIMATE SKIP Logically assigned' 994='(994) DON''T KNOW'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE lswdrg2a  408='(408) Dilaudid' 508='(508) Nitrous oxide, whippets, dentist gas'
                  601='(601) see also 618' 605='(605) PCP (angel dust, phencyclidine)'
                  803='(803) sic' 805='(805) Cocaine, coke' 806='(806) Crack, rock'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  809='(809) Pills'
                  813='(813) Cigarettes, smoking (subst spec), tobacco not spec'
                  840='(840) Cough medicine (contents not specified)'
                  900='(900) Non-Drug reason given for Drug Problem'
                  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE lswdrg3a  339='(339) Amphetamines (speed generically)'
                  605='(605) PCP (angel dust, phencyclidine)' 803='(803) sic'
                  804='(804) Hashish'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  813='(813) Cigarettes, smoking (subst spec), tobacco not spec'
                  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE lswdrg4a  510='(510) OTHER Inhalant, NOT SPECIFIED' 805='(805) Cocaine, coke'
                  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE lswdrg5a  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 994='(994) DON''T KNOW'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE drsuspic  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE sspdrg1a  312='(312) Ionamin' 322='(322) Methamphetamine (speed or ice or crank)'
                  324='(324) Uppers; OTHER Stimulant, NOT SPECIFIED'
                  339='(339) Amphetamines (speed generically)' 348='(348) Crystal'
                  355='(355) Crystal meth' 601='(601) see also 618'
                  605='(605) PCP (angel dust, phencyclidine)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 702='(702) Heroin'
                  707='(707) Black Tar' 801='(801) OTHER Drugs, NOT SPECIFIED' 803='(803) sic'
                  804='(804) Hashish' 805='(805) Cocaine, coke, coca' 806='(806) Crack, rock'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  812='(812) Cigars'
                  813='(813) Cigarettes, smoking (subst spec), tobacco not spec'
                  816='(816) Smokeless tobacco, snuff, chewing tobacco'
                  840='(840) Cough medicine (contents not specified)'
                  900='(900) Non-Drug reason given for Drug Problem'
                  989='(989) LEGITIMATE SKIP Logically assigned' 994='(994) DON''T KNOW'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE sspdrg2a  322='(322) Methamphetamine (speed or ice or crank)'
                  408='(408) Dilaudid' 601='(601) see also 618'
                  604='(604) Psilocybin (mushrooms)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 803='(803) sic'
                  805='(805) Cocaine, coke' 806='(806) Crack, rock'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  809='(809) Pills'
                  813='(813) Cigarettes, smoking (subst spec), tobacco not spec'
                  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE sspdrg3a  339='(339) Amphetamines (speed generically)' 702='(702) Heroin'
                  803='(803) sic' 805='(805) Cocaine, coke'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  809='(809) Pills'
                  813='(813) Cigarettes, smoking (subst spec), tobacco not spec'
                  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE sspdrg4a  510='(510) OTHER Inhalant, NOT SPECIFIED' 805='(805) Cocaine, coke'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE sspdrg5a  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 994='(994) DON''T KNOW'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE drcope    1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE cpedrg1a  209='(209) Xanax' 221='(221) OTHER Tranquilizer, NOT SPECIFIED'
                  241='(241) Prozac' 312='(312) Ionamin'
                  322='(322) Methamphetamine (speed or ice or crank)'
                  339='(339) Amphetamines (speed generically)' 348='(348) Crystal'
                  355='(355) Crystal meth' 510='(510) OTHER Inhalant, NOT SPECIFIED'
                  601='(601) see also 618' 605='(605) PCP (angel dust, phencyclidine)'
                  702='(702) Heroin' 704='(704) Dope' 801='(801) OTHER Drugs, NOT SPECIFIED'
                  803='(803) sic' 805='(805) Cocaine, coke, coca' 806='(806) Crack, rock'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  809='(809) Pills' 812='(812) Cigars'
                  813='(813) Cigarettes, smoking (subst spec), tobacco not spec'
                  818='(818) Nicotine' 824='(824) Steroids' 877='(877) Methazolamide'
                  900='(900) Non-Drug reason given for Drug Problem'
                  989='(989) LEGITIMATE SKIP Logically assigned' 994='(994) DON''T KNOW'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE cpedrg2a  239='(239) see also 228' 408='(408) Dilaudid' 601='(601) see also 618'
                  605='(605) PCP (angel dust, phencyclidine)' 803='(803) sic'
                  805='(805) Cocaine, coke' 806='(806) Crack, rock'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  809='(809) Pills'
                  813='(813) Cigarettes, smoking (subst spec), tobacco not spec'
                  900='(900) Non-Drug reason given for Drug Problem'
                  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE cpedrg3a  339='(339) Amphetamines (speed generically)' 803='(803) sic'
                  804='(804) Hashish' 805='(805) Cocaine, coke'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  813='(813) Cigarettes, smoking (subst spec), tobacco not spec'
                  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE cpedrg4a  510='(510) OTHER Inhalant, NOT SPECIFIED' 994='(994) DON''T KNOW'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE cpedrg5a  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 994='(994) DON''T KNOW'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE dremgmed  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE emdrg1a   108='(108) Nembutal' 209='(209) Xanax' 312='(312) Ionamin'
                  322='(322) Methamphetamine (speed or ice or crank)'
                  339='(339) Amphetamines (speed generically)' 348='(348) Crystal'
                  430='(430) Aspirin, Ecotrin, Empirin'
                  435='(435) Tylenol, Tylenol Extrastrength'
                  503='(503) Other aerosol sprays' 601='(601) see also 618'
                  605='(605) PCP (angel dust, phencyclidine)' 606='(606) sic'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 702='(702) Heroin'
                  704='(704) Dope' 801='(801) OTHER Drugs, NOT SPECIFIED' 803='(803) sic'
                  805='(805) Cocaine, coke' 806='(806) Crack, rock'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  812='(812) Cigars'
                  813='(813) Cigarettes, smoking (subst spec), tobacco not spec'
                  815='(815) Coffee' 858='(858) Antibiotic'
                  900='(900) Non-Drug reason given for Drug Problem'
                  989='(989) LEGITIMATE SKIP Logically assigned' 994='(994) DON''T KNOW'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE emdrg2a   339='(339) Amphetamines (speed generically)'
                  420='(420) OTHER Analgesic, NOT SPECIFIED' 803='(803) sic'
                  805='(805) Cocaine, coke' 806='(806) Crack, rock'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  809='(809) Pills'
                  813='(813) Cigarettes, smoking (subst spec), tobacco not spec'
                  900='(900) Non-Drug reason given for Drug Problem'
                  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE emdrg3a   813='(813) Cigarettes, smoking (subst spec), tobacco not spec'
                  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE emdrg4a   994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE emdrg5a   994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE drtrmt    1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE tmtdrg1a  312='(312) Ionamin' 322='(322) Methamphetamine (speed or ice or crank)'
                  339='(339) Amphetamines (speed generically)' 348='(348) Crystal'
                  355='(355) Crystal meth'
                  409='(409) Tylenol with Codeine, Tylenol 3, Tylenol'
                  415='(415) Codeine'
                  434='(434) Co-Gesic, Hydrocodone, Tussionex, Vicodin'
                  435='(435) Tylenol, Tylenol Extrastrength'
                  510='(510) OTHER Inhalant, NOT SPECIFIED' 601='(601) see also 618'
                  605='(605) PCP (angel dust, phencyclidine)' 702='(702) Heroin'
                  704='(704) Dope' 801='(801) OTHER Drugs, NOT SPECIFIED' 803='(803) sic'
                  805='(805) Cocaine, coke' 806='(806) Crack, rock'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  808='(808) All of the ones I''ve tried' 809='(809) Pills' 812='(812) Cigars'
                  813='(813) Cigarettes, smoking (subst spec), tobacco not spec'
                  815='(815) Coffee'
                  816='(816) Smokeless tobacco, snuff, chewing tobacco'
                  818='(818) Nicotine' 900='(900) Non-Drug reason given for Drug Problem'
                  989='(989) LEGITIMATE SKIP Logically assigned' 994='(994) DON''T KNOW'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE tmtdrg2a  332='(332) see also 346' 339='(339) Amphetamines (speed generically)'
                  408='(408) Dilaudid' 417='(417) Morphine'
                  605='(605) PCP (angel dust, phencyclidine)' 803='(803) sic'
                  805='(805) Cocaine, coke' 806='(806) Crack, rock'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  809='(809) Pills'
                  813='(813) Cigarettes, smoking (subst spec), tobacco not spec'
                  900='(900) Non-Drug reason given for Drug Problem'
                  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE tmtdrg3a  702='(702) Heroin' 805='(805) Cocaine, coke'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  813='(813) Cigarettes, smoking (subst spec), tobacco not spec'
                  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE tmtdrg4a  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE tmtdrg5a  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE drdrvun   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE drvdrg1a  110='(110) Tuinal' 312='(312) Ionamin'
                  322='(322) Methamphetamine (speed or ice or crank)' 348='(348) Crystal'
                  601='(601) see also 618' 604='(604) Psilocybin (mushrooms)'
                  605='(605) PCP (angel dust, phencyclidine)' 702='(702) Heroin'
                  801='(801) OTHER Drugs, NOT SPECIFIED' 803='(803) sic'
                  805='(805) Cocaine, coke' 806='(806) Crack, rock'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  808='(808) All of the ones I''ve tried' 812='(812) Cigars'
                  813='(813) Cigarettes, smoking (subst spec), tobacco not spec'
                  900='(900) Non-Drug reason given for Drug Problem'
                  989='(989) LEGITIMATE SKIP Logically assigned' 994='(994) DON''T KNOW'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE drvdrg2a  322='(322) Methamphetamine (speed or ice or crank)'
                  408='(408) Dilaudid' 601='(601) see also 618'
                  605='(605) PCP (angel dust, phencyclidine)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 702='(702) Heroin'
                  803='(803) sic' 804='(804) Hashish' 805='(805) Cocaine, coke'
                  806='(806) Crack, rock'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  813='(813) Cigarettes, smoking (subst spec), tobacco not spec'
                  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE drvdrg3a  601='(601) see also 618' 607='(607) OTHER Hallucinogen, NOT SPECIFIED'
                  803='(803) sic' 805='(805) Cocaine, coke'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  813='(813) Cigarettes, smoking (subst spec), tobacco not spec'
                  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE drvdrg4a  120='(120) Downers; OTHER Sedative, NOT SPECIFIED' 804='(804) Hashish'
                  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE drvdrg5a  221='(221) OTHER Tranquilizer, NOT SPECIFIED' 994='(994) DON''T KNOW'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE tmtread   1='(1) Wants interviewer to continue reading'
                  2='(2) Wants to do it himself/herself' 96='(96) MULTIPLE RESPONSE'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE empdrug   1='(1) Yes' 2='(2) No' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE cighelp   1='(1) Yes' 2='(2) No'
                  81='(81) NEVER SMOKED CIGARETTES Logically Assigned'
                  91='(91) NEVER SMOKED CIGARETTES' 94='(94) DON''T KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE drnkhelp  1='(1) Yes' 2='(2) No' 81='(81) NEVER USED ALCOHOL Logically assigned'
                  91='(91) NEVER USED ALCOHOL' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE trmthelp  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED'
                  4='(4) No LOGICALLY IMPUTED'
                  81='(81) NEVER USED DRUGS Logically assigned'
                  83='(83) NEVER RECEIVED TREATMENT BUT MAY USE DRUGS Lg.ass.'
                  91='(91) NEVER USED DRUGS'
                  93='(93) NEVER RECEIVED TREATMENT BUT MAY USE DRUGS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE trmtemrg  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED'
                  81='(81) NEVER USED DRUGS Logically assigned'
                  83='(83) NEVER RECEIVED TREATMENT BUT MAY USE DRUGS Lg.ass.'
                  91='(91) NEVER USED DRUGS'
                  93='(93) NEVER RECEIVED TREATMENT BUT MAY USE DRUGS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE trmthosp  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED'
                  81='(81) NEVER USED DRUGS Logically assigned'
                  83='(83) NEVER RECEIVED TREATMENT BUT MAY USE DRUGS Lg.ass.'
                  91='(91) NEVER USED DRUGS'
                  93='(93) NEVER RECEIVED TREATMENT BUT MAY USE DRUGS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE trmtdoc   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED'
                  4='(4) No LOGICALLY IMPUTED'
                  81='(81) NEVER USED DRUGS Logically assigned'
                  83='(83) NEVER RECEIVED TREATMENT BUT MAY USE DRUGS Lg.ass.'
                  91='(91) NEVER USED DRUGS'
                  93='(93) NEVER RECEIVED TREATMENT BUT MAY USE DRUGS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE trmttrmt  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED'
                  4='(4) No LOGICALLY IMPUTED'
                  81='(81) NEVER USED DRUGS Logically assigned'
                  83='(83) NEVER RECEIVED TREATMENT BUT MAY USE DRUGS Lg.ass.'
                  91='(91) NEVER USED DRUGS'
                  93='(93) NEVER RECEIVED TREATMENT BUT MAY USE DRUGS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE trmtmhc   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED'
                  4='(4) No LOGICALLY IMPUTED'
                  81='(81) NEVER USED DRUGS Logically assigned'
                  83='(83) NEVER RECEIVED TREATMENT BUT MAY USE DRUGS Lg.ass.'
                  91='(91) NEVER USED DRUGS'
                  93='(93) NEVER RECEIVED TREATMENT BUT MAY USE DRUGS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE trmtshg   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED'
                  4='(4) No LOGICALLY IMPUTED'
                  81='(81) NEVER USED DRUGS Logically assigned'
                  83='(83) NEVER RECEIVED TREATMENT BUT MAY USE DRUGS Lg.ass.'
                  91='(91) NEVER USED DRUGS'
                  93='(93) NEVER RECEIVED TREATMENT BUT MAY USE DRUGS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE trmtsop   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED'
                  4='(4) No LOGICALLY IMPUTED'
                  81='(81) NEVER USED DRUGS Logically assigned'
                  83='(83) NEVER RECEIVED TREATMENT BUT MAY USE DRUGS Lg.ass.'
                  91='(91) NEVER USED DRUGS'
                  93='(93) NEVER RECEIVED TREATMENT BUT MAY USE DRUGS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE trmtsp    4='(4) AA or NA or CA' 5='(5) Residential placement'
                  9='(9) Within myself (self-treatment)'
                  10='(10) Church or religious influence' 12='(12) Friends'
                  13='(13) Court or correctional facilities'
                  14='(14) Counselor, therapist, psychologist' 15='(15) School'
                  16='(16) Home, family' 22='(22) Hospital'
                  24='(24) Drug treatment or rehab. center'
                  25='(25) Mental health center' 26='(26) Self-help group'
                  81='(81) NEVER USED DRUGS Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED DRUGS'
                  93='(93) NEVER RECEIVED TREATMENT BUT MAY USE DRUGS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE trmtrec   1='(1) Within the past month'
                  2='(2) More than one month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago'
                  8='(8) Received treatment in past year LOGICALLY IMPUTED'
                  9='(9) Received treatment in lifetime LOGICALLY IMPUTED'
                  81='(81) NEVER USED DRUGS Logically assigned'
                  83='(83) NEVER RECEIVED TREATMENT BUT MAY USE DRUGS Lg.ass.'
                  91='(91) NEVER USED DRUGS'
                  93='(93) NEVER RECEIVED TREATMENT BUT MAY USE DRUGS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE nrtxlife  0='(0) NONE' 985='(985) BAD DATA Logically assigned'
                  994='(994) DON''T KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' ;
  VALUE notrmt    1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED'
                  85='(85) BAD DATA Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE txemrg    1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE txhosp    1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE txdoc     1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE txtrmt    1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE txmhc     1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE txshg     1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE txsop     1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE txsp      4='(4) AA or NA or CA' 5='(5) Residential placement'
                  9='(9) Within myself (self-treatment)'
                  10='(10) Church or religious influence' 12='(12) Friends'
                  13='(13) Court or correctional facilities'
                  14='(14) Counselor, therapist, psychologist' 15='(15) School'
                  16='(16) Home, family'
                  17='(17) Employer''s hotline, job corps, on the job'
                  22='(22) Hospital' 24='(24) Drug treatment or rehab. center'
                  25='(25) Mental health center'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE trmtlife  1='(1) Very important' 2='(2) Somewhat important'
                  3='(3) Not at all important'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE trmtresp  1='(1) Very important' 2='(2) Somewhat important'
                  3='(3) Not at all important'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE trmtfear  1='(1) Very important' 2='(2) Somewhat important'
                  3='(3) Not at all important'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE trmtcost  1='(1) Very important' 2='(2) Somewhat important'
                  3='(3) Not at all important'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE trmtevnt  1='(1) Very important' 2='(2) Somewhat important'
                  3='(3) Not at all important'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE trmtpr    1='(1) Very important' 2='(2) Somewhat important'
                  3='(3) Not at all important'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE trmthlth  1='(1) Very important' 2='(2) Somewhat important'
                  3='(3) Not at all important'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE trmtjob   1='(1) Very important' 2='(2) Somewhat important'
                  3='(3) Not at all important'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE trmtjail  1='(1) Very important' 2='(2) Somewhat important'
                  3='(3) Not at all important'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE trmtserv  1='(1) Very important' 2='(2) Somewhat important'
                  3='(3) Not at all important'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE trmtbqd   1='(1) Very important' 2='(2) Somewhat important'
                  3='(3) Not at all important'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE trmtdna   1='(1) Very important' 2='(2) Somewhat important'
                  3='(3) Not at all important'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE trmtsor   1='(1) Very important' 2='(2) Somewhat important'
                  3='(3) Not at all important' 4='(4) Response circled only'
                  5='(5) Reason specified but no ranking'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE trmtrsp   1='(1) Wanted to change lifestyle'
                  2='(2) Had family responsibilities'
                  5='(5) Occurrence of a signif. personal or special event'
                  6='(6) Pressure from family (or close friends)'
                  7='(7) Had concerns about health' 8='(8) Had concerns about job'
                  9='(9) Sent to jail' 14='(14) Depression'
                  15='(15) Fear of dying/suicide(fear of, or attempted)'
                  16='(16) Church or other religious influence'
                  17='(17) Forced/compelled (but by whom is unknown)'
                  18='(18) Wanted to quit drugs'
                  19='(19) Reason connected to the military' 20='(20) Overdose'
                  21='(21) Loss of control/dependency'
                  22='(22) Felt bad about self/wanted to do or be better'
                  23='(23) Reason connected to driver''s license'
                  25='(25) Committing violence'
                  26='(26) Pressure from counselor/soc. srvcs/etc.'
                  27='(27) Psychological disorders'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE trmtdrga  108='(108) Nembutal' 116='(116) Methaqualone, Quaalude, Sopor'
                  118='(118) Pentobarbital, pentothal, sodium pentothal'
                  120='(120) Downers; OTHER Sedative, NOT SPECIFIED' 201='(201) Valium'
                  202='(202) Librium' 204='(204) Menrium' 228='(228) see also 239' 241='(241) Prozac'
                  247='(247) Adapin, Doxepin, Sinequan' 319='(319) Cylert'
                  322='(322) Methamphetamine (speed or ice or crank)'
                  324='(324) Uppers; OTHER Stimulant, NOT SPECIFIED'
                  336='(336) Diet pills' 339='(339) Amphetamines (speed generically)'
                  348='(348) Crystal' 355='(355) Crystal meth' 401='(401) Darvon'
                  406='(406) Oxycodone, Percodan, Roxicet' 408='(408) Dilaudid'
                  409='(409) Tylenol with Codeine, Tylenol 3, Tylenol'
                  417='(417) Morphine' 418='(418) Methadone'
                  430='(430) Aspirin, Ecotrin, Empirin'
                  434='(434) Co-Gesic, Hydrocodone, Tussionex, Vicodin'
                  435='(435) Tylenol, Tylenol Extrastrength'
                  501='(501) Gasoline or lighter fluids' 503='(503) Other aerosol sprays'
                  510='(510) OTHER Inhalant, NOT SPECIFIED' 601='(601) see also 618'
                  605='(605) PCP (angel dust, phencyclidine)' 702='(702) Heroin'
                  801='(801) OTHER Drugs, NOT SPECIFIED' 803='(803) sic'
                  805='(805) Cocaine, coke, coca' 806='(806) Crack, rock'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  808='(808) All of the ones I''ve tried' 809='(809) Pills'
                  813='(813) Cigarettes, smoking (subst spec), tobacco not spec'
                  824='(824) Steroids'
                  840='(840) Cough medicine (contents not specified)' 875='(875) Buds'
                  900='(900) Not a drug' 989='(989) LEGITIMATE SKIP Logically assigned'
                  992='(992) Illegible' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE trmtdrgb  120='(120) Downers; OTHER Sedative, NOT SPECIFIED'
                  322='(322) Methamphetamine (speed or ice or crank)' 415='(415) Codeine'
                  423='(423) Percocet' 427='(427) Darvocet' 601='(601) see also 618'
                  605='(605) PCP (angel dust, phencyclidine)' 702='(702) Heroin'
                  801='(801) OTHER Drugs, NOT SPECIFIED' 803='(803) sic' 804='(804) Hashish'
                  805='(805) Cocaine, coke, coca' 806='(806) Crack, rock'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  900='(900) Not a drug' 989='(989) LEGITIMATE SKIP Logically assigned'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE trmtdrgc  221='(221) OTHER Tranquilizer, NOT SPECIFIED'
                  246='(246) Clonopin, Klonopin' 355='(355) Crystal meth'
                  601='(601) see also 618' 805='(805) Cocaine, coke, coca'
                  806='(806) Crack, rock'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  989='(989) LEGITIMATE SKIP Logically assigned' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE trmtdrgd  605='(605) PCP (angel dust, phencyclidine)'
                  989='(989) LEGITIMATE SKIP Logically assigned' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE trmtdrge  989='(989) LEGITIMATE SKIP Logically assigned' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE trmtoutc  1='(1) Still in treatment' 2='(2) Successfully completed treatment'
                  3='(3) Had a problem with program'
                  4='(4) Couldn''t afford to continue treatment'
                  5='(5) Family needed me' 6='(6) Began using drug(s) again'
                  7='(7) Other outcome, not specified' 8='(8) Didn''t need treatment'
                  10='(10) Successful because of own efforts, not trmt.'
                  11='(11) Use to a lesser extent'
                  14='(14) Successful because of religious reasons'
                  15='(15) Discontinued treatment, success unknown'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE tmtphi    1='(1) Response circled' 2='(2) Response not circled'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE tmtpsave  1='(1) Response circled' 2='(2) Response not circled'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE tmtpfmly  1='(1) Response circled' 2='(2) Response not circled'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE tmtpempr  1='(1) Response circled' 2='(2) Response not circled' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE tmtpmedi  1='(1) Response circled' 2='(2) Response not circled'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE tmtpfree  1='(1) Response circled' 2='(2) Response not circled' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE tmtpoth   1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE tmtpasp   1='(1) Health Insurance' 2='(2) Own savings or earnings'
                  3='(3) Family member' 4='(4) Employer or union'
                  5='(5) Medicare or Medicaid' 6='(6) Free'
                  9='(9) State/city public assistance/welfare/relief' 10='(10) Court'
                  12='(12) School' 13='(13) Hospital'
                  14='(14) Veterans Administration/military services'
                  15='(15) Treatment program' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE rskpkcig  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rsktrymj  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rskmjocc  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rskmjreg  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rktrypcp  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rkpcpreg  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rktryher  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rkherreg  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rktrycoc  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rkcococc  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rkcocreg  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rkcrkocc  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rkansocc  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rkansreg  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rk2drink  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rk5drink  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rskbinge  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rskdifmj  1='(1) Probably impossible' 2='(2) Very difficult'
                  3='(3) Fairly difficult' 4='(4) Fairly easy' 5='(5) Very easy'
                  94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE rkdiflsd  1='(1) Probably impossible' 2='(2) Very difficult'
                  3='(3) Fairly difficult' 4='(4) Fairly easy' 5='(5) Very easy'
                  94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE rkdifpcp  1='(1) Probably impossible' 2='(2) Very difficult'
                  3='(3) Fairly difficult' 4='(4) Fairly easy' 5='(5) Very easy'
                  94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE rkdifcoc  1='(1) Probably impossible' 2='(2) Very difficult'
                  3='(3) Fairly difficult' 4='(4) Fairly easy' 5='(5) Very easy'
                  94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE rkdifher  1='(1) Probably impossible' 2='(2) Very difficult'
                  3='(3) Fairly difficult' 4='(4) Fairly easy' 5='(5) Very easy'
                  94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE rsksell   1='(1) Yes' 2='(2) No' 94='(94) DON''T KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE rkneidrn  1='(1) Often' 2='(2) Occasionally' 3='(3) Rarely' 4='(4) Never'
                  94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE rkneisel  1='(1) Often' 2='(2) Occasionally' 3='(3) Rarely' 4='(4) Never'
                  94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE highbp    1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE bpmed     1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE walkpain  1='(1) Yes' 2='(2) No' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE timepain  1='(1) Yes' 2='(2) No' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE upshor    1='(1) Yes' 2='(2) No' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE asthma    1='(1) Yes' 2='(2) No' 94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE trpsych   1='(1) Yes' 2='(2) No' 94='(94) DON''T KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE heart     1='(1) Yes' 2='(2) No' 94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE flu       1='(1) Yes' 2='(2) No' 94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE allerg    1='(1) Yes' 2='(2) No' 94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE hospyr    1='(1) Yes' 2='(2) No' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE soreyr    1='(1) Yes' 2='(2) No' 94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE runnyyr   1='(1) Yes' 2='(2) No' 94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE coughyr   1='(1) Yes' 2='(2) No' 94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE phlegmyr  1='(1) Yes' 2='(2) No' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE healthyr  1='(1) Excellent' 2='(2) Very good' 3='(3) Good' 4='(4) Fair' 5='(5) Poor'
                  94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE flteat    1='(1) Rarely or none of the time (less than a day)'
                  2='(2) Some or a little of the time (1-2 days)'
                  3='(3) Occasion. or a moderate amount of time (3-4 days)'
                  4='(4) Most or all of the time (5-7 days)'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE fltmind   1='(1) Rarely or none of the time (less than a day)'
                  2='(2) Some or a little of the time (1-2 days)'
                  3='(3) Occasion. or a moderate amount of time (3-4 days)'
                  4='(4) Most or all of the time (5-7 days)' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE fltdeprs  1='(1) Rarely or none of the time (less than a day)'
                  2='(2) Some or a little of the time (1-2 days)'
                  3='(3) Occasion. or a moderate amount of time (3-4 days)'
                  4='(4) Most or all of the time (5-7 days)' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE flteffrt  1='(1) Rarely or none of the time (less than a day)'
                  2='(2) Some or a little of the time (1-2 days)'
                  3='(3) Occasion. or a moderate amount of time (3-4 days)'
                  4='(4) Most or all of the time (5-7 days)' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE fltsleep  1='(1) Rarely or none of the time (less than a day)'
                  2='(2) Some or a little of the time (1-2 days)'
                  3='(3) Occasion. or a moderate amount of time (3-4 days)'
                  4='(4) Most or all of the time (5-7 days)' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE fltsad    1='(1) Rarely or none of the time (less than a day)'
                  2='(2) Some or a little of the time (1-2 days)'
                  3='(3) Occasion. or a moderate amount of time (3-4 days)'
                  4='(4) Most or all of the time (5-7 days)' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE fltgoing  1='(1) Rarely or none of the time (less than a day)'
                  2='(2) Some or a little of the time (1-2 days)'
                  3='(3) Occasion. or a moderate amount of time (3-4 days)'
                  4='(4) Most or all of the time (5-7 days)' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE marital   1='(1) Married' 2='(2) Widowed' 3='(3) Divorced or separated'
                  4='(4) Has never married' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE nomarr    85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE workstat  1='(1) Working full-time, 35 hours or more a week'
                  2='(2) Working part-time, less than 35 hours a week'
                  3='(3) Have job but out: illness/leave/furlough/strike'
                  4='(4) Unemployed or laid off and looking for work'
                  5='(5) Unemployed and not looking for work'
                  6='(6) Full-time homemaker only' 7='(7) In school only' 8='(8) Retired'
                  9='(9) Disabled, not able to work'
                  21='(21) Working full time, 35 hours or more a week'
                  22='(22) Working part time, less than 35 hours a week'
                  23='(23) Have a job but out: illness/leave/furlough/strike'
                  24='(24) Unemployed or laid off and looking for work'
                  25='(25) Unemployed and not looking for work'
                  26='(26) Full-time homemaker' 27='(27) In school only' 28='(28) Retired'
                  29='(29) Disabled, not able to work' 30='(30) Other, in labor force'
                  31='(31) Other, not in the labor force'
                  85='(85) BAD DATA Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE paymo     89='(89) LEGITIMATE SKIP Logically assigned'
                  91='(91) NEVER WORKED FOR PAY' 94='(94) DON''T KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE payyr     985='(985) BAD DATA Logically assigned'
                  989='(989) LEGITIMATE SKIP Logically assigned'
                  991='(991) NEVER WORKED FOR PAY' 994='(994) DON''T KNOW' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE no5job    94='(94) DON''T KNOW' 95='(95) BAD DATA' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE workdays  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  95='(95) BAD DATA' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE workblah  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  95='(95) BAD DATA' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE cwe       1='(1) Respondent' 2='(2) Someone else (see CWESCs)'
                  3='(3) Income contributed equally by R and (see CWESCs)'
                  4='(4) No one'
                  6='(6) Some one else (see CWESCs) LOGICALLY ASSIGNED'
                  7='(7) Inc. from R & other(s) equally (see CWESCs) LOG AS'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE cwesc1ff  9='(9) Head of Household' 10='(10) Spouse' 20='(20) Parent/Guardian'
                  50='(50) Grandparent/Great+ Grandparent' 60='(60) Live-In Partner'
                  61='(61) Friend/Roommate/Companion' 71='(71) Cousin'
                  85='(85) Landlord/Home Owner'
                  91='(91) Other Non-Relative, Gender not specified'
                  92='(92) Other, Relation and Gender Unspecified'
                  109='(109) Male Head of Household' 110='(110) Husband' 111='(111) Ex-Husband'
                  120='(120) Father/Male Guardian' 121='(121) Step/Adopted/Foster Father'
                  122='(122) Father In-Law/Step Father In-Law' 130='(130) Son'
                  132='(132) Son In-Law' 133='(133) Grandson' 140='(140) Brother/Half Brother'
                  141='(141) Step/Adopted/Foster Brother' 142='(142) Brother In-Law'
                  150='(150) Grandfather/Great+ Grandfather'
                  160='(160) Male Live-In Partner'
                  161='(161) Male Fiance/Boyfriend/Roommate/Companion' 170='(170) Uncle'
                  171='(171) Male Cousin' 181='(181) Other Male God Relative'
                  190='(190) Other Male Relative' 191='(191) Other Male Non-Relative'
                  192='(192) Other Male, Relation Unspecified' 210='(210) Wife'
                  220='(220) Mother/Female Guardian'
                  221='(221) Step/Adopted/Foster Mother'
                  222='(222) Mother In-Law/Step Mother In-Law' 230='(230) Daughter'
                  231='(231) Step/Adopted/Foster Daughter' 232='(232) Daughter In-Law'
                  240='(240) Sister/Half Sister' 241='(241) Step/Adopted/Foster Sister'
                  242='(242) Sister In-Law' 250='(250) Grandmother/Great+ Grandmother'
                  260='(260) Female Live-In Partner'
                  261='(261) Female Fiancee/Girlfriend/Roommate/Companion'
                  270='(270) Aunt' 271='(271) Female Cousin' 272='(272) Niece'
                  285='(285) Female Landlord/Home Owner'
                  291='(291) Other Female Non-Relative'
                  292='(292) Other Female, Relation Unspecified' 315='(315) In-Laws'
                  320='(320) Parents/Guardians'
                  350='(350) Grandparents/Great+ Grandparents'
                  361='(361) Friends/Roommates/Companions' 371='(371) Cousins'
                  390='(390) Other Relatives, Gender not specified'
                  392='(392) Others, Relation and Gender Unspecified' 430='(430) Sons'
                  442='(442) Brothers In-Law' 540='(540) Sisters/Half Sisters'
                  985='(985) BAD DATA Logically assigned' 994='(994) DON''T KNOW'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE cwesc2ff  20='(20) Parent/Guardian' 60='(60) Live-In Partner'
                  61='(61) Friend/Roommate/Companion'
                  92='(92) Other, Relation and Gender Unspecified' 110='(110) Husband'
                  120='(120) Father/Male Guardian' 121='(121) Step/Adopted/Foster Father'
                  140='(140) Brother/Half Brother' 142='(142) Brother In-Law'
                  150='(150) Grandfather/Great+ Grandfather'
                  161='(161) Male Fiance/Boyfriend/Roommate/Companion' 170='(170) Uncle'
                  191='(191) Other Male Non-Relative' 210='(210) Wife'
                  220='(220) Mother/Female Guardian'
                  221='(221) Step/Adopted/Foster Mother' 230='(230) Daughter'
                  240='(240) Sister/Half Sister' 242='(242) Sister In-Law'
                  250='(250) Grandmother/Great+ Grandmother' 270='(270) Aunt'
                  291='(291) Other Female Non-Relative' 315='(315) In-Laws'
                  392='(392) Others, Relation and Gender Unspecified'
                  540='(540) Sisters/Half Sisters' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE fullpart  1='(1) Full-time' 2='(2) Part-time'
                  3='(3) Chief source of income does not work'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE educ      0='(0) No schooling' 1='(1) First Grade' 2='(2) Second grade'
                  3='(3) Third grade' 4='(4) Fourth grade' 5='(5) Fifth grade'
                  6='(6) Sixth grade' 7='(7) Seventh Grade' 8='(8) Eighth grade'
                  9='(9) Ninth grade' 10='(10) Tenth grade' 11='(11) Eleventh grade'
                  12='(12) Twelfth grade' 13='(13) One year college'
                  14='(14) 2 years college' 15='(15) 3 years college'
                  16='(16) 4 years college' 17='(17) Graduate/professional school'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE gradhs    1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY IMPUTED (from DIPLOMA)'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE diploma   1='(1) High school diploma' 2='(2) GED certificate'
                  3='(3) Neither of the above'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE enrolld   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED'
                  4='(4) No LOGICALLY IMPUTED' 94='(94) DON''T KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE schplans  1='(1) Has plans to enroll in a school in future'
                  2='(2) Has completed all schooling'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE student   1='(1) A full-time student' 2='(2) A part-time student'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE schdays   89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  95='(95) BAD DATA' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE skipped   89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE miles     99989='(99989) LEGITIMATE SKIP Logically assigned'
                  99991='(99991) HAS NEVER DRIVEN A MOTOR VEHICLE'
                  99994='(99994) DON''T KNOW' 99997='(99997) REFUSED'
                  99998='(99998) BLANK (NO ANSWER)' 99999='(99999) LEGITIMATE SKIP' ;
  VALUE accid     1='(1) Yes' 2='(2) No' 3='(3) Did not drive in past 12 months'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE totpeop   97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE mother    0='(0) No' 1='(1) Yes' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE father    0='(0) No' 1='(1) Yes' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE stepmom   0='(0) No' 1='(1) Yes' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE stepdad   0='(0) No' 1='(1) Yes' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE spouse    0='(0) No' 1='(1) Yes' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE inlaw     0='(0) None' 93='(93) RELATIONSHIP SPECIFIED, NO COUNT RECORDED'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ownchild  0='(0) None' 93='(93) RELATIONSHIP SPECIFIED, NO COUNT RECORDED'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE stepchld  0='(0) None' 93='(93) RELATIONSHIP SPECIFIED, NO COUNT RECORDED'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE brosis    0='(0) None' 93='(93) RELATIONSHIP SPECIFIED, NO COUNT RECORDED'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE othrel    0='(0) None' 93='(93) RELATIONSHIP SPECIFIED, NO COUNT RECORDED'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE friends   0='(0) None' 93='(93) RELATIONSHIP SPECIFIED, NO COUNT RECORDED'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE othernon  0='(0) None' 93='(93) RELATIONSHIP SPECIFIED, NO COUNT RECORDED'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE movdaway  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED'
                  4='(4) No LOGICALLY IMPUTED' 94='(94) DON''T KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE dorm      94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (MOVDAWAY=2)' ;
  VALUE milbase   94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (MOVDAWAY=2)' ;
  VALUE hosp      94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (MOVDAWAY=2)' ;
  VALUE othgph    85='(85) BAD DATA Logically assigned' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (MOVDAWAY=2)' ;
  VALUE othgphsp  1='(1) Own dwelling' 2='(2) Married'
                  3='(3) (Moved to)another dwelling,ownership not specified'
                  4='(4) (Moved to) apartment, ownership not specified'
                  7='(7) Foster home'
                  8='(8) Nursing home/home for handicapped/retirement home'
                  9='(9) Died' 10='(10) Lives out of state/city/county'
                  11='(11) Staying/living with a friend'
                  12='(12) Moved away for job or job training(incl. military)'
                  14='(14) Overseas/out of country'
                  15='(15) Lives with mother/father/relatives'
                  17='(17) With other children in school group housing'
                  18='(18) Group housing in college' 20='(20) Hotel'
                  21='(21) Group home/halfway house/shelter/tx. or rehab.'
                  85='(85) BAD DATA Logically assigned' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE service   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE milstat   2='(2) In a Reserves component'
                  3='(3) Separated/retired from Reserves or active duty'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE telno     94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE moves     94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE nofamres  0='(0) Some relative(s) do(es) or may reside in household'
                  1='(1) No relative resides in household' ;
  VALUE proxable  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE proxyrel  1='(1) Respondent''s spouse/live-in partner'
                  2='(2) Respondent''s father' 3='(3) Respondent''s mother'
                  4='(4) Respondent''s brother' 5='(5) Respondent''s sister'
                  6='(6) Other family member, relation not specified'
                  20='(20) Parent/Guardian' 50='(50) Grandparent/Great+ Grandparent'
                  60='(60) Live-In Partner' 61='(61) Friend/Roommate/Companion'
                  71='(71) Cousin' 91='(91) Other Non-Relative, Gender not specified'
                  110='(110) Husband' 120='(120) Father/Male Guardian'
                  121='(121) Step/Adopted/Foster Father' 130='(130) Son' 132='(132) Son In-Law'
                  142='(142) Brother In-Law' 150='(150) Grandfather/Great+ Grandfather'
                  170='(170) Uncle' 210='(210) Wife' 220='(220) Mother/Female Guardian'
                  221='(221) Step/Adopted/Foster Mother' 230='(230) Daughter'
                  231='(231) Step/Adopted/Foster Daughter' 232='(232) Daughter In-Law'
                  240='(240) Sister/Half Sister' 242='(242) Sister In-Law'
                  250='(250) Grandmother/Great+ Grandmother'
                  261='(261) Female Fiancee/Girlfriend/Roommate/Companion'
                  270='(270) Aunt' 291='(291) Other Female Non-Relative'
                  321='(321) Step/Adopted/Foster Parents'
                  350='(350) Grandparents/Great+ Grandparents'
                  989='(989) LEGITIMATE SKIP Logically assigned'
                  996='(996) MULTIPLE RESPONSE' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE proxhome  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE proxjoin  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE medicare  1='(1) Yes' 2='(2) No' 94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE medicaid  1='(1) Yes' 2='(2) No' 94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE champus   1='(1) Yes' 2='(2) No' 94='(94) DON''T KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE prvhltin  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ownhltin  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE grphltin  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE hltinalc  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE hltindrg  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE hltinmnt  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE whoanshi  1='(1) Sample member'
                  2='(2) Proxy, relationship to sample member not specified'
                  10='(10) Spouse' 20='(20) Parent/Guardian'
                  50='(50) Grandparent/Great+ Grandparent' 60='(60) Live-In Partner'
                  61='(61) Friend/Roommate/Companion' 71='(71) Cousin'
                  91='(91) Other Non-Relative, Gender not specified'
                  92='(92) Other, Relation and Gender Unspecified' 110='(110) Husband'
                  120='(120) Father/Male Guardian' 121='(121) Step/Adopted/Foster Father'
                  130='(130) Son' 132='(132) Son In-Law' 140='(140) Brother/Half Brother'
                  142='(142) Brother In-Law' 150='(150) Grandfather/Great+ Grandfather'
                  160='(160) Male Live-In Partner' 170='(170) Uncle'
                  191='(191) Other Male Non-Relative' 210='(210) Wife'
                  220='(220) Mother/Female Guardian'
                  221='(221) Step/Adopted/Foster Mother' 230='(230) Daughter'
                  231='(231) Step/Adopted/Foster Daughter' 232='(232) Daughter In-Law'
                  240='(240) Sister/Half Sister' 242='(242) Sister In-Law'
                  250='(250) Grandmother/Great+ Grandmother'
                  261='(261) Female Fiancee/Girlfriend/Roommate/Companion'
                  270='(270) Aunt' 291='(291) Other Female Non-Relative'
                  320='(320) Parents/Guardians'
                  350='(350) Grandparents/Great+ Grandparents' 994='(994) DON''T KNOW'
                  996='(996) MULTIPLE RESPONSE' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE job       1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED'
                  4='(4) No LOGICALLY IMPUTED' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE hours     985='(985) BAD DATA Logically assigned' 994='(994) DON''T KNOW'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE work      1='(1) Worked only for an employer' 2='(2) Was self-employed only'
                  3='(3) Self-employed and working for an employer'
                  4='(4) Did not work during the month'
                  5='(5) Did work during the month LOGICALLY IMPUTED'
                  6='(6) Did not work during the month LOGICALLY IMPUTED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE wag1ffff  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE awag1fff  999985='(999985) BAD DATA Logically assigned' 999994='(999994) DON''T KNOW'
                  999997='(999997) REFUSED' 999998='(999998) BLANK (NO ANSWER)'
                  999999='(999999) LEGITIMATE SKIP' ;
  VALUE weeks     94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE soc1ffff  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED'
                  4='(4) No LOGICALLY IMPUTED' 94='(94) DON''T KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE asoc1fff  999985='(999985) BAD DATA Logically assigned' 999994='(999994) DON''T KNOW'
                  999997='(999997) REFUSED' 999998='(999998) BLANK (NO ANSWER)'
                  999999='(999999) LEGITIMATE SKIP' ;
  VALUE ssi1ffff  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE assi1fff  999985='(999985) BAD DATA Logically assigned' 999994='(999994) DON''T KNOW'
                  999997='(999997) REFUSED' 999998='(999998) BLANK (NO ANSWER)'
                  999999='(999999) LEGITIMATE SKIP' ;
  VALUE pub1ffff  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED'
                  4='(4) No LOGICALLY IMPUTED' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE afdc1fff  1='(1) Income from AFDC/ADC' 2='(2) Income from other'
                  3='(3) Income from both' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE wel1ffff  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED'
                  4='(4) No LOGICALLY IMPUTED' 94='(94) DON''T KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE awel1fff  999985='(999985) BAD DATA Logically assigned' 999994='(999994) DON''T KNOW'
                  999997='(999997) REFUSED' 999998='(999998) BLANK (NO ANSWER)'
                  999999='(999999) LEGITIMATE SKIP' ;
  VALUE int1ffff  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED'
                  4='(4) No LOGICALLY IMPUTED' 94='(94) DON''T KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE aint1fff  999985='(999985) BAD DATA Logically assigned' 999994='(999994) DON''T KNOW'
                  999997='(999997) REFUSED' 999998='(999998) BLANK (NO ANSWER)'
                  999999='(999999) LEGITIMATE SKIP' ;
  VALUE chd1ffff  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED'
                  4='(4) No LOGICALLY IMPUTED' 94='(94) DON''T KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE achd1fff  999985='(999985) BAD DATA Logically assigned'
                  999989='(999989) LEGITIMATE SKIP Logically assigned'
                  999994='(999994) DON''T KNOW' 999997='(999997) REFUSED'
                  999998='(999998) BLANK (NO ANSWER)' 999999='(999999) LEGITIMATE SKIP' ;
  VALUE oth1ffff  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED'
                  4='(4) No LOGICALLY IMPUTED' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE aoth1fff  999985='(999985) BAD DATA Logically assigned'
                  999989='(999989) LEGITIMATE SKIP Logically assigned'
                  999994='(999994) DON''T KNOW' 999997='(999997) REFUSED'
                  999998='(999998) BLANK (NO ANSWER)' 999999='(999999) LEGITIMATE SKIP' ;
  VALUE famlyres  1='(1) Yes' 2='(2) No' 94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE wag2ffff  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED'
                  4='(4) No LOGICALLY IMPUTED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE awag2fff  999985='(999985) BAD DATA Logically assigned'
                  999989='(999989) LEGITIMATE SKIP Logically assigned'
                  999994='(999994) DON''T KNOW' 999997='(999997) REFUSED'
                  999998='(999998) BLANK (NO ANSWER)' 999999='(999999) LEGITIMATE SKIP' ;
  VALUE soc2ffff  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED'
                  4='(4) No LOGICALLY IMPUTED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE asoc2fff  999985='(999985) BAD DATA Logically assigned'
                  999989='(999989) LEGITIMATE SKIP Logically assigned'
                  999994='(999994) DON''T KNOW' 999997='(999997) REFUSED'
                  999998='(999998) BLANK (NO ANSWER)' 999999='(999999) LEGITIMATE SKIP' ;
  VALUE ssi2ffff  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED'
                  4='(4) No LOGICALLY IMPUTED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE assi2fff  999985='(999985) BAD DATA Logically assigned'
                  999989='(999989) LEGITIMATE SKIP Logically assigned'
                  999994='(999994) DON''T KNOW' 999997='(999997) REFUSED'
                  999998='(999998) BLANK (NO ANSWER)' 999999='(999999) LEGITIMATE SKIP' ;
  VALUE pub2ffff  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED'
                  4='(4) No LOGICALLY IMPUTED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE afdc2fff  1='(1) Income from AFDC/ADC' 2='(2) Income from other'
                  3='(3) Income from both'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE wel2ffff  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED'
                  4='(4) No LOGICALLY IMPUTED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE awel2fff  999985='(999985) BAD DATA Logically assigned'
                  999989='(999989) LEGITIMATE SKIP Logically assigned'
                  999994='(999994) DON''T KNOW' 999997='(999997) REFUSED'
                  999998='(999998) BLANK (NO ANSWER)' 999999='(999999) LEGITIMATE SKIP' ;
  VALUE int2ffff  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED'
                  4='(4) No LOGICALLY IMPUTED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE aint2fff  999985='(999985) BAD DATA Logically assigned'
                  999989='(999989) LEGITIMATE SKIP Logically assigned'
                  999994='(999994) DON''T KNOW' 999997='(999997) REFUSED'
                  999998='(999998) BLANK (NO ANSWER)' 999999='(999999) LEGITIMATE SKIP' ;
  VALUE chd2ffff  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE achd2fff  999985='(999985) BAD DATA Logically assigned'
                  999989='(999989) LEGITIMATE SKIP Logically assigned'
                  999994='(999994) DON''T KNOW' 999997='(999997) REFUSED'
                  999998='(999998) BLANK (NO ANSWER)' 999999='(999999) LEGITIMATE SKIP' ;
  VALUE oth2ffff  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED'
                  4='(4) No LOGICALLY IMPUTED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE aoth2fff  999985='(999985) BAD DATA Logically assigned'
                  999989='(999989) LEGITIMATE SKIP Logically assigned'
                  999994='(999994) DON''T KNOW' 999997='(999997) REFUSED'
                  999998='(999998) BLANK (NO ANSWER)' 999999='(999999) LEGITIMATE SKIP' ;
  VALUE whoansin  1='(1) Sample member'
                  2='(2) Proxy, relationship to sample member not specified'
                  10='(10) Spouse' 20='(20) Parent/Guardian' 60='(60) Live-In Partner'
                  61='(61) Friend/Roommate/Companion' 71='(71) Cousin'
                  91='(91) Other Non-Relative, Gender not specified' 110='(110) Husband'
                  120='(120) Father/Male Guardian' 121='(121) Step/Adopted/Foster Father'
                  130='(130) Son' 132='(132) Son In-Law' 133='(133) Grandson'
                  140='(140) Brother/Half Brother' 142='(142) Brother In-Law'
                  150='(150) Grandfather/Great+ Grandfather'
                  160='(160) Male Live-In Partner'
                  161='(161) Male Fiance/Boyfriend/Roommate/Companion' 170='(170) Uncle'
                  210='(210) Wife' 220='(220) Mother/Female Guardian'
                  221='(221) Step/Adopted/Foster Mother'
                  222='(222) Mother In-Law/Step Mother In-Law' 230='(230) Daughter'
                  231='(231) Step/Adopted/Foster Daughter' 232='(232) Daughter In-Law'
                  240='(240) Sister/Half Sister' 242='(242) Sister In-Law'
                  250='(250) Grandmother/Great+ Grandmother'
                  261='(261) Female Fiancee/Girlfriend/Roommate/Companion'
                  270='(270) Aunt' 291='(291) Other Female Non-Relative'
                  320='(320) Parents/Guardians' 321='(321) Step/Adopted/Foster Parents'
                  350='(350) Grandparents/Great+ Grandparents'
                  989='(989) LEGITIMATE SKIP Logically assigned' 994='(994) DON''T KNOW'
                  996='(996) MULTIPLE RESPONSE' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE fstamp    1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED'
                  4='(4) No LOGICALLY IMPUTED' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE peopfd    85='(85) BAD DATA Logically assigned' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE food      1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED'
                  4='(4) No LOGICALLY IMPUTED' 94='(94) DON''T KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE afood     999985='(999985) BAD DATA Logically assigned' 999994='(999994) DON''T KNOW'
                  999997='(999997) REFUSED' 999998='(999998) BLANK (NO ANSWER)'
                  999999='(999999) LEGITIMATE SKIP' ;
  VALUE bap       1='(1) AM' 2='(2) PM' 98='(98) BLANK (NO ANSWER)' ;
  VALUE eap       1='(1) AM' 2='(2) PM' 96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE langver   1='(1) English' 2='(2) Spanish' 98='(98) BLANK (NO ANSWER)' ;
  VALUE undint    1='(1) No difficulty-no language or reading problem'
                  2='(2) Just a little difficulty-almost no lang/readg prob'
                  3='(3) Fair amount of difficulty-some lang/reading prob'
                  4='(4) A lot of difficulty-considerable lang/reading prob'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE coopint   1='(1) Very cooperative' 2='(2) Fairly cooperative'
                  3='(3) Not very cooperative' 4='(4) Openly hostile'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE privacy   1='(1) Completely private-no one present/able to overhear'
                  3='(3) Minor distractions'
                  5='(5) Person(s) in room or listening 1/3 of the time'
                  7='(7) Serious interruptions more than half the time'
                  9='(9) Constant presence of other person(s)'
                  85='(85) BAD DATA Logically assigned' 96='(96) MULTIPLE RESPONSE'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE ppres     1='(1) Response circled' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (PRIVACY=1)' ;
  VALUE spres     2='(2) Response circled' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (PRIVACY=1)' ;
  VALUE parpres   3='(3) Response circled' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (PRIVACY=1)' ;
  VALUE oarpres   4='(4) Response circled' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (PRIVACY=1)' ;
  VALUE oapres    5='(5) Response circled' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (PRIVACY=1)' ;
  VALUE cpres     6='(6) Response circled' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (PRIVACY=1)' ;
  VALUE opresnsp  7='(7) Response circled' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (PRIVACY=1)' ;
  VALUE opresspa  9='(9) Head of Household' 10='(10) Spouse' 20='(20) Parent/Guardian'
                  37='(37) Child, Relation Unspecified' 60='(60) Live-In Partner'
                  61='(61) Friend/Roommate/Companion' 71='(71) Cousin'
                  83='(83) Nurse/Health Care Aide/Home Care Worker'
                  84='(84) Neighbor/Co-Worker/Visitor' 85='(85) Landlord/Home Owner'
                  91='(91) Other Non-Relative, Gender not specified'
                  92='(92) Other, Relation and Gender Unspecified' 110='(110) Husband'
                  120='(120) Father/Male Guardian' 121='(121) Step/Adopted/Foster Father'
                  130='(130) Son' 131='(131) Step/Adopted/Foster Son'
                  140='(140) Brother/Half Brother'
                  141='(141) Step/Adopted/Foster Brother'
                  150='(150) Grandfather/Great+ Grandfather'
                  161='(161) Male Fiance/Boyfriend/Roommate/Companion' 170='(170) Uncle'
                  191='(191) Other Male Non-Relative'
                  192='(192) Other Male, Relation Unspecified' 210='(210) Wife'
                  220='(220) Mother/Female Guardian'
                  221='(221) Step/Adopted/Foster Mother'
                  222='(222) Mother In-Law/Step Mother In-Law' 230='(230) Daughter'
                  231='(231) Step/Adopted/Foster Daughter' 232='(232) Daughter In-Law'
                  240='(240) Sister/Half Sister' 242='(242) Sister In-Law'
                  250='(250) Grandmother/Great+ Grandmother'
                  261='(261) Female Fiancee/Girlfriend/Roommate/Companion'
                  270='(270) Aunt' 280='(280) Female God Child/God Daughter'
                  292='(292) Other Female, Relation Unspecified'
                  337='(337) Children, Relation Unspecified' 340='(340) Siblings'
                  350='(350) Grandparents/Great+ Grandparents'
                  361='(361) Friends/Roommates/Companions' 371='(371) Cousins'
                  384='(384) Neighbors/Co-Workers/Visitors'
                  390='(390) Other Relatives, Gender not specified'
                  391='(391) Other Non-Relatives, Gender not specified'
                  392='(392) Others, Relation and Gender Unspecified' 430='(430) Sons'
                  440='(440) Brothers/Half Brothers'
                  461='(461) Male Fiances/Boyfriends/Roommates/Companions'
                  492='(492) Other Males, Relation Unspecified'
                  540='(540) Sisters/Half Sisters'
                  561='(561) Female Fiancees/Girlfriends/Roommates/Companions'
                  900='(900) Not A Person' 985='(985) BAD DATA Logically assigned'
                  994='(994) DON''T KNOW' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE opresspb  9='(9) Head of Household' 33='(33) Grandchild'
                  61='(61) Friend/Roommate/Companion' 71='(71) Cousin'
                  84='(84) Neighbor/Co-Worker/Visitor' 170='(170) Uncle' 230='(230) Daughter'
                  240='(240) Sister/Half Sister'
                  261='(261) Female Fiancee/Girlfriend/Roommate/Companion'
                  270='(270) Aunt' 272='(272) Niece'
                  292='(292) Other Female, Relation Unspecified'
                  330='(330) Own Children/Own Half Children'
                  337='(337) Children, Relation Unspecified'
                  384='(384) Neighbors/Co-Workers/Visitors'
                  390='(390) Other Relatives, Gender not specified'
                  392='(392) Others, Relation and Gender Unspecified'
                  900='(900) Not A Person' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE whomarkd  1='(1) Respondent marked ALL the Answer Sheet responses'
                  2='(2) Interviewer marked All the Answer Sheet responses'
                  3='(3) Combination of respondent and F.I.BLANK (NO ANSWER'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE quarter   1='(1) Quarter' 2='(2) Quarter' 3='(3) Quarter' 4='(4) Quarter' ;
  VALUE famskip   0='(0) Respondent has other family members in household'
                  1='(1) Respondent didn''t have other family in household'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE pden      1='(1) Segment in a MSA with 1 million or more persons'
                  2='(2) Segment in a MSA with fewer than 1 million persons'
                  3='(3) Segment not in MSA' ;
  VALUE gqtype    1='(1) Halfway House' 2='(2) Boarding House' 3='(3) College Dorm'
                  4='(4) Shelter' 5='(5) Other' 9='(9) Not Group Quarters' ;
  VALUE pden2fff  1='(1) Segment in MSA with 1 million or more persons'
                  2='(2) Segm. in a MSA from 250000 to 999999 persons'
                  3='(3) Segment in a MSA with fewer than 250000 persons'
                  4='(4) Segment not in a MSA and not in a rural area'
                  5='(5) Segment not in a MSA and in a rural area' ;
  VALUE dc        1='(1) Low SES - DC' 2='(2) Not Low SES - DC' 9='(9) NOT IN DC' ;
  VALUE chicago   1='(1) Low SES - CHICAGO' 2='(2) Not Low SES - CHICAGO'
                  9='(9) NOT IN CHICAGO' ;
  VALUE denver    1='(1) Low SES - DENVER' 2='(2) Not Low SES - DENVER'
                  9='(9) NOT IN DENVER' ;
  VALUE la        1='(1) Low SES - LA' 2='(2) Not Low SES - LA' 9='(9) NOT IN LA' ;
  VALUE miami     1='(1) Low SES - MIAMI' 2='(2) Not Low SES - MIAMI'
                  9='(9) NOT IN MIAMI' ;
  VALUE newyork   1='(1) Low SES - NEW YORK' 2='(2) Not Low SES - NEW YORK'
                  9='(9) NOT IN NEW YORK' ;
  VALUE region    1='(1) Northeast' 2='(2) North Central' 3='(3) South' 4='(4) West' ;
  VALUE division  1='(1) New England' 2='(2) Middle Atlantic' 3='(3) East North Central'
                  4='(4) West North Central' 5='(5) South Atlantic'
                  6='(6) East South Central' 7='(7) West South Central' 8='(8) Mountain'
                  9='(9) Pacific' ;
  VALUE cencty    1='(1) Yes' 2='(2) No' 3='(3) Not in any of the 6 metropolitan areas' ;
  VALUE urbare    1='(1) Yes' 2='(2) No' 3='(3) Not in any of the 6 metropolitan areas'
                  9='(9) Data suppressed for reasons of confidentiality' ;
  VALUE metro     1='(1) Chicago Metropolitan area' 2='(2) Denver Metropolitan area'
                  3='(3) Los Angeles Metropolitan area'
                  4='(4) Miami Metropolitan area' 5='(5) New York Metropolitan area'
                  6='(6) Washington, D.C. Metropolitan area'
                  9='(9) Not in any of the 6 Metropolitan areas' ;
  VALUE centralc  1='(1) Sample segm. within a central city of metro area'
                  2='(2) Sam. segm. not within a central city of metro area'
                  3='(3) Sample segment not within a MSA' ;
  VALUE iiage     1='(1) Age from birthdate' 2='(2) Age from cover of questionnaire'
                  3='(3) Age from roster'
                  4='(4) Age statistically imputed using age gr from roster' ;
  VALUE irsex     1='(1) Male' 2='(2) Female' ;
  VALUE iisex     1='(1) Sex from questionnaire'
                  2='(2) Sex from relationship on roster' 3='(3) Sex from roster'
                  4='(4) Sex statistically imputed' ;
  VALUE irrace    1='(1) American indian or Alaskan native'
                  2='(2) Asian or Pacific islander' 3='(3) Black' 4='(4) White' ;
  VALUE iirace    1='(1) Race from questionnaire'
                  2='(2) Race from interview observation' 3='(3) Race from roster'
                  4='(4) Race statis imputed using race - Other on roster'
                  5='(5) Race statistically imputed, no infor. from roster' ;
  VALUE irhoind   1='(1) Hispanic' 2='(2) Nonhispanic' ;
  VALUE iihoind   1='(1) Hispanicity derived from questionnaire'
                  2='(2) Hispanicity derived from roster' ;
  VALUE irhogrp   1='(1) Puerto Rican' 2='(2) Mexican' 3='(3) Cuban' 4='(4) Other'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE iihogrp   1='(1) Hispanic-Origin Group taken from questionnaire'
                  3='(3) Statistically imputed data'
                  9='(9) LEGITIMATE SKIP Respondent is not hispanic' ;
  VALUE irhogrpf  1='(1) Puerto Rican' 2='(2) Mexican' 3='(3) Cuban' 4='(4) Other'
                  5='(5) Central American' 6='(6) South American' 7='(7) Caribbean'
                  99='(99) LEGITIMATE SKIP Respondent is not hispanic' ;
  VALUE iihogrpf  1='(1) Hispanic-Origin Group taken from questionnaire'
                  3='(3) Statistically imputed data'
                  9='(9) LEGITIMATE SKIP Respondent is not hispanic' ;
  VALUE irmarit   1='(1) Married' 2='(2) Widowed' 3='(3) Divorced or Separated'
                  4='(4) Never Married' 99='(99) LEGITIMATE SKIP' ;
  VALUE iimarit   1='(1) Questionnaire data'
                  2='(2) Logically imputed data from questionnaire'
                  4='(4) Logically imputed data from roster'
                  5='(5) Statistically imputed data'
                  6='(6) Logically imputed from relationship on roster'
                  9='(9) LEGITIMATE SKIP (less than or = 14 years old)' ;
  VALUE ireduc    0='(0) No schooling' 1='(1) First grade' 2='(2) Second grade'
                  3='(3) Third grade' 4='(4) Fourth grade' 5='(5) Fifth grade'
                  6='(6) Sixth grade' 7='(7) Seventh grade' 8='(8) Eighth grade'
                  9='(9) Ninth grade' 10='(10) Tenth grade' 11='(11) Eleventh grade'
                  12='(12) Twelfth grade' 13='(13) One year of college'
                  14='(14) Two years of college' 15='(15) Three years of college'
                  16='(16) Four years of college'
                  17='(17) Graduate/professional school' ;
  VALUE iieduc    1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE irhsgrad  1='(1) Yes, graduated from high school'
                  2='(2) No, did not graduate from high school' ;
  VALUE iihsgrad  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irworkst  1='(1) Working full-time, 35 hours or more a week'
                  2='(2) Working part-time, less than 35 hours a week'
                  3='(3) Have job but out: illness/leave/furlough/strike'
                  4='(4) Unemployed or laid off and looking for work'
                  5='(5) Unemployed and not looking for work'
                  6='(6) Full-time homemaker only' 7='(7) In school only' 8='(8) Retired'
                  9='(9) Disabled, not able to work' 10='(10) Other, in labor force'
                  11='(11) Other, not in labor force' ;
  VALUE iiworkst  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irpinsur  1='(1) Yes, respondent does have private health insurance'
                  2='(2) No, respondent does not have private health insur.' ;
  VALUE iipinsur  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irinsur   1='(1) Yes, respondent does have health insurance'
                  2='(2) No, respondent does not have health insurance' ;
  VALUE iiinsur   1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irwag1ff  1='(1) Yes' 2='(2) No' ;
  VALUE iiwag1ff  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irawag1f  0='(0) Zero income received' ;
  VALUE iiawag1f  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE irsoc1ff  1='(1) Yes' 2='(2) No' ;
  VALUE iisoc1ff  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irasoc1f  0='(0) Zero income received' ;
  VALUE iiasoc1f  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE irssi1ff  1='(1) Yes' 2='(2) No' ;
  VALUE iissi1ff  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irassi1f  0='(0) Zero income received' ;
  VALUE iiassi1f  1='(1) Questionnaire data' 3='(3) Statistically imputed data'
                  9='(9) LEGITIMATE SKIP' ;
  VALUE irwel1ff  1='(1) Yes' 2='(2) No' ;
  VALUE iiwel1ff  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irawel1f  0='(0) Zero income received' ;
  VALUE iiawel1f  1='(1) Questionnaire data' 3='(3) Statistically imputed data'
                  9='(9) LEGITIMATE SKIP' ;
  VALUE irint1ff  1='(1) Yes' 2='(2) No' ;
  VALUE iiint1ff  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE iraint1f  0='(0) Zero income received' ;
  VALUE iiaint1f  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE irchd1ff  1='(1) Yes' 2='(2) No' ;
  VALUE iichd1ff  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irachd1f  0='(0) Zero income received' ;
  VALUE iiachd1f  1='(1) Questionnaire data' 3='(3) Statistically imputed data'
                  9='(9) LEGITIMATE SKIP' ;
  VALUE iroth1ff  1='(1) Yes' 2='(2) No' ;
  VALUE iioth1ff  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE iraoth1f  0='(0) Zero income received' ;
  VALUE iiaoth1f  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE irwag2ff  1='(1) Yes' 2='(2) No' ;
  VALUE iiwag2ff  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE irawag2f  0='(0) Zero income received' ;
  VALUE iiawag2f  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE irsoc2ff  1='(1) Yes' 2='(2) No' ;
  VALUE iisoc2ff  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE irasoc2f  0='(0) Zero income received' ;
  VALUE iiasoc2f  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE irssi2ff  1='(1) Yes' 2='(2) No' ;
  VALUE iissi2ff  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE irassi2f  0='(0) Zero income received' ;
  VALUE iiassi2f  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE irwel2ff  1='(1) Yes' 2='(2) No' ;
  VALUE iiwel2ff  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE irawel2f  0='(0) Zero income received' ;
  VALUE iiawel2f  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE irint2ff  1='(1) Yes' 2='(2) No' ;
  VALUE iiint2ff  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE iraint2f  0='(0) Zero income received' ;
  VALUE iiaint2f  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE irchd2ff  1='(1) Yes' 2='(2) No' ;
  VALUE iichd2ff  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE irachd2f  0='(0) Zero income received' ;
  VALUE iiachd2f  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE iroth2ff  1='(1) Yes' 2='(2) No' ;
  VALUE iioth2ff  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE iraoth2f  0='(0) Zero income received' ;
  VALUE iiaoth2f  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE irfood    1='(1) Yes' 2='(2) No' ;
  VALUE iifood    1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irafood   0='(0) Zero income received' ;
  VALUE iiafood   1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE iralcrc   1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago' 9='(9) Never used alcohol' ;
  VALUE iialcrc   1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irmjrc    1='(1) Within the past week (7 days)'
                  2='(2) More than 1 week ago but less than 1 month ago'
                  3='(3) 1 or more months ago but less than 6 months ago'
                  4='(4) 6 or more months ago but less than 1 year ago'
                  5='(5) 1 or more years ago but less than 3 years ago'
                  6='(6) 3 or more years ago' 9='(9) Never used marijuana' ;
  VALUE iimjrc    1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE ircocrc   1='(1) Within the past week (7 days)'
                  2='(2) More than 1 week ago but less than 1 month ago'
                  3='(3) 1 or more months ago but less than 6 months ago'
                  4='(4) 6 or more months ago but less than 1 year ago'
                  5='(5) 1 or more years ago but less than 3 years ago'
                  6='(6) 3 or more years ago' 9='(9) Never used cocaine' ;
  VALUE iicocrc   1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irsedrc   1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago' 9='(9) Never used sedatives' ;
  VALUE iisedrc   1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE irtrnrc   1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago' 9='(9) Never used tranquilizers' ;
  VALUE iitrnrc   1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE irstmrc   1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago' 9='(9) Never used stimulants' ;
  VALUE iistmrc   1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE iranlrc   1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago' 9='(9) Never used analgesics' ;
  VALUE iianlrc   1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE ircigrc   1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago' 9='(9) Never smoked cigarettes' ;
  VALUE iicigrc   1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irotbrc   1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago' 9='(9) Never used smokeless tobacco' ;
  VALUE iiotbrc   1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE irinhrc   1='(1) Within the past week (7 days)'
                  2='(2) More than 1 week ago but less than 1 month ago'
                  3='(3) 1 or more months ago but less than 6 months ago'
                  4='(4) 6 or more months ago but less than 1 year ago'
                  5='(5) 1 or more years ago but less than 3 years ago'
                  6='(6) 3 or more years ago' 9='(9) Never used inhalants' ;
  VALUE iiinhrc   1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE ircrkrc   1='(1) Within the past week (7 days)'
                  2='(2) More than 1 week ago but less than 1 month ago'
                  3='(3) 1 or more months ago but less than 6 months ago'
                  4='(4) 6 or more months ago but less than 1 year ago'
                  5='(5) 1 or more years ago but less than 3 years ago'
                  6='(6) 3 or more years ago' 9='(9) Never used crack' ;
  VALUE iicrkrc   1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irhalrc   1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago' 9='(9) Never used hallucinogens' ;
  VALUE iihalrc   1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irherrc   1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago' 9='(9) Never used heroin' ;
  VALUE iiherrc   1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irpcprc   1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago' 9='(9) Never used PCP' ;
  VALUE iipcprc   1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE iricerc   1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago but less than 10 years ago'
                  6='(6) 10 or more years ago' 9='(9) Never used ice' ;
  VALUE iiicerc   1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE irstrrc   1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago' 9='(9) Never used anabolic steroids' ;
  VALUE iistrrc   1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE iralcfq   1='(1) Used daily in past year'
                  2='(2) Used almost daily in past year'
                  3='(3) Used 1-2 days per week in past year'
                  4='(4) Used several times a month in past year'
                  5='(5) Used 1-2 times per month in past year'
                  6='(6) Used every other month in past year'
                  7='(7) Used 3-5 times in past year'
                  8='(8) Used 1-2 times in past year'
                  9='(9) Never used or did not use in the past year' ;
  VALUE iialcfq   1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irmjfq    1='(1) Used several times per day in past year'
                  2='(2) Used daily in past year'
                  3='(3) Used almost daily in past year'
                  4='(4) Used 1-2 days per week in past year'
                  5='(5) Used several times per month in past year'
                  6='(6) Used 1-2 times per month in past year'
                  7='(7) Used every other month in past year'
                  8='(8) Used 3-5 times in past year'
                  9='(9) Used 1-2 times in past year'
                  10='(10) Never used or did not use in the past year' ;
  VALUE iimjfq    1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE ircocfq   1='(1) Used daily in past year'
                  2='(2) Used almost daily in past year'
                  3='(3) Used 1-2 days per week in past year'
                  4='(4) Used several times per month in past year'
                  5='(5) Used 1-2 times per month in past year'
                  6='(6) Used every other month in past year'
                  7='(7) Used 3-5 times in past year'
                  8='(8) Used 1-2 times in past year'
                  9='(9) Never used or did not use in the past year' ;
  VALUE iicocfq   1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irsedfq   1='(1) Used daily in past year'
                  2='(2) Used almost daily in past year'
                  3='(3) Used 1-2 days per week in past year'
                  4='(4) Used several times a month in past year'
                  5='(5) Used 1-2 times per month in past year'
                  6='(6) Used every other month in past year'
                  7='(7) Used 3-5 times in past year'
                  8='(8) Used 1-2 times in past year'
                  9='(9) Never used or did not use in the past year' ;
  VALUE iisedfq   1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irtrnfq   1='(1) Used daily in past year'
                  2='(2) Used almost daily in past year'
                  3='(3) Used 1-2 days per week in past year'
                  4='(4) Used several times a month in past year'
                  5='(5) Used 1-2 times per month in past year'
                  6='(6) Used every other month in past year'
                  7='(7) Used 3-5 times in past year'
                  8='(8) Used 1-2 times in past year'
                  9='(9) Never used or did not use in the past year' ;
  VALUE iitrnfq   1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irstmfq   1='(1) Used daily in past year'
                  2='(2) Used almost daily in past year'
                  3='(3) Used 1-2 days per week in past year'
                  4='(4) Used several times a month in past year'
                  5='(5) Used 1-2 times per month in past year'
                  6='(6) Used every other month in past year'
                  7='(7) Used 3-5 times in past year'
                  8='(8) Used 1-2 times in past year'
                  9='(9) Never used or did not use in the past year' ;
  VALUE iistmfq   1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE iranlfq   1='(1) Used daily in past year'
                  2='(2) Used almost daily in past year'
                  3='(3) Used 1-2 days per week in past year'
                  4='(4) Used several times a month in past year'
                  5='(5) Used 1-2 times per month in past year'
                  6='(6) Used every other month in past year'
                  7='(7) Used 3-5 times in past year'
                  8='(8) Used 1-2 times in past year'
                  9='(9) Never used or did not use in the past year' ;
  VALUE iianlfq   1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irotbfq   1='(1) Used daily in past year'
                  2='(2) Used almost daily in past year'
                  3='(3) Used 1-2 days per week in past year'
                  4='(4) Used several times a month in past year'
                  5='(5) Used 1-2 times per month in past year'
                  6='(6) Used every other month in past year'
                  7='(7) Used 3-5 times in past year'
                  8='(8) Used 1-2 times in past year'
                  9='(9) Never used or did not use in the past year' ;
  VALUE iiotbfq   1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irinhfq   1='(1) Use daily in past year'
                  2='(2) Used almost daily in past year'
                  3='(3) Used 1-2 days per week in past year'
                  4='(4) Used several times a month in past year'
                  5='(5) Used 1-2 times per month in past year'
                  6='(6) Used every other month in past year'
                  7='(7) Used 3-5 times in past year'
                  8='(8) Used 1-2 times in past year'
                  9='(9) Never used or did not use in the past year' ;
  VALUE iiinhfq   1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irhalfq   1='(1) Used daily in past year'
                  2='(2) Used almost daily in past year'
                  3='(3) Used 1-2 days per week in past year'
                  4='(4) Used several times a month in past year'
                  5='(5) Used 1-2 times per month in past year'
                  6='(6) Used every other month in past year'
                  7='(7) Used 3-5 times in past year'
                  8='(8) Used 1-2 times in past year'
                  9='(9) Never used or did not use in the past year' ;
  VALUE iihalfq   1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE catage    1='(1) 12-17 years' 2='(2) 18-25 years' 3='(3) 26-34 years'
                  4='(4) 35+ years' ;
  VALUE catag2ff  1='(1) 12-17 years' 2='(2) 18-25 years' 3='(3) 26+ years' ;
  VALUE catag3ff  1='(1) 12-17 years' 2='(2) 18-25 years' 3='(3) 26-34 years'
                  4='(4) 35-49 years' 5='(5) 50+ years' ;
  VALUE race      1='(1) White (IRRACE = 4 and IRHOIND = 2)'
                  2='(2) Black (IRRACE = 3 and IRHOIND = 2)'
                  3='(3) Hispanic (IRHOIND = 1)'
                  4='(4) Other (IRRACE = 1-2 and IRHOIND = 2)' ;
  VALUE hisprace  1='(1) Hispanic' 2='(2) Nonhispanic Black' 3='(3) Nonhispanic Nonblack' ;
  VALUE educcatf  1='(1) Less than high school (IREDUC=0-11 and IRAGE=>18)'
                  2='(2) High school graduate (IREDUC = 12 and IRAGE=>18)'
                  3='(3) Some college (IREDUC = 13-15 and IRAGE => 18)'
                  4='(4) College graduate (IREDUC = 16-17 and IRAGE => 18)'
                  5='(5) 12-17 year olds (IRAGE = 12-17)' ;
  VALUE empstatf  1='(1) Full=time (IRWORKST =1,3 and IRAGE => 18)'
                  2='(2) Part-time (IRWORKST = 2 and IRAGE => 18)'
                  3='(3) Unemployed (IRWORKST = 4,5,10 and IRAGE => 18)'
                  4='(4) Other (IRWORKST = 6-9,11 and IRAGE => 18)'
                  5='(5) 12-17 year olds (IRAGE = 12-17)' ;
  VALUE iiindinc  1='(1) All personal income sources from questionnaire'
                  3='(3) At least 1 of sources were stat or logic imputed' ;
  VALUE indcat    1='(1) $0' 2='(2) $1-$4,999' 3='(3) $5,000-$6,999' 4='(4) $7,000-$8,999'
                  5='(5) $9,000-$11,999' 6='(6) $12,000-$14,999' 7='(7) $15,000-$19,999'
                  8='(8) $20,000-$24,999' 9='(9) $25,000-$29,999'
                  10='(10) $30,000-$39,999' 11='(11) $40,000-$49,999'
                  12='(12) $50,000-$74,999' 13='(13) $75,000+' ;
  VALUE perinc    1='(1) $0-$8,999' 2='(2) $9,000-$19,999' 3='(3) $20,000-$39,999'
                  4='(4) $40,000-$74,999' 5='(5) $75,000+' ;
  VALUE perinc2f  1='(1) $0-9,999' 2='(2) $10,000-$19,999' 3='(3) $20,000-$29,999'
                  4='(4) $30,000-$39,999' 5='(5) $40,000-$49,999' 6='(6) $50,000-$74,999'
                  7='(7) $75,000+' ;
  VALUE perinc3f  1='(1) $0-$9,999' 2='(2) $10,000-$19,999' 3='(3) $20,000-$29,999'
                  4='(4) $30,000-$39,999' 5='(5) $40,000-$49,999' 6='(6) $50,000-$74,999'
                  7='(7) $75,000+' 8='(8) 12-17 Years Old' ;
  VALUE totinc    0='(0) No family income' ;
  VALUE iitotinc  1='(1) All income sources from questionnaire'
                  3='(3) At least 1 of sources were stat or logic imputed' ;
  VALUE totcat    1='(1) $0' 2='(2) $1-$4,999' 3='(3) $5,000-$6,999' 4='(4) $7,000-$8,999'
                  5='(5) $9,000-$11,999' 6='(6) $12,000-$14,999' 7='(7) $15,000-$19,999'
                  8='(8) $20,000-$24,999' 9='(9) $25,000-$29,999'
                  10='(10) $30,000-$39,999' 11='(11) $40,000-$49,999'
                  12='(12) $50,000-$74,999' 13='(13) $75,000+' ;
  VALUE faminc    1='(1) $0-$8,999' 2='(2) $9,000-$19,999' 3='(3) $20,000-$39,999'
                  4='(4) $40,000-$74,000' 5='(5) $75,000+' ;
  VALUE faminc2f  1='(1) $0-$9,999' 2='(2) $10,000-$19,999' 3='(3) $20,000-$29,999'
                  4='(4) $30,000-$39,999' 5='(5) $40,000-$49,999' 6='(6) $50,000-$74,999'
                  7='(7) $75,000+' ;
  VALUE faminc3f  1='(1) $0-$9,999' 2='(2) $10,000-$19,999' 3='(3) $20,000-$29,999'
                  4='(4) $30,000-$39,999' 5='(5) $40,000-$49,999' 6='(6) $50,000-$74,999'
                  7='(7) $75,000+' 8='(8) 12-17 Years old' ;
  VALUE welfare   1='(1) Yes, respondent or another fam member on welfare'
                  2='(2) No, there was no one in the family on welfare' ;
  VALUE halflag   0='(0) Never used (IRHALRC = 9)' 1='(1) Ever used (IRHALRC = 1-5)' ;
  VALUE halyr     0='(0) Did not use in the past year (IRHALRC = 4-5,9)'
                  1='(1) Used within the past year (IRHALRC = 1-3)' ;
  VALUE halmon    0='(0) Did not use in the past month (IRHALRC = 2-5,9)'
                  1='(1) Used within the past month (IRHALRC = 1)' ;
  VALUE pcpflag   0='(0) Never used (IRPCPRC = 9)' 1='(1) Ever used (IRPCPRC = 1-5)' ;
  VALUE pcpyr     0='(0) Did not use in the past year (IRPCPRC = 4-5,9)'
                  1='(1) Used within the past year (IRPCPRC = 1-3)' ;
  VALUE pcpmon    0='(0) Did not use in the past month (IRPCPRC = 2-5,9)'
                  1='(1) Used within the past month (IRPCPRC = 1)' ;
  VALUE stmflag   0='(0) Never used (IRSTMRC = 9)' 1='(1) Ever used (IRSTMRC = 1-5)' ;
  VALUE stmyr     0='(0) Did not use in the past year (IRSTMRC = 4-5,9)'
                  1='(1) Used within the past year (IRSTMRC = 1-3)' ;
  VALUE stmmon    0='(0) Did not use in the past month (IRSTMRC = 2-5,9)'
                  1='(1) Used within the past month (IRSTMRC = 1)' ;
  VALUE sedflag   0='(0) Never used (IRSEDRC = 9)' 1='(1) Ever used (IRSEDRC = 1-5)' ;
  VALUE sedyr     0='(0) Did not use in the past year (IRSEDRC = 4-5,9)'
                  1='(1) Used within the past year (IRSEDRC = 1-3)' ;
  VALUE sedmon    0='(0) Did not use in the past month (IRSEDRC = 2-5,9)'
                  1='(1) Used within the past month (IRSEDRC = 1)' ;
  VALUE trqflag   0='(0) Never used (IRTRNRC = 9)' 1='(1) Ever used (IRTRNRC = 1-5)' ;
  VALUE trqyr     0='(0) Did not use in the past year (IRTRNRC = 4-5,9)'
                  1='(1) Used within the past year (IRTRNRC = 1-3)' ;
  VALUE trqmon    0='(0) Did not use in the past month (IRTRNRC = 2-5,9)'
                  1='(1) Used within the past month (IRTRNRC = 1)' ;
  VALUE anlflag   0='(0) Never used (IRANLRC = 9)' 1='(1) Ever used (IRANLRC = 1-5)' ;
  VALUE anlyr     0='(0) Did not use in the past year (IRANLRC = 4-5,9)'
                  1='(1) Used within the past year (IRANLRC = 1-3)' ;
  VALUE anlmon    0='(0) Did not use in the past month (IRANLRC = 2-5,9)'
                  1='(1) Used within the past month (IRANLRC = 1)' ;
  VALUE alcflag   0='(0) Never used (IRALCRC = 9)' 1='(1) Ever used (IRALCRC = 1-5)' ;
  VALUE alcyr     0='(0) Did not use in the past year (IRALCRC = 4-5,9)'
                  1='(1) Used within the past year (IRALCRC = 1-3)' ;
  VALUE alcmon    0='(0) Did not use in the past month (IRALCRC = 2-5,9)'
                  1='(1) Used within the past month (IRALCRC = 1)' ;
  VALUE cigflag   0='(0) Never used (IRCIGRC = 9)' 1='(1) Ever used (IRCIGRC = 1-5)' ;
  VALUE cigyr     0='(0) Did not use in the past year (IRCIGRC = 4-5,9)'
                  1='(1) Used within the past year (IRCIGRC = 1-3)' ;
  VALUE cigmon    0='(0) Did not use in the past month (IRCIGRC = 2-5,9)'
                  1='(1) Used within the past month (IRCIGRC = 1)' ;
  VALUE smkflag   0='(0) Never used (IROTBRC = 9)' 1='(1) Ever used (IROTBRC = 1-5)' ;
  VALUE smkyr     0='(0) Did not use in the past year (IROTBRC = 4-5,9)'
                  1='(1) Used within the past year (IROTBRC = 1-3)' ;
  VALUE smkmon    0='(0) Did not use in the past month (IROTBRC = 2-5,9)'
                  1='(1) Used within the past month (IROTBRC = 1)' ;
  VALUE herflag   0='(0) Never used (IRHERRC = 9)' 1='(1) Ever used (IRHERRC = 1-5)' ;
  VALUE heryr     0='(0) Did not use in the past year (IRHERRC = 4-5,9)'
                  1='(1) Used within the past year (IRHERRC = 1-3)' ;
  VALUE hermon    0='(0) Did not use in the past month (IRHERRC = 2-5,9)'
                  1='(1) Used within the past month (IRHERRC = 1)' ;
  VALUE strflag   0='(0) Never used (IRSTRRC = 9)' 1='(1) Ever used (IRSTRRC = 1-5)' ;
  VALUE stryr     0='(0) Did not use in the past year (IRSTRRC = 4-5,9)'
                  1='(1) Used within the past year (IRSTRRC = 1-3)' ;
  VALUE strmon    0='(0) Did not use in the past month (IRSTRRC = 2-5,9)'
                  1='(1) Used within the past month (IRSTRRC = 1)' ;
  VALUE mrjflag   0='(0) Never used (IRMJRC = 9)' 1='(1) Ever used (IRMJRC = 1-6)' ;
  VALUE mrjyr     0='(0) Did not use in the past year (IRMJRC = 5-6,9)'
                  1='(1) Used within the past year (IRMJRC = 1-4)' ;
  VALUE mrjmon    0='(0) Did not use in the past month (IRMJRC = 3-6,9)'
                  1='(1) Used within the past month (IRMJRC = 1-2)' ;
  VALUE cocflag   0='(0) Never used (IRCOCRC = 9)' 1='(1) Ever used (IRCOCRC = 1-6)' ;
  VALUE cocyr     0='(0) Did not use in the past year (IRCOCRC = 5-6,9)'
                  1='(1) Used within the past year (IRCOCRC = 1-4)' ;
  VALUE cocmon    0='(0) Did not use in the past month (IRCOCRC = 3-6,9)'
                  1='(1) Used within the past month (IRCOCRC = 1-2)' ;
  VALUE crkflag   0='(0) Never used (IRCRKRC = 9)' 1='(1) Ever used (IRCRKRC = 1-6)' ;
  VALUE crkyr     0='(0) Did not use in the past year (IRCRKRC= 5-6,9)'
                  1='(1) Used within the past year (IRCRKRC = 1-4)' ;
  VALUE crkmon    0='(0) Did not use in the past month (IRCRKRC = 3-6,9)'
                  1='(1) Used within the past month (IRCRKRC = 1-2)' ;
  VALUE inhflag   0='(0) Never used (IRINHRC = 9)' 1='(1) Ever used (IRINHRC = 1-6)' ;
  VALUE inhyr     0='(0) Did not use in the past year (IRINHRC = 5-6,9)'
                  1='(1) Used within the past year (IRINHRC = 1-4)' ;
  VALUE inhmon    0='(0) Did not use in the past month (IRINHRC = 3-6,9)'
                  1='(1) Used within the past month (IRINHRC = 1-2)' ;
  VALUE iceflag   0='(0) Never used (IRICERC = 9)' 1='(1) Ever used (IRICERC = 1-6)' ;
  VALUE iceyr     0='(0) Did not use in the past year (IRICERC = 4-6,9)'
                  1='(1) Used within the past year (IRICERC = 1-3)' ;
  VALUE icemon    0='(0) Did not use in the past month (IRICERC = 2-6,9)'
                  1='(1) Used within the past month (IRICERC = 1)' ;
  VALUE needlrec  1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago but less than 10 years ago'
                  6='(6) 10 or more years ago'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER USED A NEEDLE TO INJECT ANY DRUG'
                  98='(98) NEEDLE USE NOT INDICATED BUT 1+ SOURCE VAR BLANK' ;
  VALUE ndl90rec  1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago but less than 10 years ago'
                  6='(6) 10 or more years ago'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER USED A NEEDLE TO INJECT ANY DRUG'
                  98='(98) NEEDLE USE NOT INDICATED BUT 1+ SOURCE VAR BLANK' ;
  VALUE nedflagf  0='(0) Never used (NDL90REC=91,98)'
                  1='(1) Ever used (NDL90REC=1-9)' ;
  VALUE nedyr3ff  0='(0) Never used (NDL90REC=4-6,9,91,98)'
                  1='(1) Ever used (NDL90REC=1-3,8)' ;
  VALUE halyrf    0='(0) Never used or did not use in past year (IRHALFQ=9)'
                  1='(1) Any use within the past year (IRHALFQ=1-8)' ;
  VALUE halmonf   0='(0) Did not use monthly/more past year (IRHALFQ=6-9)'
                  1='(1) Used monthly or more often past year (IRHALFQ=1-5)' ;
  VALUE halwkf    0='(0) Did not use weekly or more past year (IRHALFQ=4-9)'
                  1='(1) Used weekly or more often past year (IRHALFQ=1-3)' ;
  VALUE haloccf   0='(0) Used monthly/more or none in pst yr(IRHALFQ=1-5,9)'
                  1='(1) Used past year but less than monthly (IRHALFQ=6-8)' ;
  VALUE haldlyf   0='(0) Did not use daily/almost daily pst yr(IRHALFQ=3-9)'
                  1='(1) Used daily/almost daily in past year (IRHALFQ=1-2)' ;
  VALUE stmyrf    0='(0) Never used or did not use in past year (IRSTMFQ=9)'
                  1='(1) Any use within the past year (IRSTMFQ=1-8)' ;
  VALUE stmmonf   0='(0) Did not use monthly/more past year (IRSTMFQ=6-9)'
                  1='(1) Used monthly or more often past year (IRSTMFQ=1-5)' ;
  VALUE stmwkf    0='(0) Did not use weekly or more past year (IRSTMFQ=4-9)'
                  1='(1) Used weekly or more often past year (IRSTMFQ=1-3)' ;
  VALUE stmoccf   0='(0) Used monthly/more or none in pst yr(IRSTMFQ=1-5,9)'
                  1='(1) Used past year but less than monthly (IRSTMFQ=6-8)' ;
  VALUE stmdlyf   0='(0) Did not use daily/almost daily pst yr(IRSTMFQ=3-9)'
                  1='(1) Used daily/almost daily in past year (IRSTMFQ=1-2)' ;
  VALUE sedyrf    0='(0) Never used or did not use in past year (IRSEDFQ=9)'
                  1='(1) Any use within the past year (IRSEDFQ=1-8)' ;
  VALUE sedmonf   0='(0) Did not use monthly/more past year (IRSEDFQ=6-9)'
                  1='(1) Used monthly or more often past year (IRSEDFQ=1-5)' ;
  VALUE sedwkf    0='(0) Did not use weekly or more past year (IRSEDFQ=4-9)'
                  1='(1) Used weekly or more often past year (IRSEDFQ=1-3)' ;
  VALUE sedoccf   0='(0) Used monthly/more or none in pst yr(IRSEDFQ=1-5,9)'
                  1='(1) Used past year but less than monthly (IRSEDFQ=6-8)' ;
  VALUE seddlyf   0='(0) Did not use daily/almost daily pst yr(IRSEDFQ=3-9)'
                  1='(1) Used daily/almost daily in past year (IRSEDFQ=1-2)' ;
  VALUE trqyrf    0='(0) Never used or did not use in past year (IRTRNFQ=9)'
                  1='(1) Any use within the past year (IRTRNFQ=1-8)' ;
  VALUE trqmonf   0='(0) Did not use monthly/more past year (IRTRNFQ=6-9)'
                  1='(1) Used monthly or more often past year (IRTRNFQ=1-5)' ;
  VALUE trqwkf    0='(0) Did not use weekly or more past year (IRTRNFQ=4-9)'
                  1='(1) Used weekly or more often past year (IRTRNFQ=1-3)' ;
  VALUE trqoccf   0='(0) Used monthly/more or none in pst yr(IRTRNFQ=1-5,9)'
                  1='(1) Used past year but less than monthly (IRTRNFQ=6-8)' ;
  VALUE trqdlyf   0='(0) Did not use daily/almost daily pst yr(IRTRNFQ=3-9)'
                  1='(1) Used daily/almost daily in past year (IRTRNFQ=1-2)' ;
  VALUE anlyrf    0='(0) Never used or did not use in past year (IRANLFQ=9)'
                  1='(1) Any use within the past year (IRANLFQ=1-8)' ;
  VALUE anlmonf   0='(0) Did not use monthly/more past year (IRANLFQ=6-9)'
                  1='(1) Used monthly or more often past year (IRANLFQ=1-5)' ;
  VALUE anlwkf    0='(0) Did not use weekly or more past year (IRANLFQ=4-9)'
                  1='(1) Used weekly or more often past year (IRANLFQ=1-3)' ;
  VALUE anloccf   0='(0) Used monthly/more or none in pst yr(IRANLFQ=1-5,9)'
                  1='(1) Used past year but less than monthly (IRANLFQ=6-8)' ;
  VALUE anldlyf   0='(0) Did not use daily/almost daily pst yr(IRANLFQ=3-9)'
                  1='(1) Used daily/almost daily in past year (IRANLFQ=1-2)' ;
  VALUE alcyrf    0='(0) Never used or not used in past year (IRALCFQ=9)'
                  1='(1) Any use within the past year (IRALCFQ=1-8)' ;
  VALUE alcmonf   0='(0) Did not use monthly/more past year (IRALCFQ=6-9)'
                  1='(1) Used monthly or more often past year (IRALCFQ=1-5)' ;
  VALUE alcwkf    0='(0) Did not use weekly or more past year (IRALCFQ=4-9)'
                  1='(1) Used weekly or more in past year (IRALCFQ=1-3)' ;
  VALUE alcoccf   0='(0) Used monthly/more or none in pst yr(IRALCFQ=1-5,9)'
                  1='(1) Used past year but less than monthly (IRALCFQ=6-8)' ;
  VALUE alcdlyf   0='(0) Did not use daily/almost daily pst yr(IRALCFQ=3-9)'
                  1='(1) Used daily/almost daily in past year (IRALCFQ=1-2)' ;
  VALUE smkyrf    0='(0) Never used or did not use in past year (IROTBFQ=9)'
                  1='(1) Any use within the past year (IROTBFQ=1-8)' ;
  VALUE smkmonf   0='(0) Did not use monthly/more past year (IROTBFQ=6-9)'
                  1='(1) Used monthly or more often past year (IROTBFQ=1-5)' ;
  VALUE smkwkf    0='(0) Did not use weekly or more past year (IROTBFQ=4-9)'
                  1='(1) Used weekly or more often past year (IROTBFQ=1-3)' ;
  VALUE smkoccf   0='(0) Used monthly/more or none in pst yr(IROTBFQ=1-5,9)'
                  1='(1) Used past year but less than monthly (IROTBFQ=6-8)' ;
  VALUE smkdlyf   0='(0) Did not use daily/almost daily pst yr(IROTBFQ=3-9)'
                  1='(1) Used daily/almost daily in past year (IROTBFQ=1-2)' ;
  VALUE mrjyrf    0='(0) Never used or did not use in past year (IRMJFQ=10)'
                  1='(1) Any use within the past year (IRMJFQ=1-9)' ;
  VALUE mrjmonf   0='(0) Did not use monthly/more past year (IRMJFQ=7-10)'
                  1='(1) Used monthly or more in past year (IRMJFQ=1-6)' ;
  VALUE mrjwkf    0='(0) Did not use weekly/more past year (IRMJFQ=5-10)'
                  1='(1) Used weekly or more in past year (IRMJFQ=1-4)' ;
  VALUE mrjoccf   0='(0) Used monthly/more or none in pst yr(IRMJFQ=1-6,10)'
                  1='(1) Used past year but less than monthly (IRMJFQ=7-9)' ;
  VALUE mrjdlyf   0='(0) Did not use daily/almost daily pst yr(IRMJFQ=4-10)'
                  1='(1) Used daily/almost daily in past year (IRMJFQ=1-3)' ;
  VALUE cocyrf    0='(0) Never used or did not use in past year (IRCOCFQ=9)'
                  1='(1) Any use within the past year (IRCOCFQ = 1-8)' ;
  VALUE cocmonf   0='(0) Did not use monthly/more past year (IRCOCFQ=6-9)'
                  1='(1) Used monthly or more often past year (IRCOCFQ=1-5)' ;
  VALUE cocwkf    0='(0) Did not use weekly or more past year (IRCOCFQ=4-9)'
                  1='(1) Used weekly or more often past year (IRCOCFQ=1-3)' ;
  VALUE cococcf   0='(0) Used monthly/more or none in pst yr(IRCOCFQ=1-5,9)'
                  1='(1) Used past year but less than monthly (IRCOCFQ=6-8)' ;
  VALUE cocdlyf   0='(0) Did not use daily/almost daily pst yr(IRCOCFQ=3-9)'
                  1='(1) Used daily/almost daily in past year (IRCOCFQ=1-2)' ;
  VALUE inhyrf    0='(0) Never used or did not use in past year (IRINHFQ=9)'
                  1='(1) Any use within the past year (IRINHFQ=1-8)' ;
  VALUE inhmonf   0='(0) Did not use monthly/more past year (IRINHFQ=6-9)'
                  1='(1) Used monthly or more often past year (IRINHFQ=1-5)' ;
  VALUE inhwkf    0='(0) Did not use weekly or more past year (IRINHFQ=4-9)'
                  1='(1) Used weekly or more often past year (IRINHFQ=1-3)' ;
  VALUE inhoccf   0='(0) Used monthly/more or none in pst yr(IRINHFQ=1-5,9)'
                  1='(1) Used past year but less than monthly (IRINHFQ=6-8)' ;
  VALUE inhdlyf   0='(0) Did not use daily/almost daily pst yr(IRINHFQ=3-9)'
                  1='(1) Used daily/almost daily in past year (IRINHFQ=1-2)' ;
  VALUE psyflagf  0='(0) Never used (ALL SOURCE VARIABLES = 9)'
                  1='(1) Ever used (ANY SOURCE VARIABLE < 9)' ;
  VALUE psyyr2ff  0='(0) Did not use within past year (ALL SOURCE VARS > 3)'
                  1='(1) Used in past year (ANY SOURCE VARIABLE < 4)' ;
  VALUE psymon2f  0='(0) Did not use in past month (ALL SOURCE VARS > 1)'
                  1='(1) Used in past month (ANY SOURCE VARIABLE = 1)' ;
  VALUE sumflag   0='(0) Never used (ALL SOURCE VARIABLES = 0)'
                  1='(1) Ever used (ANY SOURCE VARIABLE = 1)' ;
  VALUE sumyr     0='(0) Did not use in past year (ALL SOURCE VARS =0)'
                  1='(1) Used in past year (ANY SOURCE VARIABLE = 1)' ;
  VALUE summon    0='(0) Did not use in past month (ALL SOURCE VARS = 0)'
                  1='(1) Used in past month (ANY SOURCE VARIABLE = 1)' ;
  VALUE mjoflag   0='(0) Never used MJ/has used both MJ & anothr illct drug'
                  1='(1) Marijuana is only (illicit) drug ever used' ;
  VALUE mjoyr2ff  0='(0) MJ not used past yr/Used MJ & othr drug past yr'
                  1='(1) Marijuana is only (illicit) drug in past year' ;
  VALUE mjomon2f  0='(0) MJ not used past mnth/Used MJ & othr drug past mo'
                  1='(1) Marijuana only (illicit) drug in past month' ;
  VALUE iemflag   0='(0) Never used drug/used only marijuana'
                  1='(1) Illicit drug except for marijuana are ever used' ;
  VALUE iemyr     0='(0) Never used drug/used only marijuana past year'
                  1='(1) Illicit drug except for marijuana used past year' ;
  VALUE iemmon    0='(0) Never used drug/used only marijuana past month'
                  1='(1) Illicit drug except for marijuana used past month' ;
  VALUE hsphconc  1='(1) Greater than or equaled 50 percent'
                  2='(2) Greater than or equaled 10 pcnt, less than 50 pcnt'
                  3='(3) Less than 10 percent' ;
  VALUE hsppconc  1='(1) Greater than or equaled 50 percent'
                  2='(2) Greater than or equaled 10 pcnt, less than 50 pcnt'
                  3='(3) Less than 10 percent' ;
  VALUE ownoconc  1='(1) Greater than or equaled 50 percent'
                  2='(2) Greater than or equaled 10 pcnt, less than 50 pcnt'
                  3='(3) Less than 10 pcnt' ;
  VALUE uclass9f  0='(0) Above poverty level' 1='(1) Below poverty level' ;
  VALUE qc06ffff  1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago' 94='(94) DON''T KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE qc09ffff  1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago' 91='(91) NEVER USED SMOKELESS TOBACCO'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE al02ffff  1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago' 91='(91) NEVER USED ALCOHOL'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE se04ffff  1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago' 98='(98) BLANK (NO ANSWER)' ;
  VALUE tr04ffff  1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago' 98='(98) BLANK (NO ANSWER)' ;
  VALUE st04ffff  1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago' 98='(98) BLANK (NO ANSWER)' ;
  VALUE st07ffff  1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago but less than 10 years ago'
                  6='(6) 10 or more years ago'
                  93='(93) NEVER USED AMPHETAMINES WITH A NEEDLE'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE an04ffff  1='(1) Within past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago' 98='(98) BLANK (NO ANSWER)' ;
  VALUE mj04ffff  1='(1) Within the past week (7 days)'
                  2='(2) More than 1 week ago but less than 1 month ago'
                  3='(3) 1 or more months ago but less than 6 months ago'
                  4='(4) 6 or more months ago but less than 1 year ago'
                  5='(5) 1 or more years ago but less than 3 years ago'
                  6='(6) 3 or more years ago' 91='(91) NEVER USED MARIJUANA'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE in04ffff  1='(1) Within the past week (7 days)'
                  2='(2) More than 1 week ago but less than 1 month ago'
                  3='(3) 1 or more months ago but less than 6 months ago'
                  4='(4) 6 or more months ago but less than 1 year ago'
                  5='(5) 1 or more years ago but less than 3 years ago'
                  6='(6) 3 or more years ago' 91='(91) NEVER USED INHALANTS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cc04ffff  1='(1) Within the past week (7 days)'
                  2='(2) More than 1 week ago but less than 1 month ago'
                  3='(3) 1 or more months ago but less than 6 months ago'
                  4='(4) 6 or more months ago but less than 1 year ago'
                  5='(5) 1 or more years ago but less than 3 years ago'
                  6='(6) 3 or more years ago' 91='(91) NEVER USED COCAINE'
                  94='(94) DON''T KNOW' 98='(98) BLANK (NO ANSWER)' ;
  VALUE cc11ffff  1='(1) Within past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago but less than 10 years ago'
                  6='(6) 10 or more years ago' 91='(91) NEVER USED COCAINE'
                  93='(93) NEVER USED COCAINE WITH A NEEDLE' 94='(94) DON''T KNOW'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE ck01ffff  1='(1) Within the past week (7 days)'
                  2='(2) More than 1 week ago but less than 1 month ago'
                  3='(3) 1 or months ago but less than 6 months ago'
                  4='(4) 6 or months ago but less than 1 year ago'
                  5='(5) 1 or more years ago but less than 3 years ago'
                  6='(6) 3 or more years ago' 91='(91) NEVER USED CRACK'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ls05ffff  1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago' 85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED HALLUCINOGENS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE ls08ffff  1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago' 91='(91) NEVER USED PCP' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE he04ffff  1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago' 85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED HEROIN' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE he07ffff  1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago but less than 10 years ago'
                  6='(6) 10 or more years ago' 85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED HEROIN' 93='(93) NEVER USED HEROIN WITH A NEEDLE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE nd02ffff  1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months'
                  3='(3) 6 or more months ago but less than a year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago but less than 10 years ago'
                  6='(6) 10 or more years ago'
                  91='(91) NEVER USED ANY DRUG FOR NONMEDICAL REASONS'
                  93='(93) NEVER USED A NEEDLE TO TAKE ANY DRUG' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE sp04ffff  1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago but less than 10 years ago'
                  6='(6) 10 or more years ago' 91='(91) NEVER USED ICE'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE sp08ffff  1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) More than 6 months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago' 91='(91) NEVER USED ANABOLIC STEROIDS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE mjtot2ff  1='(1) Never used marijuana (MJTOT = 81,91)'
                  2='(2) 1-2 times (MJTOT = 1)' 3='(3) 3-10 times (MJTOT = 2,3)'
                  4='(4) 11-99 times (MJTOT = 4,5)'
                  5='(5) 100 or more times (MJTOT = 6,7)'
                  6='(6) Unknown (MJTOT = 85,94,97,98)' ;
  VALUE coctot2f  1='(1) Never used cocaine (COCTOT = 81,91)'
                  2='(2) 1-2 times (COCTOT = 1)' 3='(3) 3-10 times (COCTOT = 2,3)'
                  4='(4) 11-99 times (COCTOT = 4,5)'
                  5='(5) 100 or more times (COCTOT = 6,7)'
                  6='(6) Unknown (COCTOT = 85,97,98)' ;
  VALUE mjtot3ff  1='(1) 1-2 times (MJTOT2 = 2)' 2='(2) 3-10 times (MJTOT2 = 3)'
                  3='(3) 11-99 times (MJTOT2 = 4)'
                  4='(4) 100 or more times (MJTOT2 = 5)'
                  5='(5) Never used marijuana (MJTOT2 = 1)' ;
  VALUE coctot3f  1='(1) 1-2 times (COCTOT2 = 2)' 2='(2) 3-10 times (COCTOT2 = 3)'
                  3='(3) 11-99 times (COCTOT2 = 4)'
                  4='(4) 100 or more times (COCTOT2 = 5)'
                  5='(5) Never used cocaine (COCTOT2 = 1)' ;
  VALUE mjdy30af  1='(1) None/never used marijuana (MJDAY30A = 0,81,91,93)'
                  2='(2) 1-2 days (MJDAY30A = 1-2)' 3='(3) 3-4 days (MJDAY30A = 3-4)'
                  4='(4) 5-19 days (MJDAY30A = 5-19)'
                  5='(5) 20-30 days (MJDAY30A = 20-30)'
                  6='(6) Unknown (MJDAY30A = 85,94,95,98)' ;
  VALUE alcdaysf  1='(1) None or never used alcohol (ALCDAYS = 0,81,91,93)'
                  2='(2) 1-2 days (ALCDAYS = 1-2)' 3='(3) 3-4 days (ALCDAYS = 3-4)'
                  4='(4) 5-19 days (ALCDAYS = 5-19)'
                  5='(5) 20-30 days (ALCDAYS = 20-31)'
                  6='(6) Don''t know, bad data, or blank (no answer)' ;
  VALUE mrjmon2f  1='(1) Did not use in past month (MRJMON = 0)'
                  2='(2) Used within the past month (MRJMON = 1)' ;
  VALUE alcmon2f  1='(1) Did not use in the past month (ALCMON = 0)'
                  2='(2) Used within the past month (ALCMON = 1)' ;
  VALUE cigmon2f  1='(1) Did not use in past month (CIGMON = 0)'
                  2='(2) Used within past month (CIGMON = 1)' ;
  VALUE lsd2ffff  0='(0) Never used hallucinogens (LSD = 2,81,91,97,98)'
                  1='(1) Ever used LSD (LSD = 1)' ;
  VALUE peyote2f  0='(0) Never used hallucinogens (PEYOTE = 2,81,91,97,98)'
                  1='(1) Ever used Peyote (PEYOTE = 1)' ;
  VALUE mesc2fff  0='(0) Never used hallucinogens (MESC = 2,81,91,97,98)'
                  1='(1) Ever used Mescaline (MESC = 1)' ;
  VALUE psilcy2f  0='(0) Never used hallucinogens (PSILCY = 2,81,91,97,98)'
                  1='(1) Ever used Psilocybin (PSILCY = 1)' ;
  VALUE ecstasyf  0='(0) Never used hallucinogens (ECSTASY=2,81,91,97,98)'
                  1='(1) Ever used Ecstasy (ECSTASY=1)' ;
  VALUE gas2ffff  0='(0) Never inhaled (GAS = 2,81,91,98)'
                  1='(1) Ever inhaled (GAS = 1,3)' ;
  VALUE lgas2fff  0='(0) Never inhaled (LGAS=2,81,91,98)'
                  1='(1) Ever inhaled (LGAS=1,3)' ;
  VALUE sppaintf  0='(0) Never inhaled (SPPAINT = 2,81,91,98)'
                  1='(1) Ever inhaled (SPPAINT = 1,3)' ;
  VALUE aeros2ff  0='(0) Never inhaled (AEROS = 2,81,91,98)'
                  1='(1) Ever inhaled (AEROS = 1,3)' ;
  VALUE glue2fff  0='(0) Never inhaled (GLUE = 2,81,91,98)'
                  1='(1) Ever inhaled (GLUE = 1,3)' ;
  VALUE solventf  0='(0) Never inhaled (SOLVENT = 2,81,91,98)'
                  1='(1) Ever inhaled (SOLVENT = 1,3)' ;
  VALUE amylnitf  0='(0) Never inhaled (AMYLNIT = 2,81,91,98)'
                  1='(1) Ever inhaled (AMYLNIT = 1,3)' ;
  VALUE ether2ff  0='(0) Never inhaled (ETHER = 2,81,91,98)'
                  1='(1) Ever inhaled (ETHER = 1,3)' ;
  VALUE nitoxidf  0='(0) Never inhaled (NITOXID = 2,81,91,98)'
                  1='(1) Ever inhaled (NITOXID = 1,3)' ;
  VALUE cleflu2f  0='(0) Never inhaled (CLEFLU = 2,81,91,98)'
                  1='(1) Ever inhaled (CLEFLU = 1,3)' ;
  VALUE cocsni0f  0='(0) Never/no use pst 12 mos(COCSNIFF=2,81,83,91,93,97)'
                  1='(1) Sniffed/snorted in past 12 months (COCSNIFF = 1)' ;
  VALUE freebasf  0='(0) Never/no use pst 12 mos(FREEBASE=2,81,83,91,93,97)'
                  1='(1) Freebased in past 12 months (FREEBASE = 1,3)' ;
  VALUE cocswalf  0='(0) Never/no use pst 12 mos(COCSWAL=2,81,83,91,93,97)'
                  1='(1) Swallowed/drank in past 12 months (COCSWAL = 1)' ;
  VALUE cociv2ff  0='(0) Never/no use past 12 mos (COCIV=2,81,83,91,93,97)'
                  1='(1) Injected in the past 12 months (COCIV = 1,3)' ;
  VALUE mjdy300f  1='(1) 1-2 days (MJDAY30A2 = 2)' 2='(2) 3-4 days (MJDAY30A2 = 3)'
                  3='(3) 5-19 days (MJDAY30A2 = 4)'
                  4='(4) 20-30 days (MJDAY30A2 = 5)'
                  5='(5) None or never used marijuana (MJDAY30A2 = 1)' ;
  VALUE alcday0f  1='(1) None or never used alcohol (ALCDAYS2 = 1)'
                  2='(2) 1-4 days (ALCDAYS2 = 2-3)' 3='(3) 5-19 days (ALCDAYS2 = 4)'
                  4='(4) 20-30 days (ALCDAYS2 = 5)' ;
  VALUE drinkerf  0='(0) Never/no ALC use (ALCMON=0 and DR5DAY=0,81,91,93)'
                  1='(1) Alcohol use (ALCMON = 1 and DR5DAY = 0-30)' ;
  VALUE hvydrk2f  0='(0) Never/no heavy use (DR5DAY=0-4,81,91,93)'
                  1='(1) Heavy alcohol use (DR5DAY = 5-30)' ;
  VALUE avcig2ff  1='(1) None/never smoked cigarettes (AVCIG=81,89,91,99)'
                  2='(2) Currently smoke < a pack per day (AVCIG = 1-3)'
                  3='(3) Currently smoke a pack or more per day (AVCIG=4-6)' ;
  VALUE racesex   1='(1) White male (SEX = 1 and RACE = 1)'
                  2='(2) Black male (SEX = 1 and RACE = 2)'
                  3='(3) Hispanic male (SEX = 1 and RACE = 3)'
                  4='(4) White female (SEX = 2 and RACE = 1)'
                  5='(5) Black female (SEX = 2 and RACE = 2)'
                  6='(6) Hispanic female (SEX = 2 and RACE = 3)' ;
  VALUE notmarj   0='(0) No (ALL SOURCE VARIABLES = 0)'
                  1='(1) Yes (ANY SOURCE VARIABLES = 1)' ;
  VALUE cocway2f  0='(0) Never/no use past 12 months (COCWAY=2,81,83,91,93)'
                  1='(1) Used other ways past 12 months (COCWAY=1,3,6-9)' ;
  VALUE racesexf  1='(1) White male (SEX=1 and RACE=1)'
                  2='(2) Black male (SEX=1 and RACE=2)'
                  3='(3) Hispanic male (SEX=1 and RACE=3)'
                  4='(4) Other male (SEX=1 and RACE=4)'
                  5='(5) White female (SEX=2 and RACE=1)'
                  6='(6) Black female (SEX=2 and RACE=2)'
                  7='(7) Hispanic female (SEX=2 and RACE=3)'
                  8='(8) Other female (SEX=2 and RACE=4)' ;
  VALUE ircdcig   1='(1) Yes' 2='(2) No'
                  13='(13) Did not try to cut down on any drug in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE ircdalc   1='(1) Yes' 2='(2) No'
                  13='(13) Did not try to cut down on any drug in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE ircdmj    1='(1) Yes' 2='(2) No'
                  13='(13) Did not try to cut down on any drug in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE ircdcoc   1='(1) Yes' 2='(2) No'
                  13='(13) Did not try to cut down on any drug in past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE irefcig   1='(1) Yes' 2='(2) No'
                  13='(13) Did not need more of any drug used for same effect'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE irefalc   1='(1) Yes' 2='(2) No'
                  13='(13) Did not need more of any drug used for same effect'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE irefmj    1='(1) Yes' 2='(2) No'
                  13='(13) Did not need more of any drug used for same effect'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE irefcoc   1='(1) Yes' 2='(2) No'
                  13='(13) Did not need more of any drug used for same effect'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE irudcig   1='(1) Yes' 2='(2) No'
                  13='(13) Did not use any drug daily in the past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE irudalc   1='(1) Yes' 2='(2) No'
                  13='(13) Did not use any drug daily in the past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE irudmj    1='(1) Yes' 2='(2) No'
                  13='(13) Did not use any drug daily in the past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE irudcoc   1='(1) Yes' 2='(2) No'
                  13='(13) Did not use any drug daily in the past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE irdpcig   1='(1) Yes' 2='(2) No'
                  13='(13) Did not feel like had to have any drug used pst yr'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE irdpalc   1='(1) Yes' 2='(2) No'
                  13='(13) Did not feel like had to have any drug used past'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE irdpmj    1='(1) Yes' 2='(2) No'
                  13='(13) Did not feel like had to have any drug used pst yr'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE irdpcoc   1='(1) Yes' 2='(2) No'
                  13='(13) Did not feel like had to have any drug used pst yr'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE irwscig   1='(1) Yes' 2='(2) No'
                  13='(13) Did not have withdrawal symptoms in the past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE irwsalc   1='(1) Yes' 2='(2) No'
                  13='(13) Did not have withdrawal symptoms in the past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE irwsmj    1='(1) Yes' 2='(2) No'
                  13='(13) Did not have withdrawal symptoms in the past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE irwscoc   1='(1) Yes' 2='(2) No'
                  13='(13) Did not have withdrawal symptoms in the past year'
                  81='(81) NEVER USED ANY DRUGS Logically assigned'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE avcig3ff  0='(0) None/never/< pack a day (AVCIG=1-3,81,89,91,98,99)'
                  1='(1) Currently smoke a pack or more per day (AVCIG=4-6)' ;
  VALUE alcprobs  0='(0) No' 1='(1) Yes' ;
  VALUE mjprobs   0='(0) No' 1='(1) Yes' ;
  VALUE cocprobs  0='(0) No' 1='(1) Yes' ;
  VALUE cigprobs  0='(0) No' 1='(1) Yes' ;
  VALUE iralcagg  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRNOBOOZ = 1)' ;
  VALUE iralcarg  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRNOBOOZ = 1)' ;
  VALUE iralcabs  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRNOBOOZ = 1)' ;
  VALUE iralchig  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRNOBOOZ = 1)' ;
  VALUE iralcjob  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRNOBOOZ = 1)' ;
  VALUE iralcmat  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRNOBOOZ = 1)' ;
  VALUE iralcrel  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRNOBOOZ = 1)' ;
  VALUE iralcfrd  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRNOBOOZ = 1)' ;
  VALUE iralctos  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRNOBOOZ = 1)' ;
  VALUE iralchol  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRNOBOOZ = 1)' ;
  VALUE iralcdru  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRNOBOOZ = 1)' ;
  VALUE iralcint  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRNOBOOZ = 1)' ;
  VALUE iralcrem  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRNOBOOZ = 1)' ;
  VALUE iralcqui  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRNOBOOZ = 1)' ;
  VALUE iralcmor  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRNOBOOZ = 1)' ;
  VALUE iralcsho  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRNOBOOZ = 1)' ;
  VALUE iralcalo  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRNOBOOZ = 1)' ;
  VALUE iralcbrk  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRNOBOOZ = 1)' ;
  VALUE irnobooz  1='(1) No use of alcohol in the past year'
                  2='(2) Used alcohol in the past year' ;
  VALUE anyalc    0='(0) No' 1='(1) Yes' ;
  VALUE threalc   0='(0) No' 1='(1) Yes' ;
  VALUE drunkyrf  0='(0) Unknown (DRUNKYR = 85,96,97,98)'
                  1='(1) Drunk more than twice a month (DRUNKYR = 1-4)'
                  2='(2) Drunk twice a month or less (DRUNKYR = 5-8)'
                  3='(3) Never drunk in past year (DRUNKYR = 9)' ;
  VALUE irdep     1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRAS13 = 1)' ;
  VALUE irarg     1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRAS13 = 1)' ;
  VALUE iraln     1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRAS13 = 1)' ;
  VALUE iranx     1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRAS13 = 1)' ;
  VALUE irhlt     1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRAS13 = 1)' ;
  VALUE irntk     1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRAS13 = 1)' ;
  VALUE irups     1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRAS13 = 1)' ;
  VALUE irlsw     1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRAS13 = 1)' ;
  VALUE irssp     1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRAS13 = 1)' ;
  VALUE ircpe     1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRAS13 = 1)' ;
  VALUE iremg     1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRAS13 = 1)' ;
  VALUE irdep1ff  116='(116) Methaqualone, Parest, Quaalude, Sopor' 201='(201) Valium'
                  209='(209) Xanax' 221='(221) OTHER Tranquilizer, NOT SPECIFIED'
                  241='(241) Prozac' 312='(312) Ionamin' 313='(313) Fastin, Phentermine'
                  322='(322) Methamphetamine (speed or ice or crank)'
                  324='(324) OTHER Stimulant, NOT SPECIFIED, Uppers'
                  339='(339) Amphetamines (speed generically)' 348='(348) Crystal'
                  355='(355) Crystal meth' 375='(375) sic'
                  426='(426) Butalbital, Fiorinal, Phrenilin Forte'
                  501='(501) Lighter fluids, Gasoline' 502='(502) Spray paints'
                  510='(510) OTHER Inhalant, NOT SPECIFIED' 557='(557) Hagwash'
                  601='(601) LSD (acid, white lightning)'
                  605='(605) PCP (angel dust, phencyclidine)'
                  606='(606) Ecstasy (MDMA), X-TC' 702='(702) Heroin' 704='(704) Dope'
                  801='(801) OTHER Drugs, NOT SPECIFIED' 803='(803) Marijuana'
                  804='(804) Hashish' 805='(805) Cocaine, Coke' 806='(806) Crack' 807='(807) Alcohol'
                  808='(808) All of the ones I''ve tried' 809='(809) Pills' 810='(810) Hemp'
                  812='(812) Cigars' 813='(813) Cigarettes, tobacco not specified'
                  814='(814) Caffeine'
                  816='(816) Smokeless tobacco, snuff, chewing tobacco' 869='(869) sic'
                  874='(874) Premarin' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irdep2ff  120='(120) Downers; OTHER Sedative, NOT SPECIFIED'
                  221='(221) OTHER Tranquilizer, NOT SPECIFIED'
                  322='(322) Methamphetamine (speed or ice or crank)'
                  324='(324) Uppers; OTHER Stimulant, NOT SPECIFIED'
                  339='(339) Amphetamines (speed generically)' 348='(348) Crystal'
                  601='(601) LSD (acid, white lightning)'
                  605='(605) PCP (angel dust, phencyclidine)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 702='(702) Heroin'
                  803='(803) Marijuana' 805='(805) Cocaine, Coke' 806='(806) Crack, rock'
                  807='(807) Alcohol' 813='(813) Cigarettes, tobacco not specified'
                  840='(840) Cough medicine (contents not specified) <OTC>'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irdep3ff  339='(339) Amphetamines (speed generically)'
                  510='(510) OTHER Inhalant, NOT SPECIFIED'
                  601='(601) LSD (acid, white lightning)'
                  604='(604) Psilocybin (mushrooms)' 803='(803) Marijuana' 804='(804) Hashish'
                  805='(805) Cocaine, Coke' 806='(806) Crack, rock' 807='(807) Alcohol'
                  813='(813) Cigarettes, tobacco not specified'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irdep4ff  415='(415) Codeine' 601='(601) LSD (acid, white lightning)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 805='(805) Cocaine, Coke'
                  807='(807) Alcohol' 809='(809) Pills' 999='(999) LEGITIMATE SKIP' ;
  VALUE irdep5ff  607='(607) OTHER Hallucinogen, NOT SPECIFIED'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irarg1ff  209='(209) Xanax' 221='(221) OTHER Tranquilizer, NOT SPECIFIED'
                  241='(241) Prozac' 312='(312) Ionamin'
                  322='(322) Methamphetamine (speed or ice or crank)'
                  324='(324) OTHER Stimulant, NOT SPECIFIED, Uppers'
                  339='(339) Amphetamines (speed generically)' 348='(348) Crystal'
                  355='(355) Crystal meth' 415='(415) Codeine' 440='(440) Soma' 557='(557) Hagwash'
                  601='(601) LSD (acid, white lightning)'
                  605='(605) PCP (angel dust, phencyclidine)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 702='(702) Heroin'
                  704='(704) Dope' 801='(801) OTHER Drugs, NOT SPECIFIED' 803='(803) Marijuana'
                  804='(804) Hashish' 805='(805) Cocaine, Coke' 806='(806) Crack' 807='(807) Alcohol'
                  808='(808) All of the ones I''ve tried' 810='(810) Hemp' 812='(812) Cigars'
                  813='(813) Cigarettes, tobacco not specified'
                  816='(816) Smokeless tobacco, snuff, chewing tobacco'
                  818='(818) Nicotine' 824='(824) Steroids' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irarg2ff  221='(221) OTHER Tranquilizer, NOT SPECIFIED' 324='(324) Uppers'
                  332='(332) Ephedrine (HCl)'
                  339='(339) Amphetamines (speed generically)' 348='(348) Crystal'
                  408='(408) Dilaudid' 601='(601) LSD (acid, white lightning)'
                  605='(605) PCP (angel dust, phencyclidine)' 702='(702) Heroin'
                  803='(803) Marijuana' 805='(805) Cocaine, Coke' 806='(806) Crack'
                  807='(807) Alcohol' 813='(813) Cigarettes, tobacco not specified'
                  840='(840) Cough medicine (contents not specified) <OTC>'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irarg3ff  601='(601) LSD (acid, white lightning)'
                  605='(605) PCP (angel dust, phencyclidine)' 803='(803) Marijuana'
                  805='(805) Cocaine, Coke' 807='(807) Alcohol'
                  813='(813) Cigarettes, tobacco not specified'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irarg4ff  508='(508) Nitrous oxide, whippets, dentist gas'
                  805='(805) Cocaine, Coke' 807='(807) Alcohol' 999='(999) LEGITIMATE SKIP' ;
  VALUE irarg5ff  999='(999) LEGITIMATE SKIP' ;
  VALUE iraln1ff  201='(201) Valium' 209='(209) Xanax'
                  221='(221) OTHER Tranquilizer, NOT SPECIFIED' 241='(241) Prozac'
                  312='(312) Ionamin' 322='(322) Methamphetamine (speed or ice or crank)'
                  324='(324) Uppers' 339='(339) Amphetamines (speed generically)'
                  348='(348) Crystal' 355='(355) Crystal meth' 401='(401) Darvon'
                  406='(406) Oxycodone, Percodan, Roxicet' 408='(408) Dilaudid'
                  601='(601) LSD (acid, white lightning)'
                  604='(604) Psilocybin (mushrooms)'
                  605='(605) PCP (angel dust, phencyclidine)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 702='(702) Heroin'
                  704='(704) Dope' 707='(707) Black Tar' 801='(801) OTHER Drugs, NOT SPECIFIED'
                  803='(803) Marijuana' 805='(805) Cocaine, Coke' 806='(806) Crack'
                  807='(807) Alcohol' 808='(808) All of the ones I''ve tried' 809='(809) Pills'
                  812='(812) Cigars' 813='(813) Cigarettes, tobacco not specified'
                  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE iraln2ff  209='(209) Xanax' 324='(324) Uppers; OTHER Stimulant, NOT SPECIFIED'
                  434='(434) Co-Gesic, Hydrocodone, Lortab, Tussionex, Vicodin.'
                  601='(601) LSD (acid, white lightning)'
                  605='(605) PCP (angel dust, phencyclidine)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 702='(702) Heroin'
                  803='(803) Marijuana' 805='(805) Cocaine, Coke' 806='(806) Crack'
                  807='(807) Alcohol' 813='(813) Cigarettes, tobacco not specified'
                  840='(840) Cough medicine (contents not specified)'
                  848='(848) Liquid vitamin <OTC>' 999='(999) LEGITIMATE SKIP' ;
  VALUE iraln3ff  803='(803) Marijuana' 805='(805) Cocaine, Coke' 807='(807) Alcohol'
                  813='(813) Cigarettes, tobacco not specified'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE iraln4ff  510='(510) OTHER Inhalant, NOT SPECIFIED' 807='(807) Alcohol'
                  809='(809) Pills' 999='(999) LEGITIMATE SKIP' ;
  VALUE iraln5ff  607='(607) OTHER Hallucinogen, NOT SPECIFIED'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE iranx1ff  209='(209) Xanax' 221='(221) OTHER Tranquilizer, NOT SPECIFIED'
                  241='(241) Prozac' 247='(247) Adapin, Doxepin, Sinequan' 271='(271) Zoloft'
                  301='(301) Dexedrine' 309='(309) Didrex' 312='(312) Ionamin'
                  313='(313) Fastin, Phentermine'
                  322='(322) Methamphetamine (speed or ice or crank)'
                  324='(324) OTHER Stimulant, NOT SPECIFIED, Uppers'
                  332='(332) Ephedrine' 336='(336) Diet pills'
                  339='(339) Amphetamines (speed generically)' 348='(348) Crystal'
                  354='(354) Vivarin <OTC>' 355='(355) Crystal meth' 375='(375) sic'
                  408='(408) Dilaudid' 415='(415) Codeine'
                  420='(420) OTHER Analgesic, NOT SPECIFIED'
                  435='(435) Tylenol, Tylenol Extra-Strength <OTC>'
                  510='(510) OTHER Inhalant, NOT SPECIFIED' 557='(557) Hagwash'
                  601='(601) LSD (acid, white lightning)'
                  605='(605) Phencyclidine (angel dust, PCP)'
                  606='(606) Ecstasy (MDMA), X-TC'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 702='(702) Heroin'
                  704='(704) Dope' 801='(801) OTHER Drugs, NOT SPECIFIED' 803='(803) Marijuana'
                  804='(804) Hashish' 805='(805) Cocaine, Coke' 806='(806) Crack' 807='(807) Alcohol'
                  808='(808) All of the ones I''ve tried' 812='(812) Cigars'
                  813='(813) Cigarettes, tobacco not specified' 814='(814) Caffeine'
                  815='(815) Coffee'
                  816='(816) Smokeless tobacco, snuff, chewing tobacco'
                  818='(818) Nicotine' 873='(873) Contraceptives, Feutal, Ortho Novum'
                  998='(998) BLANK (NOT ANSWERED)' 999='(999) LEGITIMATE SKIP' ;
  VALUE iranx2ff  120='(120) Downers' 322='(322) Methamphetamine (speed or ice or crank)'
                  324='(324) Uppers; OTHER Stimulant, NOT SPECIFIED'
                  339='(339) Amphetamines (speed generically)' 355='(355) Crystal meth'
                  601='(601) LSD (acid, white lightning)'
                  604='(604) Psilcybin (mushrooms)'
                  605='(605) PCP (angel dust, phencyclidine)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 702='(702) Heroin'
                  803='(803) Marijuana' 805='(805) Cocaine, Coke' 806='(806) Crack'
                  807='(807) Alcohol' 813='(813) Cigarettes, tobacco not specified'
                  840='(840) Cough medicine (contents not specified) <OTC>'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE iranx3ff  326='(326) White cross' 702='(702) Heroin' 803='(803) Marijuana'
                  805='(805) Cocaine, Coke'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  813='(813) Cigarettes, tobacco not specified'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE iranx4ff  510='(510) OTHER Inhalant, NOT SPECIFIED' 803='(803) Marijuana'
                  807='(807) Alcohol' 809='(809) Pills' 999='(999) LEGITIMATE SKIP' ;
  VALUE iranx5ff  607='(607) OTHER Hallucinogen, NOT SPECIFIED'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irhlt1ff  209='(209) Xanax' 312='(312) Ionamin'
                  322='(322) Methamphetamine (speed or ice or crank)'
                  339='(339) Amphetamines (speed generically)' 348='(348) Crystal'
                  355='(355) Crystal meth' 362='(362) Benadryl' 408='(408) Dilaudid'
                  501='(501) Gasoline or lighter fluids' 557='(557) Hagwash'
                  601='(601) LSD (acid, white lightning)'
                  605='(605) PCP (angel dust, phencyclidine)' 639='(639) Cloves, Nutmet'
                  702='(702) Heroin' 704='(704) Dope' 801='(801) OTHER Drugs, NOT SPECIFIED'
                  803='(803) Marijuana' 805='(805) Cocaine, Coke' 806='(806) Crack'
                  807='(807) Alcohol' 809='(809) Pills' 812='(812) Cigars'
                  813='(813) Cigarettes, tobacco not specified' 814='(814) Caffeine'
                  816='(816) Smokeless tobacco, snuff, chewing tobacco'
                  818='(818) Nicotine' 870='(870) sic' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irhlt2ff  332='(332) see also 346' 339='(339) Amphetamines (speed generically)'
                  426='(426) Butalbital, Fiorinal, Phrenilin Forte'
                  506='(506) Amyl nitrate, poppers, locker rm odorizer,rush'
                  530='(530) Asthma inhaler, asthma med., bronchial dilators'
                  601='(601) LSD (acid, white lightning)'
                  605='(605) PCP (angel dust, phencyclidine)' 702='(702) Heroin'
                  803='(803) Marijuana' 805='(805) Cocaine, Coke' 806='(806) Crack'
                  807='(807) Alcohol' 812='(812) Cigars'
                  813='(813) Cigarettes, tobacco not specified' 814='(814) Caffeine'
                  815='(815) Coffee'
                  816='(816) Smokeless tobacco, snuff, chewing tobacco'
                  865='(865) Diuretics, Water pills' 999='(999) LEGITIMATE SKIP' ;
  VALUE irhlt3ff  339='(339) Amphetamines (speed generically)' 348='(348) Crystal'
                  702='(702) Heroin' 803='(803) Marijuana' 807='(807) Alcohol'
                  813='(813) Cigarettes, tobacco not specified'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irhlt4ff  807='(807) Alcohol' 999='(999) LEGITIMATE SKIP' ;
  VALUE irhlt5ff  999='(999) LEGITIMATE SKIP' ;
  VALUE irntk1ff  116='(116) Methaqualone, Parest, Quaalude, Sopor'
                  120='(120) OTHER Sedative, NOT SPECIFIED, Downers' 209='(209) Xanax'
                  221='(221) OTHER Tranquilizer, NOT SPECIFIED' 241='(241) Prozac'
                  247='(247) Adapin, Doxepin, Sinequan' 271='(271) Zoloft' 312='(312) Ionamin'
                  322='(322) Methamphetamine (speed or ice or crank)'
                  324='(324) OTHER Stimulant, NOT SPECIFIED, Uppers'
                  336='(336) Diet pills' 339='(339) Amphetamines (speed generically)'
                  348='(348) Crystal' 354='(354) Vivarin <OTC>' 355='(355) Crystal meth'
                  401='(401) Darvon' 407='(407) Demerol' 408='(408) Dilaudid'
                  409='(409) Tylenol with Codeine, Tylenol' 418='(418) Methadone'
                  501='(501) Gasoline or lighter fluids' 502='(502) Spray paints'
                  504='(504) Shoeshine liq, glue,toluene,SuperGlue,rubber cem..'
                  510='(510) OTHER Inhalant, NOT SPECIFIED'
                  511='(511) Markers, felt-tip pens, ink pens'
                  601='(601) LSD (acid, white lightning)'
                  605='(605) PCP (angel dust, phencyclidine)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 609='(609) sic'
                  702='(702) Heroin' 704='(704) Dope' 705='(705) Speel Ball (heroin + cocaine)'
                  801='(801) OTHER Drugs, NOT SPECIFIED' 803='(803) Marijuana'
                  804='(804) Hashish' 805='(805) Cocaine, Coke' 806='(806) Crack' 807='(807) Alcohol'
                  810='(810) Hemp' 812='(812) Cigars'
                  813='(813) Cigarettes, tobacco not specified' 815='(815) Coffee'
                  823='(823) sic'
                  840='(840) Cough medicine (contents not specified) <OTC>'
                  873='(873) Contraceptives, Feutal, Ortho Novum'
                  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE irntk2ff  322='(322) Methamphetamine (speed or ice or crank)'
                  339='(339) Amphetamines (speed generically)' 348='(348) Crystal'
                  407='(407) Demerol' 420='(420) OTHER Analgesic, NOT SPECIFIED'
                  426='(426) Butalbital, Fiorinal, Phrenilin Forte'
                  506='(506) Amyl nitrate, poppers, locker rm odorizer,rush'
                  508='(508) Nitrous oxide, whippets, dentist gas'
                  510='(510) OTHER Inhalant, NOT SPECIFIED'
                  601='(601) LSD (acid, white lightning)'
                  605='(605) PCP (angel dust, phencyclidine)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 702='(702) Heroin'
                  803='(803) Marijuana' 805='(805) Cocaine, Coke' 806='(806) Crack'
                  807='(807) Alcohol' 809='(809) Pills'
                  813='(813) Cigarettes, tobacco not specified'
                  816='(816) Smokeless tobacco, snuff, chewing tobacco'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irntk3ff  324='(324) Uppers; OTHER Stimulant, NOT SPECIFIED'
                  339='(339) Amphetamines (speed generically)'
                  601='(601) LSD (acid, white lightning)' 602='(602) Peyote'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 702='(702) Heroin'
                  803='(803) Marijuana' 804='(804) Hashish' 805='(805) Cocaine, Coke'
                  807='(807) Alcohol' 813='(813) Cigarettes, tobacco not specified'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irntk4ff  415='(415) Codeine' 510='(510) OTHER Inhalant, NOT SPECIFIED'
                  803='(803) Marijuana' 805='(805) Cocaine, Coke' 807='(807) Alcohol'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irntk5ff  201='(201) Valium' 607='(607) OTHER Hallucinogen, NOT SPECIFIED'
                  803='(803) sic' 999='(999) LEGITIMATE SKIP' ;
  VALUE irups1ff  209='(209) Xanax' 221='(221) OTHER Tranquilizer, NOT SPECIFIED'
                  241='(241) Prozac' 312='(312) Ionamin'
                  322='(322) Methamphetamine (speed or ice or crank)'
                  324='(324) OTHER Stimulant, NOT SPECIFIED, Uppers'
                  332='(332) Ephedrine' 339='(339) Amphetamines (speed generically)'
                  348='(348) Crystal' 355='(355) Crystal meth'
                  406='(406) Oxycodone, Percodan, Roxicet'
                  409='(409) Tylenol with Codeine, Tylenol'
                  434='(434) Co-Gesic, Hydrocodone, Lortab, Tussionex, Vicodin.'
                  510='(510) OTHER Inhalant, NOT SPECIFIED'
                  601='(601) LSD (acid, white lightning)'
                  604='(604) Psilocybin (mushrooms)'
                  605='(605) PCP (angel dust, phencyclidine)' 702='(702) Heroin'
                  704='(704) Dope' 801='(801) OTHER Drugs, NOT SPECIFIED' 803='(803) Marijuana'
                  805='(805) Cocaine, Coke' 806='(806) Crack' 807='(807) Alcohol'
                  808='(808) All of the ones I''ve tried' 810='(810) Hemp' 812='(812) Cigars'
                  813='(813) Cigarettes, tobacco not specified' 814='(814) Caffeine'
                  815='(815) Coffee'
                  816='(816) Smokeless tobacco, snuff, chewing tobacco'
                  818='(818) Nicotine' 824='(824) Steroids'
                  840='(840) Cough medicine (contents not specified) <OTC>'
                  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE irups2ff  324='(324) OTHER Stimulant, NOT SPECIFIED, Uppers'
                  339='(339) Amphetamines (speed generically)' 408='(408) Dilaudid'
                  434='(434) Co-Gesic, Hydrocodone, Lortab, Tussionex, Vicodin.'
                  508='(508) Notrous oxide, whippets, dentist gas'
                  601='(601) LSD (acid, white lightning)'
                  605='(605) PCP (angel dust, phencyclidine)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 702='(702) Heroin'
                  803='(803) Marijuana' 805='(805) Cocaine, Coke' 806='(806) Crack'
                  807='(807) Alcohol' 809='(809) Pills' 811='(811) Muscle relaxers'
                  813='(813) Cigarettes, tobacco not specified' 814='(814) Caffeine'
                  815='(815) Coffee' 999='(999) LEGITIMATE SKIP' ;
  VALUE irups3ff  437='(437) Parafon Forte' 601='(601) LSD (acid, white lightning)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 702='(702) Heroin'
                  803='(803) Marijuana' 805='(805) Cocaine, Coke' 807='(807) Alcohol'
                  809='(809) Pills' 813='(813) Cigarettes, tobacco not specified'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irups4ff  510='(510) OTHER Inhalant, NOT SPECIFIED' 803='(803) Marijuana'
                  805='(805) Cocaine, Coke' 807='(807) Alcohol'
                  813='(813) cigarettes, tobacco not specified'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irups5ff  607='(607) OTHER Hallucinogen, NOT SPECIFIED'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irlsw1ff  201='(201) Valium' 312='(312) Ionamin'
                  322='(322) Methamphetamine (speed or ice or crank)' 324='(324) Uppers'
                  336='(336) Diet pills' 339='(339) Amphetamines (speed generically)'
                  348='(348) Crystal' 355='(355) Crystal meth'
                  406='(406) Oxycodone, Percodan, Roxicet'
                  501='(501) Gasoline or lighter fluids'
                  530='(530) Asthma inhaler, asthma med., bronchial dilators'
                  601='(601) LSD (acid, white lightning)'
                  605='(605) PCP (angel dust, phencyclidine)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 702='(702) Heroin'
                  704='(704) Dope' 801='(801) OTHER Drugs, NOT SPECIFIED' 803='(803) Marijuana'
                  804='(804) Hashish' 805='(805) Cocaine, Coke' 806='(806) Crack' 807='(807) Alcohol'
                  810='(810) Hemp' 812='(812) Cigars'
                  813='(813) Cigarettes, tobacco not specified' 815='(815) Coffee'
                  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE irlsw2ff  408='(408) Dilaudid' 508='(508) Nitrous oxide, whippets, dentist gas'
                  601='(601) LSD (acid, white lightning)'
                  605='(605) PCP (angel dust, phencyclidine)' 803='(803) Marijuana'
                  805='(805) Cocaine, Coke' 806='(806) Crack' 807='(807) Alcohol' 809='(809) Pills'
                  813='(813) Cigarettes, tobacco not specified'
                  840='(840) Cough medicine (contents not specified) <OTC>'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irlsw3ff  339='(339) Amphetamines (speed generically)'
                  605='(605) PCP (angel dust, phencyclidine)' 803='(803) Marijuana'
                  804='(804) Hashish' 807='(807) Alcohol'
                  813='(813) Cigarettes, tobacco not specified'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irlsw4ff  510='(510) OTHER Inhalant, NOT SPECIFIED' 805='(805) Cocaine, Coke'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irlsw5ff  607='(607) OTHER Hallucinogen, NOT SPECIFIED'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irssp1ff  312='(312) Ionamin' 322='(322) Methamphetamine (speed or ice or crank)'
                  324='(324) Uppers; OTHER Stimulant, NOT SPECIFIED'
                  339='(339) Amphetamines (speed generically)' 348='(348) Crystal'
                  355='(355) Crystal meth' 601='(601) LSD (acid, white lightning)'
                  605='(605) PCP (angel dust, phencyclidine)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 702='(702) Heroin'
                  707='(707) Black Tar' 801='(801) OTHER Drugs, NOT SPECIFIED'
                  803='(803) Marijuana' 804='(804) Hashish' 805='(805) Cocaine, Coke'
                  806='(806) Crack' 807='(807) Alcohol' 812='(812) Cigars'
                  813='(813) Cigarettes, tobacco not specified'
                  816='(816) Smokeless tobacco, snuff, chewing tobacco'
                  840='(840) Cough medicine (contents not specified) <OTC>'
                  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE irssp2ff  322='(322) Methamphetamine (speed or ice or crank)'
                  408='(408) Dilaudid' 601='(601) LSD (acid, white lightning)'
                  604='(604) Psilocybin (mushrooms)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 803='(803) Marijuana'
                  805='(805) Cocaine, Coke' 806='(806) Crack' 807='(807) Alcohol' 809='(809) Pills'
                  813='(813) Cigarettes, tobacco not specified'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irssp3ff  339='(339) Amphetamines (speed generically)' 702='(702) Heroin'
                  803='(803) Marijuana' 805='(805) Cocaine, Coke'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champagne'
                  809='(809) Pills' 813='(813) Cigarettes, tobacco not specified'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irssp4ff  510='(510) OTHER Inhalant, NOT SPECIFIED' 805='(805) Cocaine, Coke'
                  807='(807) Alcohol' 999='(999) LEGITIMATE SKIP' ;
  VALUE irssp5ff  607='(607) OTHER Hallucinogen, NOT SPECIFIED'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE ircpe1ff  209='(209) Xanax' 221='(221) OTHER Tranquilizer, NOT SPECIFIED'
                  241='(241) Prozac' 312='(312) Ionamin'
                  322='(322) Methamphetamine (speed or ice or crank)'
                  339='(339) Amphetamines (speed generically)' 348='(348) Crystal'
                  355='(355) Crystal meth' 510='(510) OTHER Inhalant, NOT SPECIFIED'
                  601='(601) LSD (acid, white lightning)'
                  605='(605) PCP (angel dust, phencyclidine)' 702='(702) Heroin'
                  704='(704) Dope' 801='(801) OTHER Drugs, NOT SPECIFIED' 803='(803) Marijuana'
                  805='(805) Cocaine, Coke' 806='(806) Crack' 807='(807) Alcohol' 809='(809) Pills'
                  812='(812) Cigars' 813='(813) Cigarettes, tobacco not specified'
                  818='(818) Nicotine' 824='(824) Steroids' 877='(877) Methozolamide'
                  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE ircpe2ff  239='(239) Elavil' 408='(408) Dilaudid'
                  601='(601) LSD (acid, white lightning)'
                  605='(605) PCP (angel dust, phencyclidine)' 803='(803) Marijuana'
                  805='(805) Cocaine, Coke' 806='(806) Crack' 807='(807) Alcohol' 809='(809) Pills'
                  813='(813) Cigarettes, tobacco not specified'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE ircpe3ff  339='(339) Amphetamines (speed generically)' 803='(803) Marijuana'
                  804='(804) Hashish' 805='(805) Cocaine, Coke' 807='(807) Alcohol'
                  813='(813) Cigarettes, tobacco not specified'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE ircpe4ff  510='(510) OTHER Inhalant, NOT SPECIFIED' 999='(999) LEGITIMATE SKIP' ;
  VALUE ircpe5ff  607='(607) OTHER HAllucinogen, NOT SPECIFIED'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE iremg1ff  108='(108) Carbrital, Nembutal' 209='(209) Xanax' 312='(312) Ionamin'
                  322='(322) Methamphetamine (speed or ice or crank)'
                  339='(339) Amphetamines (speed generically)' 348='(348) Crystal'
                  430='(430) Aspirin, Ecotrin, Empiron <OTC>' 435='(435) Tylenol'
                  503='(503) Other aerosol sprays' 601='(601) see also 618'
                  605='(605) PCP (angel dust, phencyclidine)' 606='(606) sic'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 702='(702) Heroin'
                  704='(704) Dope' 801='(801) OTHER Drugs, NOT SPECIFIED' 803='(803) Marijuana'
                  805='(805) Cocaine, Coke' 806='(806) Crack' 807='(807) Alcohol' 812='(812) Cigars'
                  813='(813) Cigarettes, tobacco not specified' 815='(815) Coffee'
                  858='(858) Antibiotic' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE iremg2ff  339='(339) Amphetamines (speed generically)'
                  420='(420) OTHER Analgesic, NOT SPECIFIED' 803='(803) Marijuana'
                  805='(805) Cocaine, Coke' 806='(806) Crack' 807='(807) Alcohol' 809='(809) Pills'
                  813='(813) Cigarettes, tobacco not specified'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE iremg3ff  813='(813) Cigarettes, tobacco not specified'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE iremg4ff  999='(999) LEGITIMATE SKIP' ;
  VALUE iremg5ff  999='(999) LEGITIMATE SKIP' ;
  VALUE iras13ff  1='(1) Never used any of the substances listed'
                  2='(2) Used one or more of the listed substances' ;
  VALUE depcig2f  0='(0) No' 1='(1) Yes' 93='(93) Did not use cigarettes in the past year' ;
  VALUE depalc2f  0='(0) No' 1='(1) Yes' 93='(93) Did not use alcohol in the past year' ;
  VALUE depmrj2f  0='(0) No' 1='(1) Yes' 93='(93) Did not use marijuana in the past year' ;
  VALUE depcoc2f  0='(0) No' 1='(1) Yes' 93='(93) Did not use cocaine in the past year' ;
  VALUE argcig2f  0='(0) No' 1='(1) Yes' 93='(93) Did not use cigarettes in the past year' ;
  VALUE argalc2f  0='(0) No' 1='(1) Yes' 93='(93) Did not use alcohol in the past year' ;
  VALUE argmrj2f  0='(0) No' 1='(1) Yes' 93='(93) Did not use marijuana in the past year' ;
  VALUE argcoc2f  0='(0) No' 1='(1) Yes' 93='(93) Did not use cocaine in the past year' ;
  VALUE alncig2f  0='(0) No' 1='(1) Yes' 93='(93) Did not use cigarettes in the past year' ;
  VALUE alnalc2f  0='(0) No' 1='(1) Yes' 93='(93) Did not use alcohol in the past year' ;
  VALUE alnmrj2f  0='(0) No' 1='(1) Yes' 93='(93) Did not use marijuana in the past year' ;
  VALUE alncoc2f  0='(0) No' 1='(1) Yes' 93='(93) Did not use cocaine in the past year' ;
  VALUE anxcig2f  0='(0) No' 1='(1) Yes' 93='(93) Did not use cigarettes in the past year' ;
  VALUE anxalc2f  0='(0) No' 1='(1) Yes' 93='(93) Did not use alcohol in the past year' ;
  VALUE anxmrj2f  0='(0) No' 1='(1) Yes' 93='(93) Did not use marijuana in the past year' ;
  VALUE anxcoc2f  0='(0) No' 1='(1) Yes' 93='(93) Did not use cocaine in the past year' ;
  VALUE hltcig2f  0='(0) No' 1='(1) Yes' 93='(93) Did not use cigarettes in the past year' ;
  VALUE hltalc2f  0='(0) No' 1='(1) Yes' 93='(93) Did not use alcohol in the past year' ;
  VALUE hltmrj2f  0='(0) No' 1='(1) Yes' 93='(93) Did not use marijuana in the past year' ;
  VALUE hltcoc2f  0='(0) No' 1='(1) Yes' 93='(93) Did not use cocaine in the past year' ;
  VALUE ntkcig2f  0='(0) No' 1='(1) Yes' 93='(93) Did not use cigarettes in the past year' ;
  VALUE ntkalc2f  0='(0) No' 1='(1) Yes' 93='(93) Did not use alcohol in the past year' ;
  VALUE ntkmrj2f  0='(0) No' 1='(1) Yes' 93='(93) Did not use marijuana in the past year' ;
  VALUE ntkcoc2f  0='(0) No' 1='(1) Yes' 93='(93) Did not use cocaine in the past year' ;
  VALUE upscig2f  0='(0) No' 1='(1) Yes' 93='(93) Did not use cigarettes in the past year' ;
  VALUE upsalc2f  0='(0) No' 1='(1) Yes' 93='(93) Did not use alcohol in the past year' ;
  VALUE upsmrj2f  0='(0) No' 1='(1) Yes' 93='(93) Did not use marijuana in the past year' ;
  VALUE upscoc2f  0='(0) No' 1='(1) Yes' 93='(93) Did not use cocaine in the past year' ;
  VALUE lswcig2f  0='(0) No' 1='(1) Yes' 93='(93) Did not use cigarettes in the past year' ;
  VALUE lswalc2f  0='(0) No' 1='(1) Yes' 93='(93) Did not use alcohol in the past year' ;
  VALUE lswmrj2f  0='(0) No' 1='(1) Yes' 93='(93) Did not use marijuana in the past year' ;
  VALUE lswcoc2f  0='(0) No' 1='(1) Yes' 93='(93) Did not use cocaine in the past year' ;
  VALUE sspcig2f  0='(0) No' 1='(1) Yes' 93='(93) Did not use cigarettes in the past year' ;
  VALUE sspalc2f  0='(0) No' 1='(1) Yes' 93='(93) Did not use alcohol in the past year' ;
  VALUE sspmrj2f  0='(0) No' 1='(1) Yes' 93='(93) Did not use marijuana in the past year' ;
  VALUE sspcoc2f  0='(0) No' 1='(1) Yes' 93='(93) Did not use cocaine in the past year' ;
  VALUE cpecig2f  0='(0) No' 1='(1) Yes' 93='(93) Did not use cigarettes in the past year' ;
  VALUE cpealc2f  0='(0) No' 1='(1) Yes' 93='(93) Did not use alcohol in the past year' ;
  VALUE cpemrj2f  0='(0) No' 1='(1) Yes' 93='(93) Did not use marijuana in the past year' ;
  VALUE cpecoc2f  0='(0) No' 1='(1) Yes' 93='(93) Did not use cocaine in the past year' ;
  VALUE emcig2ff  0='(0) No' 1='(1) Yes' 93='(93) Did not use cigarettes in the past year' ;
  VALUE emalc2ff  0='(0) No' 1='(1) Yes' 93='(93) Did not use alcohol in the past year' ;
  VALUE emmrj2ff  0='(0) No' 1='(1) Yes' 93='(93) Did not use marijuana in the past year' ;
  VALUE emcoc2ff  0='(0) No' 1='(1) Yes' 93='(93) Did not use cocaine in the past year' ;
  VALUE prb1cig   0='(0) No' 1='(1) Yes' 93='(93) Did not use cigarettes in the past year' ;
  VALUE prb1alc   0='(0) No' 1='(1) Yes' 93='(93) Did not use alcohol in the past year' ;
  VALUE prb1mrj   0='(0) No' 1='(1) Yes' 93='(93) Did not use marijuana in the past year' ;
  VALUE prb1coc   0='(0) No' 1='(1) Yes' 93='(93) Did not use cocaine in the past year' ;
  VALUE prb2cig   0='(0) No' 1='(1) Yes' 93='(93) Did not use cigarettes in the past year' ;
  VALUE prb2alc   0='(0) No' 1='(1) Yes' 93='(93) Did not use alcohol in the past year' ;
  VALUE prb2mrj   0='(0) No' 1='(1) Yes' 93='(93) Did not use marijuana in the past year' ;
  VALUE prb2coc   0='(0) No' 1='(1) Yes' 93='(93) Did not use cocaine in the past year' ;
  VALUE prb3cig   0='(0) No' 1='(1) Yes' 93='(93) Did not use cigarettes in the past year' ;
  VALUE prb3alc   0='(0) No' 1='(1) Yes' 93='(93) Did not use alcohol in the past year' ;
  VALUE prb3mrj   0='(0) No' 1='(1) Yes' 93='(93) Did not use marijuana in the past year' ;
  VALUE prb3coc   0='(0) No' 1='(1) Yes' 93='(93) Did not use cocaine in the past year' ;
  VALUE anyprob   0='(0) No' 1='(1) Yes' ;
  VALUE twoprob   0='(0) No' 1='(1) Yes' ;
  VALUE threprob  0='(0) No' 1='(1) Yes' ;
  VALUE alconlyl  0='(0) No' 1='(1) Yes (ALCFLAG=1 AND SUMFLAG=0)' ;
  VALUE alconlyy  0='(0) No' 1='(1) Yes (ALCYR=1 AND SUMYR=0)' ;
  VALUE alconlym  0='(0) No' 1='(1) Yes (ALCMON=1 AND SUMMON=0)' ;
  VALUE illonlyl  0='(0) No' 1='(1) Yes (SUMFLAG=1 AND ALCFLAG=0)' ;
  VALUE illonlyy  0='(0) No' 1='(1) Yes (SUMYR=1 AND ALCYR=0)' ;
  VALUE illonlym  0='(0) No' 1='(1) Yes (SUMMON=1 AND ALCMON=0)' ;
  VALUE mrjonlyl  0='(0) No' 1='(1) Yes (MJOFLAG=1 AND ALCFLAG=0)' ;
  VALUE mrjonlyy  0='(0) No' 1='(1) Yes (MJOYR2=1 AND ALCYR=0)' ;
  VALUE mrjonlym  0='(0) No' 1='(1) Yes (MJOMON2=1 AND ALCMON=0)' ;
  VALUE psyonlyl  0='(0) No' 1='(1) Yes (PSYFLAG2=1 AND ALL OTHER SOURCE VARS=0)' ;
  VALUE psyonlyy  0='(0) No' 1='(1) Yes (PSYYR2=1 AND ALL OTHER SOURCE VARS=0)' ;
  VALUE psyonlym  0='(0) No' 1='(1) Yes (PSYMON2=1 AND ALL OTHER SOURCE VARS=0)' ;
  VALUE othonlyl  0='(0) No'
                  1='(1) Yes (FIRST 3 SOURCE VAR=0 & ANY OTHR SOURCE VAR=1)' ;
  VALUE othonlyy  0='(0) No'
                  1='(1) Yes (FIRST 3 SOURCE VAR=0 & ANY OTHR SOURCE VAR=1)' ;
  VALUE othonlym  0='(0) No'
                  1='(1) Yes (FIRST 3 SOURCE VAR=0 & ANY OTHR SOURCE VAR=1)' ;
  VALUE alcilll   0='(0) No' 1='(1) Yes (ALCFLAG=1 AND SUMFLAG=1)' ;
  VALUE alcilly   0='(0) No' 1='(1) Yes (ALCYR=1 AND SUMYR=1)' ;
  VALUE alcillm   0='(0) No' 1='(1) Yes (ALCMON=1 AND SUMMON=1)' ;
  VALUE alcmrjl   0='(0) No'
                  1='(1) Yes (ALCFLAG,MRJFLAG=1 AND ALL OTHER SOURCE VAR=0)' ;
  VALUE alcmrjy   0='(0) No'
                  1='(1) Yes (ALCYR AND MRJYR=1 AND ALL OTHER SOURCE VAR=0)' ;
  VALUE alcmrjm   0='(0) No'
                  1='(1) Yes (ALCMON & MRJMON=1 AND ALL OTHER SOURCE VAR=0)' ;
  VALUE alcpsyl   0='(0) No'
                  1='(1) Yes (ALCFLAG,PSYFLAG2=1 & ALL OTHER SOURCE VAR=0)' ;
  VALUE alcpsyy   0='(0) No'
                  1='(1) Yes (ALCYR & PSYYR2=1 AND ALL OTHER SOURCE VAR=0)' ;
  VALUE alcpsym   0='(0) No'
                  1='(1) Yes (ALCMON & PSYMON2=1 & ALL OTHER SOURCE VAR=0)' ;
  VALUE alcothl   0='(0) No' 1='(1) Yes (ALCFLAG=1 & NEXT 2 VAR=0 & ANY OTHER VAR=1)' ;
  VALUE alcothy   0='(0) No' 1='(1) Yes (ALCYR=1 & NEXT 2 VAR=0 & ANY OTHER VAR=1)' ;
  VALUE alcothm   0='(0) No' 1='(1) Yes (ALCMON=1 & NEXT 2 VAR=0 & ANY OTHER VAR=1)' ;
  VALUE sub1lif   0='(0) No' 1='(1) Yes (ONLY ONE OF THE SOURCE VARS=1)' ;
  VALUE sub2lif   0='(0) No' 1='(1) Yes (ONLY TWO OF THE SOURCE VARS=1)' ;
  VALUE sub3lif   0='(0) No' 1='(1) Yes (THREE OR MORE OF THE SOURCE VARS=1)' ;
  VALUE sub1yr    0='(0) No' 1='(1) Yes (ONLY ONE OF THE SOURCE VARS=1)' ;
  VALUE sub2yr    0='(0) No' 1='(1) Yes (ONLY TWO OF THE SOURCE VARS=1)' ;
  VALUE sub3yr    0='(0) No' 1='(1) Yes (THREE OR MORE OF THE SOURCE VARS=1)' ;
  VALUE sub1mon   0='(0) No' 1='(1) Yes (ONLY ONE OF THE SOURCE VARS=1)' ;
  VALUE sub2mon   0='(0) No' 1='(1) Yes (ONLY TWO OF THE SOURCE VARS=1)' ;
  VALUE sub3mon   0='(0) No' 1='(1) Yes (THREE OR MORE OF THE SOURCE VARS=1)' ;
  VALUE chancmjf  0='(0) Did not have a chance to use marijuana'
                  1='(1) Had a chance to use marijuana' 94='(94) UNKNOWN' ;
  VALUE chancocf  0='(0) Did not have a chance to use cocaine'
                  1='(1) Had a chance to use cocaine' 94='(94) UNKNOWN' ;
  VALUE chanhalf  0='(0) Did not have a chance to use hallucinogens'
                  1='(1) Had a chance to use hallucinogens' 94='(94) UNKNOWN' ;
  VALUE chanherf  0='(0) Did not have a chance to use heroin'
                  1='(1) Had a chance to use heroin' 94='(94) UNKNOWN' ;
  VALUE trmthlpf  0='(0) No (TRMTHELP=2)' 1='(1) Yes (TRMTHELP=1)' ;
  VALUE drnkhlpf  0='(0) No (DRNKHELP=2)' 1='(1) Yes (DRNKHELP=1)' ;
  VALUE dralhelp  0='(0) No (see note above)' 1='(1) Yes (TRMTHLP2=1 or DRNKHLP2=1)' ;
  VALUE rurorurb  1='(1) Rural' 2='(2) Urban' ;
  VALUE pblackhh  1='(1) Greater than or equal to 50 percent'
                  2='(2) Greater than or equal to 10 percent,'
                  3='(3) Less than 10 percent' ;
  VALUE pblackp   1='(1) Greater than or equal to 50 percent'
                  2='(2) Greater than or equal to 10 percent,'
                  3='(3) Less than 10 percent' ;
  VALUE ppoverty  1='(1) 0 - 2.65 percent' 2='(2) 2.66 - 5.12 percent'
                  3='(3) 5.13 - 9.02 percent' 4='(4) 9.03 - 16.15 percent'
                  5='(5) 16.16 percent or more' ;
  VALUE powned    1='(1) 0 - 50.25 percent' 2='(2) 50.26 - 67.58 percent'
                  3='(3) 67.59 - 76.38 percent' 4='(4) 76.39 - 83.96 percent'
                  5='(5) 83.97 percent or more' ;
  VALUE prented   1='(1) 0 - 16.04 percent' 2='(2) 16.05 - 23.62 percent'
                  3='(3) 23.63 - 32.42 percent' 4='(4) 32.43 - 49.75 percent'
                  5='(5) 49.75 percent or more' ;
  VALUE ownedave  1='(1) 0 - $44,777' 2='(2) $44,778 - $60,832' 3='(3) $60,833 - $85,121'
                  4='(4) $85,122 - $142,831' 5='(5) $142,832 or more' ;
  VALUE rentave   1='(1) 0 - $315.81' 2='(2) $315.82 - $393.95' 3='(3) $393.96 - $476.96'
                  4='(4) $476.97 - $619.72' 5='(5) $619.72 or more' ;
  VALUE irkids    0='(0) None' 1='(1) One' 2='(2) Two' 3='(3) Three' 4='(4) Four' 5='(5) Five'
                  6='(6) Six or more' ;
  VALUE cweocc2f  990='(990) INDUSTRY NOT REPORTED' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE roccup2f  990='(990) OCCUPATION NOT REPORTED' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE cwebus2f  990='(990) INDUSTRY NOT REPORTED' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE businesf  990='(990) INDUSTRY NOT REPORTED' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
*/


* SAS DATA, INFILE, INPUT STATEMENTS;

DATA;
INFILE "data-filename" LRECL=2768;
INPUT
        CASEID 1-5              RESPID 6-11             VESTR 12-15
        VEREP 16                ENCPSU 17-19            ENCSEG 20-23
        ENCCASE 24-28           CIGTRY 29-31            CIG5PK 32-33
        CIGAGE 34-36            CIGYRS 37-39            PACKS 40-41
        CIGREC 42-43            AVCIG 44-45             CIGTIME 46-49
        SNUFREC 50-51           OTHTOB 52-53            ALCTRY 54-56
        ALCREC 57-58            ALCAGE 59-61            ALCDAYS 62-63
        NODR30A 64-65           DR5DAY 66-67            MODR30A 68-69
        MODR30DY 70-71          ALCPAT 72-73            DRUNKYR 74-75
        ALCBEER 76-77           ALCWINE 78-79           ALCLIQR 80-81
        ALCVARY 82-83           NOSEDAT 84-85           BUTISOL 86-87
        BUTICAPS 88-89          AMYTAL 90-91            MEBARAL 92-93
        PLACIDYL 94-95          DORIDEN 96-97           NOLUDAR 98-99
        NEMBUTAL 100-101        SECONAL 102-103         TUINAL 104-105
        DALMANE 106-107         RESTORIL 108-109        HALCION 110-111
        AMOBARB 112-113         PHENOBAR 114-115        METHAQ 116-117
        CHHYD 118-119           PENTOB 120-121          SECOB 122-123
        SEDNEWA 124-126         SEDNEWB 127-129         SEDNEWC 130-132
        SEDNEWD 133-135         SEDNEWE 136-138         SEDNOSP 139-140
        SEDDKNAM 141-142        SEDAGE 143-145          SEDTOT 146-147
        SEDREC 148-149          SEDYRFRQ 150-151        TRNREAD 152-153
        NOTRANQ 154-155         VALIUM 156-157          LIBRIUM 158-159
        LIMBTROL 160-161        MENRIUM 162-163         SERAX 164-165
        TRANXENE 166-167        ATIVAN 168-169          CENTRAX 170-171
        XANAX 172-173           PAXIPAM 174-175         BUSPAR 176-177
        MILTOWN 178-179         EQUANIL 180-181         DEPROL 182-183
        VISTAR 184-185          ATARAX 186-187          DURRAX 188-189
        DIAZEPAM 190-191        SKLY 192-193            MEPROB 194-195
        TRNEWA 196-198          TRNEWB 199-201          TRNEWC 202-204
        TRNEWD 205-207          TRNEWE 208-210          TRNOSP 211-212
        TRDKNAM 213-214         TRANAGE 215-217         TRANTOT 218-219
        TRANREC 220-221         TRNYRFRQ 222-223        STMREAD 224-225
        NOSTIMS 226-227         DEXED 228-229           DEXAMYL 230-231
        ESKAT 232-233           BENZ 234-235            BIPHET 236-237
        DESOXYN 238-239         TENUATE 240-241         TEPANIL 242-243
        DIDREX 244-245          PLEGINE 246-247         PRELUDIN 248-249
        IONAMIN 250-251         FASTIN 252-253          PONDIMIN 254-255
        VORANIL 256-257         SANOREX 258-259         MAZANOR 260-261
        RITALIN 262-263         CYLERT 264-265          DETAMP 266-267
        METHI 268-269           METHAMP 270-271         OBLA 272-273
        STIMNEWA 274-276        STIMNEWB 277-279        STIMNEWC 280-282
        STIMNEWD 283-285        STIMNEWE 286-288        STIMNOSP 289-290
        STMDKNAM 291-292        STIMAGE 293-295         STIMTOT 296-297
        STIMREC 298-299         STMYRFRQ 300-301        STNEEDLE 302-303
        STNDLREC 304-305        ANLREAD 306-307         ANALNONE 308-309
        DARVON 310-311          DOLENE 312-313          SK65A 314-315
        WYGESIC 316-317         LEVODRO 318-319         PERCODAN 320-321
        DEMEROL 322-323         DILAUD 324-325          TYLCOD 326-327
        PHENCOD 328-329         TALWIN 330-331          TALWINNX 332-333
        TALACEN 334-335         PROPOXY 336-337         CODEINE 338-339
        ANILERID 340-341        MORPHINE 342-343        METHDON 344-345
        STADOL 346-347          ANALNEWA 348-350        ANALNEWB 351-353
        ANALNEWC 354-356        ANALNEWD 357-359        ANALNEWE 360-362
        ANLNOSP 363-364         ANLDKNAM 365-366        ANALAGE 367-369
        ANALTOT 370-371         ANALREC 372-373         ANLYRFRQ 374-375
        MJOPP 376-378           MJAGE 379-381           MJTOT 382-383
        MJREC 384-385           MJDAY30A 386-387        MJAV30A 388-389
        MJAV30B 390-391         MJAMT30A 392-393        MJFRIEND 394-395
        MJDEALER 396-397        MJOTHSHR 398-399        MJGIVEN 400-401
        MJTRGOOD 402-403        MJTRSERV 404-405        MJSTOLE 406-407
        MJTRICK 408-409         MJGREW 410-411          MJOBTNON 412-413
        MJBUCK 414-419 .1       MJYRFREQ 420-421        MJJOINT 422-423
        MJPIPE 424-425          MJBAKE 426-427          MJCHEW 428-429
        MJWAY 430-431           MJLFDALY 432-433        INHREAD 434-435
        GAS 436-437             LGAS 438-439            SPPAINT 440-441
        AEROS 442-443           GLUE 444-445            SOLVENT 446-447
        AMYLNIT 448-449         ETHER 450-451           NITOXID 452-453
        CLEFLU 454-455          INHNEWA 456-458         INHNEWB 459-461
        INHNEWC 462-464         INHNEWD 465-467         INHNEWE 468-470
        INHNOSP 471-472         INHDKNAM 473-474        INHAGE 475-477
        INHTOT 478-479          INHREC 480-481          GAS30A 482-483
        LGAS30A 484-485         SPPAN30A 486-487        AEROS30A 488-489
        GLUE30A 490-491         SOLVN30A 492-493        AMLNT30A 494-495
        ETHER30A 496-497        NOX30A 498-499          CLFL30A 500-501
        INNEW30A 502-504        INNEW30B 505-507        INNEW30C 508-510
        INNEW30D 511-513        INNEW30E 514-516        IN30NOSP 517-518
        INH30NO 519-520         INHDY30A 521-522        INHYRFRQ 523-524
        INHPO 525-526           INHQNC1 527-528         INHQNC2 529-530
        INHQNC3 531-532         INHQNC4 533-534         INHQNC5 535-536
        INHQNC6 537-538         INHQNC7 539-540         INHQNC8 541-542
        INHQNC10 543-544        INHANSY 545-546         COCOPP 547-549
        COCAGE 550-552          COCTOT 553-554          COCREC 555-556
        COCUS30A 557-558        COCAM30A 559-560        CCFRIEND 561-562
        CCDEALER 563-564        CCOTHSHR 565-566        CCGIVEN 567-568
        CCTRGOOD 569-570        CCTRSERV 571-572        CCSTOLE 573-574
        CCTRICK 575-576         CCOBTNON 577-578        COCBUCK 579-582
        COCYRFRQ 583-584        COCSNIFF 585-586        COCSWAL 587-588
        COCIV 589-590           FREEBASE 591-592        COCWAY 593-594
        CONDLREC 595-596        CCLFDALY 597-598        CRAKREC 599-600
        CRKAM30A 601-603        CKFRIEND 604-605        CKDEALER 606-607
        CKOTHSHR 608-609        CKGIVEN 610-611         CKTRGOOD 612-613
        CKTRSERV 614-615        CKSTOLE 616-617         CKTRICK 618-619
        CKOBTNON 620-621        CRAKBUCK 622-625        CKLFDALY 626-627
        HALREAD 628-629         LSD 630-631             PEYOTE 632-633
        MESC 634-635            PSILCY 636-637          PCP 638-639
        ECSTASY 640-641         HALNEWA 642-644         HALNEWB 645-647
        HALNEWC 648-650         HALNEWD 651-653         HALNEWE 654-656
        HALNOSP 657-658         HALDKNAM 659-660        HALLOPP 661-663
        HALLAGE 664-666         HALLTOT 667-668         HALLREC 669-670
        HAL30USE 671-672        HALYRFRQ 673-674        PCPREC 675-676
        HERREAD 677-678         HEROPP 679-681          HERAGE 682-684
        HERTOT 685-686          HERREC 687-688          HER30USE 689-690
        HERNEEDL 691-692        HRNDLREC 693-694        HERSMOKE 695-696
        HRSMKREC 697-698        HERSNIFF 699-700        HRSNFREC 701-702
        DRGREAD 703-704         CDCIG 705-706           CDALC 707-708
        CDSED 709-710           CDTRAN 711-712          CDSTM 713-714
        CDANAL 715-716          CDMJ 717-718            CDINH 719-720
        CDCOC 721-722           CDHALL 723-724          CDHER 725-726
        CDOTHOP 727-728         CDNONE 729-730          UCDCIG 731-732
        UCDALC 733-734          UCDSED 735-736          UCDTRAN 737-738
        UCDSTM 739-740          UCDANAL 741-742         UCDMJ 743-744
        UCDINH 745-746          UCDCOC 747-748          UCDHALL 749-750
        UCDHER 751-752          UCDOTHOP 753-754        UCDNONE 755-756
        EFFCIG 757-758          EFFALC 759-760          EFFSED 761-762
        EFFTRAN 763-764         EFFSTM 765-766          EFFANAL 767-768
        EFFMJ 769-770           EFFINH 771-772          EFFCOC 773-774
        EFFHALL 775-776         EFFHER 777-778          EFFOTHOP 779-780
        EFFNONE 781-782         UDAYCIG 783-784         UDAYALC 785-786
        UDAYSED 787-788         UDAYTRAN 789-790        UDAYSTM 791-792
        UDAYANAL 793-794        UDAYMJ 795-796          UDAYINH 797-798
        UDAYCOC 799-800         UDAYHALL 801-802        UDAYHER 803-804
        UDAYOTH 805-806         UDAYNONE 807-808        DEPCIG 809-810
        DEPALC 811-812          DEPSED 813-814          DEPTRAN 815-816
        DEPSTM 817-818          DEPANAL 819-820         DEPMJ 821-822
        DEPINH 823-824          DEPCOC 825-826          DEPHALL 827-828
        DEPHER 829-830          DEPOTHOP 831-832        DEPNONE 833-834
        WSCIG 835-836           WSALC 837-838           WSSED 839-840
        WSTRAN 841-842          WSSTM 843-844           WSANAL 845-846
        WSMJ 847-848            WSINH 849-850           WSCOC 851-852
        WSHALL 853-854          WSHER 855-856           WSOTHOP 857-858
        WSNONE 859-860          NDLREAD 861-862         GNNDLLIF 863-864
        GNNDLREC 865-866        GNNDLSED 867-868        GNNDLTRA 869-870
        GNNDLSTM 871-872        GNNDLANL 873-874        GNNDLINH 875-876
        GNNDLCOC 877-878        GNNDLHAL 879-880        GNNDLHER 881-882
        GNNDLOPT 883-884        GNNDLSTR 885-886        GNNDLNON 887-888
        GNNDLSH1 889-890        GNNDLSH2 891-892        SPTREAD 893-894
        DRUGTEST 895-896        TESTPOS 897-898         ICELIFE 899-900
        ICEREC 901-902          STEROPP 903-905         STERAGE 906-908
        STERTOT 909-910         STERREC 911-912         SPNEWA 913-915
        SPNEWB 916-918          SPNEWC 919-921          SPNEWD 922-924
        SPNEWE 925-927          BOOKED 928-929          NOBOOKYR 930-931
        BKLARCNY 932-933        BKBURGL 934-935         BKAGASLT 936-937
        BKSMASLT 938-939        BKMVTHFT 940-941        BKROB 942-943
        BKRAPE 944-945          BKMURDER 946-947        BKARSON 948-949
        BKDRVINF 950-951        BKDRUNK 952-953         BKDRUG 954-955
        BKPROS 956-957          BKVANDAL 958-959        BKOTHOFF 960-961
        NOTBKED 962-963         PROBATON 964-965        PAROLE 966-967
        STRSTEAL 968-969        OTHSTEAL 970-971        DAMAGE 972-973
        CARSTEAL 974-975        FORCEMON 976-977        BREAKIN 978-979
        PHYFIGHT 980-981        HURTBAD 982-983         GUNMONEY 984-985
        DRUNKDRV 986-987        SOLDDRUG 988-989        OTHDOING 990-991
        OTHDOSP1 992-993        OTHDOSP2 994-995        DEXREAD 996-997
        NOBOOZYR 998-999        ALCAGGR 1000-1001       ALCARGUM 1002-1003
        ALCABSNT 1004-1005      ALCHIGH 1006-1007       ALCJOB 1008-1009
        ALCMATCD 1010-1011      ALCRELCD 1012-1013      ALCFRDCD 1014-1015
        ALCTOSS 1016-1017       ALCHOLIC 1018-1019      ALCDRUNK 1020-1021
        ALCINTOX 1022-1023      ALCREM 1024-1025        ALCQUICK 1026-1027
        ALCMORN 1028-1029       ALCSHOOK 1030-1031      ALCALONE 1032-1033
        ALCBRKPM 1034-1035      ALCMJ 1036-1037         ALCCOC 1038-1039
        ALCOPT 1040-1041        ALCHAL 1042-1043        ALCINH 1044-1045
        ALCANAL 1046-1047       ALCTRAN 1048-1049       ALCSTM 1050-1051
        ALCSED 1052-1053        AS13NONE 1054-1055      DRDEPRSS 1056-1057
        DEPDRG1A 1058-1060      DEPDRG2A 1061-1063      DEPDRG3A 1064-1066
        DEPDRG4A 1067-1069      DEPDRG5A 1070-1072      DRARGUM 1073-1074
        ARGDRG1A 1075-1077      ARGDRG2A 1078-1080      ARGDRG3A 1081-1083
        ARGDRG4A 1084-1086      ARGDRG5A 1087-1089      DRALONE 1090-1091
        ALNDRG1A 1092-1094      ALNDRG2A 1095-1097      ALNDRG3A 1098-1100
        ALNDRG4A 1101-1103      ALNDRG5A 1104-1106      DRANX 1107-1108
        ANXDRG1A 1109-1111      ANXDRG2A 1112-1114      ANXDRG3A 1115-1117
        ANXDRG4A 1118-1120      ANXDRG5A 1121-1123      DRHEALTH 1124-1125
        HLTDRG1A 1126-1128      HLTDRG2A 1129-1131      HLTDRG3A 1132-1134
        HLTDRG4A 1135-1137      HLTDRG5A 1138-1140      DRNTHINK 1141-1142
        NTKDRG1A 1143-1145      NTKDRG2A 1146-1148      NTKDRG3A 1149-1151
        NTKDRG4A 1152-1154      NTKDRG5A 1155-1157      DRUPSET 1158-1159
        UPSDRG1A 1160-1162      UPSDRG2A 1163-1165      UPSDRG3A 1166-1168
        UPSDRG4A 1169-1171      UPSDRG5A 1172-1174      DRLSWORK 1175-1176
        LSWDRG1A 1177-1179      LSWDRG2A 1180-1182      LSWDRG3A 1183-1185
        LSWDRG4A 1186-1188      LSWDRG5A 1189-1191      DRSUSPIC 1192-1193
        SSPDRG1A 1194-1196      SSPDRG2A 1197-1199      SSPDRG3A 1200-1202
        SSPDRG4A 1203-1205      SSPDRG5A 1206-1208      DRCOPE 1209-1210
        CPEDRG1A 1211-1213      CPEDRG2A 1214-1216      CPEDRG3A 1217-1219
        CPEDRG4A 1220-1222      CPEDRG5A 1223-1225      DREMGMED 1226-1227
        EMDRG1A 1228-1230       EMDRG2A 1231-1233       EMDRG3A 1234-1236
        EMDRG4A 1237-1239       EMDRG5A 1240-1242       DRTRMT 1243-1244
        TMTDRG1A 1245-1247      TMTDRG2A 1248-1250      TMTDRG3A 1251-1253
        TMTDRG4A 1254-1256      TMTDRG5A 1257-1259      DRDRVUN 1260-1261
        DRVDRG1A 1262-1264      DRVDRG2A 1265-1267      DRVDRG3A 1268-1270
        DRVDRG4A 1271-1273      DRVDRG5A 1274-1276      TMTREAD 1277-1278
        EMPDRUG 1279-1280       CIGHELP 1281-1282       DRNKHELP 1283-1284
        TRMTHELP 1285-1286      TRMTEMRG 1287-1288      TRMTHOSP 1289-1290
        TRMTDOC 1291-1292       TRMTTRMT 1293-1294      TRMTMHC 1295-1296
        TRMTSHG 1297-1298       TRMTSOP 1299-1300       TRMTSP 1301-1302
        TRMTREC 1303-1304       NRTXLIFE 1305-1307      NOTRMT 1308-1309
        TXEMRG 1310-1311        TXHOSP 1312-1313        TXDOC 1314-1315
        TXTRMT 1316-1317        TXMHC 1318-1319         TXSHG 1320-1321
        TXSOP 1322-1323         TXSP 1324-1325          TRMTLIFE 1326-1327
        TRMTRESP 1328-1329      TRMTFEAR 1330-1331      TRMTCOST 1332-1333
        TRMTEVNT 1334-1335      TRMTPR 1336-1337        TRMTHLTH 1338-1339
        TRMTJOB 1340-1341       TRMTJAIL 1342-1343      TRMTSERV 1344-1345
        TRMTBQD 1346-1347       TRMTDNA 1348-1349       TRMTSOR 1350-1351
        TRMTRSP 1352-1353       TRMTDRGA 1354-1356      TRMTDRGB 1357-1359
        TRMTDRGC 1360-1362      TRMTDRGD 1363-1365      TRMTDRGE 1366-1368
        TRMTOUTC 1369-1370      TMTPHI 1371-1372        TMTPSAVE 1373-1374
        TMTPFMLY 1375-1376      TMTPEMPR 1377-1378      TMTPMEDI 1379-1380
        TMTPFREE 1381-1382      TMTPOTH 1383-1384       TMTPASP 1385-1386
        RSKPKCIG 1387-1388      RSKTRYMJ 1389-1390      RSKMJOCC 1391-1392
        RSKMJREG 1393-1394      RKTRYPCP 1395-1396      RKPCPREG 1397-1398
        RKTRYHER 1399-1400      RKHERREG 1401-1402      RKTRYCOC 1403-1404
        RKCOCOCC 1405-1406      RKCOCREG 1407-1408      RKCRKOCC 1409-1410
        RKANSOCC 1411-1412      RKANSREG 1413-1414      RK2DRINK 1415-1416
        RK5DRINK 1417-1418      RSKBINGE 1419-1420      RSKDIFMJ 1421-1422
        RKDIFLSD 1423-1424      RKDIFPCP 1425-1426      RKDIFCOC 1427-1428
        RKDIFHER 1429-1430      RSKSELL 1431-1432       RKNEIDRN 1433-1434
        RKNEISEL 1435-1436      HIGHBP 1437-1438        BPMED 1439-1440
        WALKPAIN 1441-1442      TIMEPAIN 1443-1444      UPSHOR 1445-1446
        ASTHMA 1447-1448        TRPSYCH 1449-1450       HEART 1451-1452
        FLU 1453-1454           ALLERG 1455-1456        HOSPYR 1457-1458
        SOREYR 1459-1460        RUNNYYR 1461-1462       COUGHYR 1463-1464
        PHLEGMYR 1465-1466      HEALTHYR 1467-1468      FLTEAT 1469-1470
        FLTMIND 1471-1472       FLTDEPRS 1473-1474      FLTEFFRT 1475-1476
        FLTSLEEP 1477-1478      FLTSAD 1479-1480        FLTGOING 1481-1482
        MARITAL 1483-1484       NOMARR 1485-1486        WORKSTAT 1487-1488
        PAYMO 1489-1490         PAYYR 1491-1493         NO5JOB 1494-1495
        WORKDAYS 1496-1497      WORKBLAH 1498-1499      CWE 1500-1501
        CWESC1 1502-1504        CWESC2 1505-1507        FULLPART 1508-1509
        EDUC 1510-1511          GRADHS 1512-1513        DIPLOMA 1514-1515
        ENROLLD 1516-1517       SCHPLANS 1518-1519      STUDENT 1520-1521
        SCHDAYS 1522-1523       SKIPPED 1524-1525       MILES 1526-1530
        ACCID 1531-1532         TOTPEOP 1533-1534       MOTHER 1535-1536
        FATHER 1537-1538        STEPMOM 1539-1540       STEPDAD 1541-1542
        SPOUSE 1543-1544        INLAW 1545-1546         OWNCHILD 1547-1548
        STEPCHLD 1549-1550      BROSIS 1551-1552        OTHREL 1553-1554
        FRIENDS 1555-1556       OTHERNON 1557-1558      MOVDAWAY 1559-1560
        DORM 1561-1562          MILBASE 1563-1564       HOSP 1565-1566
        OTHGPH 1567-1568        OTHGPHSP 1569-1570      SERVICE 1571-1572
        MILSTAT 1573-1574       TELNO 1575-1576         MOVES 1577-1578
        NOFAMRES 1579           PROXABLE 1580-1581      PROXYREL 1582-1584
        PROXHOME 1585-1586      PROXJOIN 1587-1588      MEDICARE 1589-1590
        MEDICAID 1591-1592      CHAMPUS 1593-1594       PRVHLTIN 1595-1596
        OWNHLTIN 1597-1598      GRPHLTIN 1599-1600      HLTINALC 1601-1602
        HLTINDRG 1603-1604      HLTINMNT 1605-1606      WHOANSHI 1607-1609
        JOB 1610-1611           HOURS 1612-1614         WORK 1615-1616
        WAG1 1617-1618          AWAG1 1619-1624         WEEKS 1625-1626
        SOC1 1627-1628          ASOC1 1629-1634         SSI1 1635-1636
        ASSI1 1637-1642         PUB1 1643-1644          AFDC1 1645-1646
        WEL1 1647-1648          AWEL1 1649-1654         INT1 1655-1656
        AINT1 1657-1662         CHD1 1663-1664          ACHD1 1665-1670
        OTH1 1671-1672          AOTH1 1673-1678         FAMLYRES 1679-1680
        WAG2 1681-1682          AWAG2 1683-1688         SOC2 1689-1690
        ASOC2 1691-1696         SSI2 1697-1698          ASSI2 1699-1704
        PUB2 1705-1706          AFDC2 1707-1708         WEL2 1709-1710
        AWEL2 1711-1716         INT2 1717-1718          AINT2 1719-1724
        CHD2 1725-1726          ACHD2 1727-1732         OTH2 1733-1734
        AOTH2 1735-1740         WHOANSIN 1741-1743      FSTAMP 1744-1745
        PEOPFD 1746-1747        FOOD 1748-1749          AFOOD 1750-1755
        BHOUR 1756-1757         BMIN 1758-1759          BAP 1760-1761
        EAP 1762-1763           LANGVER 1764-1765       UNDINT 1766-1767
        COOPINT 1768-1769       PRIVACY 1770-1771       PPRES 1772-1773
        SPRES 1774-1775         PARPRES 1776-1777       OARPRES 1778-1779
        OAPRES 1780-1781        CPRES 1782-1783         OPRESNSP 1784-1785
        OPRESSPA 1786-1788      OPRESSPB 1789-1791      WHOMARKD 1792-1793
        QUARTER 1794            FAMSKIP 1795-1796       PDEN 1797
        GQTYPE 1798             PDEN2 1799              DC 1800
        CHICAGO 1801            DENVER 1802             LA 1803
        MIAMI 1804              NEWYORK 1805            REGION 1806
        DIVISION 1807           CENCTY 1808             URBARE 1809
        METRO 1810              CENTRALC 1811           BIRMONTH 1812-1813
        BIRYEAR 1814-1817       IRAGE 1818-1819         IIAGE 1820
        IRSEX 1821              IISEX 1822              IRRACE 1823
        IIRACE 1824             IRHOIND 1825            IIHOIND 1826
        IRHOGRP 1827-1828       IIHOGRP 1829            IRHOGRP2 1830-1831
        IIHOGRP2 1832           IRMARIT 1833-1834       IIMARIT 1835
        IREDUC 1836-1837        IIEDUC 1838             IRHSGRAD 1839
        IIHSGRAD 1840           IRWORKST 1841-1842      IIWORKST 1843
        IRPINSUR 1844           IIPINSUR 1845           IRINSUR 1846
        IIINSUR 1847            IRWAG1 1848             IIWAG1 1849
        IRAWAG1 1850-1854       IIAWAG1 1855            IRSOC1 1856
        IISOC1 1857             IRASOC1 1858-1861       IIASOC1 1862
        IRSSI1 1863             IISSI1 1864             IRASSI1 1865-1868
        IIASSI1 1869            IRWEL1 1870             IIWEL1 1871
        IRAWEL1 1872-1875       IIAWEL1 1876            IRINT1 1877
        IIINT1 1878             IRAINT1 1879-1882       IIAINT1 1883
        IRCHD1 1884             IICHD1 1885             IRACHD1 1886-1889
        IIACHD1 1890            IROTH1 1891             IIOTH1 1892
        IRAOTH1 1893-1896       IIAOTH1 1897            IRWAG2 1898
        IIWAG2 1899             IRAWAG2 1900-1904       IIAWAG2 1905
        IRSOC2 1906             IISOC2 1907             IRASOC2 1908-1911
        IIASOC2 1912            IRSSI2 1913             IISSI2 1914
        IRASSI2 1915-1918       IIASSI2 1919            IRWEL2 1920
        IIWEL2 1921             IRAWEL2 1922-1925       IIAWEL2 1926
        IRINT2 1927             IIINT2 1928             IRAINT2 1929-1932
        IIAINT2 1933            IRCHD2 1934             IICHD2 1935
        IRACHD2 1936-1939       IIACHD2 1940            IROTH2 1941
        IIOTH2 1942             IRAOTH2 1943-1946       IIAOTH2 1947
        IRFOOD 1948             IIFOOD 1949             IRAFOOD 1950-1952
        IIAFOOD 1953            IRPEOP 1954-1955        IRALCRC 1956
        IIALCRC 1957            IRMJRC 1958             IIMJRC 1959
        IRCOCRC 1960            IICOCRC 1961            IRSEDRC 1962
        IISEDRC 1963            IRTRNRC 1964            IITRNRC 1965
        IRSTMRC 1966            IISTMRC 1967            IRANLRC 1968
        IIANLRC 1969            IRCIGRC 1970            IICIGRC 1971
        IROTBRC 1972            IIOTBRC 1973            IRINHRC 1974
        IIINHRC 1975            IRCRKRC 1976            IICRKRC 1977
        IRHALRC 1978            IIHALRC 1979            IRHERRC 1980
        IIHERRC 1981            IRPCPRC 1982            IIPCPRC 1983
        IRICERC 1984            IIICERC 1985            IRSTRRC 1986
        IISTRRC 1987            IRALCFQ 1988            IIALCFQ 1989
        IRMJFQ 1990-1991        IIMJFQ 1992             IRCOCFQ 1993
        IICOCFQ 1994            IRSEDFQ 1995            IISEDFQ 1996
        IRTRNFQ 1997            IITRNFQ 1998            IRSTMFQ 1999
        IISTMFQ 2000            IRANLFQ 2001            IIANLFQ 2002
        IROTBFQ 2003            IIOTBFQ 2004            IRINHFQ 2005
        IIINHFQ 2006            IRHALFQ 2007            IIHALFQ 2008
        CATAGE 2009             CATAG2 2010             CATAG3 2011
        RACE 2012               HISPRACE 2013           EDUCCAT2 2014
        EMPSTAT2 2015           INDINC 2016-2021        IIINDINC 2022
        INDCAT 2023-2024        PERINC 2025             PERINC2 2026
        PERINC3 2027            TOTINC 2028-2033        IITOTINC 2034
        TOTCAT 2035-2036        FAMINC 2037             FAMINC2 2038
        FAMINC3 2039            WELFARE 2040            HALFLAG 2041
        HALYR 2042              HALMON 2043             PCPFLAG 2044
        PCPYR 2045              PCPMON 2046             STMFLAG 2047
        STMYR 2048              STMMON 2049             SEDFLAG 2050
        SEDYR 2051              SEDMON 2052             TRQFLAG 2053
        TRQYR 2054              TRQMON 2055             ANLFLAG 2056
        ANLYR 2057              ANLMON 2058             ALCFLAG 2059
        ALCYR 2060              ALCMON 2061             CIGFLAG 2062
        CIGYR 2063              CIGMON 2064             SMKFLAG 2065
        SMKYR 2066              SMKMON 2067             HERFLAG 2068
        HERYR 2069              HERMON 2070             STRFLAG 2071
        STRYR 2072              STRMON 2073             MRJFLAG 2074
        MRJYR 2075              MRJMON 2076             COCFLAG 2077
        COCYR 2078              COCMON 2079             CRKFLAG 2080
        CRKYR 2081              CRKMON 2082             INHFLAG 2083
        INHYR 2084              INHMON 2085             ICEFLAG 2086
        ICEYR 2087              ICEMON 2088             NEEDLREC 2089-2090
        NDL90REC 2091-2092      NEDFLAG3 2093           NEDYR3 2094
        HALYRF 2095             HALMONF 2096            HALWKF 2097
        HALOCCF 2098            HALDLYF 2099            STMYRF 2100
        STMMONF 2101            STMWKF 2102             STMOCCF 2103
        STMDLYF 2104            SEDYRF 2105             SEDMONF 2106
        SEDWKF 2107             SEDOCCF 2108            SEDDLYF 2109
        TRQYRF 2110             TRQMONF 2111            TRQWKF 2112
        TRQOCCF 2113            TRQDLYF 2114            ANLYRF 2115
        ANLMONF 2116            ANLWKF 2117             ANLOCCF 2118
        ANLDLYF 2119            ALCYRF 2120             ALCMONF 2121
        ALCWKF 2122             ALCOCCF 2123            ALCDLYF 2124
        SMKYRF 2125             SMKMONF 2126            SMKWKF 2127
        SMKOCCF 2128            SMKDLYF 2129            MRJYRF 2130
        MRJMONF 2131            MRJWKF 2132             MRJOCCF 2133
        MRJDLYF 2134            COCYRF 2135             COCMONF 2136
        COCWKF 2137             COCOCCF 2138            COCDLYF 2139
        INHYRF 2140             INHMONF 2141            INHWKF 2142
        INHOCCF 2143            INHDLYF 2144            PSYFLAG2 2145
        PSYYR2 2146             PSYMON2 2147            SUMFLAG 2148
        SUMYR 2149              SUMMON 2150             MJOFLAG 2151
        MJOYR2 2152             MJOMON2 2153            IEMFLAG 2154
        IEMYR 2155              IEMMON 2156             ANALWT 2157-2167 .4
        ANALWT1 2168-2179 .4    ANALWT2 2180-2191 .4    ANALWT3 2192-2203 .4
        ANALWT4 2204-2215 .4    HSPHCONC 2216           HSPPCONC 2217
        OWNOCONC 2218           UCLASS9 2219            QC06 2220-2221
        QC09 2222-2223          AL02 2224-2225          SE04 2226-2227
        TR04 2228-2229          ST04 2230-2231          ST07 2232-2233
        AN04 2234-2235          MJ04 2236-2237          IN04 2238-2239
        CC04 2240-2241          CC11 2242-2243          CK01 2244-2245
        LS05 2246-2247          LS08 2248-2249          HE04 2250-2251
        HE07 2252-2253          ND02 2254-2255          SP04 2256-2257
        SP08 2258-2259          MJTOT2 2260             COCTOT2 2261
        MJTOT3 2262             COCTOT3 2263            MJDY30A2 2264
        ALCDAYS2 2265           MRJMON2 2266            ALCMON2 2267
        CIGMON2 2268            LSD2 2269               PEYOTE2 2270
        MESC2 2271              PSILCY2 2272            ECSTASY2 2273
        GAS2 2274               LGAS2 2275              SPPAINT2 2276
        AEROS2 2277             GLUE2 2278              SOLVENT2 2279
        AMYLNIT2 2280           ETHER2 2281             NITOXID2 2282
        CLEFLU2 2283            COCSNIF2 2284           FREEBAS2 2285
        COCSWAL2 2286           COCIV2 2287             MJDY30A3 2288
        ALCDAYS3 2289           DRINKER2 2290           HVYDRK2 2291
        AVCIG2 2292             RACESEX 2293            NOTMARJ 2294
        COCWAY2 2295            RACESEX2 2296           IRCDCIG 2297-2298
        IRCDALC 2299-2300       IRCDMJ 2301-2302        IRCDCOC 2303-2304
        IREFCIG 2305-2306       IREFALC 2307-2308       IREFMJ 2309-2310
        IREFCOC 2311-2312       IRUDCIG 2313-2314       IRUDALC 2315-2316
        IRUDMJ 2317-2318        IRUDCOC 2319-2320       IRDPCIG 2321-2322
        IRDPALC 2323-2324       IRDPMJ 2325-2326        IRDPCOC 2327-2328
        IRWSCIG 2329-2330       IRWSALC 2331-2332       IRWSMJ 2333-2334
        IRWSCOC 2335-2336       AVCIG3 2337             ALCPROBS 2338
        MJPROBS 2339            COCPROBS 2340           CIGPROBS 2341
        IRALCAGG 2342-2343      IRALCARG 2344-2345      IRALCABS 2346-2347
        IRALCHIG 2348-2349      IRALCJOB 2350-2351      IRALCMAT 2352-2353
        IRALCREL 2354-2355      IRALCFRD 2356-2357      IRALCTOS 2358-2359
        IRALCHOL 2360-2361      IRALCDRU 2362-2363      IRALCINT 2364-2365
        IRALCREM 2366-2367      IRALCQUI 2368-2369      IRALCMOR 2370-2371
        IRALCSHO 2372-2373      IRALCALO 2374-2375      IRALCBRK 2376-2377
        IRNOBOOZ 2378           ANYALC 2379             THREALC 2380
        DRUNKYR2 2381           IRDEP 2382-2383         IRARG 2384-2385
        IRALN 2386-2387         IRANX 2388-2389         IRHLT 2390-2391
        IRNTK 2392-2393         IRUPS 2394-2395         IRLSW 2396-2397
        IRSSP 2398-2399         IRCPE 2400-2401         IREMG 2402-2403
        IRDEP1 2404-2406        IRDEP2 2407-2409        IRDEP3 2410-2412
        IRDEP4 2413-2415        IRDEP5 2416-2418        IRARG1 2419-2421
        IRARG2 2422-2424        IRARG3 2425-2427        IRARG4 2428-2430
        IRARG5 2431-2433        IRALN1 2434-2436        IRALN2 2437-2439
        IRALN3 2440-2442        IRALN4 2443-2445        IRALN5 2446-2448
        IRANX1 2449-2451        IRANX2 2452-2454        IRANX3 2455-2457
        IRANX4 2458-2460        IRANX5 2461-2463        IRHLT1 2464-2466
        IRHLT2 2467-2469        IRHLT3 2470-2472        IRHLT4 2473-2475
        IRHLT5 2476-2478        IRNTK1 2479-2481        IRNTK2 2482-2484
        IRNTK3 2485-2487        IRNTK4 2488-2490        IRNTK5 2491-2493
        IRUPS1 2494-2496        IRUPS2 2497-2499        IRUPS3 2500-2502
        IRUPS4 2503-2505        IRUPS5 2506-2508        IRLSW1 2509-2511
        IRLSW2 2512-2514        IRLSW3 2515-2517        IRLSW4 2518-2520
        IRLSW5 2521-2523        IRSSP1 2524-2526        IRSSP2 2527-2529
        IRSSP3 2530-2532        IRSSP4 2533-2535        IRSSP5 2536-2538
        IRCPE1 2539-2541        IRCPE2 2542-2544        IRCPE3 2545-2547
        IRCPE4 2548-2550        IRCPE5 2551-2553        IREMG1 2554-2556
        IREMG2 2557-2559        IREMG3 2560-2562        IREMG4 2563-2565
        IREMG5 2566-2568        IRAS13 2569             DEPCIG2 2570-2571
        DEPALC2 2572-2573       DEPMRJ2 2574-2575       DEPCOC2 2576-2577
        ARGCIG2 2578-2579       ARGALC2 2580-2581       ARGMRJ2 2582-2583
        ARGCOC2 2584-2585       ALNCIG2 2586-2587       ALNALC2 2588-2589
        ALNMRJ2 2590-2591       ALNCOC2 2592-2593       ANXCIG2 2594-2595
        ANXALC2 2596-2597       ANXMRJ2 2598-2599       ANXCOC2 2600-2601
        HLTCIG2 2602-2603       HLTALC2 2604-2605       HLTMRJ2 2606-2607
        HLTCOC2 2608-2609       NTKCIG2 2610-2611       NTKALC2 2612-2613
        NTKMRJ2 2614-2615       NTKCOC2 2616-2617       UPSCIG2 2618-2619
        UPSALC2 2620-2621       UPSMRJ2 2622-2623       UPSCOC2 2624-2625
        LSWCIG2 2626-2627       LSWALC2 2628-2629       LSWMRJ2 2630-2631
        LSWCOC2 2632-2633       SSPCIG2 2634-2635       SSPALC2 2636-2637
        SSPMRJ2 2638-2639       SSPCOC2 2640-2641       CPECIG2 2642-2643
        CPEALC2 2644-2645       CPEMRJ2 2646-2647       CPECOC2 2648-2649
        EMCIG2 2650-2651        EMALC2 2652-2653        EMMRJ2 2654-2655
        EMCOC2 2656-2657        PRB1CIG 2658-2659       PRB1ALC 2660-2661
        PRB1MRJ 2662-2663       PRB1COC 2664-2665       PRB2CIG 2666-2667
        PRB2ALC 2668-2669       PRB2MRJ 2670-2671       PRB2COC 2672-2673
        PRB3CIG 2674-2675       PRB3ALC 2676-2677       PRB3MRJ 2678-2679
        PRB3COC 2680-2681       ANYPROB 2682            TWOPROB 2683
        THREPROB 2684           ALCONLYL 2685           ALCONLYY 2686
        ALCONLYM 2687           ILLONLYL 2688           ILLONLYY 2689
        ILLONLYM 2690           MRJONLYL 2691           MRJONLYY 2692
        MRJONLYM 2693           PSYONLYL 2694           PSYONLYY 2695
        PSYONLYM 2696           OTHONLYL 2697           OTHONLYY 2698
        OTHONLYM 2699           ALCILLL 2700            ALCILLY 2701
        ALCILLM 2702            ALCMRJL 2703            ALCMRJY 2704
        ALCMRJM 2705            ALCPSYL 2706            ALCPSYY 2707
        ALCPSYM 2708            ALCOTHL 2709            ALCOTHY 2710
        ALCOTHM 2711            SUB1LIF 2712            SUB2LIF 2713
        SUB3LIF 2714            SUB1YR 2715             SUB2YR 2716
        SUB3YR 2717             SUB1MON 2718            SUB2MON 2719
        SUB3MON 2720            CHANCMJ2 2721-2722      CHANCOC2 2723-2724
        CHANHAL2 2725-2726      CHANHER2 2727-2728      TRMTHLP2 2729
        DRNKHLP2 2730           DRALHELP 2731           RURORURB 2732
        PBLACKHH 2733           PBLACKP 2734            PPOVERTY 2735
        POWNED 2736             PRENTED 2737            OWNEDAVE 2738
        RENTAVE 2739            CHAGE1 2740             CHAGE2 2741
        CHAGE3 2742             CHAGE4 2743             CHAGE5 2744
        CHAGE6 2745             CHAGE7 2746             CHAGE8 2747
        CHAGE9 2748             CHAGE10 2749            IRKIDS 2750
        CWEOCC2 2751-2753       ROCCUP2 2754-2756       CWEBUS2 2757-2759
        BUSINES2 2760-2762      INTMONTH 2763-2764      EHOUR 2765-2766
        EMIN 2767-2768          ;


* SAS LABEL STATEMENT;

LABEL
   CASEID  = 'CASE IDENTIFICATION NUMBER'
   RESPID  = 'RESPONDENT IDENTIFICATION NUMBER'
   VESTR   = 'STRATUM TO BE USED IN ANALYSIS'
   VEREP   = 'REPLICATE WITHIN ANALYSIS STRATUM'
   ENCPSU  = 'PRIMARY SAMPLING UNIT (ENCRYPTED)'
   ENCSEG  = 'SEGMENT IDENTIFICATION NUMBER (ENCRYPTED'
   ENCCASE = 'HOUSEHOLD LEVEL IDENTIFICATION NUMBER (E'
   CIGTRY  = 'AGE WHEN FIRST TRIED A CIGARETTE'
   CIG5PK  = 'SMOKED 5 OR MORE PACKS OF CIGARETTES IN'
   CIGAGE  = 'AGE WHEN FIRST STARTED SMOKING DAILY'
   CIGYRS  = '# YEARS SMOKED DAILY'
   PACKS   = '# CIGARETTES SMOKED DAILY'
   CIGREC  = 'MOST RECENT TIME SMOKED A CIGARETTE'
   AVCIG   = '# CIGARETTES SMOKED PER DAY LAST 30 DAYS'
   CIGTIME = 'NUMBER OF MONTHS SMOKED # CIGARETTES/DAY'
   SNUFREC = 'MOST RECENT TIME USED SMOKELESS TOBACCO'
   OTHTOB  = 'FREQUENCY USED SMOKELESS TOBACCO PAST 12'
   ALCTRY  = 'AGE WHEN HAD FIRST DRINK OF ALCOHOL'
   ALCREC  = 'MOST RECENT ALCOHOL DRINK'
   ALCAGE  = 'AGE BEGAN DRINKING ALCOHOL MONTHLY OR MO'
   ALCDAYS = '# OF DAYS DRANK ALCOHOL PAST 30 DAYS'
   NODR30A = 'USUAL # DRINKS PER DAY PAST 30 DAYS'
   DR5DAY  = '# DAYS DRANK 5 OR MORE DRINKS PAST 30 DA'
   MODR30A = 'MOST # DRINKS ON ONE DAY IN PAST 30 DAYS'
   MODR30DY= '# DAYS DRANK AMOUNT IN MODR30A PAST 30 D'
   ALCPAT  = 'FREQUENCY ALCOHOL CONSUMPTION PAST 12 MO'
   DRUNKYR = '# TIMES GOT DRUNK ON ALCOHOL PAST 12 MON'
   ALCBEER = 'USUAL ALCOHOL BEVERAGE-BEER'
   ALCWINE = 'USUAL ALCOHOL BEVERAGE-WINE'
   ALCLIQR = 'USUAL ALCOHOL BEVERAGE-LIQUOR'
   ALCVARY = 'USUAL ALCOHOL BEVERAGE-IT VARIES'
   NOSEDAT = 'HAS NEVER TAKEN SEDATIVES FOR NONMEDICAL'
   BUTISOL = 'BUTISOL EVER TAKEN FOR NONMEDICAL REASON'
   BUTICAPS= 'BUTICAPS EVER TAKEN FOR NONMEDICAL REASO'
   AMYTAL  = 'AMYTAL EVER TAKEN FOR NONMEDICAL REASONS'
   MEBARAL = 'MEBARAL EVER TAKEN FOR NONMEDICAL REASON'
   PLACIDYL= 'PLACIDYL EVER TAKEN FOR NONMEDICAL REASO'
   DORIDEN = 'DORIDEN EVER TAKEN FOR NONMEDICAL REASON'
   NOLUDAR = 'NOLUDAR EVER TAKEN FOR NONMEDICAL REASON'
   NEMBUTAL= 'NEMBUTAL EVER TAKEN FOR NONMEDICAL REASO'
   SECONAL = 'SECONAL EVER TAKEN FOR NONMEDICAL REASON'
   TUINAL  = 'TUINAL EVER TAKEN FOR NONMEDICAL REASONS'
   DALMANE = 'DALMANE EVER TAKEN FOR NONMEDICAL REASON'
   RESTORIL= 'RESTORIL EVER TAKEN FOR NONMEDICAL REASO'
   HALCION = 'HALCION EVER TAKEN FOR NONMEDICAL REASON'
   AMOBARB = 'AMOBARBITAL EVER TAKEN FOR NONMEDICAL RE'
   PHENOBAR= 'PHENOBARBITAL EVER TAKEN FOR NONMEDICAL'
   METHAQ  = 'METHAQUALONE EVER TAKEN FOR NONMEDICAL R'
   CHHYD   = 'CHLORAL HYDRATE EVER TAKEN FOR NONMEDICA'
   PENTOB  = 'PENTOBARBITAL EVER TAKEN FOR NONMEDICAL'
   SECOB   = 'SECOBARBITAL EVER TAKEN FOR NONMEDICAL R'
   SEDNEWA = 'OTHER SEDATIVE EVER USED-1ST MENTION'
   SEDNEWB = 'OTHER SEDATIVE EVER USED-2ND MENTION'
   SEDNEWC = 'OTHER SEDATIVE EVER USED-3RD MENTION'
   SEDNEWD = 'OTHER SEDATIVE EVER USED-4TH MENTION'
   SEDNEWE = 'OTHER SEDATIVE EVER USED-5TH MENTION'
   SEDNOSP = 'OTHER SEDATIVE EVER USED (NOT SPECIFIED)'
   SEDDKNAM= 'USED SEDATIVE, DON''T KNOW NAME'
   SEDAGE  = 'AGE FIRST TOOK SEDATIVE FOR NONMEDICAL R'
   SEDTOT  = '# TIMES EVER TOOK SEDATIVE FOR NONMEDICA'
   SEDREC  = 'MOST RECENT TIME USED SEDATIVE FOR NONME'
   SEDYRFRQ= 'HOW OFTEN TKN SEDATIVES PAST YR FOR NONM'
   TRNREAD = 'TRANQUILIZERS - READING PREF. (1988-91 ='
   NOTRANQ = 'HAS NEVER TAKEN TRANQUILIZER FOR NONMED'
   VALIUM  = 'VALIUM EVER TAKEN FOR NONMEDICAL REASONS'
   LIBRIUM = 'LIBRIUM EVER TAKEN FOR NONMEDICAL REASON'
   LIMBTROL= 'LIMBITROL EVER TAKEN FOR NONMEDICAL REAS'
   MENRIUM = 'MENRIUM EVER TAKEN FOR NONMEDICAL REASON'
   SERAX   = 'SERAX EVER TAKEN FOR NONMEDICAL REASONS'
   TRANXENE= 'TRANXENE EVER TAKEN FOR NONMEDICAL REASO'
   ATIVAN  = 'ATIVAN EVER TAKEN FOR NONMEDICAL REASONS'
   CENTRAX = 'CENTRAX EVER TAKEN FOR NONMEDICAL REASON'
   XANAX   = 'XANAX EVER TAKEN FOR NONMEDICAL REASONS'
   PAXIPAM = 'PAXIPAM EVER TAKEN FOR NONMEDICAL REASON'
   BUSPAR  = 'BUSPAR EVER TAKEN FOR NONMEDICAL REASONS'
   MILTOWN = 'MILTOWN EVER TAKEN FOR NONMEDICAL REASON'
   EQUANIL = 'EQUANIL EVER TAKEN FOR NONMEDICAL REASON'
   DEPROL  = 'DEPROL EVER TAKEN FOR NONMEDICAL REASONS'
   VISTAR  = 'VISTARIL EVER TAKEN FOR NONMEDICAL REASO'
   ATARAX  = 'ATARAX EVER TAKEN FOR NONMEDICAL REASONS'
   DURRAX  = 'DURRAX EVER TAKEN FOR NONMEDICAL REASONS'
   DIAZEPAM= 'DIAZEPAM EVER TAKEN FOR NONMEDICAL REASO'
   SKLY    = 'SK-LYGEN EVER TAKEN FOR NONMEDICAL REASO'
   MEPROB  = 'MEPROBAMATE EVER TAKEN FOR NONMEDICAL RE'
   TRNEWA  = 'OTHER TRANQUILIZER EVER USED-1ST MENTION'
   TRNEWB  = 'OTHER TRANQUILIZER EVER USED-2ND MENTION'
   TRNEWC  = 'OTHER TRANQUILIZER EVER USED-3RD MENTION'
   TRNEWD  = 'OTHER TRANQUILIZER EVER USED-4TH MENTION'
   TRNEWE  = 'OTHER TRANQUILIZER EVER USED-5TH MENTION'
   TRNOSP  = 'OTHER TRANQUILIZER EVER USED (NOT SPECIF'
   TRDKNAM = 'USED TRANQUILIZER, DON''T KNOW NAME'
   TRANAGE = 'AGE FIRST TOOK TRANQUILIZER FOR NONMEDIC'
   TRANTOT = '# TIMES EVER TOOK TRANQUILIZER NONMEDICA'
   TRANREC = 'MOST RECENT TIME USED TRANQUILIZER NONME'
   TRNYRFRQ= 'FREQ IN PAST YR TKN TRANQUILIZERS FOR NO'
   STMREAD = 'STIMULANTS - READING PREF. (1988-91 = AS'
   NOSTIMS = 'HAS NEVER TAKEN STIMULANT FOR NONMEDICAL'
   DEXED   = 'DEXEDRINE EVER TAKEN FOR NONMEDICAL REAS'
   DEXAMYL = 'DEXAMYL EVER TAKEN FOR NONMEDICAL REASON'
   ESKAT   = 'ESKATROL EVER TAKEN FOR NONMEDICAL REASO'
   BENZ    = 'BENZEDRINE EVER TAKEN FOR NONMEDICAL REA'
   BIPHET  = 'BIPHETAMINE EVER TAKEN FOR NONMEDICAL RE'
   DESOXYN = 'DESOXYN EVER TAKEN FOR NONMEDICAL REASON'
   TENUATE = 'TENUATE EVER TAKEN FOR NONMEDICAL REASON'
   TEPANIL = 'TEPANIL EVER TAKEN FOR NONMEDICAL REASON'
   DIDREX  = 'DIDREX EVER TAKEN FOR NONMEDICAL REASONS'
   PLEGINE = 'PLEGINE EVER TAKEN FOR NONMEDICAL REASON'
   PRELUDIN= 'PRELUDIN EVER TAKEN FOR NONMEDICAL REASO'
   IONAMIN = 'IONAMIN EVER TAKEN FOR NONMEDICAL REASON'
   FASTIN  = 'FASTIN EVER TAKEN FOR NONMEDICAL REASONS'
   PONDIMIN= 'PONDIMIN EVER TAKEN FOR NONMEDICAL REASO'
   VORANIL = 'VORANIL EVER TAKEN FOR NONMEDICAL REASON'
   SANOREX = 'SANOREX EVER TAKEN FOR NONMEDICAL REASON'
   MAZANOR = 'MAZANOR EVER TAKEN FOR NONMEDICAL REASON'
   RITALIN = 'RITALIN EVER TAKEN FOR NONMEDICAL REASON'
   CYLERT  = 'CYLERT EVER TAKEN FOR NONMEDICAL REASONS'
   DETAMP  = 'DEXTROAMPHETAMINE EVER TAKEN FOR NONMED'
   METHI   = 'METHEDRINE EVER TAKEN FOR NONMEDICAL REA'
   METHAMP = 'METHAMPHETAMINE EVER TAKEN FOR NONMEDICA'
   OBLA    = 'OBEDRIN-L.A. EVER TAKEN FOR NONMEDICAL R'
   STIMNEWA= 'OTHER STIMULANT EVER USED-1ST MENTION'
   STIMNEWB= 'OTHER STIMULANT EVER USED-2ND MENTION'
   STIMNEWC= 'OTHER STIMULANT EVER USED-3RD MENTION'
   STIMNEWD= 'OTHER STIMULANT EVER USED-4TH MENTION'
   STIMNEWE= 'OTHER STIMULANT EVER USED-5TH MENTION'
   STIMNOSP= 'OTHER STIMULANT EVER USED (NOT SPECIFIED'
   STMDKNAM= 'USED STIMULANT, DON''T KNOW NAME'
   STIMAGE = 'AGE FIRST TOOK STIMULANT FOR NONMEDICAL'
   STIMTOT = '# TIMES EVER TOOK STIMULANT FOR NONMEDIC'
   STIMREC = 'MOST RECENT TIME USED STIMULANT FOR NONM'
   STMYRFRQ= '# TIMES USED STIMULANTS PAST 12 MONTHS'
   STNEEDLE= 'EVER USED AMPHETAMINES WITH A NEEDLE'
   STNDLREC= 'MOST RECENT TIME USED AMPHETAMINES WITH'
   ANLREAD = 'ANALGESICS - READING PREF. (1988-91 = AS'
   ANALNONE= 'HAS NEVER TAKEN ANALGESICS FOR NONMEDICA'
   DARVON  = 'DARVON EVER TAKEN FOR NONMEDICAL REASONS'
   DOLENE  = 'DOLENE EVER TAKEN FOR NONMEDICAL REASONS'
   SK65A   = 'SK-65 EVER TAKEN FOR NONMEDICAL REASONS'
   WYGESIC = 'WYGESIC EVER TAKEN FOR NONMEDICAL REASON'
   LEVODRO = 'LEVO-DROMORAN EVER TAKEN FOR NONMEDICAL'
   PERCODAN= 'PERCODAN EVER TAKEN FOR NONMEDICAL REASO'
   DEMEROL = 'DEMEROL EVER TAKEN FOR NONMEDICAL REASON'
   DILAUD  = 'DILAUDID EVER TAKEN FOR NONMEDICAL REASO'
   TYLCOD  = 'TYLENOL W/CODEINE EVER TAKEN FOR NONMEDI'
   PHENCOD = 'PHENAPHEN W/CODEINE EVER TAKEN FOR NONME'
   TALWIN  = 'TALWIN EVER TAKEN FOR NONMEDICAL REASONS'
   TALWINNX= 'TALWIN NX EVER TAKEN FOR NONMEDICAL REAS'
   TALACEN = 'TALACEN EVER TAKEN FOR NONMEDICAL REASON'
   PROPOXY = 'PROPOXYPHENE EVER TAKEN FOR NONMEDICAL R'
   CODEINE = 'CODEINE EVER TAKEN FOR NONMEDICAL REASON'
   ANILERID= 'ANILERIDINE EVER TAKEN FOR NONMEDICAL RE'
   MORPHINE= 'MORPHINE EVER TAKEN FOR NONMEDICAL REASO'
   METHDON = 'METHADONE EVER TAKEN FOR NONMEDICAL REAS'
   STADOL  = 'STADOL EVER TAKEN FOR NONMEDICAL REASONS'
   ANALNEWA= 'OTHER ANALGESICS EVER USED-1ST MENTION'
   ANALNEWB= 'OTHER ANALGESICS EVER USED-2ND MENTION'
   ANALNEWC= 'OTHER ANALGESICS EVER USED-3RD MENTION'
   ANALNEWD= 'OTHER ANALGESICS EVER USED-4TH MENTION'
   ANALNEWE= 'OTHER ANALGESICS EVER USED-5TH MENTION'
   ANLNOSP = 'OTHER ANALGESICS EVER USED (NOT SPECIFIE'
   ANLDKNAM= 'USED ANALGESICS, DON''T KNOW NAME'
   ANALAGE = 'AGE FIRST TOOK ANALGESICS FOR NONMED REA'
   ANALTOT = '# TIMES EVER TOOK ANALGESICS FOR NONMEDI'
   ANALREC = 'MOST RECENT TIME USED ANALGESIC FOR NONM'
   ANLYRFRQ= '# TIMES USED ANALGESIC PAST 12 MONTHS'
   MJOPP   = 'AGE AT FIRST CHANCE TO TRY MARIJUANA/HAS'
   MJAGE   = 'AGE WHEN FIRST USED MARIJUANA/HASH'
   MJTOT   = '# TIMES USED MARIJUANA/HASH IN LIFE'
   MJREC   = 'MOST RECENT TIME USED MARIJUANA/HASH'
   MJDAY30A= '# DAYS USED MARIJUANA/HASH IN PAST 30 DA'
   MJAV30A = '# JOINTS SMOKED PER DAY IN PAST 30 DAYS'
   MJAV30B = '# BONGS SMOKED PER DAY IN PAST 30 DAYS'
   MJAMT30A= 'TOTAL AMOUNT MARIJUANA USED PAST 30 DAYS'
   MJFRIEND= 'BOUGHT IT FROM FRIENDS, ACQUAINTANCES OR'
   MJDEALER= 'BOUGHT IT FROM A DEALER'
   MJOTHSHR= 'OTHERS SHARED WITH ME'
   MJGIVEN = 'GIVEN TO ME'
   MJTRGOOD= 'TRADED GOODS FOR IT'
   MJTRSERV= 'TRADED SERVICES FOR IT'
   MJSTOLE = 'STOLE IT'
   MJTRICK = 'OBTAINED IT BY TRICK OR FRAUD'
   MJGREW  = 'GREW IT YOURSELF'
   MJOBTNON= 'DID NOT USE MARIJUANA IN PAST 30 DAYS'
   MJBUCK  = '$ AMOUNT SPENT ON MARIJUANA USED IN PAST'
   MJYRFREQ= 'FREQUENCY USED MARIJUANA PAST 12 MONTHS'
   MJJOINT = 'SMOKED MARIJUANA CIGARETTES OR JOINTS IN'
   MJPIPE  = 'SMOKED MARIJUANA WITH A PIPE OR BONG IN'
   MJBAKE  = 'ATE MARIJUANA THAT''S BEEN BAKED IN FOOD'
   MJCHEW  = 'CHEWED MARIJUANA LIKE CHEWING TOBACCO IN'
   MJWAY   = 'USED MARIJUANA SOME OTHER WAY IN PAST 12'
   MJLFDALY= 'EVER USED MARIJUANA DAILY FOR 2 OR MORE'
   INHREAD = 'INHALANTS - READING PREFERENCE (1988-91'
   GAS     = 'EVER INHALED GASOLINE OR LIGHTER FLUIDS'
   LGAS    = 'EVER INHALED LIGHTER GASES (BUTANE, PROP'
   SPPAINT = 'EVER INHALED SPRAY PAINTS'
   AEROS   = 'EVER INHALED OTHER AEROSOL SPRAYS'
   GLUE    = 'EVER INHALED SHOESHINE LIQUID/GLUE/TOLUE'
   SOLVENT = 'EVER INHALED LACQUER THINNER/OTHER PAINT'
   AMYLNIT = 'EVER INHLD AMYL NITRITE/POPPERS/LOCK.RM'
   ETHER   = 'EVER INHALED HALOTHANE/ETHER/OTHER ANEST'
   NITOXID = 'EVER INHALED NITROUS OXIDE/WHIPPETS'
   CLEFLU  = 'EVER INHLD CORRECTN FLDS/DEGREASERS/CLEA'
   INHNEWA = 'OTHER SUBSTANCE EVER INHALED-1ST MENTION'
   INHNEWB = 'OTHER SUBSTANCE EVER INHALED-2ND MENTION'
   INHNEWC = 'OTHER SUBSTANCE EVER INHALED-3RD MENTION'
   INHNEWD = 'OTHER SUBSTANCE EVER INHALED-4TH MENTION'
   INHNEWE = 'OTHER SUBSTANCE EVER INHALED-5TH MENTION'
   INHNOSP = 'OTHER SUBSTANCE EVER INHALED (NOT SPECIF'
   INHDKNAM= 'USED INHALANT, DON''T KNOW NAME'
   INHAGE  = 'AGE WHEN FIRST SNIFFED ONE OF THESE INHA'
   INHTOT  = '# TIMES USED INHALANT IN LIFETIME'
   INHREC  = 'MOST RECENT TIME USED INHALANT'
   GAS30A  = 'INHALED GASOLINE OR LIGHTER FLUIDS PAST'
   LGAS30A = 'INHALED LIGHTER GASES (BUTANE,PROPANE) P'
   SPPAN30A= 'INHALED SPRAY PAINTS PAST 30 DAYS'
   AEROS30A= 'INHALED OTHER AEROSOL SPRAYS PAST 30 DAY'
   GLUE30A = 'INHALED SHOESHINE LIQUID/GLUE/TOLUENE PA'
   SOLVN30A= 'INHALED LACQUER THINNER/PAINT SOLVENTS P'
   AMLNT30A= 'INHLD AMYL NITRITE/POPRS/LCR.RM ODZ/RUSH'
   ETHER30A= 'INHALED HALOTHANE/ETHER/OTH ANESTHETICS'
   NOX30A  = 'INHALED NITROUS OXIDE/WHIPPETS PAST 30 D'
   CLFL30A = 'INHALED CORRECTION FLD/DEGREASER/CLN FLD'
   INNEW30A= 'OTHER SUBSTANCE INHALED PAST 30 DAYS-1ST'
   INNEW30B= 'OTHER SUBSTANCE INHALED PAST 30 DAYS-2ND'
   INNEW30C= 'OTHER SUBSTANCE INHALED PAST 30 DAYS-3RD'
   INNEW30D= 'OTHER SUBSTANCE INHALED PAST 30 DAYS-4TH'
   INNEW30E= 'OTHER SUBSTANCE INHALED PAST 30 DAYS-5TH'
   IN30NOSP= 'OTH SUBSTANCE INHALED PAST 30 DAYS (NOT'
   INH30NO = 'DID NOT USE ANY INHALANT PAST 30 DAYS'
   INHDY30A= '# DAYS USED AN INHALANT IN PAST 30 DAYS'
   INHYRFRQ= 'FREQ IN PAST YR SNIFFED OR INHALED SUBST'
   INHPO   = 'EVER PASSED OUT FROM USING INHALANTS'
   INHQNC1 = 'QUESTION 1 NOT CLEAR'
   INHQNC2 = 'QUESTION 2 NOT CLEAR'
   INHQNC3 = 'QUESTION 3 NOT CLEAR'
   INHQNC4 = 'QUESTION 4 NOT CLEAR'
   INHQNC5 = 'QUESTION 5 NOT CLEAR'
   INHQNC6 = 'QUESTION 6 NOT CLEAR'
   INHQNC7 = 'QUESTION 7 NOT CLEAR'
   INHQNC8 = 'QUESTION 8 NOT CLEAR'
   INHQNC10= 'ALL QUESTIONS WERE CLEAR'
   INHANSY = 'ANSWER MARKED FOR EACH QUESTION'
   COCOPP  = 'AGE AT FIRST CHANCE TO TRY COCAINE'
   COCAGE  = 'AGE WHEN FIRST USED COCAINE'
   COCTOT  = '# TIMES USED COCAINE IN LIFE'
   COCREC  = 'MOST RECENT TIME USED COCAINE (IN ANY FO'
   COCUS30A= '# DAYS USED COCAINE PAST 30 DAYS'
   COCAM30A= '# OF GRAMS OF COCAINE USED IN PAST 30 DA'
   CCFRIEND= 'BOUGHT COC FRM FRIENDS,ACQNTNCES,FAMLY P'
   CCDEALER= 'BOUGHT COCAINE FROM DEALER PAST 30 DAYS'
   CCOTHSHR= 'OTHERS SHARED COCAINE WITH ME PAST 30 DA'
   CCGIVEN = 'COCAINE WAS GIVEN TO ME PAST 30 DAYS'
   CCTRGOOD= 'TRADED GOODS FOR COCAINE PAST 30 DAYS'
   CCTRSERV= 'TRADED SERVICES FOR COCAINE PAST 30 DAYS'
   CCSTOLE = 'STOLE COCAINE PAST 30 DAYS'
   CCTRICK = 'OBTAINED COCAINE BY TRICK OR FRAUD PAST'
   CCOBTNON= 'DID NOT USE COCAINE IN PAST 30 DAYS'
   COCBUCK = '$ AMOUNT SPENT ON COCAINE USED IN PAST 3'
   COCYRFRQ= 'FREQUENCY USED COCAINE PAST 12 MONTHS'
   COCSNIFF= 'SNIFFED/SNORTED COCAINE THRU NOSE IN PAS'
   COCSWAL = 'SWALLOWED/DRANK COCAINE IN PAST 12 MONTH'
   COCIV   = 'INJECTED COCAINE WITH A NEEDLE IN PAST 1'
   FREEBASE= 'SMOKED/FREE-BASED COCAINE IN PAST 12 MON'
   COCWAY  = 'USED COCAINE SOME OTH WAY PST 12 MOS-ONL'
   CONDLREC= 'MOST RECENT TIME USED COCAINE WITH A NEE'
   CCLFDALY= 'EVER USED COCAINE DAILY FOR 2 OR MORE WE'
   CRAKREC = 'MOST RECENT TIME USED ''CRACK'''
   CRKAM30A= '# OF VIALS OF ''CRACK'' USED IN PAST 30 DA'
   CKFRIEND= 'BOUGHT ''CRACK'' FRM FRNDS,ACQNTNCES,FAMLY'
   CKDEALER= 'BOUGHT ''CRACK'' FROM DEALER PAST 30 DAYS'
   CKOTHSHR= 'OTHERS SHARED ''CRACK'' WITH ME PAST 30 DA'
   CKGIVEN = '''CRACK'' WAS GIVEN TO ME PAST 30 DAYS'
   CKTRGOOD= 'TRADED GOODS FOR ''CRACK'' PAST 30 DAYS'
   CKTRSERV= 'TRADED SERVICES FOR ''CRACK'' PAST 30 DAYS'
   CKSTOLE = 'STOLE ''CRACK'' PAST 30 DAYS'
   CKTRICK = 'OBTAINED ''CRACK'' BY TRICK OR FRAUD PAST'
   CKOBTNON= 'DID NOT USE ''CRACK'' IN PAST 30 DAYS'
   CRAKBUCK= '$ AMOUNT SPENT ON ''CRACK'' USED IN PAST 3'
   CKLFDALY= 'EVER USED ''CRACK'' DAILY FOR 2 OR MORE WE'
   HALREAD = 'HALLUCINOGENS - READING PREF. (1988-91 ='
   LSD     = 'EVER USED LSD (''ACID,'' ''WHITE LIGHTNING'''
   PEYOTE  = 'EVER USED PEYOTE'
   MESC    = 'EVER USED MESCALINE'
   PSILCY  = 'EVER USED PSILOCYBIN (MUSHROOMS)'
   PCP     = 'EVER USED PCP (''ANGEL DUST,'' PHENCYCLIDI'
   ECSTASY = 'EVER USED ''ECSTASY'' (MDMA)'
   HALNEWA = 'OTHER HALLUCINOGENS EVER USED-1ST MENTIO'
   HALNEWB = 'OTHER HALLUCINOGENS EVER USED-2ND MENTIO'
   HALNEWC = 'OTHER HALLUCINOGENS EVER USED-3RD MENTIO'
   HALNEWD = 'OTHER HALLUCINOGENS EVER USED-4TH MENTIO'
   HALNEWE = 'OTHER HALLUCINOGENS EVER USED-5TH MENTIO'
   HALNOSP = 'OTHER HALLUCINOGENS EVER USED (NOT SPECI'
   HALDKNAM= 'USED A HALLUCINOGEN, DON''T KNOW NAME'
   HALLOPP = 'AGE AT FIRST CHANCE TO TRY HALLUCINOGENS'
   HALLAGE = 'AGE WHEN FIRST USED LSD/PCP/OTHER HALLUC'
   HALLTOT = '# TIMES USED LSD/PCP/OTHER HALLUCINOGENS'
   HALLREC = 'MOST RECENT TIME USED HALLUCINOGENS'
   HAL30USE= '# DAYS USED HALLUCINOGENS PAST 30 DAYS'
   HALYRFRQ= '# TIMES USED HALLUCINOGENS PAST 12 MONTH'
   PCPREC  = 'MOST RECENT TIME USED PCP'
   HERREAD = 'HEROIN - READING PREFERENCE (1988-91 = A'
   HEROPP  = 'AGE AT FIRST CHANCE TO TRY HEROIN'
   HERAGE  = 'AGE WHEN FIRST USED HEROIN'
   HERTOT  = '# TIMES USED HEROIN IN LIFE'
   HERREC  = 'MOST RECENT TIME USED HEROIN'
   HER30USE= '# DAYS USED HEROIN PAST 30 DAYS'
   HERNEEDL= 'EVER USED HEROIN WITH A NEEDLE'
   HRNDLREC= 'MOST RECENT TIME USED HEROIN WITH A NEED'
   HERSMOKE= 'EVER SMOKED HEROIN'
   HRSMKREC= 'MOST RECENT TIME SMOKED HEROIN'
   HERSNIFF= 'EVER SNIFFED HEROIN POWDER THROUGH NOSE'
   HRSNFREC= 'MOST RECENT/SNIFFED HEROIN POWDER THROUG'
   DRGREAD = 'DRUGS - READING PREFERENCE (1988-91 = AS'
   CDCIG   = 'TRIED TO CUT DOWN ON USE OF CIGARETTES P'
   CDALC   = 'TRIED TO CUT DOWN ON USE OF ALCOHOL PAST'
   CDSED   = 'TRIED TO CUT DOWN ON USE OF SEDATIVES PA'
   CDTRAN  = 'TRIED TO CUT DOWN ON USE OF TRANQUILIZER'
   CDSTM   = 'TRIED TO CUT DOWN ON USE OF STIMULANTS P'
   CDANAL  = 'TRIED TO CUT DOWN ON USE OF ANALGESICS P'
   CDMJ    = 'TRIED TO CUT DOWN ON USE OF MARIJUANA PA'
   CDINH   = 'TRIED TO CUT DOWN ON USE OF INHALANTS PA'
   CDCOC   = 'TRIED TO CUT DOWN ON USE OF COCAINE PAST'
   CDHALL  = 'TRIED TO CUT DOWN ON USE OF HALLUCINOGEN'
   CDHER   = 'TRIED TO CUT DOWN ON USE OF HEROIN PAST'
   CDOTHOP = 'TRIED TO CUT DOWN ON USE OF OTHER OPIATE'
   CDNONE  = 'DID NOT TRY TO CUT DOWN ON ANY DRUG USED'
   UCDCIG  = 'UNABLE TO CUT DOWN ON CIGARETTES DURING'
   UCDALC  = 'UNABLE TO CUT DOWN ON ALCOHOL IN PAST 12'
   UCDSED  = 'UNABLE TO CUT DOWN ON SEDATIVES DURING P'
   UCDTRAN = 'UNABLE TO CUT DOWN ON TRANQUILIZERS PAST'
   UCDSTM  = 'UNABLE TO CUT DOWN ON STIMULANTS DURING'
   UCDANAL = 'UNABLE TO CUT DOWN ON ANALGESICS DURING'
   UCDMJ   = 'UNABLE TO CUT DOWN ON MARIJUANA DURING P'
   UCDINH  = 'UNABLE TO CUT DOWN ON INHALANTS DURING P'
   UCDCOC  = 'UNABLE TO CUT DOWN ON COCAINE IN PAST 12'
   UCDHALL = 'UNABLE TO CUT DOWN ON HALLUCINOGENS PAST'
   UCDHER  = 'UNABLE TO CUT DOWN ON HEROIN DURING PAST'
   UCDOTHOP= 'UNABLE TO CUT DOWN ON OPIATES/MORPHINE P'
   UCDNONE = 'DID NOT TRY TO CUT DOWN ON ANY DRUG IN P'
   EFFCIG  = 'NEEDED MORE CIGARETTES TO GET SAME EFFEC'
   EFFALC  = 'NEEDED MORE ALCOHOL TO GET SAME EFFECT P'
   EFFSED  = 'NEEDED MORE SEDATIVES TO GET SAME EFFECT'
   EFFTRAN = 'NEEDED MORE TRANQ. TO GET SAME EFFECT PA'
   EFFSTM  = 'NEEDED MORE STIMULANTS TO GET SAME EFFEC'
   EFFANAL = 'NEEDED MORE ANALGESICS TO GET SAME EFFEC'
   EFFMJ   = 'NEEDED MORE MARIJUANA TO GET SAME EFFECT'
   EFFINH  = 'NEEDED MORE INHALANTS TO GET SAME EFFECT'
   EFFCOC  = 'NEEDED MORE COCAINE TO GET SAME EFFECT P'
   EFFHALL = 'NEEDED MORE HALLUCIN. TO GET SAME EFFECT'
   EFFHER  = 'NEEDED MORE HEROIN TO GET SAME EFFECT PA'
   EFFOTHOP= 'NEEDED MORE OTHER OPIATES TO GET SAME EF'
   EFFNONE = 'DID NOT NEED MORE OF ANY DRUG FOR SAME E'
   UDAYCIG = 'USED CIGARETTES DAILY FOR 2+ WEEKS IN PA'
   UDAYALC = 'USED ALCOHOL DAILY FOR 2+ WEEKS IN PAST'
   UDAYSED = 'USED SEDATIVES DAILY FOR 2+ WEEKS IN PAS'
   UDAYTRAN= 'USED TRANQUILIZERS DAILY FOR 2+ WKS IN P'
   UDAYSTM = 'USED STIMULANTS DAILY FOR 2+ WEEKS IN PA'
   UDAYANAL= 'USED ANALGESICS DAILY FOR 2+ WEEKS IN PA'
   UDAYMJ  = 'USED MARIJUANA DAILY FOR 2+ WEEKS IN PAS'
   UDAYINH = 'USED INHALANTS DAILY FOR 2+ WEEKS IN PAS'
   UDAYCOC = 'USED COCAINE DAILY FOR 2+ WEEKS IN PAST'
   UDAYHALL= 'USED HALLUCINOGENS DAILY FOR 2+ WEEKS IN'
   UDAYHER = 'USED HEROIN DAILY FOR 2+ WEEKS IN PAST Y'
   UDAYOTH = 'USED OTHER OPIATES DAILY FOR 2+ WEEKS IN'
   UDAYNONE= 'DID NOT USE ANY DRUG DAILY FOR 2+ WEEKS'
   DEPCIG  = 'FELT DEPENDENT ON CIGARETTES PAST YEAR'
   DEPALC  = 'FELT DEPENDENT ON ALCOHOL PAST YEAR'
   DEPSED  = 'FELT DEPENDENT ON SEDATIVES PAST YEAR'
   DEPTRAN = 'FELT DEPENDENT ON TRANQUILIZERS PAST YEA'
   DEPSTM  = 'FELT DEPENDENT ON STIMULANTS PAST YEAR'
   DEPANAL = 'FELT DEPENDENT ON ANALGESICS PAST YEAR'
   DEPMJ   = 'FELT DEPENDENT ON MARIJUANA PAST YEAR'
   DEPINH  = 'FELT DEPENDENT ON INHALANTS PAST YEAR'
   DEPCOC  = 'FELT DEPENDENT ON COCAINE PAST YEAR'
   DEPHALL = 'FELT DEPENDENT ON HALLUCINOGENS PAST YEA'
   DEPHER  = 'FELT DEPENDENT ON HEROIN PAST YEAR'
   DEPOTHOP= 'FELT DEPENDENT ON OTHER OPIATES PAST YEA'
   DEPNONE = 'DID NOT FEEL DEPENDENT ON ANY DRUG USED'
   WSCIG   = 'FELT SICK WHEN CUT DOWN ON CIGARETTES PA'
   WSALC   = 'FELT SICK WHEN CUT DOWN ON ALCOHOL PAST'
   WSSED   = 'FELT SICK WHEN CUT DOWN ON SEDATIVES PAS'
   WSTRAN  = 'FELT SICK WHEN CUT DOWN ON TRANQUILIZERS'
   WSSTM   = 'FELT SICK WHEN CUT DOWN ON STIMULANTS PA'
   WSANAL  = 'FELT SICK WHEN CUT DOWN ON ANALGESICS PA'
   WSMJ    = 'FELT SICK WHEN CUT DOWN ON MARIJUANA PAS'
   WSINH   = 'FELT SICK WHEN CUT DOWN ON INHALANTS PAS'
   WSCOC   = 'FELT SICK WHEN CUT DOWN ON COCAINE PAST'
   WSHALL  = 'FELT SICK WHEN CUT DOWN ON HALLUCINOGENS'
   WSHER   = 'FELT SICK WHEN CUT DOWN ON HEROIN PAST Y'
   WSOTHOP = 'FELT SICK WHEN CUT DOWN ON OTHER OPIATES'
   WSNONE  = 'DID NOT HAVE WITHDRAWAL SYMPTOMS PAST YE'
   NDLREAD = 'NEEDLES - READING PREFERENCE'
   GNNDLLIF= 'EVER USED NEEDLE TO INJECT DRUGS FOR NON'
   GNNDLREC= 'MOST RECENT TIME USED ANY DRUG WITH A NE'
   GNNDLSED= 'USED SEDATIVE W/NEEDLE FOR NONMEDICAL RS'
   GNNDLTRA= 'USED TRANQUILIZER W/NEEDLE FOR NONMEDICA'
   GNNDLSTM= 'USED STIMULANT W/NEEDLE FOR NONMEDICAL R'
   GNNDLANL= 'USED ANALGESIC W/NEEDLE FOR NONMEDICAL R'
   GNNDLINH= 'USED INHALANTS W/NEEDLE FOR NONMEDICAL R'
   GNNDLCOC= 'USED COCAINE W/NEEDLE FOR NONMEDICAL RSN'
   GNNDLHAL= 'USED HALLUCINOGENS W/NEEDLE FOR NONMEDIC'
   GNNDLHER= 'USED HEROIN W/NEEDLE FOR NONMEDICAL RSN'
   GNNDLOPT= 'USED OTHER OPIATES W/NEEDLE FOR NONMEDIC'
   GNNDLSTR= 'USED ANABOLIC STEROIDS W/NEEDLE FOR NONM'
   GNNDLNON= 'NEVER USED A NEEDLE TO TAKE ANY DRUG'
   GNNDLSH1= 'EVER USED A NEEDLE AFTER SOMEONE ELSE US'
   GNNDLSH2= 'SOMEONE ELSE EVER USED A NEEDLE AFTER YO'
   SPTREAD = 'SPECIAL TOPICS - READING PREF.(1990-91 ='
   DRUGTEST= 'BEEN REQUIRED TO TAKE DRUG TEST IN PAST'
   TESTPOS = 'DRUG TEST INDICATED PRESENCE OF DRUG IN'
   ICELIFE = 'HAVE YOU USED ''ICE''?'
   ICEREC  = 'MOST RECENT TIME USED ''ICE'''
   STEROPP = 'AGE FIRST HAD CHANCE TO TRY ANABOLIC STE'
   STERAGE = 'AGE FIRST TIME ACTUALLY TRIED ANABOLIC S'
   STERTOT = '# TIMES YOU HAVE USED ANABOLIC STEROIDS'
   STERREC = 'MOST RECENT TIME YOU USED ANABOLIC STERO'
   SPNEWA  = 'OTHER DRUGS USED IN PAST 12 MONTHS-1ST M'
   SPNEWB  = 'OTHER DRUGS USED IN PAST 12 MONTHS-2ND M'
   SPNEWC  = 'OTHER DRUGS USED IN PAST 12 MONTHS-3RD M'
   SPNEWD  = 'OTHER DRUGS USED IN PAST 12 MONTHS-4TH M'
   SPNEWE  = 'OTHER DRUGS USED IN PAST 12 MONTHS-5TH M'
   BOOKED  = 'EVER ARRESTED & BOOKED FOR BREAKING THE'
   NOBOOKYR= '# TIMES ARRESTED AND BOOKED IN PAST 12 M'
   BKLARCNY= 'ARRSTD & BOOKED FOR LARCENY/THEFT IN PAS'
   BKBURGL = 'ARRSTD & BOOKED FOR BURGLARY OR B & E IN P'
   BKAGASLT= 'ARRSTD & BOOKED FOR AGGRAVATED ASSAULT P'
   BKSMASLT= 'ARRSTD & BOOKED FOR OTHER ASSAULT IN PST'
   BKMVTHFT= 'ARRSTD & BOOKED FOR MOTOR VEHICLE THEFT'
   BKROB   = 'ARRSTD & BOOKED FOR ROBBERY IN PAST 12 M'
   BKRAPE  = 'ARRSTD & BOOKED FOR FORCIBLE RAPE IN PST'
   BKMURDER= 'ARRST & BKD FOR MURDER/HOMICIDE/MNSLGHTR'
   BKARSON = 'ARRSTD & BOOKED FOR ARSON IN PAST 12 MON'
   BKDRVINF= 'ARRSTD & BOOKED FOR DUI IN PAST 12 MONTH'
   BKDRUNK = 'ARRST & BKD FOR DRNKNNSS/OTH LIQ LAW VIO'
   BKDRUG  = 'ARRSTD & BKED FOR POSSESS/SALE OF DRUGS'
   BKPROS  = 'ARRSTD & BOOKED FOR PROSTITUTION IN PAST'
   BKVANDAL= 'ARRSTD & BOOKED FOR OTHR PROP OFFENSE PS'
   BKOTHOFF= 'ARRSTD & BOOKED FOR OTHER OFFENSES'
   NOTBKED = 'NOT ARRSTD & BOOKED FOR ANY OFFENSE PAST'
   PROBATON= 'ON PROBATION AT ANY TIME IN PAST 12 MONT'
   PAROLE  = 'ON PAROLE AT ANY TIME IN PAST 12 MONTHS'
   STRSTEAL= 'TAKEN SOMETHING FROM STORE W/O PAYING PA'
   OTHSTEAL= 'TAKEN SMTHNG NOT YOURS (NOT FROM STORE)'
   DAMAGE  = 'PURPOSELY DAMAGED PROPERTY NOT YOURS PAS'
   CARSTEAL= 'TAKEN A CAR NOT YOUR FAMILY''S IN PAST 12'
   FORCEMON= 'USE WEPON/FRCE GET MONEY/THNGS FRM PERS'
   BREAKIN = 'BROKEN INTO A HOUSE/BUILDING IN THE PAST'
   PHYFIGHT= 'GOTTEN INTO A PHYSICAL FIGHT IN PAST 12'
   HURTBAD = 'HRT SOMEONE ENOUGH TO NEED BANDAGE/A DR.'
   GUNMONEY= 'USED WEAPON TO GET SOMETHING FRM PERSON'
   DRUNKDRV= 'DRIVEN UNDER INFLUENCE OF ALC/DRUGS PST'
   SOLDDRUG= 'SOLD ILLEGAL DRUGS IN PAST 12 MONTHS'
   OTHDOING= 'ANYTHING ELSE TO GET IN TROUBL W/POLICE'
   OTHDOSP1= 'OTHER CRIMINAL BEHAVIOR PST 12 MONTHS-1S'
   OTHDOSP2= 'OTHER CRIMINAL BEHAVIOR PAST 12 MONTHS-2'
   DEXREAD = 'DRINKING EXPER. READING PREF. (1988-91 ='
   NOBOOZYR= 'DID NOT USE BEER, WINE, OR LIQUOR IN PAS'
   ALCAGGR = 'FELT AGGRESSIVE OR CROSS WHILE DRINKING'
   ALCARGUM= 'GOT INTO HEATED ARGUMENT WHILE DRINKING'
   ALCABSNT= 'STAYED OUT OF WORK/SCHOOL DUE TO HANGOVE'
   ALCHIGH = 'HIGH OR LITTLE DRUNK ON JOB OR AT SCHOOL'
   ALCJOB  = 'LOST/NEARLY LOST JOB DUE TO DRINKING PAS'
   ALCMATCD= 'TOLD BY SPOUSE/DATE TO CUT DOWN DRINKING'
   ALCRELCD= 'TOLD BY RELATIVE TO CUT DOWN DRINKING PA'
   ALCFRDCD= 'TOLD BY FRIENDS TO CUT DOWN DRINKING PAS'
   ALCTOSS = 'TOSSED DOWN DRINKS FAST TO GET QUICKER E'
   ALCHOLIC= 'WAS AFRAID MIGHT BE/BECOME AN ALCOHOLIC'
   ALCDRUNK= 'STAYED DRUNK MORE THAN 1 DAY AT A TIME P'
   ALCINTOX= 'COULDN''T STOP TILL COMPLETELY INTOXICATI'
   ALCREM  = 'COULDN''T RECALL THINGS DONE WHILE DRINKI'
   ALCQUICK= 'HAD QUICK DRINK WHEN NO ONE WAS LOOKING'
   ALCMORN = 'OFTEN HAD A DRINK FIRST THING IN MORNING'
   ALCSHOOK= 'HANDS SHOOK AFTER DRINKING DAY BEFORE IN'
   ALCALONE= 'SOMETIMES GOT HIGH/DRUNK WHILE DRNKNG AL'
   ALCBRKPM= 'KEPT ON DRINKING AFTER PROMISING MYSELF'
   ALCMJ   = 'MARIJUANA USED W/ALCOHOL PAST 12 MONTHS'
   ALCCOC  = 'COCAINE USED W/ALCOHOL PAST 12 MONTHS'
   ALCOPT  = 'HEROIN USED W/ALCOHOL PAST 12 MONTHS'
   ALCHAL  = 'HALLUCINOGENS USED W/ALCOHOL PAST 12 MON'
   ALCINH  = 'INHALANTS USED W/ALCOHOL PAST 12 MONTHS'
   ALCANAL = 'ANALGESICS USED W/ALCOHOL PAST 12 MONTHS'
   ALCTRAN = 'TRANQUILIZERS USED W/ALCOHOL PAST 12 MON'
   ALCSTM  = 'STIMULANTS USED W/ALCOHOL PAST 12 MONTHS'
   ALCSED  = 'SEDATIVES USED W/ALCOHOL PAST 12 MONTHS'
   AS13NONE= 'NEVER USED CIGARETTES, ALCOHOL, OR DRUGS'
   DRDEPRSS= 'BECAME DEPRESSED/LOST INTEREST DUE TO DR'
   DEPDRG1A= 'DRUG CAUSING DEPRESSION/LOST INTEREST-1S'
   DEPDRG2A= 'DRUG CAUSING DEPRESSION/LOST INTEREST-2N'
   DEPDRG3A= 'DRUG CAUSING DEPRESSION/LOST INTEREST-3R'
   DEPDRG4A= 'DRUG CAUSING DEPRESSION/LOST INTEREST-4T'
   DEPDRG5A= 'DRUG CAUSING DEPRESSION/LOST INTEREST-5T'
   DRARGUM = 'HAD ARGUMNTS W/FAMILY/FRNDS PST YR DUE T'
   ARGDRG1A= 'DRUG CAUSING ARGUMENTS/FIGHTS-1ST MENTIO'
   ARGDRG2A= 'DRUG CAUSING ARGUMENTS/FIGHTS-2ND MENTIO'
   ARGDRG3A= 'DRUG CAUSING ARGUMENTS/FIGHTS-3RD MENTIO'
   ARGDRG4A= 'DRUG CAUSING ARGUMENTS/FIGHTS-4TH MENTIO'
   ARGDRG5A= 'DRUG CAUSING ARGUMENTS/FIGHTS-5TH MENTIO'
   DRALONE = 'FELT ALONE/ISOLATED PAST YEAR DUE TO DRU'
   ALNDRG1A= 'DRUG CAUSING FEELING ALONE/ISOLATED-1ST'
   ALNDRG2A= 'DRUG CAUSING FEELING ALONE/ISOLATED-2ND'
   ALNDRG3A= 'DRUG CAUSING FEELING ALONE/ISOLATED-3RD'
   ALNDRG4A= 'DRUG CAUSING FEELING ALONE/ISOLATED-4TH'
   ALNDRG5A= 'DRUG CAUSING FEELING ALONE/ISOLATED-5TH'
   DRANX   = 'FELT VERY NERVOUS/ANXIOUS PAST YR DUE TO'
   ANXDRG1A= 'DRUG CAUSING FEELING NERVOUS/ANXIOUS-1ST'
   ANXDRG2A= 'DRUG CAUSING FEELING NERVOUS/ANXIOUS-2ND'
   ANXDRG3A= 'DRUG CAUSING FEELING NERVOUS/ANXIOUS-3RD'
   ANXDRG4A= 'DRUG CAUSING FEELING NERVOUS/ANXIOUS-4TH'
   ANXDRG5A= 'DRUG CAUSING FEELING NERVOUS/ANXIOUS-5TH'
   DRHEALTH= 'HAD HEALTH PROBLEMS PAST YEAR DUE TO DRU'
   HLTDRG1A= 'DRUG CAUSING HEALTH PROBLEMS-1ST MENTION'
   HLTDRG2A= 'DRUG CAUSING HEALTH PROBLEMS-2ND MENTION'
   HLTDRG3A= 'DRUG CAUSING HEALTH PROBLEMS-3RD MENTION'
   HLTDRG4A= 'DRUG CAUSING HEALTH PROBLEMS-4TH MENTION'
   HLTDRG5A= 'DRUG CAUSING HEALTH PROBLEMS-5TH MENTION'
   DRNTHINK= 'HAD DIFFCLTY THNKNG CLEARLY PST YR DUE T'
   NTKDRG1A= 'DRUG CAUSING DIFFICULTY THNKNG CLEARLY-1'
   NTKDRG2A= 'DRUG CAUSING DIFFICULTY THINKING CLEAR-2'
   NTKDRG3A= 'DRUG CAUSING DIFFICULTY THINKING CLEAR-3'
   NTKDRG4A= 'DRUG CAUSING DIFFICULTY THINKING CLEAR-4'
   NTKDRG5A= 'DRUG CAUSING DIFFICULTY THINKING CLEAR-5'
   DRUPSET = 'FELT IRRITABLE/UPSET PAST YEAR DUE TO DR'
   UPSDRG1A= 'DRUG CAUSING FEELING IRRITABLE/UPSET-1ST'
   UPSDRG2A= 'DRUG CAUSING FEELING IRRITABLE/UPSET-2ND'
   UPSDRG3A= 'DRUG CAUSING FEELING IRRITABLE/UPSET-3RD'
   UPSDRG4A= 'DRUG CAUSING FEELING IRRITABLE/UPSET-4TH'
   UPSDRG5A= 'DRUG CAUSING FEELING IRRITABLE/UPSET-5TH'
   DRLSWORK= 'GOT LESS WRK DONE @ SCH/JOB PST YR DUE T'
   LSWDRG1A= 'DRUG CAUSING LESS WORK GETTING DONE-1ST'
   LSWDRG2A= 'DRUG CAUSING LESS WORK GETTING DONE-2ND'
   LSWDRG3A= 'DRUG CAUSING LESS WORK GETTING DONE-3RD'
   LSWDRG4A= 'DRUG CAUSING LESS WORK GETTING DONE-4TH'
   LSWDRG5A= 'DRUG CAUSING LESS WORK GETTING DONE-5TH'
   DRSUSPIC= 'FELT DISTRUSTFUL/SUSPICIOUS PST YR DUE T'
   SSPDRG1A= 'DRUG CAUSING FEELING SUSPIC./DISTRUST-1S'
   SSPDRG2A= 'DRUG CAUSING FEELING SUSPIC./DISTRUST-2N'
   SSPDRG3A= 'DRUG CAUSING FEELING SUSPIC./DISTRUST-3R'
   SSPDRG4A= 'DRUG CAUSING FEELING SUSPIC./DISTRUST-4T'
   SSPDRG5A= 'DRUG CAUSING FEELING SUSPIC./DISTRUST-5T'
   DRCOPE  = 'PROBLEMS HARDER TO HANDLE PAST YR DUE TO'
   CPEDRG1A= 'DRUG MAKING PROBLEMS HARDER TO HANDLE-1S'
   CPEDRG2A= 'DRUG MAKING PROBLEMS HARDER TO HANDLE-2N'
   CPEDRG3A= 'DRUG MAKING PROBLEMS HARDER TO HANDLE-3R'
   CPEDRG4A= 'DRUG MAKING PROBLEMS HARDER TO HANDLE-4T'
   CPEDRG5A= 'DRUG MAKING PROBLEMS HARDER TO HANDLE-5T'
   DREMGMED= 'HAD TO GET EMERG MED HELP PST YR DUE TO'
   EMDRG1A = 'DRUG CAUSING NEED FOR EMER. MED. HELP-1S'
   EMDRG2A = 'DRUG CAUSING NEED FOR EMER. MED. HELP-2N'
   EMDRG3A = 'DRUG CAUSING NEED FOR EMER. MED. HELP-3R'
   EMDRG4A = 'DRUG CAUSING NEED FOR EMER. MED. HELP-4T'
   EMDRG5A = 'DRUG CAUSING NEED FOR EMER. MED. HELP-5T'
   DRTRMT  = 'SOMEONE SUGGEST TREATMENT PST YR DUE TO'
   TMTDRG1A= 'DRUG CAUSING ONE TO SUGGEST TREATMENT-1S'
   TMTDRG2A= 'DRUG CAUSING ONE TO SUGGEST TREATMENT-2N'
   TMTDRG3A= 'DRUG CAUSING ONE TO SUGGEST TREATMENT-3R'
   TMTDRG4A= 'DRUG CAUSING ONE TO SUGGEST TREATMENT-4T'
   TMTDRG5A= 'DRUG CAUSING ONE TO SUGGEST TREATMENT-5T'
   DRDRVUN = 'DROVE UNSAFELY IN PAST YEAR DUE TO DRUG'
   DRVDRG1A= 'DRUG CAUSING UNSAFE DRIVING-1ST MENTION'
   DRVDRG2A= 'DRUG CAUSING UNSAFE DRIVING-2ND MENTION'
   DRVDRG3A= 'DRUG CAUSING UNSAFE DRIVING-3RD MENTION'
   DRVDRG4A= 'DRUG CAUSING UNSAFE DRIVING-4TH MENTION'
   DRVDRG5A= 'DRUG CAUSING UNSAFE DRIVING-5TH MENTION'
   TMTREAD = 'TREATMENT - READING PREFERENCE (1991 = A'
   EMPDRUG = 'REFD. TO DRG TRMT THRU EMPLOYEE ASST.PGM'
   CIGHELP = 'GONE TO TRTMNT PROF. TO QUIT SMOKING IN'
   DRNKHELP= 'GOTTEN TREATMENT FOR DRINKING IN PAST 12'
   TRMTHELP= 'RECEIVED TREATMENT FOR DRUG USE IN PAST'
   TRMTEMRG= 'RECEIVED TRTMNT/DRUG USE/EMERGENCY RM PS'
   TRMTHOSP= 'RECVD TRTMNT/DRUG USE/HOSPITAL INPATIENT'
   TRMTDOC = 'RECEIVED TREATMENT/DRUG USE/DR''S OFFICE/'
   TRMTTRMT= 'REC TRTMNT/DRG USE/TRTMNT OR REHAB FCLTY'
   TRMTMHC = 'RECVD TRTMNT/DRUG USE/MENTAL HLTH CENTER'
   TRMTSHG = 'RECVD TRTMNT/DRUG USE/SELF-HELP GROUP/PS'
   TRMTSOP = 'RECEIVED TRTMNT/DRUG USE/SOME OTHR PLACE'
   TRMTSP  = 'OTHER PLACE RECEIVED TREATMENT (SPECIFIE'
   TRMTREC = 'LAST TIME RECEIVED TREATMENT FOR DRUGS'
   NRTXLIFE= '#TIMES IN LIFE RECEIVED TRMT FOR USE OF'
   NOTRMT  = 'NEVER RECEIVED TRMT OR COUNSELING FOR DR'
   TXEMRG  = 'LAST DRUG TREATMENT IN AN EMERGENCY ROOM'
   TXHOSP  = 'LAST DRUG TREATMENT IN A HOSPITAL AS AN'
   TXDOC   = 'LAST DRUG TREATMENT IN A PRIVATE DOCTOR'''
   TXTRMT  = 'LAST DRUG TRTMNT IN A DRUG TRTMNT OR REH'
   TXMHC   = 'LAST DRUG TRTMNT IN A MENTAL HEALTH CENT'
   TXSHG   = 'LAST DRUG TRTMNT IN A SELF-HELP GROUP'
   TXSOP   = 'LAST DRUG TRTMNT IN SOME OTHER PLACE'
   TXSP    = 'OTHER PLACE LAST RECVD TRTMNT SPECIFIED'
   TRMTLIFE= 'IMPORT OF WANTNG TO CHNGE LIFESTYLE AS R'
   TRMTRESP= 'IMPORT OF FAMILY RESPONSBLTY AS RSN FOR'
   TRMTFEAR= 'IMPORT OF FEAR OF BEING JAILED AS REASON'
   TRMTCOST= 'IMPORT OF DRUGS BEING TOO COSTLY AS RSN'
   TRMTEVNT= 'IMPORT OF SIGNIFICANT EVENT AS REASON FO'
   TRMTPR  = 'IMPORT OF PRESSR FRM FAMILY/FRNDS AS RSN'
   TRMTHLTH= 'IMPORT OF CONCERNS ABOUT HEALTH AS REASO'
   TRMTJOB = 'IMPORT OF CONCERNS ABOUT JOB AS REASON F'
   TRMTJAIL= 'IMPORT OF HAVING BEEN SENT TO JAIL AS RS'
   TRMTSERV= 'IMPORT OF AVAILABILITY OF SVCS AS RSN FO'
   TRMTBQD = 'IMPORT OF BAD QUALITY DRUGS AS REASON FO'
   TRMTDNA = 'IMPORT OF DRGS NOT BEING AVAILBL AS RSN'
   TRMTSOR = 'IMPORTANCE OF SOME OTHER REASON FOR TRMT'
   TRMTRSP = 'OTHER REASON FOR TRMT SPECIFIED'
   TRMTDRGA= 'PRIMARY DRUG RECEIVED TRMT FOR/LAST TREA'
   TRMTDRGB= 'PRIMARY DRUG RECEIVED TRMT FOR/LAST TREA'
   TRMTDRGC= 'PRIMARY DRUG RECEIVED TRMT FOR/LAST TREA'
   TRMTDRGD= 'PRIMARY DRUG RECEIVED TRMT FOR/LAST TREA'
   TRMTDRGE= 'PRIMARY DRUG RECEIVED TRMT FOR/LAST TREA'
   TRMTOUTC= 'OUTCOME OF THE TREATMENT OR COUNSELING L'
   TMTPHI  = 'LAST TREATMENT PAID BY HEALTH INSURANCE'
   TMTPSAVE= 'LAST TREATMENT PAID BY OWN SAVINGS OR EA'
   TMTPFMLY= 'LAST TREATMENT PAID BY FAMILY MEMBERS'
   TMTPEMPR= 'LAST TREATMENT PAID BY EMPLOYER'
   TMTPMEDI= 'LAST TREATMENT PAID BY MEDICARE OR MEDIC'
   TMTPFREE= 'LAST TREATMENT WAS FREE'
   TMTPOTH = 'LAST TREATMENT PAID BY OTHER'
   TMTPASP = 'OTHER PAYER FOR LAST TREATMENT SPECIFIED'
   RSKPKCIG= 'RISK IF SMOKE 1 OR MORE PACKS CIGARETTES'
   RSKTRYMJ= 'RISK IF TRY MARIJUANA ONCE OR TWICE'
   RSKMJOCC= 'RISK IF SMOKE MARIJUANA OCCASIONALLY'
   RSKMJREG= 'RISK IF SMOKE MARIJUANA REGULARLY'
   RKTRYPCP= 'RISK IF TRY PCP ONCE OR TWICE'
   RKPCPREG= 'RISK IF USE PCP REGULARLY'
   RKTRYHER= 'RISK IF TRY HEROIN ONCE OR TWICE'
   RKHERREG= 'RISK IF USE HEROIN REGULARLY'
   RKTRYCOC= 'RISK IF TRY COCAINE ONCE OR TWICE'
   RKCOCOCC= 'RISK IF USE COCAINE OCCASIONALLY'
   RKCOCREG= 'RISK IF USE COCAINE REGULARLY'
   RKCRKOCC= 'RISK IF USE ''CRACK'' OCCASIONALLY'
   RKANSOCC= 'RISK IF USE ANABOLIC STEROIDS OCCASIONAL'
   RKANSREG= 'RISK IF USE ANABOLIC STEROIDS REGULARLY'
   RK2DRINK= 'RISK IF TAKE 1 OR 2 DRINKS NEARLY EVERY'
   RK5DRINK= 'RISK IF TAKE 4 OR 5 DRINKS NEARLY EVERY'
   RSKBINGE= 'RISK IF HAVE 5 OR MORE DRINKS ONCE OR TW'
   RSKDIFMJ= 'DIFFICULTY OF GETTING MARIJUANA IF YOU W'
   RKDIFLSD= 'DIFFICULTY OF GETTING LSD IF YOU WANTED'
   RKDIFPCP= 'DIFFICULTY OF GETTING PCP IF YOU WANTED'
   RKDIFCOC= 'DIFF. OF GETTING COCAINE OR ''CRACK'' IF Y'
   RKDIFHER= 'DIFFICULTY OF GETTING HEROIN IF YOU WANT'
   RSKSELL = 'SOMEONE APPR YOU TO SELL YOU ILLEG DRG P'
   RKNEIDRN= 'FREQ. OF SEEING DRUNK/HIGH PEOPLE IN NEI'
   RKNEISEL= 'FREQ. OF SEEING PEOPLE SELL DRUGS IN NEI'
   HIGHBP  = 'EVER DIAGNOSED AS HAVING HIGH BLOOD PRES'
   BPMED   = 'MEDICATION EVER PRESCRIBED FOR HIGH BLOO'
   WALKPAIN= 'EVER HAD PAIN IN CHEST FROM EXERTION'
   TIMEPAIN= 'EVER HAD SEVERE CHEST PAIN LASTING 1/2 H'
   UPSHOR  = 'EVER HAD SHORTNESS OF BREATH FROM EXERTI'
   ASTHMA  = 'EVER DIAGNOSED AS HAVING LUNG/CHEST COND'
   TRPSYCH = 'EVER TREATED FOR PSYCHOLOGICAL/EMOTIONAL'
   HEART   = 'EVER DIAGNOSED AS HAVING HEART CONDITION'
   FLU     = 'GET BAD COLD OR FLU EVERY YEAR'
   ALLERG  = 'HAS HAY FEVER'
   HOSPYR  = 'HOSPITALIZED OVERNIGHT FOR INJURY/ILLNES'
   SOREYR  = 'HAD SORE THROAT LASTING 3 OR MORE DAYS I'
   RUNNYYR = 'HAD RUNNY NOSE LASTING 3 OR MORE DAYS IN'
   COUGHYR = 'HAD COUGH LASTING ABOUT A WK 3/MORE TIME'
   PHLEGMYR= 'HAD COUGH W/PHLEGM LASTING 3 OR MORE WEE'
   HEALTHYR= 'HEALTH FOR PAST 12 MONTHS'
   FLTEAT  = 'DID NOT FEEL LIKE EATING; APPETITE POOR'
   FLTMIND = 'HAD TRBL KEEPING MIND ON WHAT I WAS DOIN'
   FLTDEPRS= 'FELT DEPRESSED PAST WK'
   FLTEFFRT= 'FELT EVERYTHING I DID WAS AN EFFORT PAST'
   FLTSLEEP= 'MY SLEEP WAS RESTLESS PAST WK'
   FLTSAD  = 'FELT SAD PAST WK'
   FLTGOING= 'COULD NOT GET ''GOING'' PAST WK'
   MARITAL = 'EDITED MARITAL STATUS'
   NOMARR  = '# TIMES MARRIED'
   WORKSTAT= 'PRESENT WORK SITUATION'
   PAYMO   = 'MONTH LAST WORKED FOR PAY'
   PAYYR   = 'YEAR (19__) LAST WORKED FOR PAY'
   NO5JOB  = '# OF JOBS LAST 5 YEARS'
   WORKDAYS= '# DAYS MISSED WORK DUE TO ILL/INJURY LAS'
   WORKBLAH= '# DAYS SKIPPED WORK LAST 30 DAYS'
   CWE     = 'CHIEF WAGE EARNER IN HOUSEHOLD'
   CWESC1  = 'REL. OF CHIEF WAGE EARNER TO RESPONDENT'
   CWESC2  = 'REL. OF CHIEF WAGE EARNER TO RESPONDENT'
   FULLPART= 'WORK STATUS OF CHIEF WAGE EARNER'
   EDUC    = 'LAST GRADE COMPLETED IN SCHOOL'
   GRADHS  = 'GRADUATED FROM HIGH SCHOOL'
   DIPLOMA = 'EVIDENCE OF HIGH SCHOOL COMPLETION'
   ENROLLD = 'NOW ENROLLED IN ANY SCHOOL'
   SCHPLANS= 'PLANS FOR FUTURE SCHOOLING'
   STUDENT = 'STUDENT STATUS NOW'
   SCHDAYS = '# OF DAYS MISSED SCHOOL DUE TO ILL/INJUR'
   SKIPPED = '# DAYS SKIPPED SCHOOL LAST MONTH'
   MILES   = '# MILES RESPONDENT DRIVES IN A TYPICAL W'
   ACCID   = 'HAD MOTOR VEHICLE ACCIDENT IN PAST 12 MO'
   TOTPEOP = '# OF RESIDENTS IN HOUSEHOLD'
   MOTHER  = 'MOTHER OF RESPONDENT RESIDES IN HOUSEHOL'
   FATHER  = 'FATHER OF RESPONDENT RESIDES IN HOUSEHOL'
   STEPMOM = 'STEPMOTHER OF RESPONDENT RESIDES IN HOUS'
   STEPDAD = 'STEPFATHER OF RESPONDENT RESIDES IN HOUS'
   SPOUSE  = 'SPOUSE/LIVE-IN PARTNER OF RESP RESIDES I'
   INLAW   = '# PARENT(S)-IN-LAW OF RESP RESIDES IN HO'
   OWNCHILD= '# BIOLOGICAL CHILDREN OF RESP RESIDES IN'
   STEPCHLD= '# ADOPTED/STEPCHILDREN OF RESP RESIDES I'
   BROSIS  = '# BROTHERS/SISTERS OF RESP RESIDES IN HO'
   OTHREL  = '# OTHER RELATIVES OF RESP RESIDES IN HOU'
   FRIENDS = '# FRIENDS/ROOMMATES OF RESP RESIDES IN H'
   OTHERNON= '# OTHER PEOPLE UNRELATD TO RESP RESIDES'
   MOVDAWAY= 'ANY RESIDENT FOR 6 MONTHS IN PAST YEAR N'
   DORM    = '# OF FORMER RESIDENTS NOW LIVING AT COLL'
   MILBASE = '# OF FORMER RESIDENTS NOW LIVING ON MILI'
   HOSP    = '# OF FORMR RESDNTS NOW LVNG IN JAIL,HOSP'
   OTHGPH  = '# OF FORMR RESDNTS NOW LIVING IN OTHR GR'
   OTHGPHSP= 'OTHR GRP HOUSING (SPECIFIED) WHRE FORMR'
   SERVICE = 'EVER SERVED IN ARMED FORCES'
   MILSTAT = 'CURRENT MILITARY STATUS'
   TELNO   = '# OF TELEPHONE NUMBERS IN HOUSEHOLD'
   MOVES   = '# OF TIMES MOVED PAST 5 YEARS'
   NOFAMRES= 'RELATIVES RESIDENT IN HOUSEHOLD'
   PROXABLE= 'OTHR FMLY MEMBR ABLE TO GIVE INFO ON HLT'
   PROXYREL= 'RELATN TO R OF PERSN ABLE TO GIVE INFO O'
   PROXHOME= 'RELATIVE FROM PROXYREL HERE AT HOME NOW'
   PROXJOIN= 'WOULD R ASK RELATIVE FROM PROXYREL TO JO'
   MEDICARE= 'COVERED BY MEDICARE LAST FULL CALENDAR M'
   MEDICAID= 'COVERED BY MEDICAID LAST FULL CALENDAR M'
   CHAMPUS = 'COVERED BY CHAMPUS,CHAMPVA,VA,MIL HLTH C'
   PRVHLTIN= 'COVERED BY PRIVATE HEALTH INSURANCE LFCM'
   OWNHLTIN= 'PRIVATE PLAN IN OWN NAME OR FAMILY NAME'
   GRPHLTIN= 'PRIVATE PLAN OFFERED BY YOUR/FAMILY EMPL'
   HLTINALC= 'PRIVATE PLAN COVERED ALCOHOL ABUSE LFCM'
   HLTINDRG= 'PRIVATE PLAN COVERED DRUG ABUSE LFCM'
   HLTINMNT= 'PRIVATE PLAN COVERED MENTAL DIFFICULTIES'
   WHOANSHI= 'WHO ANSWERED QUESTIONS ABOUT HEALTH INSU'
   JOB     = 'HAVE A JOB IN (MONTH)'
   HOURS   = 'TOTAL HOURS WORKED IN (MONTH)'
   WORK    = 'SELF-EMPLOYED OR WORKING FOR EMPLOYER'
   WAG1    = 'PERSONALLY RECEIVED WAGES IN MONTH - REC'
   AWAG1   = 'INCOME RECEIVED FROM ALL JOBS AND SELF E'
   WEEKS   = '# WEEKS LAST YEAR YOU WORKED'
   SOC1    = 'RECEIVED SS OR RR PAYMENTS'
   ASOC1   = 'AMOUNT OF INCOME RECEIVED FROM SS OR RR'
   SSI1    = 'RECEIVED MONEY FROM SSI'
   ASSI1   = 'AMOUNT OF INCOME RECEIVED FROM SSI'
   PUB1    = 'RECEIVED PUBLIC ASSISTANCE OR WELFARE PA'
   AFDC1   = 'RECEIVED AFDC OR OTHER TYPE OF ASSISTANC'
   WEL1    = 'PERSONALLY RECEIVED INCOME FROM WELFARE'
   AWEL1   = 'AMOUNT OF INCOME RECEIVED FROM PUB.ASSIT'
   INT1    = 'HAD MONEY THAT EARNED INTEREST'
   AINT1   = 'AMOUNT OF INCOME FROM INTEREST'
   CHD1    = 'RECEIVED ANY CHILD SUPPORT PAYMENTS'
   ACHD1   = 'AMOUNT OF INCOME RECEIVED FROM CHILD SUP'
   OTH1    = 'RECEIVED INCOME FROM OTHER SOURCES'
   AOTH1   = 'AMOUNT OF INCOME RECEIVED FROM OTHER SOU'
   FAMLYRES= 'FAMILY MEMBERS ARE LIVING IN THIS RESIDE'
   WAG2    = 'DID MEMBER OF FAMILY RECEIVE INCOME FROM'
   AWAG2   = 'INCOME RECEIVED FROM ALL MEMS OF FAMILY/'
   SOC2    = 'DID FAM MEM RECEIVE MONEY FROM SS OR RR'
   ASOC2   = 'FAMILY INCOME FROM SS OR RR'
   SSI2    = 'OTHER FAMILY MEMBER RECEIVED MONEY FROM'
   ASSI2   = 'AMOUNT OF FAMILY INCOME RECEIVED FROM SS'
   PUB2    = 'OTHR FAM MEMBR RECEIVED PUB ASSISTANCE O'
   AFDC2   = 'OTHER FAMILY MEMBER RECEIVED AFDC OR ADC'
   WEL2    = 'OTHR FAMLY MEM RECVD INCOME FROM WELFARE'
   AWEL2   = 'AMOUNT FAMLY RECEIVED FROM PUB ASSISTCE'
   INT2    = 'OTHER FAMILY MEMBER HAD MONEY THAT EARNE'
   AINT2   = 'AMOUNT OF FAMILY INCOME EARNED FROM INTE'
   CHD2    = 'OTHER FAM MEMBER RECEIVED CHILD SUPPORT'
   ACHD2   = 'AMOUNT OF INCOME FAMLY RECEIVED FROM CHI'
   OTH2    = 'OTHER FAMLY MEM RECEIVED INCOME FROM OTH'
   AOTH2   = 'AMOUNT OF INCOME FAMILY RECEIVED FROM OT'
   WHOANSIN= 'WHO ANSWERED MOST QUESTIONS ABOUT FAMILY'
   FSTAMP  = 'YOU OR FAMILY LIVING HERE RECEIVED FOOD'
   PEOPFD  = '# PEOPLE COUNTED IN FOOD STAMP ALLOTMENT'
   FOOD    = 'ANY FAMILY MEMBER RECEIVED FOOD STAMPS -'
   AFOOD   = 'TOTAL VALUE OF FOOD STAMP ALLOTMENT'
   BHOUR   = 'BEGINNING HOUR OF INTERVIEW'
   BMIN    = 'BEGINNING MINUTE OF INTERVIEW'
   BAP     = 'BEGINNING TIME OF INTERVIEW - AM/PM INDI'
   EAP     = 'ENDING TIME OF INTERVIEW - AM/PM INDICAT'
   LANGVER = 'LANGUAGE VERSION'
   UNDINT  = 'ESTIMATE RESPONDENT''S UNDERSTANDING OF I'
   COOPINT = 'COOPERATION OF RESPONDENT'
   PRIVACY = 'SCALE FOR PRIVACY DURING INTERVIEW'
   PPRES   = 'PARENT(S) PRESENT OR LISTENING'
   SPRES   = 'SPOUSE PRESENT OR LISTENING'
   PARPRES = 'LIVE-IN PARTNR/FRIEND PRSNT OR LISTENING'
   OARPRES = 'ADULT RELATIVE(S) PRESENT/LISTENING'
   OAPRES  = 'OTHER ADULT(S) PRESENT OR LISTENING'
   CPRES   = 'CHILD(REN) UNDER 15 PRESENT/LISTENING'
   OPRESNSP= 'OTHER PERSON(S) (NOT SPECIFIED) PRESENT/'
   OPRESSPA= 'OTHER PERSON(S) PRESENT/LISTENING-1ST ME'
   OPRESSPB= 'OTHER PERSON(S) PRESENT/LISTENING-2ND ME'
   WHOMARKD= 'WHO MARKED ANSWERS ON ANSWER SHEET'
   QUARTER = 'QUARTER INDICATOR'
   FAMSKIP = 'OTHER FAMILY MEMBERS IN THE HH INDICATOR'
   PDEN    = 'POPULATION DENSITY'
   GQTYPE  = 'TYPE OF GROUP QUARTERS'
   PDEN2   = 'POPULATION DENSITY - FIVE LEVELS'
   DC      = 'DC MSA INDICATOR'
   CHICAGO = 'CHICAGO MSA INDICATOR'
   DENVER  = 'DENVER MSA INDICATOR'
   LA      = 'LA MSA INDICATOR'
   MIAMI   = 'MIAMI MSA INDICATOR'
   NEWYORK = 'NEW YORK MSA INDICATOR'
   REGION  = 'CENSUS REGION'
   DIVISION= 'CENSUS DIVISION CODE'
   CENCTY  = 'CENTRAL CITY IN THE SIX MSAs'
   URBARE  = 'URBANIZED AREA IN THE 6 MSAs'
   METRO   = 'METROPOLITAN AREA'
   CENTRALC= 'CENTRAL CITY FOR ALL MSA''S'
   BIRMONTH= 'BIRTH MONTH'
   BIRYEAR = 'BIRTH YEAR'
   IRAGE   = 'IMPUTATION-REVISED AGE OF RESPONDENT'
   IIAGE   = 'IRAGE INDICATOR'
   IRSEX   = 'SEX - IMPUTATION REVISED'
   IISEX   = 'IRSEX INDICATOR'
   IRRACE  = 'IMPUTATION-REVISED RACE OF RESPONDENT'
   IIRACE  = 'IRRACE INDICATOR'
   IRHOIND = 'IMPUTATION-REVISED HISPANIC ORIGIN'
   IIHOIND = 'IRHOIND INDICATOR'
   IRHOGRP = 'IMPUTATION-REVISED HISPANIC-ORIGIN GROUP'
   IIHOGRP = 'IMPUTATION INDICATOR FOR HISPANIC GROUP'
   IRHOGRP2= 'IMPUTATION-REVISED HISPANIC-ORIGIN GROUP'
   IIHOGRP2= 'IMPUTATION INDICATOR FOR HISPANIC GROUP'
   IRMARIT = 'MARITAL STATUS - IMPUTATION INDICATOR'
   IIMARIT = 'IRMARIT INDICATOR'
   IREDUC  = 'EDUCATION - IMPUTATION REVISED'
   IIEDUC  = 'EDUCATION - IMPUTATION INDICATOR'
   IRHSGRAD= 'HIGH SCHOOL GRADUATE - IMPUTATION REVISE'
   IIHSGRAD= 'HIGH SCHOOL GRADUATE - IMPUTATION INDICA'
   IRWORKST= 'WORK STATUS - IMPUTATION REVISED'
   IIWORKST= 'WORK STATUS - IMPUTATION INDICATOR'
   IRPINSUR= 'PRIVATE HEALTH INSURANCE - IMPUTATION RE'
   IIPINSUR= 'PRIVATE HEALTH INSURANCE - IMPUTATION IN'
   IRINSUR = 'HEALTH INSURANCE - IMPUTATION REVISED'
   IIINSUR = 'HEALTH INSURANCE - IMPUTATION INDICATOR'
   IRWAG1  = 'RECEIVED WAGES - IMPUTATION REVISED'
   IIWAG1  = 'RECEIVED WAGES - IMPUTATION INDICATOR'
   IRAWAG1 = 'AMNT RECEIVED FROM WAGES - IMPUTATION RE'
   IIAWAG1 = 'AMOUNT RECEIVED FROM WAGES - IMPUTATION'
   IRSOC1  = 'RECEIVED INCOME FROM SS/RR - IMPUTATION'
   IISOC1  = 'RECEIVED INCOME FR SS/RR - IMPUTATION IN'
   IRASOC1 = 'AMNT RECEIVED FROM SS OR RR - IMPUTATION'
   IIASOC1 = 'AMT RECEIVED FROM SS/RR - IMPUTATION IND'
   IRSSI1  = 'RECEIVED INCOME FROM SSI - IMPUTATION RE'
   IISSI1  = 'RECEIVED INCOME FROM SSI - IMPUTATION IN'
   IRASSI1 = 'AMNT RECEIVED FROM SSI - IMPUTATION REVI'
   IIASSI1 = 'AMOUNT RECEIVED FROM SSI - IMPUTATION IN'
   IRWEL1  = 'RECEIVED WELFARE - IMPUTATION REVISED'
   IIWEL1  = 'RECEIVED WELFARE - IMPUTATION INDICATOR'
   IRAWEL1 = 'AMNT RECEIVED FROM WELFARE - IMPUTATION'
   IIAWEL1 = 'AMT RECEIVED FROM WELFARE - IMPUTATION I'
   IRINT1  = 'RECEIVED INTEREST - IMPUTATION REVISED'
   IIINT1  = 'RECEIVED INTEREST - IMPUTATION INDICATOR'
   IRAINT1 = 'AMNT RECEIVED FROM INTEREST - IMPUTATION'
   IIAINT1 = 'AMT RECEIVED FROM INTEREST - IMPUTATION'
   IRCHD1  = 'RECEIVED CHILD SUPPORT - IMPUTATION REVI'
   IICHD1  = 'RECEIVED FROM CHILD SUPPORT - IMPUTATION'
   IRACHD1 = 'AMNT RECEIVED FROM CHILD SUPPORT - IMPUT'
   IIACHD1 = 'AMT RECVD FR CHILD SUPPORT - IMPUTATION'
   IROTH1  = 'RECEIVED OTHER SOURCES - IMPUTATION REVI'
   IIOTH1  = 'RECVD INCOME FR OTHR SOURCS - IMPUTATION'
   IRAOTH1 = 'AMNT RECEIVED FROM OTHER SOURCES - IMPUT'
   IIAOTH1 = 'AMT RECVD FR OTHR SOURCES - IMPUTATION I'
   IRWAG2  = 'OTHR FAM MEM RECEIVED WAGES - IMPUTATION'
   IIWAG2  = 'OTHR FAM MEM RECVD WAGES - IMPUTATION IN'
   IRAWAG2 = 'AMNT OTHR FAM RECVD FR WAGES - IMPUTATIO'
   IIAWAG2 = 'AMT OTHR FAM RECVD FR WAGES - IMPUTATION'
   IRSOC2  = 'OTHR FAM RECVD INCOME FR SS/RR - IMPUT.'
   IISOC2  = 'OTHR FAM RECVED INCOME FR SS/RR - IMPUT.'
   IRASOC2 = 'AMNT OTHR FAM RECVD FROM SS/RR - IMPUT.'
   IIASOC2 = 'AMT OTHR FAM RECVD FR SS/RR - IMPUTATION'
   IRSSI2  = 'OTHR FAM RECVD INCOME FR SSI - IMPUT. RE'
   IISSI2  = 'OTHR FAM RECVED FROM SSI - IMPUTATION IN'
   IRASSI2 = 'AMNT OTHR FAM RECVD FROM SSI - IMPUTATIO'
   IIASSI2 = 'AMT OTHR FAM RECVD FROM SSI - IMPUTATION'
   IRWEL2  = 'OTHR FAM MEM RECEIVED WELFARE - IMPUTATI'
   IIWEL2  = 'OTHR FAM MEM RECVD WELFARE - IMPUTATION'
   IRAWEL2 = 'AMNT OTHR FAM RECVD FR WELFARE - IMPUT.'
   IIAWEL2 = 'AMT OTHR FAM RECVD FROM WELFARE - IMPUT.'
   IRINT2  = 'OTHR FAM RECVD INTEREST - IMPUTATION REV'
   IIINT2  = 'OTHR FAM RECVD INTEREST - IMPUTATION IND'
   IRAINT2 = 'AMNT FAM RECVD FROM INTEREST - IMPUTATIO'
   IIAINT2 = 'AMT OTHR FAM RECVD FR INTEREST - IMPUT.'
   IRCHD2  = 'OTHR FAM RECVED CHILD SUPPORT - IMPUTATI'
   IICHD2  = 'OTHR FAM RECVD FR CHILD SUPPORT - IMPUT.'
   IRACHD2 = 'AMNT OTHR FAM RECVD FR CHLD SUPRT - IMPU'
   IIACHD2 = 'AMT OTHR RECVD FR CHILD SUPPORT - IMPUT.'
   IROTH2  = 'OTHR FAM RECVD OTHR SOURCES - IMPUT. REV'
   IIOTH2  = 'OTHR FAM RECVD OTHR SOURCES - IMPUTATION'
   IRAOTH2 = 'AMNT OTHR FAM RECVD FR OTHR SRCES-IMPUT.'
   IIAOTH2 = 'AMT OTHR FAM RECVD FR OTHR SOURCS-IMPUT'
   IRFOOD  = 'ANY FAM MEM RECVD FOOD STAMP - IMPUT REV'
   IIFOOD  = 'ANY FAM MEM RECVD FOOD STMP - IMPUTATION'
   IRAFOOD = 'VALUE OF FOOD STAMP - IMPUTATION REVISED'
   IIAFOOD = 'AMT FAM RECVD FR FOOD STAMP - IMPUTATION'
   IRPEOP  = 'TOTAL # OF PEOPLE IN HOUSEHOLD-IMPUT REV'
   IRALCRC = 'ALCOHOL RECENCY - IMPUTATION REVISED'
   IIALCRC = 'ALCOHOL RECENCY - IMPUTATION INDICATOR'
   IRMJRC  = 'MARIJUANA RECENCY - IMPUTATION REVISED'
   IIMJRC  = 'MARIJUANA RECENCY - IMPUTATION INDICATOR'
   IRCOCRC = 'COCAINE RECENCY - IMPUTATION REVISED'
   IICOCRC = 'COCAINE RECENCY - IMPUTATION INDICATOR'
   IRSEDRC = 'SEDATIVES RECENCY - IMPUTATION REVISED'
   IISEDRC = 'SEDATIVES RECENCY - IMPUTATION INDICATOR'
   IRTRNRC = 'TRANQUILIZERS RECENCY-IMPUTATION REVISED'
   IITRNRC = 'TRANQUILIZERS RECENCY - IMPUTATION INDIC'
   IRSTMRC = 'STIMULANTS RECENCY - IMPUTATION REVISED'
   IISTMRC = 'STIMULANTS RECENCY-IMPUTATION INDICATOR'
   IRANLRC = 'ANALGESICS RECENCY - IMPUTATION REVISED'
   IIANLRC = 'ANALGESICS RECENCY-IMPUTATION INDICATOR'
   IRCIGRC = 'CIGARETTES RECENCY - IMPUTATION REVISED'
   IICIGRC = 'CIGARETTES RECENCY-IMPUTATION INDICATOR'
   IROTBRC = 'SMOKELESS TOBACCO RECENCY-IMPUTATION REV'
   IIOTBRC = 'SMOKELESS TOBACCO RECENCY-IMPUTATION IND'
   IRINHRC = 'INHALANTS RECENCY - IMPUTATION REVISED'
   IIINHRC = 'INHALANTS RECENCY - IMPUTATION INDICATOR'
   IRCRKRC = '''CRACK'' RECENCY - IMPUTATION REVISED'
   IICRKRC = '''CRACK'' RECENCY - IMPUTATION INDICATOR'
   IRHALRC = 'HALLUCINOGENS RECENCY-IMPUTATION REVISED'
   IIHALRC = 'HALLUCINOGENS RECENCY - IMPUTATION INDIC'
   IRHERRC = 'HEROIN RECENCY - IMPUTATION REVISED'
   IIHERRC = 'HEROIN RECENCY - IMPUTATION INDICATOR'
   IRPCPRC = 'PCP RECENCY - IMPUTATION REVISED'
   IIPCPRC = 'PCP RECENCY - IMPUTATION INDICATOR'
   IRICERC = 'ICE RECENCY - IMPUTATION REVISED'
   IIICERC = 'ICE RECENCY - IMPUTATION INDICATOR'
   IRSTRRC = 'ANABOLIC STEROIDS RECENCY-IMPUTATION REV'
   IISTRRC = 'ANABOLIC STEROIDS RECENCY-IMPUTATION IND'
   IRALCFQ = 'ALCOHOL FREQUENCY PAST  YEAR-IMPUT. REV'
   IIALCFQ = 'ALCOHOL FREQUENCY - IMPUTATION INDICATOR'
   IRMJFQ  = 'MARIJUANA FREQUENCY PAST YEAR-IMPUT. REV'
   IIMJFQ  = 'MARIJUANA FREQUENCY-IMPUTATION INDICATOR'
   IRCOCFQ = 'COCAINE FREQUENCY PAST YEAR - IMPUT. REV'
   IICOCFQ = 'COCAINE RECENCY - IMPUTATION INDICATOR'
   IRSEDFQ = 'SEDATIVES FREQUENCY - IMPUTATION REVISED'
   IISEDFQ = 'SEDATIVES FREQUENCY-IMPUTATION INDICATOR'
   IRTRNFQ = 'TRANQUILIZERS FREQUENCY - IMPUTATION REV'
   IITRNFQ = 'TRANQUILIZERS FREQUENCY - IMPUTATION IND'
   IRSTMFQ = 'STIMULANTS FREQUENCY-IMPUTATION REVISED'
   IISTMFQ = 'STIMULANTS FREQUENCY-IMPUTATION INDICATR'
   IRANLFQ = 'ANALGESICS FREQUENCY-IMPUTATION REVISED'
   IIANLFQ = 'ANALGESICS FREQUENCY-IMPUTATION INDICTAT'
   IROTBFQ = 'SMOKELESS TOBACCO FREQUENCY - IMPUT. REV'
   IIOTBFQ = 'SMOKELESS TOBACCO FREQUENCY-IMPUT. IND'
   IRINHFQ = 'INHALANTS FREQUENCY - IMPUTATION REVISED'
   IIINHFQ = 'INHALANTS FREQUENCY - IMPUTATION INDICAT'
   IRHALFQ = 'HALLUCINOGENS FREQUENCY - IMPUTATION REV'
   IIHALFQ = 'HALLUCINOGENS FREQUENCY - IMPUTATION IND'
   CATAGE  = 'AGE CATEGORY'
   CATAG2  = 'AGE CATEGORY RECODE (3 LEVELS)'
   CATAG3  = 'AGE CATEGORY RECODE (5 LEVELS)'
   RACE    = 'RACE/HISPANIC-ORIGIN RECODE'
   HISPRACE= 'RACE ETHNICITY'
   EDUCCAT2= 'EDUCATION RECODE'
   EMPSTAT2= 'EMPLOYMENT STATUS RECODE'
   INDINC  = 'ANNUAL TOTAL PERSONAL INCOME RECEIVED'
   IIINDINC= 'TOTL PERSONAL INCOME-IMPUTATION INDICAT'
   INDCAT  = 'ANNUAL TOTAL PERSONAL INC RECODE-13 CAT'
   PERINC  = 'ANNUAL TOTAL PERSONAL INCOME RECODE-5CAT'
   PERINC2 = 'ANNUAL TOTAL PERSONAL INCOME RECODE-7CAT'
   PERINC3 = 'ANNUAL TOTAL PERSONAL INCOME RECODE-8CAT'
   TOTINC  = 'ANNUAL TOTAL FAMILY INC-NOT INCLD FOOD S'
   IITOTINC= 'TOTL FAM INCOME (NOT FD STMP)-IMPUT. IND'
   TOTCAT  = 'TOTAL FAMILY INCOME - CATEGORIZED TOTINC'
   FAMINC  = 'ANNUAL TOTAL FAMILY INCOME RECODE -5 CAT'
   FAMINC2 = 'ANNUAL TOTAL FAMILY INCOME RECODE -7 CAT'
   FAMINC3 = 'ANNUAL TOTAL FAMILY INCOME RECODE -8 CAT'
   WELFARE = 'ANY FAMILY MEMBER ON WELFARE PAST MONTH'
   HALFLAG = 'HALLUCINOGENS - EVER USED'
   HALYR   = 'HALLUCINOGENS - PAST YEAR USE'
   HALMON  = 'HALLUCINOGENS - PAST MONTH USE'
   PCPFLAG = 'PCP - EVER USED'
   PCPYR   = 'PCP - PAST YEAR USE'
   PCPMON  = 'PCP - PAST MONTH USE'
   STMFLAG = 'STIMULANTS - EVER USED'
   STMYR   = 'STIMULANTS - PAST YEAR USE'
   STMMON  = 'STIMULANTS - PAST MONTH USE'
   SEDFLAG = 'SEDATIVES - EVER USED'
   SEDYR   = 'SEDATIVES - PAST YEAR USE'
   SEDMON  = 'SEDATIVES - PAST MONTH USE'
   TRQFLAG = 'TRANQUILIZERS - EVER USED'
   TRQYR   = 'TRANQUILIZERS - PAST YEAR USE'
   TRQMON  = 'TRANQUILIZERS - PAST MONTH USE'
   ANLFLAG = 'ANALGESICS - EVER USED'
   ANLYR   = 'ANALGESICS - PAST YEAR USE'
   ANLMON  = 'ANALGESICS - PAST MONTH USE'
   ALCFLAG = 'ALCOHOL - EVER USED'
   ALCYR   = 'ALCOHOL - PAST YEAR USE'
   ALCMON  = 'ALCOHOL - PAST MONTH USE'
   CIGFLAG = 'CIGARETTES - EVER USED'
   CIGYR   = 'CIGARETTES - PAST YEAR USE'
   CIGMON  = 'CIGARETTES - PAST MONTH USE'
   SMKFLAG = 'SMOKELESS TOBACCO - EVER USED'
   SMKYR   = 'SMOKELESS TOBACCO - PAST YEAR USE'
   SMKMON  = 'SMOKELESS TOBACCO - PAST MONTH USE'
   HERFLAG = 'HEROIN - EVER USED'
   HERYR   = 'HEROIN - PAST YEAR USE'
   HERMON  = 'HEROIN - PAST MONTH USE'
   STRFLAG = 'ANABOLIC STEROIDS - EVER USED'
   STRYR   = 'ANABOLIC STEROIDS - PAST YEAR USE'
   STRMON  = 'ANABOLIC STEROIDS - PAST MONTH USE'
   MRJFLAG = 'MARIJUANA - EVER USED'
   MRJYR   = 'MARIJUANA - PAST YEAR USE'
   MRJMON  = 'MARIJUANA - PAST MONTH USE'
   COCFLAG = 'COCAINE - EVER USED'
   COCYR   = 'COCAINE - PAST YEAR USE'
   COCMON  = 'COCAINE - PAST MONTH USE'
   CRKFLAG = '''CRACK'' - EVER USED'
   CRKYR   = '''CRACK'' - PAST YEAR USE'
   CRKMON  = '''CRACK'' - PAST MONTH USE'
   INHFLAG = 'INHALANTS - EVER USED'
   INHYR   = 'INHALANTS - PAST YEAR USE'
   INHMON  = 'INHALANTS - PAST MONTH USE'
   ICEFLAG = 'EVER USED ICE'
   ICEYR   = 'ICE - PAST YEAR USE'
   ICEMON  = 'ICE - PAST MONTH USE'
   NEEDLREC= 'LAST TIME USED STM,COC OR HER WTH/NEEDLE'
   NDL90REC= 'MOST RECENT TIME USED DRUG W/ A NEEDLE'
   NEDFLAG3= 'NEEDLE USE (ANY DRUG) - EVER USE'
   NEDYR3  = 'NEEDLE USE (ANY DRUG) - PAST YEAR USE'
   HALYRF  = 'HALLUCINOGENS YEAR FLAG'
   HALMONF = 'HALLUCINOGENS MONTH FLAG'
   HALWKF  = 'HALLUCINOGENS WEEK FLAG'
   HALOCCF = 'HALLUCINOGENS OCCASIONAL FLAG'
   HALDLYF = 'HALLUCINOGENS DAILY/ALMOST DAILY FLAG'
   STMYRF  = 'STIMULANTS YEAR FLAG'
   STMMONF = 'STIMULANTS MONTH FLAG'
   STMWKF  = 'STIMULANTS WEEK FLAG'
   STMOCCF = 'STIMULANTS OCCASIONAL FLAG'
   STMDLYF = 'STIMULANTS DAILY/ALMOST DAILY FLAG'
   SEDYRF  = 'SEDATIVES YEAR FLAG'
   SEDMONF = 'SEDATIVES MONTH FLAG'
   SEDWKF  = 'SEDATIVES WEEK FLAG'
   SEDOCCF = 'SEDATIVES OCCASIONAL FLAG'
   SEDDLYF = 'SEDATIVES DAILY/ALMOST DAILY FLAG'
   TRQYRF  = 'TRANQUILIZERS YEAR FLAG'
   TRQMONF = 'TRANQUILIZERS MONTH FLAG'
   TRQWKF  = 'TRANQUILIZERS WEEK FLAG'
   TRQOCCF = 'TRANQUILIZERS OCCASIONAL FLAG'
   TRQDLYF = 'TRANQUILIZERS DAILY/ALMOST DAILY FLAG'
   ANLYRF  = 'ANALGESICS YEAR FLAG'
   ANLMONF = 'ANALGESICS MONTH FLAG'
   ANLWKF  = 'ANALGESICS WEEK FLAG'
   ANLOCCF = 'ANALGESICS OCCASIONAL FLAG'
   ANLDLYF = 'ANALGESICS DAILY/ALMOST DAILY FLAG'
   ALCYRF  = 'ALCOHOL - ANY USE PAST YEAR'
   ALCMONF = 'ALCOHOL-MONTHLY OR MORE FREQ USE PAST YR'
   ALCWKF  = 'ALCOHOL-WEEKLY OR MORE FREQ USE PAST YR'
   ALCOCCF = 'ALCOHOL OCCASIONAL FLAG'
   ALCDLYF = 'ALCOHOL DAILY/ALMOST FLAG'
   SMKYRF  = 'SMOKELESS TOBACCO YEAR FLAG'
   SMKMONF = 'SMOKELESS TOBACCO MONTH FLAG'
   SMKWKF  = 'SMOKELESS TOBACCO WEEK FLAG'
   SMKOCCF = 'SMOKELESS TOBACCO OCCASIONAL FLAG'
   SMKDLYF = 'SMOKELESS TOBACCO DAILY/ALMOST FLAG'
   MRJYRF  = 'MARIJUANA - ANY USE PAST YEAR'
   MRJMONF = 'MARIJUANA - MONTHLY OR MORE FREQUENT USE'
   MRJWKF  = 'MARIJUANA - WEEKLY OR MORE FREQUENT USE'
   MRJOCCF = 'MARIJUANA OCCASIONAL FLAG'
   MRJDLYF = 'MARIJUANA DAILY/ALMOST FLAG'
   COCYRF  = 'COCAINE - ANY USE PAST YEAR'
   COCMONF = 'COCAINE-MONTHLY OR MORE FREQ USE PAST YR'
   COCWKF  = 'COCAINE-WEEKLY OR MORE FREQ USE PAST YR'
   COCOCCF = 'COCAINE OCCASIONAL FLAG'
   COCDLYF = 'COCAINE DAILY/ALMOST FLAG'
   INHYRF  = 'INHALANTS YEAR FLAG'
   INHMONF = 'INHALANTS MONTH FLAG'
   INHWKF  = 'INHALANTS WEEK FLAG'
   INHOCCF = 'INHALANTS OCCASIONAL FLAG'
   INHDLYF = 'INHALANTS DAILY/ALMOST FLAG'
   PSYFLAG2= 'ANY PSYCHOTHERAPEUTICS - EVER USED'
   PSYYR2  = 'ANY PSYCHOTHERAPEUTICS - PAST YEAR USE'
   PSYMON2 = 'ANY PSYCHOTHERAPEUTICS - PAST MONTH USE'
   SUMFLAG = 'ANY ILLICIT DRUG - EVER USED'
   SUMYR   = 'ANY ILLICIT DRUG - PAST YEAR USE'
   SUMMON  = 'ANY ILLICIT DRUG - PAST MONTH USE'
   MJOFLAG = 'MARIJUANA ONLY - EVER USED'
   MJOYR2  = 'MARIJUANA ONLY - PAST YEAR USE'
   MJOMON2 = 'MARIJUANA ONLY - PAST MONTH USE'
   IEMFLAG = 'ILLICIT DRUG EXCEPT MARIJUANA-EVER USED'
   IEMYR   = 'ILLICIT DRUG EXPT MARIJUANA-PST YR USED'
   IEMMON  = 'ILLICIT DRUG EXPT MARIJUANA-PST MTH USED'
   ANALWT  = 'ANNUAL ANALYSIS WEIGHT (WT1*...*WT11)'
   ANALWT1 = 'ANALYSIS WEIGHT FOR QUARTER 1'
   ANALWT2 = 'ANALYSIS WEIGHT FOR QUARTER 2'
   ANALWT3 = 'ANALYSIS WEIGHT FOR QUARTER 3'
   ANALWT4 = 'ANALYSIS WEIGHT FOR QUARTER 4'
   HSPHCONC= 'CATEG. % HISPANIC HH''S IN SEGMENT'
   HSPPCONC= 'CATEG. % HISPANIC POP. IN SEGMENT'
   OWNOCONC= 'CATEG. % OWNER-OCCUPIED HH''S IN SEGMENT'
   UCLASS9 = 'UNDERCLASS'
   QC06    = 'MOST RECENT TIME SMOKED A CIGARETTE'
   QC09    = 'MOST RECENT TIME USED SMOKELESS TOBACCO'
   AL02    = 'MOST RECENT TIME HAD AN ALCOHOL DRINK'
   SE04    = 'LAST TIME USED SEDATIVE FOR NONMED REAS'
   TR04    = 'LAST TIME USED TRANQUILIZER NONMED REAS'
   ST04    = 'LAST TIME USED STIMULANT FOR NONMED REAS'
   ST07    = 'LAST TIME USED AMPHETAMINES WITH NEEDLE'
   AN04    = 'LAST TIME USED ANALGESICS NONMEDL REASON'
   MJ04    = 'MOST RECENT TIME USED MARIJUANA/HASH'
   IN04    = 'MOST RECENT TIME USED INHALANT'
   CC04    = 'LAST TIME USED COCAINE (IN ANY FORM)'
   CC11    = 'LAST TIME USED COCAINE WITH A NEEDLE'
   CK01    = 'MOST RECENT TIME USED ''CRACK'''
   LS05    = 'MOST RECENT TIME USED HALLUCINOGENS'
   LS08    = 'MOST RECENT TIME USED PCP'
   HE04    = 'MOST RECENT TIME USED HEROIN'
   HE07    = 'LAST TIME USED HEROIN WITH A NEEDLE'
   ND02    = 'LAST TIME USED ANY DRUG WITH A NEEDLE'
   SP04    = 'MOST RECENT TIME USED ''ICE'''
   SP08    = 'MOST RECENT TIME USED ANABOLIC STEROIDS'
   MJTOT2  = '# TIMES USED MARIJUANA IN LIFE'
   COCTOT2 = '# TIMES USED COCAINE IN LIFE'
   MJTOT3  = '# TIMES USED MARIJUANA IN LIFE'
   COCTOT3 = '# TIMES USED COCAINE IN LIFE'
   MJDY30A2= '# DAYS USED MARIJUANA IN PAST 30'
   ALCDAYS2= '# DAYS DRANK ALCOHOL IN PAST 30'
   MRJMON2 = 'MARIJUANA - PAST MONTH USE'
   ALCMON2 = 'ALCOHOL - PAST MONTH USE'
   CIGMON2 = 'CIGARETTES - PAST MONTH USE'
   LSD2    = 'EVER USED LSD'
   PEYOTE2 = 'EVER USED PEYOTE'
   MESC2   = 'EVER USED MESCALINE'
   PSILCY2 = 'EVER USED PSILOCYBIN (MUSHROOMS)'
   ECSTASY2= 'EVER USED ECSTASY (MDMA)'
   GAS2    = 'EVER INHALED GASOLINE OR LIGHTER FLUIDS'
   LGAS2   = 'EVER INHALED LIGHTER GASES'
   SPPAINT2= 'EVER INHALED SPRAY PAINTS'
   AEROS2  = 'EVER INHALED OTHER AEROSOL SPRAYS'
   GLUE2   = 'EVER INHALED GLUE'
   SOLVENT2= 'EVER INHALED SOLVENTS'
   AMYLNIT2= 'EVER INHALED AMYL NITRITE'
   ETHER2  = 'EVER INHALED ANESTHETICS'
   NITOXID2= 'EVER INHALED NITROUS OXIDE'
   CLEFLU2 = 'EVER INHALED CLEANING FLUIDS'
   COCSNIF2= 'SNIFFED COCAINE PAST 12 MONTHS'
   FREEBAS2= 'FREE-BASED COCAINE PAST 12 MONTHS'
   COCSWAL2= 'SWALLOWED COCAINE PAST 12 MONTHS'
   COCIV2  = 'INJECT COCAINE PAST 12 MONTHS'
   MJDY30A3= '# DAYS USED MARIJUANA IN PAST 30'
   ALCDAYS3= '# DAYS DRANK ALCOHOL IN PAST 30'
   DRINKER2= 'DRANK ALCOHOL - PST 3O DAYS'
   HVYDRK2 = 'DRANK ALCOHOL HEAVILY-PST 30 DAYS'
   AVCIG2  = '# CIG. SMOKED PER DAY LAST 30'
   RACESEX = 'RACE AND SEX COMBINED'
   NOTMARJ = 'DRUG USE OTHER THAN MARIJUANA-PAST MONTH'
   COCWAY2 = 'OTHER USE COCAINE PAST 12 MONTHS'
   RACESEX2= 'RACE AND SEX COMBINED - ADDITIONAL VAR'
   IRCDCIG = 'LOGICALLY IMPUTED CDCIG'
   IRCDALC = 'LOGICALLY IMPUTED CDALC'
   IRCDMJ  = 'LOGICALLY IMPUTED CDMJ'
   IRCDCOC = 'LOGICALLY IMPUTED CDCOC'
   IREFCIG = 'LOGICALLY IMPUTED EFCIG'
   IREFALC = 'LOGICALLY IMPUTED EFALC'
   IREFMJ  = 'LOGICALLY IMPUTED EFMJ'
   IREFCOC = 'LOGICALLY IMPUTED EFCOC'
   IRUDCIG = 'LOGICALLY IMPUTED UDCIG'
   IRUDALC = 'LOGICALLY IMPUTED UDALC'
   IRUDMJ  = 'LOGICALLY IMPUTED UDMJ'
   IRUDCOC = 'LOGICALLY IMPUTED UDCOC'
   IRDPCIG = 'LOGICALLY IMPUTED DPCIG'
   IRDPALC = 'LOGICALLY IMPUTED DPALC'
   IRDPMJ  = 'LOGICALLY IMPUTED DPMJ'
   IRDPCOC = 'LOGICALLY IMPUTED DPCOC'
   IRWSCIG = 'LOGICALLY IMPUTED WSCIG'
   IRWSALC = 'LOGICALLY IMPUTED WSALC'
   IRWSMJ  = 'LOGICALLY IMPUTED WSMJ'
   IRWSCOC = 'LOGICALLY IMPUTED WSCOC'
   AVCIG3  = 'RECODED AVCIG'
   ALCPROBS= 'ANY PROBS DUE TO ALCOHOL'
   MJPROBS = 'ANY PROBS DUE TO MARIJUANA'
   COCPROBS= 'ANY PROBS DUE TO COCAINE'
   CIGPROBS= 'ANY PROBS DUE TO CIGARETTES'
   IRALCAGG= 'LOGICALLY IMPUTED ALCAGGR'
   IRALCARG= 'LOGICALLY IMPUTED ALCARGUM'
   IRALCABS= 'LOGICALLY IMPUTED ALCABSNT'
   IRALCHIG= 'LOGICALLY IMPUTED ALCHIGH'
   IRALCJOB= 'LOGICALLY IMPUTED ALCJOB'
   IRALCMAT= 'LOGICALLY IMPUTED ALCMATCD'
   IRALCREL= 'LOGICALLY IMPUTED ALCRELCD'
   IRALCFRD= 'LOGICALLY IMPUTED ALCFRDCD'
   IRALCTOS= 'LOGICALLY IMPUTED ALCTOSS'
   IRALCHOL= 'LOGICALLY IMPUTED ALCHOLIC'
   IRALCDRU= 'LOGICALLY IMPUTED ALCDRUNK'
   IRALCINT= 'LOGICALLY IMPUTED ALCINTOX'
   IRALCREM= 'LOGICALLY IMPUTED ALCREM'
   IRALCQUI= 'LOGICALLY IMPUTED ALCQUICK'
   IRALCMOR= 'LOGICALLY IMPUTED ALCMORN'
   IRALCSHO= 'LOGICALLY IMPUTED ALCSHOOK'
   IRALCALO= 'LOGICALLY IMPUTED ALCALONE'
   IRALCBRK= 'LOGICALLY IMPUTED ALCBRKPM'
   IRNOBOOZ= 'LOGICALLY IMPUTED NOBOOZYR'
   ANYALC  = 'ANY PROBS W/ALCOHOL PAST YR'
   THREALC = 'GE 3 PROBS W/ALCOHOL PAST YR'
   DRUNKYR2= '# TIMES DRUNK ON ALC PST 12 MON - RECODE'
   IRDEP   = 'IMPUTED DRDEPRSS'
   IRARG   = 'IMPUTED DRARGUM'
   IRALN   = 'IMPUTED DRALONE'
   IRANX   = 'IMPUTED DRANX'
   IRHLT   = 'IMPUTED DRHEALTH'
   IRNTK   = 'IMPUTED DRNTHINK'
   IRUPS   = 'IMPUTED DRUPSET'
   IRLSW   = 'IMPUTED DRLSWORK'
   IRSSP   = 'IMPUTED DRSUSPIC'
   IRCPE   = 'IMPUTED DRCOPE'
   IREMG   = 'IMPUTED DREMGMED'
   IRDEP1  = 'IMPUTED DEPDRG1A'
   IRDEP2  = 'IMPUTED DEPDRG2A'
   IRDEP3  = 'IMPUTED DEPDRG3A'
   IRDEP4  = 'IMPUTED DEPDRG4A'
   IRDEP5  = 'IMPUTED DEPDRG5A'
   IRARG1  = 'IMPUTED ARGDRG1A'
   IRARG2  = 'IMPUTED ARGDRG2A'
   IRARG3  = 'IMPUTED ARGDRG3A'
   IRARG4  = 'IMPUTED ARGDRG4A'
   IRARG5  = 'IMPUTED ARGDRG5A'
   IRALN1  = 'IMPUTED ALNDRG1A'
   IRALN2  = 'IMPUTED ALNDRG2A'
   IRALN3  = 'IMPUTED ALNDRG3A'
   IRALN4  = 'IMPUTED ALNDRG4A'
   IRALN5  = 'IMPUTED ALNDRG5A'
   IRANX1  = 'IMPUTED ANXDRG1A'
   IRANX2  = 'IMPUTED ANXDRG2A'
   IRANX3  = 'IMPUTED ANXDRG3A'
   IRANX4  = 'IMPUTED ANXDRG4A'
   IRANX5  = 'IMPUTED ANXDRG5A'
   IRHLT1  = 'IMPUTED HLTDRG1A'
   IRHLT2  = 'IMPUTED HLTDRG2A'
   IRHLT3  = 'IMPUTED HLTDRG3A'
   IRHLT4  = 'IMPUTED HLTDRG4A'
   IRHLT5  = 'IMPUTED HLTDRG5A'
   IRNTK1  = 'IMPUTED NTKDRG1A'
   IRNTK2  = 'IMPUTED NTKDRG2A'
   IRNTK3  = 'IMPUTED NTKDRG3A'
   IRNTK4  = 'IMPUTED NTKDRG4A'
   IRNTK5  = 'IMPUTED NTKDRG5A'
   IRUPS1  = 'IMPUTED UPSDRG1A'
   IRUPS2  = 'IMPUTED UPSDRG2A'
   IRUPS3  = 'IMPUTED UPSDRG3A'
   IRUPS4  = 'IMPUTED UPSDRG4A'
   IRUPS5  = 'IMPUTED UPSDRG5A'
   IRLSW1  = 'IMPUTED LSWDRG1A'
   IRLSW2  = 'IMPUTED LSWDRG2A'
   IRLSW3  = 'IMPUTED LSWDRG3A'
   IRLSW4  = 'IMPUTED LSWDRG4A'
   IRLSW5  = 'IMPUTED LSWDRG5A'
   IRSSP1  = 'IMPUTED SSPDRG1A'
   IRSSP2  = 'IMPUTED SSPDRG2A'
   IRSSP3  = 'IMPUTED SSPDRG3A'
   IRSSP4  = 'IMPUTED SSPDRG4A'
   IRSSP5  = 'IMPUTED SSPDRG5A'
   IRCPE1  = 'IMPUTED CPEDRG1A'
   IRCPE2  = 'IMPUTED CPEDRG2A'
   IRCPE3  = 'IMPUTED CPEDRG3A'
   IRCPE4  = 'IMPUTED CPEDRG4A'
   IRCPE5  = 'IMPUTED CPEDRG5A'
   IREMG1  = 'IMPUTED EMDRG1A'
   IREMG2  = 'IMPUTED EMDRG2A'
   IREMG3  = 'IMPUTED EMDRG3A'
   IREMG4  = 'IMPUTED EMDRG4A'
   IREMG5  = 'IMPUTED EMDRG5A'
   IRAS13  = 'LOGICALLY IMPUTED AS13NON2'
   DEPCIG2 = 'DEP PROB DUE TO CIG USE'
   DEPALC2 = 'DEP PROB DUE TO ALC USE'
   DEPMRJ2 = 'DEP PROB DUE TO MRJ USE'
   DEPCOC2 = 'DEP PROB DUE TO COC USE'
   ARGCIG2 = 'ARG PROB DUE TO CIG USE'
   ARGALC2 = 'ARG PROB DUE TO ALC USE'
   ARGMRJ2 = 'ARG PROB DUE TO MRJ USE'
   ARGCOC2 = 'ARG PROB DUE TO COC USE'
   ALNCIG2 = 'ALN PROB DUE TO CIG USE'
   ALNALC2 = 'ALN PROB DUE TO ALC USE'
   ALNMRJ2 = 'ALN PROB DUE TO MRJ USE'
   ALNCOC2 = 'ALN PROB DUE TO COC USE'
   ANXCIG2 = 'ANX PROB DUE TO CIG USE'
   ANXALC2 = 'ANX PROB DUE TO ALC USE'
   ANXMRJ2 = 'ANX PROB DUE TO MRJ USE'
   ANXCOC2 = 'ANX PROB DUE TO COC USE'
   HLTCIG2 = 'HLT PROB DUE TO CIG USE'
   HLTALC2 = 'HLT PROB DUE TO ALC USE'
   HLTMRJ2 = 'HLT PROB DUE TO MRJ USE'
   HLTCOC2 = 'HLT PROB DUE TO COC USE'
   NTKCIG2 = 'NTK PROB DUE TO CIG USE'
   NTKALC2 = 'NTK PROB DUE TO ALC USE'
   NTKMRJ2 = 'NTK PROB DUE TO MRJ USE'
   NTKCOC2 = 'NTK PROB DUE TO COC USE'
   UPSCIG2 = 'UPS PROB DUE TO CIG USE'
   UPSALC2 = 'UPS PROB DUE TO ALC USE'
   UPSMRJ2 = 'UPS PROB DUE TO MRJ USE'
   UPSCOC2 = 'UPS PROB DUE TO COC USE'
   LSWCIG2 = 'LSW PROB DUE TO CIG USE'
   LSWALC2 = 'LSW PROB DUE TO ALC USE'
   LSWMRJ2 = 'LSW PROB DUE TO MRJ USE'
   LSWCOC2 = 'LSW PROB DUE TO COC USE'
   SSPCIG2 = 'SSP PROB DUE TO CIG USE'
   SSPALC2 = 'SSP PROB DUE TO ALC USE'
   SSPMRJ2 = 'SSP PROB DUE TO MRJ USE'
   SSPCOC2 = 'SSP PROB DUE TO COC USE'
   CPECIG2 = 'CPE PROB DUE TO CIG USE'
   CPEALC2 = 'CPE PROB DUE TO ALC USE'
   CPEMRJ2 = 'CPE PROB DUE TO MRJ USE'
   CPECOC2 = 'CPE PROB DUE TO COC USE'
   EMCIG2  = 'EM  PROB DUE TO CIG USE'
   EMALC2  = 'EM  PROB DUE TO ALC USE'
   EMMRJ2  = 'EM  PROB DUE TO MRJ USE'
   EMCOC2  = 'EM  PROB DUE TO COC USE'
   PRB1CIG = 'CIG USER WITH 1 OR MORE PROBS DUE TO CIG'
   PRB1ALC = 'ALC USER WITH 1 OR MORE PROBS DUE TO ALC'
   PRB1MRJ = 'MRJ USER WITH 1 OR MORE PROBS DUE TO MRJ'
   PRB1COC = 'COC USER WITH 1 OR MORE PROBS DUE TO COC'
   PRB2CIG = 'CIG USER WITH 2 OR MORE PROBS DUE TO CIG'
   PRB2ALC = 'ALC USER WITH 2 OR MORE PROBS DUE TO ALC'
   PRB2MRJ = 'MRJ USER WITH 2 OR MORE PROBS DUE TO MRJ'
   PRB2COC = 'COC USER WITH 2 OR MORE PROBS DUE TO COC'
   PRB3CIG = 'CIG USER WITH 3 OR MORE PROBS DUE TO CIG'
   PRB3ALC = 'ALC USER WITH 3 OR MORE PROBS DUE TO ALC'
   PRB3MRJ = 'MRJ USER WITH 3 OR MORE PROBS DUE TO MRJ'
   PRB3COC = 'COC USER WITH 3 OR MORE PROBS DUE TO COC'
   ANYPROB = 'ANY OF THE 11 PROBS ON DRUG SHEET #16'
   TWOPROB = 'GE 2 OF THE 11 PROBS ON DRUG SHEET #16'
   THREPROB= 'GE 3 OF THE 11 PROBS ON DRUG SHEET #16'
   ALCONLYL= 'ONLY ALCOHOL - EVER USED'
   ALCONLYY= 'ONLY ALCOHOL - PAST YEAR USE'
   ALCONLYM= 'ONLY ALCOHOL - PAST MONTH USE'
   ILLONLYL= 'ONLY ILLICIT DRUGS - EVER USED'
   ILLONLYY= 'ONLY ILLICIT DRUGS - PAST YEAR USE'
   ILLONLYM= 'ONLY ILLICIT DRUGS - PAST MONTH USE'
   MRJONLYL= 'ONLY MARIJUANA - EVER USED'
   MRJONLYY= 'ONLY MARIJUANA - PAST YEAR USE'
   MRJONLYM= 'ONLY MARIJUANA - PAST MONTH USE'
   PSYONLYL= 'ONLY PSYCHOTHERAPEUTICS - EVER USED'
   PSYONLYY= 'ONLY PSYCHOTHERAPEUTICS - PAST YR USE'
   PSYONLYM= 'ONLY PSYCHOTHEARPEUTICS - PAST MON USE'
   OTHONLYL= 'ONLY OTHER DRUG COMB. - EVER USED'
   OTHONLYY= 'ONLY OTHER DRUG COMB. - PAST YEAR USE'
   OTHONLYM= 'ONLY OTHER DRUG COMB. - PAST MONTH USE'
   ALCILLL = 'ALCOHOL & ILLICIT DRUGS - EVER USED'
   ALCILLY = 'ALCOHOL & ILLICIT DRUGS - PAST YEAR USE'
   ALCILLM = 'ALCOHOL & ILLICIT DRUGS - PAST MONTH USE'
   ALCMRJL = 'ALCOHOL & MARIJUANA - EVER USED'
   ALCMRJY = 'ALCOHOL & MARIJUANA - PAST YEAR USE'
   ALCMRJM = 'ALCOHOL & MARIJUANA - PAST MONTH USE'
   ALCPSYL = 'ALCOHOL & PSYCHOTHERAPEUTICS - EVER USED'
   ALCPSYY = 'ALCOHOL & PSYCHOTHERAPEUTICS - PAST YR'
   ALCPSYM = 'ALCOHOL & PSYCHOTHEARPEUTICS - PAST MON'
   ALCOTHL = 'ALCOHOL & OTHER DRUG COMB. - EVER USED'
   ALCOTHY = 'ALCOHOL & OTHER DRUG COMB. - PAST YR'
   ALCOTHM = 'ALCOHOL & OTHER DRUG COMB. - PAST MON'
   SUB1LIF = 'USED ONLY 1 SUBSTANCE - EVER'
   SUB2LIF = 'USED ONLY 2 SUBSTANCES - EVER'
   SUB3LIF = 'USED 3 OR MORE SUBSTANCES - EVER'
   SUB1YR  = 'USED ONLY 1 SUBSTANCE - PAST YEAR'
   SUB2YR  = 'USED ONLY 2 SUBSTANCES - PAST YEAR'
   SUB3YR  = 'USE 3 OR MORE SUBSTANCES - PAST YEAR'
   SUB1MON = 'USED ONLY 1 SUBSTANCE - PAST MONTH'
   SUB2MON = 'USED ONLY 2 SBUSTANCES - PAST MONTH'
   SUB3MON = 'USED 3 OR MORE SUBSTANCES - PAST MONTH'
   CHANCMJ2= 'OPPORTUNITY TO USE MARIJUANA - REVISED'
   CHANCOC2= 'OPPORTUNITY TO USE COCAINE - REVISED'
   CHANHAL2= 'OPPORTUNITY TO USE HALLUCINOGENS - REVSD'
   CHANHER2= 'OPPORTUNITY TO USE HEROIN - REVISED'
   TRMTHLP2= 'TREATMENT RECEIVED FOR DRUGS - RECODE'
   DRNKHLP2= 'TREATMENT RECEIVED FOR ALCOHOL - RECODE'
   DRALHELP= 'TREATMENT RECEIVED FOR DRUGS OR ALCOHOL'
   RURORURB= 'RURAL OR URBAN SEGMENT'
   PBLACKHH= 'CATEG. NONHISP. BLACK HH IN SEGMENT'
   PBLACKP = 'CATEG. NONHISP. BLACK POP. IN SEGMENT'
   PPOVERTY= 'CATEG. FAMILIES BELOW POVERTY LEVEL'
   POWNED  = 'CATEG. PERCENT OF HOUSING OWNED'
   PRENTED = 'CATEG. PERCENT OF HOUSING RENTED'
   OWNEDAVE= 'CATEG. MEDIAN VALUE OF OWNED HOMES'
   RENTAVE = 'CATEG. MEDIAN RENT FOR RENTAL UNITS'
   CHAGE1  = 'NUMBER OF CHILDREN AGES 0 TO 2'
   CHAGE2  = 'NUMBER OF CHILDREN AGES 3 TO 5'
   CHAGE3  = 'NUMBER OF CHILDREN AGES 6 TO 8'
   CHAGE4  = 'NUMBER OF CHILDREN AGES 9 TO 11'
   CHAGE5  = 'NUMBER OF CHILDREN AGES 12 TO 14'
   CHAGE6  = 'NUMBER OF CHILDREN AGES 15 TO 17'
   CHAGE7  = 'NUMBER OF CHILDREN AGES 18 TO 24'
   CHAGE8  = 'NUMBER OF CHILDREN AGES 25 TO 34'
   CHAGE9  = 'NUMBER OF CHILDREN AGES 35+'
   CHAGE10 = 'NUMBER OF CHILDREN W/AGES UNKNOWN OR UNS'
   IRKIDS  = 'TOT # OF CHILDREN (UNDER 12 YEARS) IN HH'
   CWEOCC2 = 'KIND OF WORK OF CHIEF WAGE EARNER'
   ROCCUP2 = 'KIND OF WORK OF RESPONDENT'
   CWEBUS2 = 'BUSINESS OR INDUSTRY OF CHIEF WAGE EARNR'
   BUSINES2= 'BUSINESS OR INDUSTRY OF RESPONDENT'
   INTMONTH= 'INTERVIEW MONTH'
   EHOUR   = 'ENDING HOUR OF INTERVIEW'
   EMIN    = 'ENDING MINUTE OF INTERVIEW'
        ;


* USER-DEFINED MISSING VALUES RECODE TO SAS SYSMIS;

/*
   IF (CIGTRY >= 981) THEN CIGTRY = .;
   IF (CIG5PK >= 81) THEN CIG5PK = .;
   IF (CIGAGE >= 981) THEN CIGAGE = .;
   IF (CIGYRS >= 981) THEN CIGYRS = .;
   IF (PACKS >= 81) THEN PACKS = .;
   IF (CIGREC >= 81) THEN CIGREC = .;
   IF (AVCIG >= 81) THEN AVCIG = .;
   IF (CIGTIME >= 9981) THEN CIGTIME = .;
   IF (SNUFREC >= 81) THEN SNUFREC = .;
   IF (OTHTOB >= 81) THEN OTHTOB = .;
   IF (ALCTRY >= 981) THEN ALCTRY = .;
   IF (ALCREC >= 81) THEN ALCREC = .;
   IF (ALCAGE >= 981) THEN ALCAGE = .;
   IF (ALCDAYS >= 81) THEN ALCDAYS = .;
   IF (NODR30A >= 81) THEN NODR30A = .;
   IF (DR5DAY >= 81) THEN DR5DAY = .;
   IF (MODR30A >= 81) THEN MODR30A = .;
   IF (MODR30DY >= 81) THEN MODR30DY = .;
   IF (ALCPAT >= 81) THEN ALCPAT = .;
   IF (DRUNKYR >= 81) THEN DRUNKYR = .;
   IF (ALCBEER >= 81) THEN ALCBEER = .;
   IF (ALCWINE >= 81) THEN ALCWINE = .;
   IF (ALCLIQR >= 81) THEN ALCLIQR = .;
   IF (ALCVARY >= 81) THEN ALCVARY = .;
   IF (NOSEDAT >= 81) THEN NOSEDAT = .;
   IF (BUTISOL >= 81) THEN BUTISOL = .;
   IF (BUTICAPS >= 81) THEN BUTICAPS = .;
   IF (AMYTAL >= 81) THEN AMYTAL = .;
   IF (MEBARAL >= 81) THEN MEBARAL = .;
   IF (PLACIDYL >= 81) THEN PLACIDYL = .;
   IF (DORIDEN >= 81) THEN DORIDEN = .;
   IF (NOLUDAR >= 81) THEN NOLUDAR = .;
   IF (NEMBUTAL >= 81) THEN NEMBUTAL = .;
   IF (SECONAL >= 81) THEN SECONAL = .;
   IF (TUINAL >= 81) THEN TUINAL = .;
   IF (DALMANE >= 81) THEN DALMANE = .;
   IF (RESTORIL >= 81) THEN RESTORIL = .;
   IF (HALCION >= 81) THEN HALCION = .;
   IF (AMOBARB >= 81) THEN AMOBARB = .;
   IF (PHENOBAR >= 81) THEN PHENOBAR = .;
   IF (METHAQ >= 81) THEN METHAQ = .;
   IF (CHHYD >= 81) THEN CHHYD = .;
   IF (PENTOB >= 81) THEN PENTOB = .;
   IF (SECOB >= 81) THEN SECOB = .;
   IF (SEDNEWA >= 981) THEN SEDNEWA = .;
   IF (SEDNEWB >= 981) THEN SEDNEWB = .;
   IF (SEDNEWC >= 981) THEN SEDNEWC = .;
   IF (SEDNEWD >= 981) THEN SEDNEWD = .;
   IF (SEDNEWE >= 981) THEN SEDNEWE = .;
   IF (SEDNOSP >= 81) THEN SEDNOSP = .;
   IF (SEDDKNAM >= 81) THEN SEDDKNAM = .;
   IF (SEDAGE >= 981) THEN SEDAGE = .;
   IF (SEDTOT >= 81) THEN SEDTOT = .;
   IF (SEDREC >= 81) THEN SEDREC = .;
   IF (SEDYRFRQ >= 81) THEN SEDYRFRQ = .;
   IF (TRNREAD >= 81) THEN TRNREAD = .;
   IF (NOTRANQ >= 81) THEN NOTRANQ = .;
   IF (VALIUM >= 81) THEN VALIUM = .;
   IF (LIBRIUM >= 81) THEN LIBRIUM = .;
   IF (LIMBTROL >= 81) THEN LIMBTROL = .;
   IF (MENRIUM >= 81) THEN MENRIUM = .;
   IF (SERAX >= 81) THEN SERAX = .;
   IF (TRANXENE >= 81) THEN TRANXENE = .;
   IF (ATIVAN >= 81) THEN ATIVAN = .;
   IF (CENTRAX >= 81) THEN CENTRAX = .;
   IF (XANAX >= 81) THEN XANAX = .;
   IF (PAXIPAM >= 81) THEN PAXIPAM = .;
   IF (BUSPAR >= 81) THEN BUSPAR = .;
   IF (MILTOWN >= 81) THEN MILTOWN = .;
   IF (EQUANIL >= 81) THEN EQUANIL = .;
   IF (DEPROL >= 81) THEN DEPROL = .;
   IF (VISTAR >= 81) THEN VISTAR = .;
   IF (ATARAX >= 81) THEN ATARAX = .;
   IF (DURRAX >= 81) THEN DURRAX = .;
   IF (DIAZEPAM >= 81) THEN DIAZEPAM = .;
   IF (SKLY >= 81) THEN SKLY = .;
   IF (MEPROB >= 81) THEN MEPROB = .;
   IF (TRNEWA >= 981) THEN TRNEWA = .;
   IF (TRNEWB >= 981) THEN TRNEWB = .;
   IF (TRNEWC >= 981) THEN TRNEWC = .;
   IF (TRNEWD >= 981) THEN TRNEWD = .;
   IF (TRNEWE >= 981) THEN TRNEWE = .;
   IF (TRNOSP >= 81) THEN TRNOSP = .;
   IF (TRDKNAM >= 81) THEN TRDKNAM = .;
   IF (TRANAGE >= 981) THEN TRANAGE = .;
   IF (TRANTOT >= 81) THEN TRANTOT = .;
   IF (TRANREC >= 81) THEN TRANREC = .;
   IF (TRNYRFRQ >= 81) THEN TRNYRFRQ = .;
   IF (STMREAD >= 81) THEN STMREAD = .;
   IF (NOSTIMS >= 81) THEN NOSTIMS = .;
   IF (DEXED >= 81) THEN DEXED = .;
   IF (DEXAMYL >= 81) THEN DEXAMYL = .;
   IF (ESKAT >= 81) THEN ESKAT = .;
   IF (BENZ >= 81) THEN BENZ = .;
   IF (BIPHET >= 81) THEN BIPHET = .;
   IF (DESOXYN >= 81) THEN DESOXYN = .;
   IF (TENUATE >= 81) THEN TENUATE = .;
   IF (TEPANIL >= 81) THEN TEPANIL = .;
   IF (DIDREX >= 81) THEN DIDREX = .;
   IF (PLEGINE >= 81) THEN PLEGINE = .;
   IF (PRELUDIN >= 81) THEN PRELUDIN = .;
   IF (IONAMIN >= 81) THEN IONAMIN = .;
   IF (FASTIN >= 81) THEN FASTIN = .;
   IF (PONDIMIN >= 81) THEN PONDIMIN = .;
   IF (VORANIL >= 81) THEN VORANIL = .;
   IF (SANOREX >= 81) THEN SANOREX = .;
   IF (MAZANOR >= 81) THEN MAZANOR = .;
   IF (RITALIN >= 81) THEN RITALIN = .;
   IF (CYLERT >= 81) THEN CYLERT = .;
   IF (DETAMP >= 81) THEN DETAMP = .;
   IF (METHI >= 81) THEN METHI = .;
   IF (METHAMP >= 81) THEN METHAMP = .;
   IF (OBLA >= 81) THEN OBLA = .;
   IF (STIMNEWA >= 981) THEN STIMNEWA = .;
   IF (STIMNEWB >= 981) THEN STIMNEWB = .;
   IF (STIMNEWC >= 981) THEN STIMNEWC = .;
   IF (STIMNEWD >= 981) THEN STIMNEWD = .;
   IF (STIMNEWE >= 981) THEN STIMNEWE = .;
   IF (STIMNOSP >= 81) THEN STIMNOSP = .;
   IF (STMDKNAM >= 81) THEN STMDKNAM = .;
   IF (STIMAGE >= 981) THEN STIMAGE = .;
   IF (STIMTOT >= 81) THEN STIMTOT = .;
   IF (STIMREC >= 81) THEN STIMREC = .;
   IF (STMYRFRQ >= 81) THEN STMYRFRQ = .;
   IF (STNEEDLE >= 81) THEN STNEEDLE = .;
   IF (STNDLREC >= 81) THEN STNDLREC = .;
   IF (ANLREAD >= 81) THEN ANLREAD = .;
   IF (ANALNONE >= 81) THEN ANALNONE = .;
   IF (DARVON >= 81) THEN DARVON = .;
   IF (DOLENE >= 81) THEN DOLENE = .;
   IF (SK65A >= 81) THEN SK65A = .;
   IF (WYGESIC >= 81) THEN WYGESIC = .;
   IF (LEVODRO >= 81) THEN LEVODRO = .;
   IF (PERCODAN >= 81) THEN PERCODAN = .;
   IF (DEMEROL >= 81) THEN DEMEROL = .;
   IF (DILAUD >= 81) THEN DILAUD = .;
   IF (TYLCOD >= 81) THEN TYLCOD = .;
   IF (PHENCOD >= 81) THEN PHENCOD = .;
   IF (TALWIN >= 81) THEN TALWIN = .;
   IF (TALWINNX >= 81) THEN TALWINNX = .;
   IF (TALACEN >= 81) THEN TALACEN = .;
   IF (PROPOXY >= 81) THEN PROPOXY = .;
   IF (CODEINE >= 81) THEN CODEINE = .;
   IF (ANILERID >= 81) THEN ANILERID = .;
   IF (MORPHINE >= 81) THEN MORPHINE = .;
   IF (METHDON >= 81) THEN METHDON = .;
   IF (STADOL >= 81) THEN STADOL = .;
   IF (ANALNEWA >= 981) THEN ANALNEWA = .;
   IF (ANALNEWB >= 981) THEN ANALNEWB = .;
   IF (ANALNEWC >= 981) THEN ANALNEWC = .;
   IF (ANALNEWD >= 981) THEN ANALNEWD = .;
   IF (ANALNEWE >= 981) THEN ANALNEWE = .;
   IF (ANLNOSP >= 81) THEN ANLNOSP = .;
   IF (ANLDKNAM >= 81) THEN ANLDKNAM = .;
   IF (ANALAGE >= 981) THEN ANALAGE = .;
   IF (ANALTOT >= 81) THEN ANALTOT = .;
   IF (ANALREC >= 81) THEN ANALREC = .;
   IF (ANLYRFRQ >= 81) THEN ANLYRFRQ = .;
   IF (MJOPP >= 981) THEN MJOPP = .;
   IF (MJAGE >= 981) THEN MJAGE = .;
   IF (MJTOT >= 81) THEN MJTOT = .;
   IF (MJREC >= 81) THEN MJREC = .;
   IF (MJDAY30A >= 81) THEN MJDAY30A = .;
   IF (MJAV30A >= 81) THEN MJAV30A = .;
   IF (MJAV30B >= 81) THEN MJAV30B = .;
   IF (MJAMT30A >= 81) THEN MJAMT30A = .;
   IF (MJFRIEND >= 81) THEN MJFRIEND = .;
   IF (MJDEALER >= 81) THEN MJDEALER = .;
   IF (MJOTHSHR >= 81) THEN MJOTHSHR = .;
   IF (MJGIVEN >= 81) THEN MJGIVEN = .;
   IF (MJTRGOOD >= 81) THEN MJTRGOOD = .;
   IF (MJTRSERV >= 81) THEN MJTRSERV = .;
   IF (MJTRICK >= 81) THEN MJTRICK = .;
   IF (MJOBTNON >= 81) THEN MJOBTNON = .;
   IF (MJBUCK >= 9981.0) THEN MJBUCK = .;
   IF (MJYRFREQ >= 81) THEN MJYRFREQ = .;
   IF (MJJOINT >= 81) THEN MJJOINT = .;
   IF (MJPIPE >= 81) THEN MJPIPE = .;
   IF (MJBAKE >= 81) THEN MJBAKE = .;
   IF (MJCHEW >= 81) THEN MJCHEW = .;
   IF (MJWAY >= 81) THEN MJWAY = .;
   IF (MJLFDALY >= 81) THEN MJLFDALY = .;
   IF (INHREAD >= 81) THEN INHREAD = .;
   IF (GAS >= 81) THEN GAS = .;
   IF (LGAS >= 81) THEN LGAS = .;
   IF (SPPAINT >= 81) THEN SPPAINT = .;
   IF (AEROS >= 81) THEN AEROS = .;
   IF (GLUE >= 81) THEN GLUE = .;
   IF (SOLVENT >= 81) THEN SOLVENT = .;
   IF (AMYLNIT >= 81) THEN AMYLNIT = .;
   IF (ETHER >= 81) THEN ETHER = .;
   IF (NITOXID >= 81) THEN NITOXID = .;
   IF (CLEFLU >= 81) THEN CLEFLU = .;
   IF (INHNEWA >= 981) THEN INHNEWA = .;
   IF (INHNEWB >= 981) THEN INHNEWB = .;
   IF (INHNEWC >= 981) THEN INHNEWC = .;
   IF (INHNEWD >= 981) THEN INHNEWD = .;
   IF (INHNEWE >= 981) THEN INHNEWE = .;
   IF (INHNOSP >= 81) THEN INHNOSP = .;
   IF (INHDKNAM >= 81) THEN INHDKNAM = .;
   IF (INHAGE >= 981) THEN INHAGE = .;
   IF (INHTOT >= 81) THEN INHTOT = .;
   IF (INHREC >= 81) THEN INHREC = .;
   IF (GAS30A >= 81) THEN GAS30A = .;
   IF (LGAS30A >= 81) THEN LGAS30A = .;
   IF (SPPAN30A >= 81) THEN SPPAN30A = .;
   IF (AEROS30A >= 81) THEN AEROS30A = .;
   IF (GLUE30A >= 81) THEN GLUE30A = .;
   IF (SOLVN30A >= 81) THEN SOLVN30A = .;
   IF (AMLNT30A >= 81) THEN AMLNT30A = .;
   IF (ETHER30A >= 81) THEN ETHER30A = .;
   IF (NOX30A >= 81) THEN NOX30A = .;
   IF (CLFL30A >= 81) THEN CLFL30A = .;
   IF (INNEW30A >= 981) THEN INNEW30A = .;
   IF (INNEW30B >= 981) THEN INNEW30B = .;
   IF (INNEW30C >= 981) THEN INNEW30C = .;
   IF (INNEW30D >= 981) THEN INNEW30D = .;
   IF (INNEW30E >= 981) THEN INNEW30E = .;
   IF (IN30NOSP >= 81) THEN IN30NOSP = .;
   IF (INH30NO >= 81) THEN INH30NO = .;
   IF (INHDY30A >= 81) THEN INHDY30A = .;
   IF (INHYRFRQ >= 81) THEN INHYRFRQ = .;
   IF (INHPO >= 81) THEN INHPO = .;
   IF (INHQNC1 >= 81) THEN INHQNC1 = .;
   IF (INHQNC2 >= 81) THEN INHQNC2 = .;
   IF (INHQNC3 >= 81) THEN INHQNC3 = .;
   IF (INHQNC4 >= 81) THEN INHQNC4 = .;
   IF (INHQNC5 >= 81) THEN INHQNC5 = .;
   IF (INHQNC6 >= 81) THEN INHQNC6 = .;
   IF (INHQNC7 >= 81) THEN INHQNC7 = .;
   IF (INHQNC8 >= 81) THEN INHQNC8 = .;
   IF (INHQNC10 >= 81) THEN INHQNC10 = .;
   IF (INHANSY >= 81) THEN INHANSY = .;
   IF (COCOPP >= 981) THEN COCOPP = .;
   IF (COCAGE >= 981) THEN COCAGE = .;
   IF (COCTOT >= 81) THEN COCTOT = .;
   IF (COCREC >= 81) THEN COCREC = .;
   IF (COCUS30A >= 81) THEN COCUS30A = .;
   IF (COCAM30A >= 81) THEN COCAM30A = .;
   IF (CCFRIEND >= 81) THEN CCFRIEND = .;
   IF (CCDEALER >= 81) THEN CCDEALER = .;
   IF (CCOTHSHR >= 81) THEN CCOTHSHR = .;
   IF (CCGIVEN >= 81) THEN CCGIVEN = .;
   IF (CCTRGOOD >= 81) THEN CCTRGOOD = .;
   IF (CCTRSERV >= 81) THEN CCTRSERV = .;
   IF (CCSTOLE >= 81) THEN CCSTOLE = .;
   IF (CCTRICK >= 81) THEN CCTRICK = .;
   IF (CCOBTNON >= 81) THEN CCOBTNON = .;
   IF (COCBUCK >= 9981) THEN COCBUCK = .;
   IF (COCYRFRQ >= 81) THEN COCYRFRQ = .;
   IF (COCSNIFF >= 81) THEN COCSNIFF = .;
   IF (COCSWAL >= 81) THEN COCSWAL = .;
   IF (COCIV >= 81) THEN COCIV = .;
   IF (FREEBASE >= 81) THEN FREEBASE = .;
   IF (COCWAY >= 81) THEN COCWAY = .;
   IF (CONDLREC >= 81) THEN CONDLREC = .;
   IF (CCLFDALY >= 81) THEN CCLFDALY = .;
   IF (CRAKREC >= 81) THEN CRAKREC = .;
   IF (CRKAM30A >= 981) THEN CRKAM30A = .;
   IF (CKFRIEND >= 81) THEN CKFRIEND = .;
   IF (CKDEALER >= 81) THEN CKDEALER = .;
   IF (CKOTHSHR >= 81) THEN CKOTHSHR = .;
   IF (CKGIVEN >= 81) THEN CKGIVEN = .;
   IF (CKTRGOOD >= 81) THEN CKTRGOOD = .;
   IF (CKTRSERV >= 81) THEN CKTRSERV = .;
   IF (CKSTOLE >= 81) THEN CKSTOLE = .;
   IF (CKTRICK >= 81) THEN CKTRICK = .;
   IF (CKOBTNON >= 81) THEN CKOBTNON = .;
   IF (CRAKBUCK >= 9981) THEN CRAKBUCK = .;
   IF (CKLFDALY >= 81) THEN CKLFDALY = .;
   IF (HALREAD >= 81) THEN HALREAD = .;
   IF (LSD >= 81) THEN LSD = .;
   IF (PEYOTE >= 81) THEN PEYOTE = .;
   IF (MESC >= 81) THEN MESC = .;
   IF (PSILCY >= 81) THEN PSILCY = .;
   IF (PCP >= 81) THEN PCP = .;
   IF (ECSTASY >= 81) THEN ECSTASY = .;
   IF (HALNEWA >= 981) THEN HALNEWA = .;
   IF (HALNEWB >= 981) THEN HALNEWB = .;
   IF (HALNEWC >= 981) THEN HALNEWC = .;
   IF (HALNEWD >= 981) THEN HALNEWD = .;
   IF (HALNEWE >= 981) THEN HALNEWE = .;
   IF (HALNOSP >= 81) THEN HALNOSP = .;
   IF (HALDKNAM >= 81) THEN HALDKNAM = .;
   IF (HALLOPP >= 81) THEN HALLOPP = .;
   IF (HALLAGE >= 81) THEN HALLAGE = .;
   IF (HALLTOT >= 81) THEN HALLTOT = .;
   IF (HALLREC >= 81) THEN HALLREC = .;
   IF (HAL30USE >= 81) THEN HAL30USE = .;
   IF (HALYRFRQ >= 81) THEN HALYRFRQ = .;
   IF (PCPREC >= 81) THEN PCPREC = .;
   IF (HERREAD >= 81) THEN HERREAD = .;
   IF (HEROPP >= 81) THEN HEROPP = .;
   IF (HERAGE >= 81) THEN HERAGE = .;
   IF (HERTOT >= 81) THEN HERTOT = .;
   IF (HERREC >= 81) THEN HERREC = .;
   IF (HER30USE >= 81) THEN HER30USE = .;
   IF (HERNEEDL >= 81) THEN HERNEEDL = .;
   IF (HRNDLREC >= 81) THEN HRNDLREC = .;
   IF (HERSMOKE >= 81) THEN HERSMOKE = .;
   IF (HRSMKREC >= 81) THEN HRSMKREC = .;
   IF (HERSNIFF >= 81) THEN HERSNIFF = .;
   IF (HRSNFREC >= 81) THEN HRSNFREC = .;
   IF (DRGREAD >= 81) THEN DRGREAD = .;
   IF (CDCIG >= 81) THEN CDCIG = .;
   IF (CDALC >= 81) THEN CDALC = .;
   IF (CDSED >= 81) THEN CDSED = .;
   IF (CDTRAN >= 81) THEN CDTRAN = .;
   IF (CDSTM >= 81) THEN CDSTM = .;
   IF (CDANAL >= 81) THEN CDANAL = .;
   IF (CDMJ >= 81) THEN CDMJ = .;
   IF (CDINH >= 81) THEN CDINH = .;
   IF (CDCOC >= 81) THEN CDCOC = .;
   IF (CDHALL >= 81) THEN CDHALL = .;
   IF (CDHER >= 81) THEN CDHER = .;
   IF (CDOTHOP >= 81) THEN CDOTHOP = .;
   IF (CDNONE >= 81) THEN CDNONE = .;
   IF (UCDCIG >= 81) THEN UCDCIG = .;
   IF (UCDALC >= 81) THEN UCDALC = .;
   IF (UCDSED >= 81) THEN UCDSED = .;
   IF (UCDTRAN >= 81) THEN UCDTRAN = .;
   IF (UCDSTM >= 81) THEN UCDSTM = .;
   IF (UCDANAL >= 81) THEN UCDANAL = .;
   IF (UCDMJ >= 81) THEN UCDMJ = .;
   IF (UCDINH >= 81) THEN UCDINH = .;
   IF (UCDCOC >= 81) THEN UCDCOC = .;
   IF (UCDHALL >= 81) THEN UCDHALL = .;
   IF (UCDHER >= 81) THEN UCDHER = .;
   IF (UCDOTHOP >= 81) THEN UCDOTHOP = .;
   IF (UCDNONE >= 81) THEN UCDNONE = .;
   IF (EFFCIG >= 81) THEN EFFCIG = .;
   IF (EFFALC >= 81) THEN EFFALC = .;
   IF (EFFSED >= 81) THEN EFFSED = .;
   IF (EFFTRAN >= 81) THEN EFFTRAN = .;
   IF (EFFSTM >= 81) THEN EFFSTM = .;
   IF (EFFANAL >= 81) THEN EFFANAL = .;
   IF (EFFMJ >= 81) THEN EFFMJ = .;
   IF (EFFINH >= 81) THEN EFFINH = .;
   IF (EFFCOC >= 81) THEN EFFCOC = .;
   IF (EFFHALL >= 81) THEN EFFHALL = .;
   IF (EFFHER >= 81) THEN EFFHER = .;
   IF (EFFOTHOP >= 81) THEN EFFOTHOP = .;
   IF (EFFNONE >= 81) THEN EFFNONE = .;
   IF (UDAYCIG >= 81) THEN UDAYCIG = .;
   IF (UDAYALC >= 81) THEN UDAYALC = .;
   IF (UDAYSED >= 81) THEN UDAYSED = .;
   IF (UDAYTRAN >= 81) THEN UDAYTRAN = .;
   IF (UDAYSTM >= 81) THEN UDAYSTM = .;
   IF (UDAYANAL >= 81) THEN UDAYANAL = .;
   IF (UDAYMJ >= 81) THEN UDAYMJ = .;
   IF (UDAYINH >= 81) THEN UDAYINH = .;
   IF (UDAYCOC >= 81) THEN UDAYCOC = .;
   IF (UDAYHALL >= 81) THEN UDAYHALL = .;
   IF (UDAYHER >= 81) THEN UDAYHER = .;
   IF (UDAYOTH >= 81) THEN UDAYOTH = .;
   IF (UDAYNONE >= 81) THEN UDAYNONE = .;
   IF (DEPCIG >= 81) THEN DEPCIG = .;
   IF (DEPALC >= 81) THEN DEPALC = .;
   IF (DEPSED >= 81) THEN DEPSED = .;
   IF (DEPTRAN >= 81) THEN DEPTRAN = .;
   IF (DEPSTM >= 81) THEN DEPSTM = .;
   IF (DEPANAL >= 81) THEN DEPANAL = .;
   IF (DEPMJ >= 81) THEN DEPMJ = .;
   IF (DEPINH >= 81) THEN DEPINH = .;
   IF (DEPCOC >= 81) THEN DEPCOC = .;
   IF (DEPHALL >= 81) THEN DEPHALL = .;
   IF (DEPHER >= 81) THEN DEPHER = .;
   IF (DEPOTHOP >= 81) THEN DEPOTHOP = .;
   IF (DEPNONE >= 81) THEN DEPNONE = .;
   IF (WSCIG >= 81) THEN WSCIG = .;
   IF (WSALC >= 81) THEN WSALC = .;
   IF (WSSED >= 81) THEN WSSED = .;
   IF (WSTRAN >= 81) THEN WSTRAN = .;
   IF (WSSTM >= 81) THEN WSSTM = .;
   IF (WSANAL >= 81) THEN WSANAL = .;
   IF (WSMJ >= 81) THEN WSMJ = .;
   IF (WSINH >= 81) THEN WSINH = .;
   IF (WSCOC >= 81) THEN WSCOC = .;
   IF (WSHALL >= 81) THEN WSHALL = .;
   IF (WSHER >= 81) THEN WSHER = .;
   IF (WSOTHOP >= 81) THEN WSOTHOP = .;
   IF (WSNONE >= 81) THEN WSNONE = .;
   IF (NDLREAD >= 81) THEN NDLREAD = .;
   IF (GNNDLLIF >= 81) THEN GNNDLLIF = .;
   IF (GNNDLREC >= 81) THEN GNNDLREC = .;
   IF (GNNDLSED >= 81) THEN GNNDLSED = .;
   IF (GNNDLTRA >= 81) THEN GNNDLTRA = .;
   IF (GNNDLSTM >= 81) THEN GNNDLSTM = .;
   IF (GNNDLANL >= 81) THEN GNNDLANL = .;
   IF (GNNDLINH >= 81) THEN GNNDLINH = .;
   IF (GNNDLCOC >= 81) THEN GNNDLCOC = .;
   IF (GNNDLHAL >= 81) THEN GNNDLHAL = .;
   IF (GNNDLHER >= 81) THEN GNNDLHER = .;
   IF (GNNDLOPT >= 81) THEN GNNDLOPT = .;
   IF (GNNDLSTR >= 81) THEN GNNDLSTR = .;
   IF (GNNDLNON >= 81) THEN GNNDLNON = .;
   IF (GNNDLSH1 >= 81) THEN GNNDLSH1 = .;
   IF (GNNDLSH2 >= 81) THEN GNNDLSH2 = .;
   IF (SPTREAD >= 81) THEN SPTREAD = .;
   IF (DRUGTEST >= 81) THEN DRUGTEST = .;
   IF (TESTPOS >= 81) THEN TESTPOS = .;
   IF (ICELIFE >= 81) THEN ICELIFE = .;
   IF (ICEREC >= 81) THEN ICEREC = .;
   IF (STEROPP >= 981) THEN STEROPP = .;
   IF (STERAGE >= 981) THEN STERAGE = .;
   IF (STERTOT >= 81) THEN STERTOT = .;
   IF (STERREC >= 81) THEN STERREC = .;
   IF (SPNEWA >= 981) THEN SPNEWA = .;
   IF (SPNEWB >= 981) THEN SPNEWB = .;
   IF (SPNEWC >= 981) THEN SPNEWC = .;
   IF (SPNEWD >= 981) THEN SPNEWD = .;
   IF (SPNEWE >= 981) THEN SPNEWE = .;
   IF (BOOKED >= 81) THEN BOOKED = .;
   IF (NOBOOKYR >= 81) THEN NOBOOKYR = .;
   IF (BKLARCNY >= 81) THEN BKLARCNY = .;
   IF (BKBURGL >= 81) THEN BKBURGL = .;
   IF (BKAGASLT >= 81) THEN BKAGASLT = .;
   IF (BKSMASLT >= 81) THEN BKSMASLT = .;
   IF (BKMVTHFT >= 81) THEN BKMVTHFT = .;
   IF (BKROB >= 81) THEN BKROB = .;
   IF (BKRAPE >= 81) THEN BKRAPE = .;
   IF (BKMURDER >= 81) THEN BKMURDER = .;
   IF (BKARSON >= 81) THEN BKARSON = .;
   IF (BKDRVINF >= 81) THEN BKDRVINF = .;
   IF (BKDRUNK >= 81) THEN BKDRUNK = .;
   IF (BKDRUG >= 81) THEN BKDRUG = .;
   IF (BKPROS >= 81) THEN BKPROS = .;
   IF (BKVANDAL >= 81) THEN BKVANDAL = .;
   IF (BKOTHOFF >= 81) THEN BKOTHOFF = .;
   IF (NOTBKED >= 81) THEN NOTBKED = .;
   IF (PROBATON >= 81) THEN PROBATON = .;
   IF (PAROLE >= 81) THEN PAROLE = .;
   IF (STRSTEAL >= 81) THEN STRSTEAL = .;
   IF (OTHSTEAL >= 81) THEN OTHSTEAL = .;
   IF (DAMAGE >= 81) THEN DAMAGE = .;
   IF (CARSTEAL >= 81) THEN CARSTEAL = .;
   IF (FORCEMON >= 81) THEN FORCEMON = .;
   IF (BREAKIN >= 81) THEN BREAKIN = .;
   IF (PHYFIGHT >= 81) THEN PHYFIGHT = .;
   IF (HURTBAD >= 81) THEN HURTBAD = .;
   IF (GUNMONEY >= 81) THEN GUNMONEY = .;
   IF (DRUNKDRV >= 81) THEN DRUNKDRV = .;
   IF (SOLDDRUG >= 81) THEN SOLDDRUG = .;
   IF (OTHDOING >= 81) THEN OTHDOING = .;
   IF (OTHDOSP1 >= 81) THEN OTHDOSP1 = .;
   IF (OTHDOSP2 >= 81) THEN OTHDOSP2 = .;
   IF (DEXREAD >= 81) THEN DEXREAD = .;
   IF (NOBOOZYR >= 81) THEN NOBOOZYR = .;
   IF (ALCAGGR >= 81) THEN ALCAGGR = .;
   IF (ALCARGUM >= 81) THEN ALCARGUM = .;
   IF (ALCABSNT >= 81) THEN ALCABSNT = .;
   IF (ALCHIGH >= 81) THEN ALCHIGH = .;
   IF (ALCJOB >= 81) THEN ALCJOB = .;
   IF (ALCMATCD >= 81) THEN ALCMATCD = .;
   IF (ALCRELCD >= 81) THEN ALCRELCD = .;
   IF (ALCFRDCD >= 81) THEN ALCFRDCD = .;
   IF (ALCTOSS >= 81) THEN ALCTOSS = .;
   IF (ALCHOLIC >= 81) THEN ALCHOLIC = .;
   IF (ALCDRUNK >= 81) THEN ALCDRUNK = .;
   IF (ALCINTOX >= 81) THEN ALCINTOX = .;
   IF (ALCREM >= 81) THEN ALCREM = .;
   IF (ALCQUICK >= 81) THEN ALCQUICK = .;
   IF (ALCMORN >= 81) THEN ALCMORN = .;
   IF (ALCSHOOK >= 81) THEN ALCSHOOK = .;
   IF (ALCALONE >= 81) THEN ALCALONE = .;
   IF (ALCBRKPM >= 81) THEN ALCBRKPM = .;
   IF (ALCMJ >= 81) THEN ALCMJ = .;
   IF (ALCCOC >= 81) THEN ALCCOC = .;
   IF (ALCOPT >= 81) THEN ALCOPT = .;
   IF (ALCHAL >= 81) THEN ALCHAL = .;
   IF (ALCINH >= 81) THEN ALCINH = .;
   IF (ALCANAL >= 81) THEN ALCANAL = .;
   IF (ALCTRAN >= 81) THEN ALCTRAN = .;
   IF (ALCSTM >= 81) THEN ALCSTM = .;
   IF (ALCSED >= 81) THEN ALCSED = .;
   IF (AS13NONE >= 81) THEN AS13NONE = .;
   IF (DRDEPRSS >= 81) THEN DRDEPRSS = .;
   IF (DEPDRG1A >= 981) THEN DEPDRG1A = .;
   IF (DEPDRG2A >= 981) THEN DEPDRG2A = .;
   IF (DEPDRG3A >= 981) THEN DEPDRG3A = .;
   IF (DEPDRG4A >= 981) THEN DEPDRG4A = .;
   IF (DEPDRG5A >= 981) THEN DEPDRG5A = .;
   IF (DRARGUM >= 81) THEN DRARGUM = .;
   IF (ARGDRG1A >= 981) THEN ARGDRG1A = .;
   IF (ARGDRG2A >= 981) THEN ARGDRG2A = .;
   IF (ARGDRG3A >= 981) THEN ARGDRG3A = .;
   IF (ARGDRG4A >= 981) THEN ARGDRG4A = .;
   IF (ARGDRG5A >= 981) THEN ARGDRG5A = .;
   IF (DRALONE >= 81) THEN DRALONE = .;
   IF (ALNDRG1A >= 981) THEN ALNDRG1A = .;
   IF (ALNDRG2A >= 981) THEN ALNDRG2A = .;
   IF (ALNDRG3A >= 981) THEN ALNDRG3A = .;
   IF (ALNDRG4A >= 981) THEN ALNDRG4A = .;
   IF (ALNDRG5A >= 981) THEN ALNDRG5A = .;
   IF (DRANX >= 81) THEN DRANX = .;
   IF (ANXDRG1A >= 981) THEN ANXDRG1A = .;
   IF (ANXDRG2A >= 981) THEN ANXDRG2A = .;
   IF (ANXDRG3A >= 981) THEN ANXDRG3A = .;
   IF (ANXDRG4A >= 981) THEN ANXDRG4A = .;
   IF (ANXDRG5A >= 981) THEN ANXDRG5A = .;
   IF (DRHEALTH >= 81) THEN DRHEALTH = .;
   IF (HLTDRG1A >= 981) THEN HLTDRG1A = .;
   IF (HLTDRG2A >= 981) THEN HLTDRG2A = .;
   IF (HLTDRG3A >= 981) THEN HLTDRG3A = .;
   IF (HLTDRG4A >= 981) THEN HLTDRG4A = .;
   IF (HLTDRG5A >= 981) THEN HLTDRG5A = .;
   IF (DRNTHINK >= 81) THEN DRNTHINK = .;
   IF (NTKDRG1A >= 981) THEN NTKDRG1A = .;
   IF (NTKDRG2A >= 981) THEN NTKDRG2A = .;
   IF (NTKDRG3A >= 981) THEN NTKDRG3A = .;
   IF (NTKDRG4A >= 981) THEN NTKDRG4A = .;
   IF (NTKDRG5A >= 981) THEN NTKDRG5A = .;
   IF (DRUPSET >= 81) THEN DRUPSET = .;
   IF (UPSDRG1A >= 981) THEN UPSDRG1A = .;
   IF (UPSDRG2A >= 981) THEN UPSDRG2A = .;
   IF (UPSDRG3A >= 981) THEN UPSDRG3A = .;
   IF (UPSDRG4A >= 981) THEN UPSDRG4A = .;
   IF (UPSDRG5A >= 981) THEN UPSDRG5A = .;
   IF (DRLSWORK >= 81) THEN DRLSWORK = .;
   IF (LSWDRG1A >= 981) THEN LSWDRG1A = .;
   IF (LSWDRG2A >= 981) THEN LSWDRG2A = .;
   IF (LSWDRG3A >= 981) THEN LSWDRG3A = .;
   IF (LSWDRG4A >= 981) THEN LSWDRG4A = .;
   IF (LSWDRG5A >= 981) THEN LSWDRG5A = .;
   IF (DRSUSPIC >= 81) THEN DRSUSPIC = .;
   IF (SSPDRG1A >= 981) THEN SSPDRG1A = .;
   IF (SSPDRG2A >= 981) THEN SSPDRG2A = .;
   IF (SSPDRG3A >= 981) THEN SSPDRG3A = .;
   IF (SSPDRG4A >= 981) THEN SSPDRG4A = .;
   IF (SSPDRG5A >= 981) THEN SSPDRG5A = .;
   IF (DRCOPE >= 81) THEN DRCOPE = .;
   IF (CPEDRG1A >= 981) THEN CPEDRG1A = .;
   IF (CPEDRG2A >= 981) THEN CPEDRG2A = .;
   IF (CPEDRG3A >= 981) THEN CPEDRG3A = .;
   IF (CPEDRG4A >= 981) THEN CPEDRG4A = .;
   IF (CPEDRG5A >= 981) THEN CPEDRG5A = .;
   IF (DREMGMED >= 81) THEN DREMGMED = .;
   IF (EMDRG1A >= 981) THEN EMDRG1A = .;
   IF (EMDRG2A >= 981) THEN EMDRG2A = .;
   IF (EMDRG3A >= 981) THEN EMDRG3A = .;
   IF (EMDRG4A >= 981) THEN EMDRG4A = .;
   IF (EMDRG5A >= 981) THEN EMDRG5A = .;
   IF (DRTRMT >= 81) THEN DRTRMT = .;
   IF (TMTDRG1A >= 981) THEN TMTDRG1A = .;
   IF (TMTDRG2A >= 981) THEN TMTDRG2A = .;
   IF (TMTDRG3A >= 981) THEN TMTDRG3A = .;
   IF (TMTDRG4A >= 981) THEN TMTDRG4A = .;
   IF (TMTDRG5A >= 981) THEN TMTDRG5A = .;
   IF (DRDRVUN >= 81) THEN DRDRVUN = .;
   IF (DRVDRG1A >= 981) THEN DRVDRG1A = .;
   IF (DRVDRG2A >= 981) THEN DRVDRG2A = .;
   IF (DRVDRG3A >= 981) THEN DRVDRG3A = .;
   IF (DRVDRG4A >= 981) THEN DRVDRG4A = .;
   IF (DRVDRG5A >= 981) THEN DRVDRG5A = .;
   IF (TMTREAD >= 81) THEN TMTREAD = .;
   IF (EMPDRUG >= 81) THEN EMPDRUG = .;
   IF (CIGHELP >= 81) THEN CIGHELP = .;
   IF (DRNKHELP >= 81) THEN DRNKHELP = .;
   IF (TRMTHELP >= 81) THEN TRMTHELP = .;
   IF (TRMTEMRG >= 81) THEN TRMTEMRG = .;
   IF (TRMTHOSP >= 81) THEN TRMTHOSP = .;
   IF (TRMTDOC >= 81) THEN TRMTDOC = .;
   IF (TRMTTRMT >= 81) THEN TRMTTRMT = .;
   IF (TRMTMHC >= 81) THEN TRMTMHC = .;
   IF (TRMTSHG >= 81) THEN TRMTSHG = .;
   IF (TRMTSOP >= 81) THEN TRMTSOP = .;
   IF (TRMTSP >= 81) THEN TRMTSP = .;
   IF (TRMTREC >= 81) THEN TRMTREC = .;
   IF (NRTXLIFE >= 981) THEN NRTXLIFE = .;
   IF (NOTRMT >= 81) THEN NOTRMT = .;
   IF (TXEMRG >= 81) THEN TXEMRG = .;
   IF (TXHOSP >= 81) THEN TXHOSP = .;
   IF (TXDOC >= 81) THEN TXDOC = .;
   IF (TXTRMT >= 81) THEN TXTRMT = .;
   IF (TXMHC >= 81) THEN TXMHC = .;
   IF (TXSHG >= 81) THEN TXSHG = .;
   IF (TXSOP >= 81) THEN TXSOP = .;
   IF (TXSP >= 81) THEN TXSP = .;
   IF (TRMTLIFE >= 81) THEN TRMTLIFE = .;
   IF (TRMTRESP >= 81) THEN TRMTRESP = .;
   IF (TRMTFEAR >= 81) THEN TRMTFEAR = .;
   IF (TRMTCOST >= 81) THEN TRMTCOST = .;
   IF (TRMTEVNT >= 81) THEN TRMTEVNT = .;
   IF (TRMTPR >= 81) THEN TRMTPR = .;
   IF (TRMTHLTH >= 81) THEN TRMTHLTH = .;
   IF (TRMTJOB >= 81) THEN TRMTJOB = .;
   IF (TRMTJAIL >= 81) THEN TRMTJAIL = .;
   IF (TRMTSERV >= 81) THEN TRMTSERV = .;
   IF (TRMTBQD >= 81) THEN TRMTBQD = .;
   IF (TRMTDNA >= 81) THEN TRMTDNA = .;
   IF (TRMTSOR >= 81) THEN TRMTSOR = .;
   IF (TRMTRSP >= 81) THEN TRMTRSP = .;
   IF (TRMTDRGA >= 981) THEN TRMTDRGA = .;
   IF (TRMTDRGB >= 981) THEN TRMTDRGB = .;
   IF (TRMTDRGC >= 981) THEN TRMTDRGC = .;
   IF (TRMTDRGD >= 981) THEN TRMTDRGD = .;
   IF (TRMTDRGE >= 981) THEN TRMTDRGE = .;
   IF (TRMTOUTC >= 81) THEN TRMTOUTC = .;
   IF (TMTPHI >= 81) THEN TMTPHI = .;
   IF (TMTPSAVE >= 81) THEN TMTPSAVE = .;
   IF (TMTPFMLY >= 81) THEN TMTPFMLY = .;
   IF (TMTPEMPR >= 81) THEN TMTPEMPR = .;
   IF (TMTPMEDI >= 81) THEN TMTPMEDI = .;
   IF (TMTPFREE >= 81) THEN TMTPFREE = .;
   IF (TMTPOTH >= 81) THEN TMTPOTH = .;
   IF (TMTPASP >= 81) THEN TMTPASP = .;
   IF (RSKPKCIG >= 81) THEN RSKPKCIG = .;
   IF (RSKTRYMJ >= 81) THEN RSKTRYMJ = .;
   IF (RSKMJOCC >= 81) THEN RSKMJOCC = .;
   IF (RSKMJREG >= 81) THEN RSKMJREG = .;
   IF (RKTRYPCP >= 81) THEN RKTRYPCP = .;
   IF (RKPCPREG >= 81) THEN RKPCPREG = .;
   IF (RKTRYHER >= 81) THEN RKTRYHER = .;
   IF (RKHERREG >= 81) THEN RKHERREG = .;
   IF (RKTRYCOC >= 81) THEN RKTRYCOC = .;
   IF (RKCOCOCC >= 81) THEN RKCOCOCC = .;
   IF (RKCOCREG >= 81) THEN RKCOCREG = .;
   IF (RKCRKOCC >= 81) THEN RKCRKOCC = .;
   IF (RKANSOCC >= 81) THEN RKANSOCC = .;
   IF (RKANSREG >= 81) THEN RKANSREG = .;
   IF (RK2DRINK >= 81) THEN RK2DRINK = .;
   IF (RK5DRINK >= 81) THEN RK5DRINK = .;
   IF (RSKBINGE >= 81) THEN RSKBINGE = .;
   IF (RSKDIFMJ >= 81) THEN RSKDIFMJ = .;
   IF (RKDIFLSD >= 81) THEN RKDIFLSD = .;
   IF (RKDIFPCP >= 81) THEN RKDIFPCP = .;
   IF (RKDIFCOC >= 81) THEN RKDIFCOC = .;
   IF (RKDIFHER >= 81) THEN RKDIFHER = .;
   IF (RSKSELL >= 81) THEN RSKSELL = .;
   IF (RKNEIDRN >= 81) THEN RKNEIDRN = .;
   IF (RKNEISEL >= 81) THEN RKNEISEL = .;
   IF (HIGHBP >= 81) THEN HIGHBP = .;
   IF (BPMED >= 81) THEN BPMED = .;
   IF (WALKPAIN >= 81) THEN WALKPAIN = .;
   IF (TIMEPAIN >= 81) THEN TIMEPAIN = .;
   IF (UPSHOR >= 81) THEN UPSHOR = .;
   IF (ASTHMA >= 81) THEN ASTHMA = .;
   IF (TRPSYCH >= 81) THEN TRPSYCH = .;
   IF (HEART >= 81) THEN HEART = .;
   IF (FLU >= 81) THEN FLU = .;
   IF (ALLERG >= 94) THEN ALLERG = .;
   IF (HOSPYR >= 81) THEN HOSPYR = .;
   IF (SOREYR >= 81) THEN SOREYR = .;
   IF (RUNNYYR >= 81) THEN RUNNYYR = .;
   IF (COUGHYR >= 81) THEN COUGHYR = .;
   IF (PHLEGMYR >= 81) THEN PHLEGMYR = .;
   IF (HEALTHYR >= 81) THEN HEALTHYR = .;
   IF (FLTEAT >= 81) THEN FLTEAT = .;
   IF (FLTMIND >= 81) THEN FLTMIND = .;
   IF (FLTDEPRS >= 81) THEN FLTDEPRS = .;
   IF (FLTEFFRT >= 81) THEN FLTEFFRT = .;
   IF (FLTSLEEP >= 81) THEN FLTSLEEP = .;
   IF (FLTSAD >= 81) THEN FLTSAD = .;
   IF (FLTGOING >= 81) THEN FLTGOING = .;
   IF (MARITAL >= 81) THEN MARITAL = .;
   IF (NOMARR >= 81) THEN NOMARR = .;
   IF (WORKSTAT >= 81) THEN WORKSTAT = .;
   IF (PAYMO >= 89) THEN PAYMO = .;
   IF (PAYYR >= 981) THEN PAYYR = .;
   IF (NO5JOB >= 94) THEN NO5JOB = .;
   IF (WORKDAYS >= 81) THEN WORKDAYS = .;
   IF (WORKBLAH >= 81) THEN WORKBLAH = .;
   IF (CWE >= 81) THEN CWE = .;
   IF (CWESC1 >= 981) THEN CWESC1 = .;
   IF (CWESC2 >= 981) THEN CWESC2 = .;
   IF (FULLPART >= 81) THEN FULLPART = .;
   IF (EDUC >= 81) THEN EDUC = .;
   IF (GRADHS >= 81) THEN GRADHS = .;
   IF (DIPLOMA >= 81) THEN DIPLOMA = .;
   IF (ENROLLD >= 81) THEN ENROLLD = .;
   IF (SCHPLANS >= 81) THEN SCHPLANS = .;
   IF (STUDENT >= 81) THEN STUDENT = .;
   IF (SCHDAYS >= 81) THEN SCHDAYS = .;
   IF (SKIPPED >= 81) THEN SKIPPED = .;
   IF (MILES >= 99981) THEN MILES = .;
   IF (ACCID >= 81) THEN ACCID = .;
   IF (TOTPEOP >= 81) THEN TOTPEOP = .;
   IF (MOTHER >= 81) THEN MOTHER = .;
   IF (FATHER >= 81) THEN FATHER = .;
   IF (STEPMOM >= 81) THEN STEPMOM = .;
   IF (STEPDAD >= 81) THEN STEPDAD = .;
   IF (SPOUSE >= 81) THEN SPOUSE = .;
   IF (INLAW >= 81) THEN INLAW = .;
   IF (OWNCHILD >= 81) THEN OWNCHILD = .;
   IF (STEPCHLD >= 81) THEN STEPCHLD = .;
   IF (BROSIS >= 81) THEN BROSIS = .;
   IF (OTHREL >= 81) THEN OTHREL = .;
   IF (FRIENDS >= 81) THEN FRIENDS = .;
   IF (OTHERNON >= 81) THEN OTHERNON = .;
   IF (MOVDAWAY >= 81) THEN MOVDAWAY = .;
   IF (DORM >= 81) THEN DORM = .;
   IF (MILBASE >= 81) THEN MILBASE = .;
   IF (HOSP >= 81) THEN HOSP = .;
   IF (OTHGPH >= 81) THEN OTHGPH = .;
   IF (OTHGPHSP >= 81) THEN OTHGPHSP = .;
   IF (SERVICE >= 81) THEN SERVICE = .;
   IF (MILSTAT >= 81) THEN MILSTAT = .;
   IF (TELNO >= 81) THEN TELNO = .;
   IF (MOVES >= 81) THEN MOVES = .;
   IF (PROXABLE >= 81) THEN PROXABLE = .;
   IF (PROXYREL >= 981) THEN PROXYREL = .;
   IF (PROXHOME >= 81) THEN PROXHOME = .;
   IF (PROXJOIN >= 81) THEN PROXJOIN = .;
   IF (MEDICARE >= 81) THEN MEDICARE = .;
   IF (MEDICAID >= 81) THEN MEDICAID = .;
   IF (CHAMPUS >= 81) THEN CHAMPUS = .;
   IF (PRVHLTIN >= 81) THEN PRVHLTIN = .;
   IF (OWNHLTIN >= 81) THEN OWNHLTIN = .;
   IF (GRPHLTIN >= 81) THEN GRPHLTIN = .;
   IF (HLTINALC >= 81) THEN HLTINALC = .;
   IF (HLTINDRG >= 81) THEN HLTINDRG = .;
   IF (HLTINMNT >= 81) THEN HLTINMNT = .;
   IF (WHOANSHI >= 981) THEN WHOANSHI = .;
   IF (JOB >= 81) THEN JOB = .;
   IF (HOURS >= 981) THEN HOURS = .;
   IF (WORK >= 81) THEN WORK = .;
   IF (WAG1 >= 81) THEN WAG1 = .;
   IF (AWAG1 >= 999981) THEN AWAG1 = .;
   IF (WEEKS >= 81) THEN WEEKS = .;
   IF (SOC1 >= 81) THEN SOC1 = .;
   IF (ASOC1 >= 999981) THEN ASOC1 = .;
   IF (SSI1 >= 81) THEN SSI1 = .;
   IF (ASSI1 >= 999981) THEN ASSI1 = .;
   IF (PUB1 >= 81) THEN PUB1 = .;
   IF (AFDC1 >= 81) THEN AFDC1 = .;
   IF (WEL1 >= 81) THEN WEL1 = .;
   IF (AWEL1 >= 999981) THEN AWEL1 = .;
   IF (INT1 >= 81) THEN INT1 = .;
   IF (AINT1 >= 999981) THEN AINT1 = .;
   IF (CHD1 >= 81) THEN CHD1 = .;
   IF (ACHD1 >= 999981) THEN ACHD1 = .;
   IF (OTH1 >= 81) THEN OTH1 = .;
   IF (AOTH1 >= 999981) THEN AOTH1 = .;
   IF (FAMLYRES >= 81) THEN FAMLYRES = .;
   IF (WAG2 >= 81) THEN WAG2 = .;
   IF (AWAG2 >= 999981) THEN AWAG2 = .;
   IF (SOC2 >= 81) THEN SOC2 = .;
   IF (ASOC2 >= 999981) THEN ASOC2 = .;
   IF (SSI2 >= 81) THEN SSI2 = .;
   IF (ASSI2 >= 999981) THEN ASSI2 = .;
   IF (PUB2 >= 81) THEN PUB2 = .;
   IF (AFDC2 >= 81) THEN AFDC2 = .;
   IF (WEL2 >= 81) THEN WEL2 = .;
   IF (AWEL2 >= 999981) THEN AWEL2 = .;
   IF (INT2 >= 81) THEN INT2 = .;
   IF (AINT2 >= 999981) THEN AINT2 = .;
   IF (CHD2 >= 81) THEN CHD2 = .;
   IF (ACHD2 >= 999981) THEN ACHD2 = .;
   IF (OTH2 >= 81) THEN OTH2 = .;
   IF (AOTH2 >= 999981) THEN AOTH2 = .;
   IF (WHOANSIN >= 981) THEN WHOANSIN = .;
   IF (FSTAMP >= 81) THEN FSTAMP = .;
   IF (PEOPFD >= 81) THEN PEOPFD = .;
   IF (FOOD >= 81) THEN FOOD = .;
   IF (AFOOD >= 999981) THEN AFOOD = .;
   IF (BHOUR >= 81) THEN BHOUR = .;
   IF (BMIN >= 81) THEN BMIN = .;
   IF (BAP >= 81) THEN BAP = .;
   IF (EAP >= 81) THEN EAP = .;
   IF (LANGVER >= 81) THEN LANGVER = .;
   IF (UNDINT >= 81) THEN UNDINT = .;
   IF (COOPINT >= 81) THEN COOPINT = .;
   IF (PRIVACY >= 81) THEN PRIVACY = .;
   IF (PPRES >= 81) THEN PPRES = .;
   IF (SPRES >= 81) THEN SPRES = .;
   IF (PARPRES >= 81) THEN PARPRES = .;
   IF (OARPRES >= 81) THEN OARPRES = .;
   IF (OAPRES >= 81) THEN OAPRES = .;
   IF (CPRES >= 81) THEN CPRES = .;
   IF (OPRESNSP >= 81) THEN OPRESNSP = .;
   IF (OPRESSPA >= 981) THEN OPRESSPA = .;
   IF (OPRESSPB >= 981) THEN OPRESSPB = .;
   IF (WHOMARKD >= 81) THEN WHOMARKD = .;
   IF (FAMSKIP >= 81) THEN FAMSKIP = .;
   IF (GQTYPE = 9) THEN GQTYPE = .;
   IF (DC >= 9) THEN DC = .;
   IF (CHICAGO >= 9) THEN CHICAGO = .;
   IF (DENVER >= 9) THEN DENVER = .;
   IF (LA >= 9) THEN LA = .;
   IF (MIAMI >= 9) THEN MIAMI = .;
   IF (NEWYORK >= 9) THEN NEWYORK = .;
   IF (URBARE >= 9) THEN URBARE = .;
   IF (METRO >= 9) THEN METRO = .;
   IF (IRHOGRP >= 81) THEN IRHOGRP = .;
   IF (IIHOGRP >= 9) THEN IIHOGRP = .;
   IF (IRHOGRP2 >= 81) THEN IRHOGRP2 = .;
   IF (IIHOGRP2 >= 9) THEN IIHOGRP2 = .;
   IF (IRMARIT >= 81) THEN IRMARIT = .;
   IF (IIMARIT >= 9) THEN IIMARIT = .;
   IF (IRWORKST >= 81) THEN IRWORKST = .;
   IF (IIAWAG1 >= 9) THEN IIAWAG1 = .;
   IF (IIASOC1 >= 9) THEN IIASOC1 = .;
   IF (IIASSI1 >= 9) THEN IIASSI1 = .;
   IF (IIAWEL1 >= 9) THEN IIAWEL1 = .;
   IF (IIAINT1 >= 9) THEN IIAINT1 = .;
   IF (IIACHD1 >= 9) THEN IIACHD1 = .;
   IF (IIAOTH1 >= 9) THEN IIAOTH1 = .;
   IF (IIWAG2 >= 9) THEN IIWAG2 = .;
   IF (IIAWAG2 >= 9) THEN IIAWAG2 = .;
   IF (IISOC2 >= 9) THEN IISOC2 = .;
   IF (IIASOC2 >= 9) THEN IIASOC2 = .;
   IF (IISSI2 >= 9) THEN IISSI2 = .;
   IF (IIASSI2 >= 9) THEN IIASSI2 = .;
   IF (IIWEL2 >= 9) THEN IIWEL2 = .;
   IF (IIAWEL2 >= 9) THEN IIAWEL2 = .;
   IF (IIINT2 >= 9) THEN IIINT2 = .;
   IF (IIAINT2 >= 9) THEN IIAINT2 = .;
   IF (IICHD2 >= 9) THEN IICHD2 = .;
   IF (IIACHD2 >= 9) THEN IIACHD2 = .;
   IF (IIOTH2 >= 9) THEN IIOTH2 = .;
   IF (IIAOTH2 >= 9) THEN IIAOTH2 = .;
   IF (IIAFOOD >= 9) THEN IIAFOOD = .;
   IF (IRPEOP >= 81) THEN IRPEOP = .;
   IF (IRALCRC >= 9) THEN IRALCRC = .;
   IF (IRMJRC >= 9) THEN IRMJRC = .;
   IF (IRCOCRC >= 9) THEN IRCOCRC = .;
   IF (IRSEDRC >= 9) THEN IRSEDRC = .;
   IF (IRTRNRC >= 9) THEN IRTRNRC = .;
   IF (IRSTMRC >= 9) THEN IRSTMRC = .;
   IF (IRANLRC >= 9) THEN IRANLRC = .;
   IF (IRCIGRC >= 9) THEN IRCIGRC = .;
   IF (IROTBRC >= 9) THEN IROTBRC = .;
   IF (IRINHRC >= 9) THEN IRINHRC = .;
   IF (IRCRKRC >= 9) THEN IRCRKRC = .;
   IF (IRHALRC >= 9) THEN IRHALRC = .;
   IF (IRHERRC >= 9) THEN IRHERRC = .;
   IF (IRPCPRC >= 9) THEN IRPCPRC = .;
   IF (IRICERC >= 9) THEN IRICERC = .;
   IF (IRSTRRC >= 9) THEN IRSTRRC = .;
   IF (IRALCFQ >= 9) THEN IRALCFQ = .;
   IF (IRMJFQ >= 9) THEN IRMJFQ = .;
   IF (IRCOCFQ >= 9) THEN IRCOCFQ = .;
   IF (IRSEDFQ >= 9) THEN IRSEDFQ = .;
   IF (IRTRNFQ >= 9) THEN IRTRNFQ = .;
   IF (IRSTMFQ >= 9) THEN IRSTMFQ = .;
   IF (IRANLFQ >= 9) THEN IRANLFQ = .;
   IF (IROTBFQ >= 9) THEN IROTBFQ = .;
   IF (IRINHFQ >= 9) THEN IRINHFQ = .;
   IF (IRHALFQ >= 9) THEN IRHALFQ = .;
   IF (INDCAT >= 81) THEN INDCAT = .;
   IF (TOTCAT >= 81) THEN TOTCAT = .;
   IF (NEEDLREC >= 81) THEN NEEDLREC = .;
   IF (NDL90REC >= 81) THEN NDL90REC = .;
   IF (QC06 >= 81) THEN QC06 = .;
   IF (QC09 >= 81) THEN QC09 = .;
   IF (AL02 >= 81) THEN AL02 = .;
   IF (SE04 >= 81) THEN SE04 = .;
   IF (TR04 >= 81) THEN TR04 = .;
   IF (ST04 >= 81) THEN ST04 = .;
   IF (ST07 >= 81) THEN ST07 = .;
   IF (AN04 >= 81) THEN AN04 = .;
   IF (MJ04 >= 81) THEN MJ04 = .;
   IF (IN04 >= 81) THEN IN04 = .;
   IF (CC04 >= 81) THEN CC04 = .;
   IF (CC11 >= 81) THEN CC11 = .;
   IF (CK01 >= 81) THEN CK01 = .;
   IF (LS05 >= 81) THEN LS05 = .;
   IF (LS08 >= 81) THEN LS08 = .;
   IF (HE04 >= 81) THEN HE04 = .;
   IF (HE07 >= 81) THEN HE07 = .;
   IF (ND02 >= 81) THEN ND02 = .;
   IF (SP04 >= 81) THEN SP04 = .;
   IF (SP08 >= 81) THEN SP08 = .;
   IF (IRCDCIG >= 81) THEN IRCDCIG = .;
   IF (IRCDMJ >= 81) THEN IRCDMJ = .;
   IF (IREFCIG >= 81) THEN IREFCIG = .;
   IF (IREFALC >= 81) THEN IREFALC = .;
   IF (IREFMJ >= 81) THEN IREFMJ = .;
   IF (IREFCOC >= 81) THEN IREFCOC = .;
   IF (IRUDCIG >= 81) THEN IRUDCIG = .;
   IF (IRUDALC >= 81) THEN IRUDALC = .;
   IF (IRUDMJ >= 81) THEN IRUDMJ = .;
   IF (IRUDCOC >= 81) THEN IRUDCOC = .;
   IF (IRDPCIG >= 81) THEN IRDPCIG = .;
   IF (IRDPALC >= 81) THEN IRDPALC = .;
   IF (IRDPMJ >= 81) THEN IRDPMJ = .;
   IF (IRDPCOC >= 81) THEN IRDPCOC = .;
   IF (IRWSCIG >= 81) THEN IRWSCIG = .;
   IF (IRWSALC >= 81) THEN IRWSALC = .;
   IF (IRWSMJ >= 81) THEN IRWSMJ = .;
   IF (IRWSCOC >= 81) THEN IRWSCOC = .;
   IF (IRALCAGG >= 81) THEN IRALCAGG = .;
   IF (IRALCARG >= 81) THEN IRALCARG = .;
   IF (IRALCABS >= 81) THEN IRALCABS = .;
   IF (IRALCHIG >= 81) THEN IRALCHIG = .;
   IF (IRALCJOB >= 81) THEN IRALCJOB = .;
   IF (IRALCMAT >= 81) THEN IRALCMAT = .;
   IF (IRALCREL >= 81) THEN IRALCREL = .;
   IF (IRALCFRD >= 81) THEN IRALCFRD = .;
   IF (IRALCTOS >= 81) THEN IRALCTOS = .;
   IF (IRALCHOL >= 81) THEN IRALCHOL = .;
   IF (IRALCDRU >= 81) THEN IRALCDRU = .;
   IF (IRALCINT >= 81) THEN IRALCINT = .;
   IF (IRALCREM >= 81) THEN IRALCREM = .;
   IF (IRALCQUI >= 81) THEN IRALCQUI = .;
   IF (IRALCMOR >= 81) THEN IRALCMOR = .;
   IF (IRALCSHO >= 81) THEN IRALCSHO = .;
   IF (IRALCALO >= 81) THEN IRALCALO = .;
   IF (IRALCBRK >= 81) THEN IRALCBRK = .;
   IF (IRDEP >= 81) THEN IRDEP = .;
   IF (IRARG >= 81) THEN IRARG = .;
   IF (IRALN >= 81) THEN IRALN = .;
   IF (IRANX >= 81) THEN IRANX = .;
   IF (IRHLT >= 81) THEN IRHLT = .;
   IF (IRNTK >= 81) THEN IRNTK = .;
   IF (IRUPS >= 81) THEN IRUPS = .;
   IF (IRLSW >= 81) THEN IRLSW = .;
   IF (IRSSP >= 81) THEN IRSSP = .;
   IF (IRCPE >= 81) THEN IRCPE = .;
   IF (IREMG >= 81) THEN IREMG = .;
   IF (IRDEP1 >= 981) THEN IRDEP1 = .;
   IF (IRDEP2 >= 981) THEN IRDEP2 = .;
   IF (IRDEP3 >= 981) THEN IRDEP3 = .;
   IF (IRDEP4 >= 981) THEN IRDEP4 = .;
   IF (IRDEP5 >= 981) THEN IRDEP5 = .;
   IF (IRARG1 >= 981) THEN IRARG1 = .;
   IF (IRARG2 >= 981) THEN IRARG2 = .;
   IF (IRARG3 >= 981) THEN IRARG3 = .;
   IF (IRARG4 >= 981) THEN IRARG4 = .;
   IF (IRARG5 >= 981) THEN IRARG5 = .;
   IF (IRALN1 >= 981) THEN IRALN1 = .;
   IF (IRALN2 >= 981) THEN IRALN2 = .;
   IF (IRALN3 >= 981) THEN IRALN3 = .;
   IF (IRALN4 >= 981) THEN IRALN4 = .;
   IF (IRALN5 >= 981) THEN IRALN5 = .;
   IF (IRANX1 >= 981) THEN IRANX1 = .;
   IF (IRANX2 >= 981) THEN IRANX2 = .;
   IF (IRANX3 >= 981) THEN IRANX3 = .;
   IF (IRANX4 >= 981) THEN IRANX4 = .;
   IF (IRANX5 >= 981) THEN IRANX5 = .;
   IF (IRHLT1 >= 981) THEN IRHLT1 = .;
   IF (IRHLT2 >= 981) THEN IRHLT2 = .;
   IF (IRHLT3 >= 981) THEN IRHLT3 = .;
   IF (IRHLT4 >= 981) THEN IRHLT4 = .;
   IF (IRHLT5 >= 981) THEN IRHLT5 = .;
   IF (IRNTK1 >= 981) THEN IRNTK1 = .;
   IF (IRNTK2 >= 981) THEN IRNTK2 = .;
   IF (IRNTK3 >= 981) THEN IRNTK3 = .;
   IF (IRNTK4 >= 981) THEN IRNTK4 = .;
   IF (IRNTK5 >= 981) THEN IRNTK5 = .;
   IF (IRUPS1 >= 981) THEN IRUPS1 = .;
   IF (IRUPS2 >= 981) THEN IRUPS2 = .;
   IF (IRUPS3 >= 981) THEN IRUPS3 = .;
   IF (IRUPS4 >= 981) THEN IRUPS4 = .;
   IF (IRUPS5 >= 981) THEN IRUPS5 = .;
   IF (IRLSW1 >= 981) THEN IRLSW1 = .;
   IF (IRLSW2 >= 981) THEN IRLSW2 = .;
   IF (IRLSW3 >= 981) THEN IRLSW3 = .;
   IF (IRLSW4 >= 981) THEN IRLSW4 = .;
   IF (IRLSW5 >= 981) THEN IRLSW5 = .;
   IF (IRSSP1 >= 981) THEN IRSSP1 = .;
   IF (IRSSP2 >= 981) THEN IRSSP2 = .;
   IF (IRSSP3 >= 981) THEN IRSSP3 = .;
   IF (IRSSP4 >= 981) THEN IRSSP4 = .;
   IF (IRSSP5 >= 981) THEN IRSSP5 = .;
   IF (IRCPE1 >= 981) THEN IRCPE1 = .;
   IF (IRCPE2 >= 981) THEN IRCPE2 = .;
   IF (IRCPE3 >= 981) THEN IRCPE3 = .;
   IF (IRCPE4 >= 981) THEN IRCPE4 = .;
   IF (IRCPE5 >= 981) THEN IRCPE5 = .;
   IF (IREMG1 >= 981) THEN IREMG1 = .;
   IF (IREMG2 >= 981) THEN IREMG2 = .;
   IF (IREMG3 >= 981) THEN IREMG3 = .;
   IF (IREMG4 >= 981) THEN IREMG4 = .;
   IF (IREMG5 >= 981) THEN IREMG5 = .;
   IF (DEPCIG2 >= 81) THEN DEPCIG2 = .;
   IF (DEPALC2 >= 81) THEN DEPALC2 = .;
   IF (DEPMRJ2 >= 81) THEN DEPMRJ2 = .;
   IF (DEPCOC2 >= 81) THEN DEPCOC2 = .;
   IF (ARGCIG2 >= 81) THEN ARGCIG2 = .;
   IF (ARGALC2 >= 81) THEN ARGALC2 = .;
   IF (ARGMRJ2 >= 81) THEN ARGMRJ2 = .;
   IF (ARGCOC2 >= 81) THEN ARGCOC2 = .;
   IF (ALNCIG2 >= 81) THEN ALNCIG2 = .;
   IF (ALNALC2 >= 81) THEN ALNALC2 = .;
   IF (ALNMRJ2 >= 81) THEN ALNMRJ2 = .;
   IF (ALNCOC2 >= 81) THEN ALNCOC2 = .;
   IF (ANXCIG2 >= 81) THEN ANXCIG2 = .;
   IF (ANXALC2 >= 81) THEN ANXALC2 = .;
   IF (ANXMRJ2 >= 81) THEN ANXMRJ2 = .;
   IF (ANXCOC2 >= 81) THEN ANXCOC2 = .;
   IF (HLTCIG2 >= 81) THEN HLTCIG2 = .;
   IF (HLTALC2 >= 81) THEN HLTALC2 = .;
   IF (HLTMRJ2 >= 81) THEN HLTMRJ2 = .;
   IF (HLTCOC2 >= 81) THEN HLTCOC2 = .;
   IF (NTKCIG2 >= 81) THEN NTKCIG2 = .;
   IF (NTKALC2 >= 81) THEN NTKALC2 = .;
   IF (NTKMRJ2 >= 81) THEN NTKMRJ2 = .;
   IF (NTKCOC2 >= 81) THEN NTKCOC2 = .;
   IF (UPSCIG2 >= 81) THEN UPSCIG2 = .;
   IF (UPSALC2 >= 81) THEN UPSALC2 = .;
   IF (UPSMRJ2 >= 81) THEN UPSMRJ2 = .;
   IF (UPSCOC2 >= 81) THEN UPSCOC2 = .;
   IF (LSWCIG2 >= 81) THEN LSWCIG2 = .;
   IF (LSWALC2 >= 81) THEN LSWALC2 = .;
   IF (LSWMRJ2 >= 81) THEN LSWMRJ2 = .;
   IF (LSWCOC2 >= 81) THEN LSWCOC2 = .;
   IF (SSPCIG2 >= 81) THEN SSPCIG2 = .;
   IF (SSPALC2 >= 81) THEN SSPALC2 = .;
   IF (SSPMRJ2 >= 81) THEN SSPMRJ2 = .;
   IF (SSPCOC2 >= 81) THEN SSPCOC2 = .;
   IF (CPECIG2 >= 81) THEN CPECIG2 = .;
   IF (CPEALC2 >= 81) THEN CPEALC2 = .;
   IF (CPEMRJ2 >= 81) THEN CPEMRJ2 = .;
   IF (CPECOC2 >= 81) THEN CPECOC2 = .;
   IF (EMCIG2 >= 81) THEN EMCIG2 = .;
   IF (EMALC2 >= 81) THEN EMALC2 = .;
   IF (EMMRJ2 >= 81) THEN EMMRJ2 = .;
   IF (EMCOC2 >= 81) THEN EMCOC2 = .;
   IF (PRB1CIG >= 81) THEN PRB1CIG = .;
   IF (PRB1ALC >= 81) THEN PRB1ALC = .;
   IF (PRB1MRJ >= 81) THEN PRB1MRJ = .;
   IF (PRB1COC >= 81) THEN PRB1COC = .;
   IF (PRB2CIG >= 81) THEN PRB2CIG = .;
   IF (PRB2ALC >= 81) THEN PRB2ALC = .;
   IF (PRB2MRJ >= 81) THEN PRB2MRJ = .;
   IF (PRB2COC >= 81) THEN PRB2COC = .;
   IF (PRB3CIG >= 81) THEN PRB3CIG = .;
   IF (PRB3ALC >= 81) THEN PRB3ALC = .;
   IF (PRB3MRJ >= 81) THEN PRB3MRJ = .;
   IF (PRB3COC >= 81) THEN PRB3COC = .;
   IF (CHANCMJ2 >= 81) THEN CHANCMJ2 = .;
   IF (CHANCOC2 >= 81) THEN CHANCOC2 = .;
   IF (CHANHAL2 >= 81) THEN CHANHAL2 = .;
   IF (CHANHER2 >= 81) THEN CHANHER2 = .;
   IF (CWEOCC2 >= 981) THEN CWEOCC2 = .;
   IF (ROCCUP2 >= 981) THEN ROCCUP2 = .;
   IF (CWEBUS2 >= 981) THEN CWEBUS2 = .;
   IF (BUSINES2 >= 981) THEN BUSINES2 = .;
*/


* SAS FORMAT STATEMENT;

/*
  FORMAT CIGTRY cigtry. CIG5PK cig5pk. CIGAGE cigage.
         CIGYRS cigyrs. PACKS packs. CIGREC cigrec.
         AVCIG avcig. CIGTIME cigtime. SNUFREC snufrec.
         OTHTOB othtob. ALCTRY alctry. ALCREC alcrec.
         ALCAGE alcage. ALCDAYS alcdays. NODR30A nodr30a.
         DR5DAY dr5day. MODR30A modr30a. MODR30DY modr30dy.
         ALCPAT alcpat. DRUNKYR drunkyr. ALCBEER alcbeer.
         ALCWINE alcwine. ALCLIQR alcliqr. ALCVARY alcvary.
         NOSEDAT nosedat. BUTISOL butisol. BUTICAPS buticaps.
         AMYTAL amytal. MEBARAL mebaral. PLACIDYL placidyl.
         DORIDEN doriden. NOLUDAR noludar. NEMBUTAL nembutal.
         SECONAL seconal. TUINAL tuinal. DALMANE dalmane.
         RESTORIL restoril. HALCION halcion. AMOBARB amobarb.
         PHENOBAR phenobar. METHAQ methaq. CHHYD chhyd.
         PENTOB pentob. SECOB secob. SEDNEWA sednewa.
         SEDNEWB sednewb. SEDNEWC sednewc. SEDNEWD sednewd.
         SEDNEWE sednewe. SEDNOSP sednosp. SEDDKNAM seddknam.
         SEDAGE sedage. SEDTOT sedtot. SEDREC sedrec.
         SEDYRFRQ sedyrfrq. TRNREAD trnread. NOTRANQ notranq.
         VALIUM valium. LIBRIUM librium. LIMBTROL limbtrol.
         MENRIUM menrium. SERAX serax. TRANXENE tranxene.
         ATIVAN ativan. CENTRAX centrax. XANAX xanax.
         PAXIPAM paxipam. BUSPAR buspar. MILTOWN miltown.
         EQUANIL equanil. DEPROL deprol. VISTAR vistar.
         ATARAX atarax. DURRAX durrax. DIAZEPAM diazepam.
         SKLY skly. MEPROB meprob. TRNEWA trnewa.
         TRNEWB trnewb. TRNEWC trnewc. TRNEWD trnewd.
         TRNEWE trnewe. TRNOSP trnosp. TRDKNAM trdknam.
         TRANAGE tranage. TRANTOT trantot. TRANREC tranrec.
         TRNYRFRQ trnyrfrq. STMREAD stmread. NOSTIMS nostims.
         DEXED dexed. DEXAMYL dexamyl. ESKAT eskat.
         BENZ benz. BIPHET biphet. DESOXYN desoxyn.
         TENUATE tenuate. TEPANIL tepanil. DIDREX didrex.
         PLEGINE plegine. PRELUDIN preludin. IONAMIN ionamin.
         FASTIN fastin. PONDIMIN pondimin. VORANIL voranil.
         SANOREX sanorex. MAZANOR mazanor. RITALIN ritalin.
         CYLERT cylert. DETAMP detamp. METHI methi.
         METHAMP methamp. OBLA obla. STIMNEWA stimnewa.
         STIMNEWB stimnewb. STIMNEWC stimnewc. STIMNEWD stimnewd.
         STIMNEWE stimnewe. STIMNOSP stimnosp. STMDKNAM stmdknam.
         STIMAGE stimage. STIMTOT stimtot. STIMREC stimrec.
         STMYRFRQ stmyrfrq. STNEEDLE stneedle. STNDLREC stndlrec.
         ANLREAD anlread. ANALNONE analnone. DARVON darvon.
         DOLENE dolene. SK65A sk65a. WYGESIC wygesic.
         LEVODRO levodro. PERCODAN percodan. DEMEROL demerol.
         DILAUD dilaud. TYLCOD tylcod. PHENCOD phencod.
         TALWIN talwin. TALWINNX talwinnx. TALACEN talacen.
         PROPOXY propoxy. CODEINE codeine. ANILERID anilerid.
         MORPHINE morphine. METHDON methdon. STADOL stadol.
         ANALNEWA analnewa. ANALNEWB analnewb. ANALNEWC analnewc.
         ANALNEWD analnewd. ANALNEWE analnewe. ANLNOSP anlnosp.
         ANLDKNAM anldknam. ANALAGE analage. ANALTOT analtot.
         ANALREC analrec. ANLYRFRQ anlyrfrq. MJOPP mjopp.
         MJAGE mjage. MJTOT mjtot. MJREC mjrec.
         MJDAY30A mjday30a. MJAV30A mjav30a. MJAV30B mjav30b.
         MJAMT30A mjamt30a. MJFRIEND mjfriend. MJDEALER mjdealer.
         MJOTHSHR mjothshr. MJGIVEN mjgiven. MJTRGOOD mjtrgood.
         MJTRSERV mjtrserv. MJSTOLE mjstole. MJTRICK mjtrick.
         MJGREW mjgrew. MJOBTNON mjobtnon. MJBUCK mjbuck.
         MJYRFREQ mjyrfreq. MJJOINT mjjoint. MJPIPE mjpipe.
         MJBAKE mjbake. MJCHEW mjchew. MJWAY mjway.
         MJLFDALY mjlfdaly. INHREAD inhread. GAS gas.
         LGAS lgas. SPPAINT sppaint. AEROS aeros.
         GLUE glue. SOLVENT solvent. AMYLNIT amylnit.
         ETHER ether. NITOXID nitoxid. CLEFLU cleflu.
         INHNEWA inhnewa. INHNEWB inhnewb. INHNEWC inhnewc.
         INHNEWD inhnewd. INHNEWE inhnewe. INHNOSP inhnosp.
         INHDKNAM inhdknam. INHAGE inhage. INHTOT inhtot.
         INHREC inhrec. GAS30A gas30a. LGAS30A lgas30a.
         SPPAN30A sppan30a. AEROS30A aeros30a. GLUE30A glue30a.
         SOLVN30A solvn30a. AMLNT30A amlnt30a. ETHER30A ether30a.
         NOX30A nox30a. CLFL30A clfl30a. INNEW30A innew30a.
         INNEW30B innew30b. INNEW30C innew30c. INNEW30D innew30d.
         INNEW30E innew30e. IN30NOSP in30nosp. INH30NO inh30no.
         INHDY30A inhdy30a. INHYRFRQ inhyrfrq. INHPO inhpo.
         INHQNC1 inhqnc1f. INHQNC2 inhqnc2f. INHQNC3 inhqnc3f.
         INHQNC4 inhqnc4f. INHQNC5 inhqnc5f. INHQNC6 inhqnc6f.
         INHQNC7 inhqnc7f. INHQNC8 inhqnc8f. INHQNC10 inhqnc0f.
         INHANSY inhansy. COCOPP cocopp. COCAGE cocage.
         COCTOT coctot. COCREC cocrec. COCUS30A cocus30a.
         COCAM30A cocam30a. CCFRIEND ccfriend. CCDEALER ccdealer.
         CCOTHSHR ccothshr. CCGIVEN ccgiven. CCTRGOOD cctrgood.
         CCTRSERV cctrserv. CCSTOLE ccstole. CCTRICK cctrick.
         CCOBTNON ccobtnon. COCBUCK cocbuck. COCYRFRQ cocyrfrq.
         COCSNIFF cocsniff. COCSWAL cocswal. COCIV cociv.
         FREEBASE freebase. COCWAY cocway. CONDLREC condlrec.
         CCLFDALY cclfdaly. CRAKREC crakrec. CRKAM30A crkam30a.
         CKFRIEND ckfriend. CKDEALER ckdealer. CKOTHSHR ckothshr.
         CKGIVEN ckgiven. CKTRGOOD cktrgood. CKTRSERV cktrserv.
         CKSTOLE ckstole. CKTRICK cktrick. CKOBTNON ckobtnon.
         CRAKBUCK crakbuck. CKLFDALY cklfdaly. HALREAD halread.
         LSD lsd. PEYOTE peyote. MESC mesc.
         PSILCY psilcy. PCP pcp. ECSTASY ecstasy.
         HALNEWA halnewa. HALNEWB halnewb. HALNEWC halnewc.
         HALNEWD halnewd. HALNEWE halnewe. HALNOSP halnosp.
         HALDKNAM haldknam. HALLOPP hallopp. HALLAGE hallage.
         HALLTOT halltot. HALLREC hallrec. HAL30USE hal30use.
         HALYRFRQ halyrfrq. PCPREC pcprec. HERREAD herread.
         HEROPP heropp. HERAGE herage. HERTOT hertot.
         HERREC herrec. HER30USE her30use. HERNEEDL herneedl.
         HRNDLREC hrndlrec. HERSMOKE hersmoke. HRSMKREC hrsmkrec.
         HERSNIFF hersniff. HRSNFREC hrsnfrec. DRGREAD drgread.
         CDCIG cdcig. CDALC cdalc. CDSED cdsed.
         CDTRAN cdtran. CDSTM cdstm. CDANAL cdanal.
         CDMJ cdmj. CDINH cdinh. CDCOC cdcoc.
         CDHALL cdhall. CDHER cdher. CDOTHOP cdothop.
         CDNONE cdnone. UCDCIG ucdcig. UCDALC ucdalc.
         UCDSED ucdsed. UCDTRAN ucdtran. UCDSTM ucdstm.
         UCDANAL ucdanal. UCDMJ ucdmj. UCDINH ucdinh.
         UCDCOC ucdcoc. UCDHALL ucdhall. UCDHER ucdher.
         UCDOTHOP ucdothop. UCDNONE ucdnone. EFFCIG effcig.
         EFFALC effalc. EFFSED effsed. EFFTRAN efftran.
         EFFSTM effstm. EFFANAL effanal. EFFMJ effmj.
         EFFINH effinh. EFFCOC effcoc. EFFHALL effhall.
         EFFHER effher. EFFOTHOP effothop. EFFNONE effnone.
         UDAYCIG udaycig. UDAYALC udayalc. UDAYSED udaysed.
         UDAYTRAN udaytran. UDAYSTM udaystm. UDAYANAL udayanal.
         UDAYMJ udaymj. UDAYINH udayinh. UDAYCOC udaycoc.
         UDAYHALL udayhall. UDAYHER udayher. UDAYOTH udayoth.
         UDAYNONE udaynone. DEPCIG depcig. DEPALC depalc.
         DEPSED depsed. DEPTRAN deptran. DEPSTM depstm.
         DEPANAL depanal. DEPMJ depmj. DEPINH depinh.
         DEPCOC depcoc. DEPHALL dephall. DEPHER depher.
         DEPOTHOP depothop. DEPNONE depnone. WSCIG wscig.
         WSALC wsalc. WSSED wssed. WSTRAN wstran.
         WSSTM wsstm. WSANAL wsanal. WSMJ wsmj.
         WSINH wsinh. WSCOC wscoc. WSHALL wshall.
         WSHER wsher. WSOTHOP wsothop. WSNONE wsnone.
         NDLREAD ndlread. GNNDLLIF gnndllif. GNNDLREC gnndlrec.
         GNNDLSED gnndlsed. GNNDLTRA gnndltra. GNNDLSTM gnndlstm.
         GNNDLANL gnndlanl. GNNDLINH gnndlinh. GNNDLCOC gnndlcoc.
         GNNDLHAL gnndlhal. GNNDLHER gnndlher. GNNDLOPT gnndlopt.
         GNNDLSTR gnndlstr. GNNDLNON gnndlnon. GNNDLSH1 gnndlshf.
         GNNDLSH2 gnndls0f. SPTREAD sptread. DRUGTEST drugtest.
         TESTPOS testpos. ICELIFE icelife. ICEREC icerec.
         STEROPP steropp. STERAGE sterage. STERTOT stertot.
         STERREC sterrec. SPNEWA spnewa. SPNEWB spnewb.
         SPNEWC spnewc. SPNEWD spnewd. SPNEWE spnewe.
         BOOKED booked. NOBOOKYR nobookyr. BKLARCNY bklarcny.
         BKBURGL bkburgl. BKAGASLT bkagaslt. BKSMASLT bksmaslt.
         BKMVTHFT bkmvthft. BKROB bkrob. BKRAPE bkrape.
         BKMURDER bkmurder. BKARSON bkarson. BKDRVINF bkdrvinf.
         BKDRUNK bkdrunk. BKDRUG bkdrug. BKPROS bkpros.
         BKVANDAL bkvandal. BKOTHOFF bkothoff. NOTBKED notbked.
         PROBATON probaton. PAROLE parole. STRSTEAL strsteal.
         OTHSTEAL othsteal. DAMAGE damage. CARSTEAL carsteal.
         FORCEMON forcemon. BREAKIN breakin. PHYFIGHT phyfight.
         HURTBAD hurtbad. GUNMONEY gunmoney. DRUNKDRV drunkdrv.
         SOLDDRUG solddrug. OTHDOING othdoing. OTHDOSP1 othdospf.
         OTHDOSP2 othdos0f. DEXREAD dexread. NOBOOZYR noboozyr.
         ALCAGGR alcaggr. ALCARGUM alcargum. ALCABSNT alcabsnt.
         ALCHIGH alchigh. ALCJOB alcjob. ALCMATCD alcmatcd.
         ALCRELCD alcrelcd. ALCFRDCD alcfrdcd. ALCTOSS alctoss.
         ALCHOLIC alcholic. ALCDRUNK alcdrunk. ALCINTOX alcintox.
         ALCREM alcrem. ALCQUICK alcquick. ALCMORN alcmorn.
         ALCSHOOK alcshook. ALCALONE alcalone. ALCBRKPM alcbrkpm.
         ALCMJ alcmj. ALCCOC alccoc. ALCOPT alcopt.
         ALCHAL alchal. ALCINH alcinh. ALCANAL alcanal.
         ALCTRAN alctran. ALCSTM alcstm. ALCSED alcsed.
         AS13NONE as13none. DRDEPRSS drdeprss. DEPDRG1A depdrg1a.
         DEPDRG2A depdrg2a. DEPDRG3A depdrg3a. DEPDRG4A depdrg4a.
         DEPDRG5A depdrg5a. DRARGUM drargum. ARGDRG1A argdrg1a.
         ARGDRG2A argdrg2a. ARGDRG3A argdrg3a. ARGDRG4A argdrg4a.
         ARGDRG5A argdrg5a. DRALONE dralone. ALNDRG1A alndrg1a.
         ALNDRG2A alndrg2a. ALNDRG3A alndrg3a. ALNDRG4A alndrg4a.
         ALNDRG5A alndrg5a. DRANX dranx. ANXDRG1A anxdrg1a.
         ANXDRG2A anxdrg2a. ANXDRG3A anxdrg3a. ANXDRG4A anxdrg4a.
         ANXDRG5A anxdrg5a. DRHEALTH drhealth. HLTDRG1A hltdrg1a.
         HLTDRG2A hltdrg2a. HLTDRG3A hltdrg3a. HLTDRG4A hltdrg4a.
         HLTDRG5A hltdrg5a. DRNTHINK drnthink. NTKDRG1A ntkdrg1a.
         NTKDRG2A ntkdrg2a. NTKDRG3A ntkdrg3a. NTKDRG4A ntkdrg4a.
         NTKDRG5A ntkdrg5a. DRUPSET drupset. UPSDRG1A upsdrg1a.
         UPSDRG2A upsdrg2a. UPSDRG3A upsdrg3a. UPSDRG4A upsdrg4a.
         UPSDRG5A upsdrg5a. DRLSWORK drlswork. LSWDRG1A lswdrg1a.
         LSWDRG2A lswdrg2a. LSWDRG3A lswdrg3a. LSWDRG4A lswdrg4a.
         LSWDRG5A lswdrg5a. DRSUSPIC drsuspic. SSPDRG1A sspdrg1a.
         SSPDRG2A sspdrg2a. SSPDRG3A sspdrg3a. SSPDRG4A sspdrg4a.
         SSPDRG5A sspdrg5a. DRCOPE drcope. CPEDRG1A cpedrg1a.
         CPEDRG2A cpedrg2a. CPEDRG3A cpedrg3a. CPEDRG4A cpedrg4a.
         CPEDRG5A cpedrg5a. DREMGMED dremgmed. EMDRG1A emdrg1a.
         EMDRG2A emdrg2a. EMDRG3A emdrg3a. EMDRG4A emdrg4a.
         EMDRG5A emdrg5a. DRTRMT drtrmt. TMTDRG1A tmtdrg1a.
         TMTDRG2A tmtdrg2a. TMTDRG3A tmtdrg3a. TMTDRG4A tmtdrg4a.
         TMTDRG5A tmtdrg5a. DRDRVUN drdrvun. DRVDRG1A drvdrg1a.
         DRVDRG2A drvdrg2a. DRVDRG3A drvdrg3a. DRVDRG4A drvdrg4a.
         DRVDRG5A drvdrg5a. TMTREAD tmtread. EMPDRUG empdrug.
         CIGHELP cighelp. DRNKHELP drnkhelp. TRMTHELP trmthelp.
         TRMTEMRG trmtemrg. TRMTHOSP trmthosp. TRMTDOC trmtdoc.
         TRMTTRMT trmttrmt. TRMTMHC trmtmhc. TRMTSHG trmtshg.
         TRMTSOP trmtsop. TRMTSP trmtsp. TRMTREC trmtrec.
         NRTXLIFE nrtxlife. NOTRMT notrmt. TXEMRG txemrg.
         TXHOSP txhosp. TXDOC txdoc. TXTRMT txtrmt.
         TXMHC txmhc. TXSHG txshg. TXSOP txsop.
         TXSP txsp. TRMTLIFE trmtlife. TRMTRESP trmtresp.
         TRMTFEAR trmtfear. TRMTCOST trmtcost. TRMTEVNT trmtevnt.
         TRMTPR trmtpr. TRMTHLTH trmthlth. TRMTJOB trmtjob.
         TRMTJAIL trmtjail. TRMTSERV trmtserv. TRMTBQD trmtbqd.
         TRMTDNA trmtdna. TRMTSOR trmtsor. TRMTRSP trmtrsp.
         TRMTDRGA trmtdrga. TRMTDRGB trmtdrgb. TRMTDRGC trmtdrgc.
         TRMTDRGD trmtdrgd. TRMTDRGE trmtdrge. TRMTOUTC trmtoutc.
         TMTPHI tmtphi. TMTPSAVE tmtpsave. TMTPFMLY tmtpfmly.
         TMTPEMPR tmtpempr. TMTPMEDI tmtpmedi. TMTPFREE tmtpfree.
         TMTPOTH tmtpoth. TMTPASP tmtpasp. RSKPKCIG rskpkcig.
         RSKTRYMJ rsktrymj. RSKMJOCC rskmjocc. RSKMJREG rskmjreg.
         RKTRYPCP rktrypcp. RKPCPREG rkpcpreg. RKTRYHER rktryher.
         RKHERREG rkherreg. RKTRYCOC rktrycoc. RKCOCOCC rkcococc.
         RKCOCREG rkcocreg. RKCRKOCC rkcrkocc. RKANSOCC rkansocc.
         RKANSREG rkansreg. RK2DRINK rk2drink. RK5DRINK rk5drink.
         RSKBINGE rskbinge. RSKDIFMJ rskdifmj. RKDIFLSD rkdiflsd.
         RKDIFPCP rkdifpcp. RKDIFCOC rkdifcoc. RKDIFHER rkdifher.
         RSKSELL rsksell. RKNEIDRN rkneidrn. RKNEISEL rkneisel.
         HIGHBP highbp. BPMED bpmed. WALKPAIN walkpain.
         TIMEPAIN timepain. UPSHOR upshor. ASTHMA asthma.
         TRPSYCH trpsych. HEART heart. FLU flu.
         ALLERG allerg. HOSPYR hospyr. SOREYR soreyr.
         RUNNYYR runnyyr. COUGHYR coughyr. PHLEGMYR phlegmyr.
         HEALTHYR healthyr. FLTEAT flteat. FLTMIND fltmind.
         FLTDEPRS fltdeprs. FLTEFFRT flteffrt. FLTSLEEP fltsleep.
         FLTSAD fltsad. FLTGOING fltgoing. MARITAL marital.
         NOMARR nomarr. WORKSTAT workstat. PAYMO paymo.
         PAYYR payyr. NO5JOB no5job. WORKDAYS workdays.
         WORKBLAH workblah. CWE cwe. CWESC1 cwesc1ff.
         CWESC2 cwesc2ff. FULLPART fullpart. EDUC educ.
         GRADHS gradhs. DIPLOMA diploma. ENROLLD enrolld.
         SCHPLANS schplans. STUDENT student. SCHDAYS schdays.
         SKIPPED skipped. MILES miles. ACCID accid.
         TOTPEOP totpeop. MOTHER mother. FATHER father.
         STEPMOM stepmom. STEPDAD stepdad. SPOUSE spouse.
         INLAW inlaw. OWNCHILD ownchild. STEPCHLD stepchld.
         BROSIS brosis. OTHREL othrel. FRIENDS friends.
         OTHERNON othernon. MOVDAWAY movdaway. DORM dorm.
         MILBASE milbase. HOSP hosp. OTHGPH othgph.
         OTHGPHSP othgphsp. SERVICE service. MILSTAT milstat.
         TELNO telno. MOVES moves. NOFAMRES nofamres.
         PROXABLE proxable. PROXYREL proxyrel. PROXHOME proxhome.
         PROXJOIN proxjoin. MEDICARE medicare. MEDICAID medicaid.
         CHAMPUS champus. PRVHLTIN prvhltin. OWNHLTIN ownhltin.
         GRPHLTIN grphltin. HLTINALC hltinalc. HLTINDRG hltindrg.
         HLTINMNT hltinmnt. WHOANSHI whoanshi. JOB job.
         HOURS hours. WORK work. WAG1 wag1ffff.
         AWAG1 awag1fff. WEEKS weeks. SOC1 soc1ffff.
         ASOC1 asoc1fff. SSI1 ssi1ffff. ASSI1 assi1fff.
         PUB1 pub1ffff. AFDC1 afdc1fff. WEL1 wel1ffff.
         AWEL1 awel1fff. INT1 int1ffff. AINT1 aint1fff.
         CHD1 chd1ffff. ACHD1 achd1fff. OTH1 oth1ffff.
         AOTH1 aoth1fff. FAMLYRES famlyres. WAG2 wag2ffff.
         AWAG2 awag2fff. SOC2 soc2ffff. ASOC2 asoc2fff.
         SSI2 ssi2ffff. ASSI2 assi2fff. PUB2 pub2ffff.
         AFDC2 afdc2fff. WEL2 wel2ffff. AWEL2 awel2fff.
         INT2 int2ffff. AINT2 aint2fff. CHD2 chd2ffff.
         ACHD2 achd2fff. OTH2 oth2ffff. AOTH2 aoth2fff.
         WHOANSIN whoansin. FSTAMP fstamp. PEOPFD peopfd.
         FOOD food. AFOOD afood. BAP bap.
         EAP eap. LANGVER langver. UNDINT undint.
         COOPINT coopint. PRIVACY privacy. PPRES ppres.
         SPRES spres. PARPRES parpres. OARPRES oarpres.
         OAPRES oapres. CPRES cpres. OPRESNSP opresnsp.
         OPRESSPA opresspa. OPRESSPB opresspb. WHOMARKD whomarkd.
         QUARTER quarter. FAMSKIP famskip. PDEN pden.
         GQTYPE gqtype. PDEN2 pden2fff. DC dc.
         CHICAGO chicago. DENVER denver. LA la.
         MIAMI miami. NEWYORK newyork. REGION region.
         DIVISION division. CENCTY cencty. URBARE urbare.
         METRO metro. CENTRALC centralc. IIAGE iiage.
         IRSEX irsex. IISEX iisex. IRRACE irrace.
         IIRACE iirace. IRHOIND irhoind. IIHOIND iihoind.
         IRHOGRP irhogrp. IIHOGRP iihogrp. IRHOGRP2 irhogrpf.
         IIHOGRP2 iihogrpf. IRMARIT irmarit. IIMARIT iimarit.
         IREDUC ireduc. IIEDUC iieduc. IRHSGRAD irhsgrad.
         IIHSGRAD iihsgrad. IRWORKST irworkst. IIWORKST iiworkst.
         IRPINSUR irpinsur. IIPINSUR iipinsur. IRINSUR irinsur.
         IIINSUR iiinsur. IRWAG1 irwag1ff. IIWAG1 iiwag1ff.
         IRAWAG1 irawag1f. IIAWAG1 iiawag1f. IRSOC1 irsoc1ff.
         IISOC1 iisoc1ff. IRASOC1 irasoc1f. IIASOC1 iiasoc1f.
         IRSSI1 irssi1ff. IISSI1 iissi1ff. IRASSI1 irassi1f.
         IIASSI1 iiassi1f. IRWEL1 irwel1ff. IIWEL1 iiwel1ff.
         IRAWEL1 irawel1f. IIAWEL1 iiawel1f. IRINT1 irint1ff.
         IIINT1 iiint1ff. IRAINT1 iraint1f. IIAINT1 iiaint1f.
         IRCHD1 irchd1ff. IICHD1 iichd1ff. IRACHD1 irachd1f.
         IIACHD1 iiachd1f. IROTH1 iroth1ff. IIOTH1 iioth1ff.
         IRAOTH1 iraoth1f. IIAOTH1 iiaoth1f. IRWAG2 irwag2ff.
         IIWAG2 iiwag2ff. IRAWAG2 irawag2f. IIAWAG2 iiawag2f.
         IRSOC2 irsoc2ff. IISOC2 iisoc2ff. IRASOC2 irasoc2f.
         IIASOC2 iiasoc2f. IRSSI2 irssi2ff. IISSI2 iissi2ff.
         IRASSI2 irassi2f. IIASSI2 iiassi2f. IRWEL2 irwel2ff.
         IIWEL2 iiwel2ff. IRAWEL2 irawel2f. IIAWEL2 iiawel2f.
         IRINT2 irint2ff. IIINT2 iiint2ff. IRAINT2 iraint2f.
         IIAINT2 iiaint2f. IRCHD2 irchd2ff. IICHD2 iichd2ff.
         IRACHD2 irachd2f. IIACHD2 iiachd2f. IROTH2 iroth2ff.
         IIOTH2 iioth2ff. IRAOTH2 iraoth2f. IIAOTH2 iiaoth2f.
         IRFOOD irfood. IIFOOD iifood. IRAFOOD irafood.
         IIAFOOD iiafood. IRALCRC iralcrc. IIALCRC iialcrc.
         IRMJRC irmjrc. IIMJRC iimjrc. IRCOCRC ircocrc.
         IICOCRC iicocrc. IRSEDRC irsedrc. IISEDRC iisedrc.
         IRTRNRC irtrnrc. IITRNRC iitrnrc. IRSTMRC irstmrc.
         IISTMRC iistmrc. IRANLRC iranlrc. IIANLRC iianlrc.
         IRCIGRC ircigrc. IICIGRC iicigrc. IROTBRC irotbrc.
         IIOTBRC iiotbrc. IRINHRC irinhrc. IIINHRC iiinhrc.
         IRCRKRC ircrkrc. IICRKRC iicrkrc. IRHALRC irhalrc.
         IIHALRC iihalrc. IRHERRC irherrc. IIHERRC iiherrc.
         IRPCPRC irpcprc. IIPCPRC iipcprc. IRICERC iricerc.
         IIICERC iiicerc. IRSTRRC irstrrc. IISTRRC iistrrc.
         IRALCFQ iralcfq. IIALCFQ iialcfq. IRMJFQ irmjfq.
         IIMJFQ iimjfq. IRCOCFQ ircocfq. IICOCFQ iicocfq.
         IRSEDFQ irsedfq. IISEDFQ iisedfq. IRTRNFQ irtrnfq.
         IITRNFQ iitrnfq. IRSTMFQ irstmfq. IISTMFQ iistmfq.
         IRANLFQ iranlfq. IIANLFQ iianlfq. IROTBFQ irotbfq.
         IIOTBFQ iiotbfq. IRINHFQ irinhfq. IIINHFQ iiinhfq.
         IRHALFQ irhalfq. IIHALFQ iihalfq. CATAGE catage.
         CATAG2 catag2ff. CATAG3 catag3ff. RACE race.
         HISPRACE hisprace. EDUCCAT2 educcatf. EMPSTAT2 empstatf.
         IIINDINC iiindinc. INDCAT indcat. PERINC perinc.
         PERINC2 perinc2f. PERINC3 perinc3f. TOTINC totinc.
         IITOTINC iitotinc. TOTCAT totcat. FAMINC faminc.
         FAMINC2 faminc2f. FAMINC3 faminc3f. WELFARE welfare.
         HALFLAG halflag. HALYR halyr. HALMON halmon.
         PCPFLAG pcpflag. PCPYR pcpyr. PCPMON pcpmon.
         STMFLAG stmflag. STMYR stmyr. STMMON stmmon.
         SEDFLAG sedflag. SEDYR sedyr. SEDMON sedmon.
         TRQFLAG trqflag. TRQYR trqyr. TRQMON trqmon.
         ANLFLAG anlflag. ANLYR anlyr. ANLMON anlmon.
         ALCFLAG alcflag. ALCYR alcyr. ALCMON alcmon.
         CIGFLAG cigflag. CIGYR cigyr. CIGMON cigmon.
         SMKFLAG smkflag. SMKYR smkyr. SMKMON smkmon.
         HERFLAG herflag. HERYR heryr. HERMON hermon.
         STRFLAG strflag. STRYR stryr. STRMON strmon.
         MRJFLAG mrjflag. MRJYR mrjyr. MRJMON mrjmon.
         COCFLAG cocflag. COCYR cocyr. COCMON cocmon.
         CRKFLAG crkflag. CRKYR crkyr. CRKMON crkmon.
         INHFLAG inhflag. INHYR inhyr. INHMON inhmon.
         ICEFLAG iceflag. ICEYR iceyr. ICEMON icemon.
         NEEDLREC needlrec. NDL90REC ndl90rec. NEDFLAG3 nedflagf.
         NEDYR3 nedyr3ff. HALYRF halyrf. HALMONF halmonf.
         HALWKF halwkf. HALOCCF haloccf. HALDLYF haldlyf.
         STMYRF stmyrf. STMMONF stmmonf. STMWKF stmwkf.
         STMOCCF stmoccf. STMDLYF stmdlyf. SEDYRF sedyrf.
         SEDMONF sedmonf. SEDWKF sedwkf. SEDOCCF sedoccf.
         SEDDLYF seddlyf. TRQYRF trqyrf. TRQMONF trqmonf.
         TRQWKF trqwkf. TRQOCCF trqoccf. TRQDLYF trqdlyf.
         ANLYRF anlyrf. ANLMONF anlmonf. ANLWKF anlwkf.
         ANLOCCF anloccf. ANLDLYF anldlyf. ALCYRF alcyrf.
         ALCMONF alcmonf. ALCWKF alcwkf. ALCOCCF alcoccf.
         ALCDLYF alcdlyf. SMKYRF smkyrf. SMKMONF smkmonf.
         SMKWKF smkwkf. SMKOCCF smkoccf. SMKDLYF smkdlyf.
         MRJYRF mrjyrf. MRJMONF mrjmonf. MRJWKF mrjwkf.
         MRJOCCF mrjoccf. MRJDLYF mrjdlyf. COCYRF cocyrf.
         COCMONF cocmonf. COCWKF cocwkf. COCOCCF cococcf.
         COCDLYF cocdlyf. INHYRF inhyrf. INHMONF inhmonf.
         INHWKF inhwkf. INHOCCF inhoccf. INHDLYF inhdlyf.
         PSYFLAG2 psyflagf. PSYYR2 psyyr2ff. PSYMON2 psymon2f.
         SUMFLAG sumflag. SUMYR sumyr. SUMMON summon.
         MJOFLAG mjoflag. MJOYR2 mjoyr2ff. MJOMON2 mjomon2f.
         IEMFLAG iemflag. IEMYR iemyr. IEMMON iemmon.
         HSPHCONC hsphconc. HSPPCONC hsppconc. OWNOCONC ownoconc.
         UCLASS9 uclass9f. QC06 qc06ffff. QC09 qc09ffff.
         AL02 al02ffff. SE04 se04ffff. TR04 tr04ffff.
         ST04 st04ffff. ST07 st07ffff. AN04 an04ffff.
         MJ04 mj04ffff. IN04 in04ffff. CC04 cc04ffff.
         CC11 cc11ffff. CK01 ck01ffff. LS05 ls05ffff.
         LS08 ls08ffff. HE04 he04ffff. HE07 he07ffff.
         ND02 nd02ffff. SP04 sp04ffff. SP08 sp08ffff.
         MJTOT2 mjtot2ff. COCTOT2 coctot2f. MJTOT3 mjtot3ff.
         COCTOT3 coctot3f. MJDY30A2 mjdy30af. ALCDAYS2 alcdaysf.
         MRJMON2 mrjmon2f. ALCMON2 alcmon2f. CIGMON2 cigmon2f.
         LSD2 lsd2ffff. PEYOTE2 peyote2f. MESC2 mesc2fff.
         PSILCY2 psilcy2f. ECSTASY2 ecstasyf. GAS2 gas2ffff.
         LGAS2 lgas2fff. SPPAINT2 sppaintf. AEROS2 aeros2ff.
         GLUE2 glue2fff. SOLVENT2 solventf. AMYLNIT2 amylnitf.
         ETHER2 ether2ff. NITOXID2 nitoxidf. CLEFLU2 cleflu2f.
         COCSNIF2 cocsni0f. FREEBAS2 freebasf. COCSWAL2 cocswalf.
         COCIV2 cociv2ff. MJDY30A3 mjdy300f. ALCDAYS3 alcday0f.
         DRINKER2 drinkerf. HVYDRK2 hvydrk2f. AVCIG2 avcig2ff.
         RACESEX racesex. NOTMARJ notmarj. COCWAY2 cocway2f.
         RACESEX2 racesexf. IRCDCIG ircdcig. IRCDALC ircdalc.
         IRCDMJ ircdmj. IRCDCOC ircdcoc. IREFCIG irefcig.
         IREFALC irefalc. IREFMJ irefmj. IREFCOC irefcoc.
         IRUDCIG irudcig. IRUDALC irudalc. IRUDMJ irudmj.
         IRUDCOC irudcoc. IRDPCIG irdpcig. IRDPALC irdpalc.
         IRDPMJ irdpmj. IRDPCOC irdpcoc. IRWSCIG irwscig.
         IRWSALC irwsalc. IRWSMJ irwsmj. IRWSCOC irwscoc.
         AVCIG3 avcig3ff. ALCPROBS alcprobs. MJPROBS mjprobs.
         COCPROBS cocprobs. CIGPROBS cigprobs. IRALCAGG iralcagg.
         IRALCARG iralcarg. IRALCABS iralcabs. IRALCHIG iralchig.
         IRALCJOB iralcjob. IRALCMAT iralcmat. IRALCREL iralcrel.
         IRALCFRD iralcfrd. IRALCTOS iralctos. IRALCHOL iralchol.
         IRALCDRU iralcdru. IRALCINT iralcint. IRALCREM iralcrem.
         IRALCQUI iralcqui. IRALCMOR iralcmor. IRALCSHO iralcsho.
         IRALCALO iralcalo. IRALCBRK iralcbrk. IRNOBOOZ irnobooz.
         ANYALC anyalc. THREALC threalc. DRUNKYR2 drunkyrf.
         IRDEP irdep. IRARG irarg. IRALN iraln.
         IRANX iranx. IRHLT irhlt. IRNTK irntk.
         IRUPS irups. IRLSW irlsw. IRSSP irssp.
         IRCPE ircpe. IREMG iremg. IRDEP1 irdep1ff.
         IRDEP2 irdep2ff. IRDEP3 irdep3ff. IRDEP4 irdep4ff.
         IRDEP5 irdep5ff. IRARG1 irarg1ff. IRARG2 irarg2ff.
         IRARG3 irarg3ff. IRARG4 irarg4ff. IRARG5 irarg5ff.
         IRALN1 iraln1ff. IRALN2 iraln2ff. IRALN3 iraln3ff.
         IRALN4 iraln4ff. IRALN5 iraln5ff. IRANX1 iranx1ff.
         IRANX2 iranx2ff. IRANX3 iranx3ff. IRANX4 iranx4ff.
         IRANX5 iranx5ff. IRHLT1 irhlt1ff. IRHLT2 irhlt2ff.
         IRHLT3 irhlt3ff. IRHLT4 irhlt4ff. IRHLT5 irhlt5ff.
         IRNTK1 irntk1ff. IRNTK2 irntk2ff. IRNTK3 irntk3ff.
         IRNTK4 irntk4ff. IRNTK5 irntk5ff. IRUPS1 irups1ff.
         IRUPS2 irups2ff. IRUPS3 irups3ff. IRUPS4 irups4ff.
         IRUPS5 irups5ff. IRLSW1 irlsw1ff. IRLSW2 irlsw2ff.
         IRLSW3 irlsw3ff. IRLSW4 irlsw4ff. IRLSW5 irlsw5ff.
         IRSSP1 irssp1ff. IRSSP2 irssp2ff. IRSSP3 irssp3ff.
         IRSSP4 irssp4ff. IRSSP5 irssp5ff. IRCPE1 ircpe1ff.
         IRCPE2 ircpe2ff. IRCPE3 ircpe3ff. IRCPE4 ircpe4ff.
         IRCPE5 ircpe5ff. IREMG1 iremg1ff. IREMG2 iremg2ff.
         IREMG3 iremg3ff. IREMG4 iremg4ff. IREMG5 iremg5ff.
         IRAS13 iras13ff. DEPCIG2 depcig2f. DEPALC2 depalc2f.
         DEPMRJ2 depmrj2f. DEPCOC2 depcoc2f. ARGCIG2 argcig2f.
         ARGALC2 argalc2f. ARGMRJ2 argmrj2f. ARGCOC2 argcoc2f.
         ALNCIG2 alncig2f. ALNALC2 alnalc2f. ALNMRJ2 alnmrj2f.
         ALNCOC2 alncoc2f. ANXCIG2 anxcig2f. ANXALC2 anxalc2f.
         ANXMRJ2 anxmrj2f. ANXCOC2 anxcoc2f. HLTCIG2 hltcig2f.
         HLTALC2 hltalc2f. HLTMRJ2 hltmrj2f. HLTCOC2 hltcoc2f.
         NTKCIG2 ntkcig2f. NTKALC2 ntkalc2f. NTKMRJ2 ntkmrj2f.
         NTKCOC2 ntkcoc2f. UPSCIG2 upscig2f. UPSALC2 upsalc2f.
         UPSMRJ2 upsmrj2f. UPSCOC2 upscoc2f. LSWCIG2 lswcig2f.
         LSWALC2 lswalc2f. LSWMRJ2 lswmrj2f. LSWCOC2 lswcoc2f.
         SSPCIG2 sspcig2f. SSPALC2 sspalc2f. SSPMRJ2 sspmrj2f.
         SSPCOC2 sspcoc2f. CPECIG2 cpecig2f. CPEALC2 cpealc2f.
         CPEMRJ2 cpemrj2f. CPECOC2 cpecoc2f. EMCIG2 emcig2ff.
         EMALC2 emalc2ff. EMMRJ2 emmrj2ff. EMCOC2 emcoc2ff.
         PRB1CIG prb1cig. PRB1ALC prb1alc. PRB1MRJ prb1mrj.
         PRB1COC prb1coc. PRB2CIG prb2cig. PRB2ALC prb2alc.
         PRB2MRJ prb2mrj. PRB2COC prb2coc. PRB3CIG prb3cig.
         PRB3ALC prb3alc. PRB3MRJ prb3mrj. PRB3COC prb3coc.
         ANYPROB anyprob. TWOPROB twoprob. THREPROB threprob.
         ALCONLYL alconlyl. ALCONLYY alconlyy. ALCONLYM alconlym.
         ILLONLYL illonlyl. ILLONLYY illonlyy. ILLONLYM illonlym.
         MRJONLYL mrjonlyl. MRJONLYY mrjonlyy. MRJONLYM mrjonlym.
         PSYONLYL psyonlyl. PSYONLYY psyonlyy. PSYONLYM psyonlym.
         OTHONLYL othonlyl. OTHONLYY othonlyy. OTHONLYM othonlym.
         ALCILLL alcilll. ALCILLY alcilly. ALCILLM alcillm.
         ALCMRJL alcmrjl. ALCMRJY alcmrjy. ALCMRJM alcmrjm.
         ALCPSYL alcpsyl. ALCPSYY alcpsyy. ALCPSYM alcpsym.
         ALCOTHL alcothl. ALCOTHY alcothy. ALCOTHM alcothm.
         SUB1LIF sub1lif. SUB2LIF sub2lif. SUB3LIF sub3lif.
         SUB1YR sub1yr. SUB2YR sub2yr. SUB3YR sub3yr.
         SUB1MON sub1mon. SUB2MON sub2mon. SUB3MON sub3mon.
         CHANCMJ2 chancmjf. CHANCOC2 chancocf. CHANHAL2 chanhalf.
         CHANHER2 chanherf. TRMTHLP2 trmthlpf. DRNKHLP2 drnkhlpf.
         DRALHELP dralhelp. RURORURB rurorurb. PBLACKHH pblackhh.
         PBLACKP pblackp. PPOVERTY ppoverty. POWNED powned.
         PRENTED prented. OWNEDAVE ownedave. RENTAVE rentave.
         IRKIDS irkids. CWEOCC2 cweocc2f. ROCCUP2 roccup2f.
         CWEBUS2 cwebus2f. BUSINES2 businesf.  ;
*/

RUN ;
